package androidx.core.graphics.drawable;

import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.Shader;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Build;
import android.os.Parcelable;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.lang.reflect.InvocationTargetException;
import p085c.p086a.p087a.p088a.outline;

public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: j */
    public static final PorterDuff.Mode f558j = PorterDuff.Mode.SRC_IN;

    /* renamed from: a */
    public int f559a = -1;

    /* renamed from: b */
    public Object f560b;

    /* renamed from: c */
    public byte[] f561c = null;

    /* renamed from: d */
    public Parcelable f562d = null;

    /* renamed from: e */
    public int f563e = 0;

    /* renamed from: f */
    public int f564f = 0;

    /* renamed from: g */
    public ColorStateList f565g = null;

    /* renamed from: h */
    public PorterDuff.Mode f566h = f558j;

    /* renamed from: i */
    public String f567i = null;

    /* renamed from: a */
    public int mo642a() {
        int i;
        if (this.f559a == -1 && (i = Build.VERSION.SDK_INT) >= 23) {
            Icon icon = (Icon) this.f560b;
            if (i >= 28) {
                return icon.getResId();
            }
            try {
                return ((Integer) icon.getClass().getMethod("getResId", new Class[0]).invoke(icon, new Object[0])).intValue();
            } catch (IllegalAccessException e) {
                Log.e("IconCompat", "Unable to get icon resource", e);
                return 0;
            } catch (InvocationTargetException e2) {
                Log.e("IconCompat", "Unable to get icon resource", e2);
                return 0;
            } catch (NoSuchMethodException e3) {
                Log.e("IconCompat", "Unable to get icon resource", e3);
                return 0;
            }
        } else if (this.f559a == 2) {
            return this.f563e;
        } else {
            throw new IllegalStateException("called getResId() on " + this);
        }
    }

    /* renamed from: b */
    public String mo643b() {
        int i;
        if (this.f559a == -1 && (i = Build.VERSION.SDK_INT) >= 23) {
            Icon icon = (Icon) this.f560b;
            if (i >= 28) {
                return icon.getResPackage();
            }
            try {
                return (String) icon.getClass().getMethod("getResPackage", new Class[0]).invoke(icon, new Object[0]);
            } catch (IllegalAccessException e) {
                Log.e("IconCompat", "Unable to get icon package", e);
                return null;
            } catch (InvocationTargetException e2) {
                Log.e("IconCompat", "Unable to get icon package", e2);
                return null;
            } catch (NoSuchMethodException e3) {
                Log.e("IconCompat", "Unable to get icon package", e3);
                return null;
            }
        } else if (this.f559a == 2) {
            return ((String) this.f560b).split(":", -1)[0];
        } else {
            throw new IllegalStateException("called getResPackage() on " + this);
        }
    }

    /* renamed from: c */
    public Uri mo644c() {
        int i;
        if (this.f559a != -1 || (i = Build.VERSION.SDK_INT) < 23) {
            int i2 = this.f559a;
            if (i2 == 4 || i2 == 6) {
                return Uri.parse((String) this.f560b);
            }
            throw new IllegalStateException("called getUri() on " + this);
        }
        Icon icon = (Icon) this.f560b;
        if (i >= 28) {
            return icon.getUri();
        }
        try {
            return (Uri) icon.getClass().getMethod("getUri", new Class[0]).invoke(icon, new Object[0]);
        } catch (IllegalAccessException e) {
            Log.e("IconCompat", "Unable to get icon uri", e);
            return null;
        } catch (InvocationTargetException e2) {
            Log.e("IconCompat", "Unable to get icon uri", e2);
            return null;
        } catch (NoSuchMethodException e3) {
            Log.e("IconCompat", "Unable to get icon uri", e3);
            return null;
        }
    }

    @Deprecated
    /* renamed from: d */
    public Icon mo645d() {
        Icon icon;
        switch (this.f559a) {
            case -1:
                return (Icon) this.f560b;
            case 1:
                icon = Icon.createWithBitmap((Bitmap) this.f560b);
                break;
            case 2:
                icon = Icon.createWithResource(mo643b(), this.f563e);
                break;
            case 3:
                icon = Icon.createWithData((byte[]) this.f560b, this.f563e, this.f564f);
                break;
            case 4:
                icon = Icon.createWithContentUri((String) this.f560b);
                break;
            case 5:
                if (Build.VERSION.SDK_INT < 26) {
                    icon = Icon.createWithBitmap(m307a((Bitmap) this.f560b, false));
                    break;
                } else {
                    icon = Icon.createWithAdaptiveBitmap((Bitmap) this.f560b);
                    break;
                }
            case 6:
                StringBuilder a = outline.m2937a("Context is required to resolve the file uri of the icon: ");
                a.append(mo644c());
                throw new IllegalArgumentException(a.toString());
            default:
                throw new IllegalArgumentException("Unknown type");
        }
        ColorStateList colorStateList = this.f565g;
        if (colorStateList != null) {
            icon.setTintList(colorStateList);
        }
        PorterDuff.Mode mode = this.f566h;
        if (mode == f558j) {
            return icon;
        }
        icon.setTintMode(mode);
        return icon;
    }

    public String toString() {
        String str;
        if (this.f559a == -1) {
            return String.valueOf(this.f560b);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        switch (this.f559a) {
            case 1:
                str = "BITMAP";
                break;
            case 2:
                str = "RESOURCE";
                break;
            case 3:
                str = "DATA";
                break;
            case 4:
                str = "URI";
                break;
            case 5:
                str = "BITMAP_MASKABLE";
                break;
            case 6:
                str = "URI_MASKABLE";
                break;
            default:
                str = "UNKNOWN";
                break;
        }
        sb.append(str);
        switch (this.f559a) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.f560b).getWidth());
                sb.append("x");
                sb.append(((Bitmap) this.f560b).getHeight());
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(mo643b());
                sb.append(" id=");
                sb.append(String.format("0x%08x", new Object[]{Integer.valueOf(mo642a())}));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.f563e);
                if (this.f564f != 0) {
                    sb.append(" off=");
                    sb.append(this.f564f);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.f560b);
                break;
        }
        if (this.f565g != null) {
            sb.append(" tint=");
            sb.append(this.f565g);
        }
        if (this.f566h != f558j) {
            sb.append(" mode=");
            sb.append(this.f566h);
        }
        sb.append(")");
        return sb.toString();
    }

    /* renamed from: a */
    public static Bitmap m307a(Bitmap bitmap, boolean z) {
        int min = (int) (((float) Math.min(bitmap.getWidth(), bitmap.getHeight())) * 0.6666667f);
        Bitmap createBitmap = Bitmap.createBitmap(min, min, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint(3);
        float f = (float) min;
        float f2 = 0.5f * f;
        float f3 = 0.9166667f * f2;
        if (z) {
            float f4 = 0.010416667f * f;
            paint.setColor(0);
            paint.setShadowLayer(f4, 0.0f, f * 0.020833334f, 1023410176);
            canvas.drawCircle(f2, f2, f3, paint);
            paint.setShadowLayer(f4, 0.0f, 0.0f, 503316480);
            canvas.drawCircle(f2, f2, f3, paint);
            paint.clearShadowLayer();
        }
        paint.setColor(-16777216);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        BitmapShader bitmapShader = new BitmapShader(bitmap, tileMode, tileMode);
        Matrix matrix = new Matrix();
        matrix.setTranslate((float) ((-(bitmap.getWidth() - min)) / 2), (float) ((-(bitmap.getHeight() - min)) / 2));
        bitmapShader.setLocalMatrix(matrix);
        paint.setShader(bitmapShader);
        canvas.drawCircle(f2, f2, f3, paint);
        canvas.setBitmap((Bitmap) null);
        return createBitmap;
    }
}
