package androidx.core.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.Log;
import android.util.TypedValue;
import android.view.FocusFinder;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityEvent;
import android.view.animation.AnimationUtils;
import android.widget.EdgeEffect;
import android.widget.FrameLayout;
import android.widget.OverScroller;
import android.widget.ScrollView;
import androidx.recyclerview.widget.RecyclerView;
import com.newrelic.agent.android.harvest.HarvestConfiguration;
import java.util.ArrayList;
import okhttp3.internal.http1.Http1ExchangeCodec;
import p008b.p010b.p011k.AlertController;
import p008b.p033h.p045m.AccessibilityDelegateCompat;
import p008b.p033h.p045m.NestedScrollingChild3;
import p008b.p033h.p045m.NestedScrollingChildHelper;
import p008b.p033h.p045m.NestedScrollingParent3;
import p008b.p033h.p045m.NestedScrollingParentHelper;
import p008b.p033h.p045m.ViewCompat;
import p008b.p033h.p045m.p046x.AccessibilityNodeInfoCompat;
import p085c.p086a.p087a.p088a.outline;

public class NestedScrollView extends FrameLayout implements NestedScrollingParent3, NestedScrollingChild3 {

    /* renamed from: B */
    public static final C0083a f568B = new C0083a();

    /* renamed from: C */
    public static final int[] f569C = {16843130};

    /* renamed from: A */
    public C0084b f570A;

    /* renamed from: b */
    public long f571b;

    /* renamed from: c */
    public final Rect f572c;

    /* renamed from: d */
    public OverScroller f573d;

    /* renamed from: e */
    public EdgeEffect f574e;

    /* renamed from: f */
    public EdgeEffect f575f;

    /* renamed from: g */
    public int f576g;

    /* renamed from: h */
    public boolean f577h;

    /* renamed from: i */
    public boolean f578i;

    /* renamed from: j */
    public View f579j;

    /* renamed from: k */
    public boolean f580k;

    /* renamed from: l */
    public VelocityTracker f581l;

    /* renamed from: m */
    public boolean f582m;

    /* renamed from: n */
    public boolean f583n;

    /* renamed from: o */
    public int f584o;

    /* renamed from: p */
    public int f585p;

    /* renamed from: q */
    public int f586q;

    /* renamed from: r */
    public int f587r;

    /* renamed from: s */
    public final int[] f588s;

    /* renamed from: t */
    public final int[] f589t;

    /* renamed from: u */
    public int f590u;

    /* renamed from: v */
    public int f591v;

    /* renamed from: w */
    public C0085c f592w;

    /* renamed from: x */
    public final NestedScrollingParentHelper f593x;

    /* renamed from: y */
    public final NestedScrollingChildHelper f594y;

    /* renamed from: z */
    public float f595z;

    /* renamed from: androidx.core.widget.NestedScrollView$b */
    public interface C0084b {
    }

    /* renamed from: androidx.core.widget.NestedScrollView$c */
    public static class C0085c extends View.BaseSavedState {
        public static final Parcelable.Creator<C0085c> CREATOR = new C0086a();

        /* renamed from: b */
        public int f596b;

        /* renamed from: androidx.core.widget.NestedScrollView$c$a */
        public static class C0086a implements Parcelable.Creator<C0085c> {
            public Object createFromParcel(Parcel parcel) {
                return new C0085c(parcel);
            }

            public Object[] newArray(int i) {
                return new C0085c[i];
            }
        }

        public C0085c(Parcelable parcelable) {
            super(parcelable);
        }

        public String toString() {
            StringBuilder a = outline.m2937a("HorizontalScrollView.SavedState{");
            a.append(Integer.toHexString(System.identityHashCode(this)));
            a.append(" scrollPosition=");
            a.append(this.f596b);
            a.append("}");
            return a.toString();
        }

        public void writeToParcel(Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeInt(this.f596b);
        }

        public C0085c(Parcel parcel) {
            super(parcel);
            this.f596b = parcel.readInt();
        }
    }

    public NestedScrollView(Context context) {
        this(context, (AttributeSet) null);
    }

    /* renamed from: b */
    public static int m313b(int i, int i2, int i3) {
        if (i2 >= i3 || i < 0) {
            return 0;
        }
        return i2 + i > i3 ? i3 - i2 : i;
    }

    private float getVerticalScrollFactorCompat() {
        if (this.f595z == 0.0f) {
            TypedValue typedValue = new TypedValue();
            Context context = getContext();
            if (context.getTheme().resolveAttribute(16842829, typedValue, true)) {
                this.f595z = typedValue.getDimension(context.getResources().getDisplayMetrics());
            } else {
                throw new IllegalStateException("Expected theme to define listPreferredItemHeight.");
            }
        }
        return this.f595z;
    }

    /* renamed from: a */
    public boolean mo655a(int i, int i2) {
        return this.f594y.mo3125a(i, i2);
    }

    public void addView(View view) {
        if (getChildCount() <= 0) {
            super.addView(view);
            return;
        }
        throw new IllegalStateException("ScrollView can host only one direct child");
    }

    /* renamed from: b */
    public final void mo666b(int i) {
        if (i == 0) {
            return;
        }
        if (this.f583n) {
            mo649a(0, i, 250, false);
        } else {
            scrollBy(0, i);
        }
    }

    /* renamed from: b */
    public boolean mo187b(View view, View view2, int i, int i2) {
        return (i & 2) != 0;
    }

    /* renamed from: c */
    public void mo668c(int i) {
        if (getChildCount() > 0) {
            this.f573d.fling(getScrollX(), getScrollY(), 0, i, 0, 0, RecyclerView.UNDEFINED_DURATION, Integer.MAX_VALUE, 0, 0);
            mo653a(true);
        }
    }

    public int computeHorizontalScrollExtent() {
        return super.computeHorizontalScrollExtent();
    }

    public int computeHorizontalScrollOffset() {
        return super.computeHorizontalScrollOffset();
    }

    public int computeHorizontalScrollRange() {
        return super.computeHorizontalScrollRange();
    }

    public void computeScroll() {
        if (!this.f573d.isFinished()) {
            this.f573d.computeScrollOffset();
            int currY = this.f573d.getCurrY();
            int i = currY - this.f591v;
            this.f591v = currY;
            int[] iArr = this.f589t;
            boolean z = false;
            iArr[1] = 0;
            mo658a(0, i, iArr, (int[]) null, 1);
            int i2 = i - this.f589t[1];
            int scrollRange = getScrollRange();
            if (i2 != 0) {
                int scrollY = getScrollY();
                mo657a(0, i2, getScrollX(), scrollY, 0, scrollRange, 0, 0);
                int scrollY2 = getScrollY() - scrollY;
                int i3 = i2 - scrollY2;
                int[] iArr2 = this.f589t;
                iArr2[1] = 0;
                this.f594y.mo3129b(0, scrollY2, 0, i3, this.f588s, 1, iArr2);
                i2 = i3 - this.f589t[1];
            }
            if (i2 != 0) {
                int overScrollMode = getOverScrollMode();
                if (overScrollMode == 0 || (overScrollMode == 1 && scrollRange > 0)) {
                    z = true;
                }
                if (z) {
                    mo667c();
                    if (i2 < 0) {
                        if (this.f574e.isFinished()) {
                            this.f574e.onAbsorb((int) this.f573d.getCurrVelocity());
                        }
                    } else if (this.f575f.isFinished()) {
                        this.f575f.onAbsorb((int) this.f573d.getCurrVelocity());
                    }
                }
                mo648a();
            }
            if (!this.f573d.isFinished()) {
                ViewCompat.m1922A(this);
            } else {
                this.f594y.mo3130c(1);
            }
        }
    }

    public int computeVerticalScrollExtent() {
        return super.computeVerticalScrollExtent();
    }

    public int computeVerticalScrollOffset() {
        return Math.max(0, super.computeVerticalScrollOffset());
    }

    public int computeVerticalScrollRange() {
        int childCount = getChildCount();
        int height = (getHeight() - getPaddingBottom()) - getPaddingTop();
        if (childCount == 0) {
            return height;
        }
        View childAt = getChildAt(0);
        int bottom = childAt.getBottom() + ((FrameLayout.LayoutParams) childAt.getLayoutParams()).bottomMargin;
        int scrollY = getScrollY();
        int max = Math.max(0, bottom - height);
        if (scrollY < 0) {
            return bottom - scrollY;
        }
        return scrollY > max ? bottom + (scrollY - max) : bottom;
    }

    /* renamed from: d */
    public final void mo676d() {
        VelocityTracker velocityTracker = this.f581l;
        if (velocityTracker != null) {
            velocityTracker.recycle();
            this.f581l = null;
        }
    }

    public boolean dispatchKeyEvent(KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent) || mo659a(keyEvent);
    }

    public boolean dispatchNestedFling(float f, float f2, boolean z) {
        return this.f594y.mo3124a(f, f2, z);
    }

    public boolean dispatchNestedPreFling(float f, float f2) {
        return this.f594y.mo3123a(f, f2);
    }

    public boolean dispatchNestedPreScroll(int i, int i2, int[] iArr, int[] iArr2) {
        return mo658a(i, i2, iArr, iArr2, 0);
    }

    public boolean dispatchNestedScroll(int i, int i2, int i3, int i4, int[] iArr) {
        return this.f594y.mo3126a(i, i2, i3, i4, iArr);
    }

    public void draw(Canvas canvas) {
        int i;
        super.draw(canvas);
        if (this.f574e != null) {
            int scrollY = getScrollY();
            int i2 = 0;
            if (!this.f574e.isFinished()) {
                int save = canvas.save();
                int width = getWidth();
                int height = getHeight();
                int min = Math.min(0, scrollY);
                if (getClipToPadding()) {
                    width -= getPaddingRight() + getPaddingLeft();
                    i = getPaddingLeft() + 0;
                } else {
                    i = 0;
                }
                if (getClipToPadding()) {
                    height -= getPaddingBottom() + getPaddingTop();
                    min += getPaddingTop();
                }
                canvas.translate((float) i, (float) min);
                this.f574e.setSize(width, height);
                if (this.f574e.draw(canvas)) {
                    ViewCompat.m1922A(this);
                }
                canvas.restoreToCount(save);
            }
            if (!this.f575f.isFinished()) {
                int save2 = canvas.save();
                int width2 = getWidth();
                int height2 = getHeight();
                int max = Math.max(getScrollRange(), scrollY) + height2;
                if (getClipToPadding()) {
                    width2 -= getPaddingRight() + getPaddingLeft();
                    i2 = 0 + getPaddingLeft();
                }
                if (getClipToPadding()) {
                    height2 -= getPaddingBottom() + getPaddingTop();
                    max -= getPaddingBottom();
                }
                canvas.translate((float) (i2 - width2), (float) max);
                canvas.rotate(180.0f, (float) width2, 0.0f);
                this.f575f.setSize(width2, height2);
                if (this.f575f.draw(canvas)) {
                    ViewCompat.m1922A(this);
                }
                canvas.restoreToCount(save2);
            }
        }
    }

    /* renamed from: e */
    public boolean mo684e(int i) {
        return this.f594y.mo3121a(i) != null;
    }

    public float getBottomFadingEdgeStrength() {
        if (getChildCount() == 0) {
            return 0.0f;
        }
        View childAt = getChildAt(0);
        int verticalFadingEdgeLength = getVerticalFadingEdgeLength();
        int bottom = ((childAt.getBottom() + ((FrameLayout.LayoutParams) childAt.getLayoutParams()).bottomMargin) - getScrollY()) - (getHeight() - getPaddingBottom());
        if (bottom < verticalFadingEdgeLength) {
            return ((float) bottom) / ((float) verticalFadingEdgeLength);
        }
        return 1.0f;
    }

    public int getMaxScrollAmount() {
        return (int) (((float) getHeight()) * 0.5f);
    }

    public int getNestedScrollAxes() {
        return this.f593x.mo3131a();
    }

    public int getScrollRange() {
        if (getChildCount() <= 0) {
            return 0;
        }
        View childAt = getChildAt(0);
        FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
        return Math.max(0, ((childAt.getHeight() + layoutParams.topMargin) + layoutParams.bottomMargin) - ((getHeight() - getPaddingTop()) - getPaddingBottom()));
    }

    public float getTopFadingEdgeStrength() {
        if (getChildCount() == 0) {
            return 0.0f;
        }
        int verticalFadingEdgeLength = getVerticalFadingEdgeLength();
        int scrollY = getScrollY();
        if (scrollY < verticalFadingEdgeLength) {
            return ((float) scrollY) / ((float) verticalFadingEdgeLength);
        }
        return 1.0f;
    }

    public boolean hasNestedScrollingParent() {
        return mo684e(0);
    }

    public boolean isNestedScrollingEnabled() {
        return this.f594y.f2513d;
    }

    public void measureChild(View view, int i, int i2) {
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        view.measure(FrameLayout.getChildMeasureSpec(i, getPaddingRight() + getPaddingLeft(), layoutParams.width), View.MeasureSpec.makeMeasureSpec(0, 0));
    }

    public void measureChildWithMargins(View view, int i, int i2, int i3, int i4) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) view.getLayoutParams();
        view.measure(FrameLayout.getChildMeasureSpec(i, getPaddingRight() + getPaddingLeft() + marginLayoutParams.leftMargin + marginLayoutParams.rightMargin + i2, marginLayoutParams.width), View.MeasureSpec.makeMeasureSpec(marginLayoutParams.topMargin + marginLayoutParams.bottomMargin, 0));
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.f578i = false;
    }

    public boolean onGenericMotionEvent(MotionEvent motionEvent) {
        if ((motionEvent.getSource() & 2) != 0 && motionEvent.getAction() == 8 && !this.f580k) {
            float axisValue = motionEvent.getAxisValue(9);
            if (axisValue != 0.0f) {
                int scrollRange = getScrollRange();
                int scrollY = getScrollY();
                int verticalScrollFactorCompat = scrollY - ((int) (axisValue * getVerticalScrollFactorCompat()));
                if (verticalScrollFactorCompat < 0) {
                    scrollRange = 0;
                } else if (verticalScrollFactorCompat <= scrollRange) {
                    scrollRange = verticalScrollFactorCompat;
                }
                if (scrollRange != scrollY) {
                    super.scrollTo(getScrollX(), scrollRange);
                    return true;
                }
            }
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:47:0x00e3  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00e9  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean onInterceptTouchEvent(android.view.MotionEvent r12) {
        /*
            r11 = this;
            int r0 = r12.getAction()
            r1 = 1
            r2 = 2
            if (r0 != r2) goto L_0x000d
            boolean r3 = r11.f580k
            if (r3 == 0) goto L_0x000d
            return r1
        L_0x000d:
            r0 = r0 & 255(0xff, float:3.57E-43)
            r3 = 0
            if (r0 == 0) goto L_0x00ac
            r4 = -1
            if (r0 == r1) goto L_0x0085
            if (r0 == r2) goto L_0x0024
            r1 = 3
            if (r0 == r1) goto L_0x0085
            r1 = 6
            if (r0 == r1) goto L_0x001f
            goto L_0x0115
        L_0x001f:
            r11.mo651a((android.view.MotionEvent) r12)
            goto L_0x0115
        L_0x0024:
            int r0 = r11.f587r
            if (r0 != r4) goto L_0x002a
            goto L_0x0115
        L_0x002a:
            int r5 = r12.findPointerIndex(r0)
            if (r5 != r4) goto L_0x004d
            java.lang.StringBuilder r12 = new java.lang.StringBuilder
            r12.<init>()
            java.lang.String r1 = "Invalid pointerId="
            r12.append(r1)
            r12.append(r0)
            java.lang.String r0 = " in onInterceptTouchEvent"
            r12.append(r0)
            java.lang.String r12 = r12.toString()
            java.lang.String r0 = "NestedScrollView"
            android.util.Log.e(r0, r12)
            goto L_0x0115
        L_0x004d:
            float r0 = r12.getY(r5)
            int r0 = (int) r0
            int r4 = r11.f576g
            int r4 = r0 - r4
            int r4 = java.lang.Math.abs(r4)
            int r5 = r11.f584o
            if (r4 <= r5) goto L_0x0115
            int r4 = r11.getNestedScrollAxes()
            r2 = r2 & r4
            if (r2 != 0) goto L_0x0115
            r11.f580k = r1
            r11.f576g = r0
            android.view.VelocityTracker r0 = r11.f581l
            if (r0 != 0) goto L_0x0073
            android.view.VelocityTracker r0 = android.view.VelocityTracker.obtain()
            r11.f581l = r0
        L_0x0073:
            android.view.VelocityTracker r0 = r11.f581l
            r0.addMovement(r12)
            r11.f590u = r3
            android.view.ViewParent r12 = r11.getParent()
            if (r12 == 0) goto L_0x0115
            r12.requestDisallowInterceptTouchEvent(r1)
            goto L_0x0115
        L_0x0085:
            r11.f580k = r3
            r11.f587r = r4
            r11.mo676d()
            android.widget.OverScroller r4 = r11.f573d
            int r5 = r11.getScrollX()
            int r6 = r11.getScrollY()
            r7 = 0
            r8 = 0
            r9 = 0
            int r10 = r11.getScrollRange()
            boolean r12 = r4.springBack(r5, r6, r7, r8, r9, r10)
            if (r12 == 0) goto L_0x00a6
            p008b.p033h.p045m.ViewCompat.m1922A(r11)
        L_0x00a6:
            b.h.m.h r12 = r11.f594y
            r12.mo3130c(r3)
            goto L_0x0115
        L_0x00ac:
            float r0 = r12.getY()
            int r0 = (int) r0
            float r4 = r12.getX()
            int r4 = (int) r4
            int r5 = r11.getChildCount()
            if (r5 <= 0) goto L_0x00e0
            int r5 = r11.getScrollY()
            android.view.View r6 = r11.getChildAt(r3)
            int r7 = r6.getTop()
            int r7 = r7 - r5
            if (r0 < r7) goto L_0x00e0
            int r7 = r6.getBottom()
            int r7 = r7 - r5
            if (r0 >= r7) goto L_0x00e0
            int r5 = r6.getLeft()
            if (r4 < r5) goto L_0x00e0
            int r5 = r6.getRight()
            if (r4 >= r5) goto L_0x00e0
            r4 = 1
            goto L_0x00e1
        L_0x00e0:
            r4 = 0
        L_0x00e1:
            if (r4 != 0) goto L_0x00e9
            r11.f580k = r3
            r11.mo676d()
            goto L_0x0115
        L_0x00e9:
            r11.f576g = r0
            int r0 = r12.getPointerId(r3)
            r11.f587r = r0
            android.view.VelocityTracker r0 = r11.f581l
            if (r0 != 0) goto L_0x00fc
            android.view.VelocityTracker r0 = android.view.VelocityTracker.obtain()
            r11.f581l = r0
            goto L_0x00ff
        L_0x00fc:
            r0.clear()
        L_0x00ff:
            android.view.VelocityTracker r0 = r11.f581l
            r0.addMovement(r12)
            android.widget.OverScroller r12 = r11.f573d
            r12.computeScrollOffset()
            android.widget.OverScroller r12 = r11.f573d
            boolean r12 = r12.isFinished()
            r12 = r12 ^ r1
            r11.f580k = r12
            r11.mo655a((int) r2, (int) r3)
        L_0x0115:
            boolean r12 = r11.f580k
            return r12
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.core.widget.NestedScrollView.onInterceptTouchEvent(android.view.MotionEvent):boolean");
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        int i5 = 0;
        this.f577h = false;
        View view = this.f579j;
        if (view != null && m312a(view, (View) this)) {
            mo652a(this.f579j);
        }
        this.f579j = null;
        if (!this.f578i) {
            if (this.f592w != null) {
                scrollTo(getScrollX(), this.f592w.f596b);
                this.f592w = null;
            }
            if (getChildCount() > 0) {
                View childAt = getChildAt(0);
                FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
                i5 = childAt.getMeasuredHeight() + layoutParams.topMargin + layoutParams.bottomMargin;
            }
            int paddingTop = ((i4 - i2) - getPaddingTop()) - getPaddingBottom();
            int scrollY = getScrollY();
            int b = m313b(scrollY, paddingTop, i5);
            if (b != scrollY) {
                scrollTo(getScrollX(), b);
            }
        }
        scrollTo(getScrollX(), getScrollY());
        this.f578i = true;
    }

    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        if (this.f582m && View.MeasureSpec.getMode(i2) != 0 && getChildCount() > 0) {
            View childAt = getChildAt(0);
            FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
            int measuredHeight = childAt.getMeasuredHeight();
            int measuredHeight2 = (((getMeasuredHeight() - getPaddingTop()) - getPaddingBottom()) - layoutParams.topMargin) - layoutParams.bottomMargin;
            if (measuredHeight < measuredHeight2) {
                childAt.measure(FrameLayout.getChildMeasureSpec(i, getPaddingRight() + getPaddingLeft() + layoutParams.leftMargin + layoutParams.rightMargin, layoutParams.width), View.MeasureSpec.makeMeasureSpec(measuredHeight2, 1073741824));
            }
        }
    }

    public boolean onNestedFling(View view, float f, float f2, boolean z) {
        if (z) {
            return false;
        }
        dispatchNestedFling(0.0f, f2, true);
        mo668c((int) f2);
        return true;
    }

    public boolean onNestedPreFling(View view, float f, float f2) {
        return this.f594y.mo3123a(f, f2);
    }

    public void onNestedPreScroll(View view, int i, int i2, int[] iArr) {
        mo658a(i, i2, iArr, (int[]) null, 0);
    }

    public void onNestedScroll(View view, int i, int i2, int i3, int i4) {
        mo650a(i4, 0, (int[]) null);
    }

    public void onNestedScrollAccepted(View view, View view2, int i) {
        this.f593x.f2515a = i;
        mo655a(2, 0);
    }

    public void onOverScrolled(int i, int i2, boolean z, boolean z2) {
        super.scrollTo(i, i2);
    }

    public boolean onRequestFocusInDescendants(int i, Rect rect) {
        View view;
        if (i == 2) {
            i = 130;
        } else if (i == 1) {
            i = 33;
        }
        if (rect == null) {
            view = FocusFinder.getInstance().findNextFocus(this, (View) null, i);
        } else {
            view = FocusFinder.getInstance().findNextFocusFromRect(this, rect, i);
        }
        if (view != null && !(true ^ mo660a(view, 0, getHeight()))) {
            return view.requestFocus(i, rect);
        }
        return false;
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (!(parcelable instanceof C0085c)) {
            super.onRestoreInstanceState(parcelable);
            return;
        }
        C0085c cVar = (C0085c) parcelable;
        super.onRestoreInstanceState(cVar.getSuperState());
        this.f592w = cVar;
        requestLayout();
    }

    public Parcelable onSaveInstanceState() {
        C0085c cVar = new C0085c(super.onSaveInstanceState());
        cVar.f596b = getScrollY();
        return cVar;
    }

    public void onScrollChanged(int i, int i2, int i3, int i4) {
        super.onScrollChanged(i, i2, i3, i4);
        C0084b bVar = this.f570A;
        if (bVar != null) {
            AlertController cVar = (AlertController) bVar;
            androidx.appcompat.app.AlertController.m122a(this, cVar.f963a, cVar.f964b);
        }
    }

    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        View findFocus = findFocus();
        if (findFocus != null && this != findFocus && mo660a(findFocus, 0, i4)) {
            findFocus.getDrawingRect(this.f572c);
            offsetDescendantRectToMyCoords(findFocus, this.f572c);
            mo666b(mo647a(this.f572c));
        }
    }

    public boolean onStartNestedScroll(View view, View view2, int i) {
        return (i & 2) != 0;
    }

    public void onStopNestedScroll(View view) {
        this.f593x.f2515a = 0;
        this.f594y.mo3130c(0);
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        ViewParent parent;
        MotionEvent motionEvent2 = motionEvent;
        if (this.f581l == null) {
            this.f581l = VelocityTracker.obtain();
        }
        int actionMasked = motionEvent.getActionMasked();
        if (actionMasked == 0) {
            this.f590u = 0;
        }
        MotionEvent obtain = MotionEvent.obtain(motionEvent);
        obtain.offsetLocation(0.0f, (float) this.f590u);
        if (actionMasked != 0) {
            if (actionMasked == 1) {
                VelocityTracker velocityTracker = this.f581l;
                velocityTracker.computeCurrentVelocity(HarvestConfiguration.DEFAULT_MAX_TRANSACTION_COUNT, (float) this.f586q);
                int yVelocity = (int) velocityTracker.getYVelocity(this.f587r);
                if (Math.abs(yVelocity) >= this.f585p) {
                    int i = -yVelocity;
                    float f = (float) i;
                    if (!dispatchNestedPreFling(0.0f, f)) {
                        dispatchNestedFling(0.0f, f, true);
                        mo668c(i);
                    }
                } else if (this.f573d.springBack(getScrollX(), getScrollY(), 0, 0, 0, getScrollRange())) {
                    ViewCompat.m1922A(this);
                }
                this.f587r = -1;
                mo665b();
            } else if (actionMasked == 2) {
                int findPointerIndex = motionEvent2.findPointerIndex(this.f587r);
                if (findPointerIndex == -1) {
                    StringBuilder a = outline.m2937a("Invalid pointerId=");
                    a.append(this.f587r);
                    a.append(" in onTouchEvent");
                    Log.e("NestedScrollView", a.toString());
                } else {
                    int y = (int) motionEvent2.getY(findPointerIndex);
                    int i2 = this.f576g - y;
                    if (!this.f580k && Math.abs(i2) > this.f584o) {
                        ViewParent parent2 = getParent();
                        if (parent2 != null) {
                            parent2.requestDisallowInterceptTouchEvent(true);
                        }
                        this.f580k = true;
                        i2 = i2 > 0 ? i2 - this.f584o : i2 + this.f584o;
                    }
                    int i3 = i2;
                    if (this.f580k) {
                        if (mo658a(0, i3, this.f589t, this.f588s, 0)) {
                            i3 -= this.f589t[1];
                            this.f590u += this.f588s[1];
                        }
                        int i4 = i3;
                        this.f576g = y - this.f588s[1];
                        int scrollY = getScrollY();
                        int scrollRange = getScrollRange();
                        int overScrollMode = getOverScrollMode();
                        boolean z = overScrollMode == 0 || (overScrollMode == 1 && scrollRange > 0);
                        int i5 = scrollRange;
                        if (mo657a(0, i4, 0, getScrollY(), 0, scrollRange, 0, 0) && !mo684e(0)) {
                            this.f581l.clear();
                        }
                        int scrollY2 = getScrollY() - scrollY;
                        int[] iArr = this.f589t;
                        iArr[1] = 0;
                        this.f594y.mo3129b(0, scrollY2, 0, i4 - scrollY2, this.f588s, 0, iArr);
                        int i6 = this.f576g;
                        int[] iArr2 = this.f588s;
                        this.f576g = i6 - iArr2[1];
                        this.f590u += iArr2[1];
                        if (z) {
                            int i7 = i4 - this.f589t[1];
                            mo667c();
                            int i8 = scrollY + i7;
                            if (i8 < 0) {
                                this.f574e.onPull(((float) i7) / ((float) getHeight()), motionEvent2.getX(findPointerIndex) / ((float) getWidth()));
                                if (!this.f575f.isFinished()) {
                                    this.f575f.onRelease();
                                }
                            } else if (i8 > i5) {
                                this.f575f.onPull(((float) i7) / ((float) getHeight()), 1.0f - (motionEvent2.getX(findPointerIndex) / ((float) getWidth())));
                                if (!this.f574e.isFinished()) {
                                    this.f574e.onRelease();
                                }
                            }
                            EdgeEffect edgeEffect = this.f574e;
                            if (edgeEffect != null && (!edgeEffect.isFinished() || !this.f575f.isFinished())) {
                                ViewCompat.m1922A(this);
                            }
                        }
                    }
                }
            } else if (actionMasked == 3) {
                if (this.f580k && getChildCount() > 0 && this.f573d.springBack(getScrollX(), getScrollY(), 0, 0, 0, getScrollRange())) {
                    ViewCompat.m1922A(this);
                }
                this.f587r = -1;
                mo665b();
            } else if (actionMasked == 5) {
                int actionIndex = motionEvent.getActionIndex();
                this.f576g = (int) motionEvent2.getY(actionIndex);
                this.f587r = motionEvent2.getPointerId(actionIndex);
            } else if (actionMasked == 6) {
                mo651a(motionEvent);
                this.f576g = (int) motionEvent2.getY(motionEvent2.findPointerIndex(this.f587r));
            }
        } else if (getChildCount() == 0) {
            return false;
        } else {
            boolean z2 = !this.f573d.isFinished();
            this.f580k = z2;
            if (z2 && (parent = getParent()) != null) {
                parent.requestDisallowInterceptTouchEvent(true);
            }
            if (!this.f573d.isFinished()) {
                mo648a();
            }
            this.f576g = (int) motionEvent.getY();
            this.f587r = motionEvent2.getPointerId(0);
            mo655a(2, 0);
        }
        VelocityTracker velocityTracker2 = this.f581l;
        if (velocityTracker2 != null) {
            velocityTracker2.addMovement(obtain);
        }
        obtain.recycle();
        return true;
    }

    public void requestChildFocus(View view, View view2) {
        if (!this.f577h) {
            mo652a(view2);
        } else {
            this.f579j = view2;
        }
        super.requestChildFocus(view, view2);
    }

    public boolean requestChildRectangleOnScreen(View view, Rect rect, boolean z) {
        rect.offset(view.getLeft() - view.getScrollX(), view.getTop() - view.getScrollY());
        int a = mo647a(rect);
        boolean z2 = a != 0;
        if (z2) {
            if (z) {
                scrollBy(0, a);
            } else {
                mo649a(0, a, 250, false);
            }
        }
        return z2;
    }

    public void requestDisallowInterceptTouchEvent(boolean z) {
        if (z) {
            mo676d();
        }
        super.requestDisallowInterceptTouchEvent(z);
    }

    public void requestLayout() {
        this.f577h = true;
        super.requestLayout();
    }

    public void scrollTo(int i, int i2) {
        if (getChildCount() > 0) {
            View childAt = getChildAt(0);
            FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
            int b = m313b(i, (getWidth() - getPaddingLeft()) - getPaddingRight(), childAt.getWidth() + layoutParams.leftMargin + layoutParams.rightMargin);
            int b2 = m313b(i2, (getHeight() - getPaddingTop()) - getPaddingBottom(), childAt.getHeight() + layoutParams.topMargin + layoutParams.bottomMargin);
            if (b != getScrollX() || b2 != getScrollY()) {
                super.scrollTo(b, b2);
            }
        }
    }

    public void setFillViewport(boolean z) {
        if (z != this.f582m) {
            this.f582m = z;
            requestLayout();
        }
    }

    public void setNestedScrollingEnabled(boolean z) {
        NestedScrollingChildHelper hVar = this.f594y;
        if (hVar.f2513d) {
            ViewCompat.m1924C(hVar.f2512c);
        }
        hVar.f2513d = z;
    }

    public void setOnScrollChangeListener(C0084b bVar) {
        this.f570A = bVar;
    }

    public void setSmoothScrollingEnabled(boolean z) {
        this.f583n = z;
    }

    public boolean shouldDelayChildPressedState() {
        return true;
    }

    public boolean startNestedScroll(int i) {
        return this.f594y.mo3125a(i, 0);
    }

    public void stopNestedScroll() {
        this.f594y.mo3130c(0);
    }

    public NestedScrollView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    /* renamed from: a */
    public boolean mo658a(int i, int i2, int[] iArr, int[] iArr2, int i3) {
        return this.f594y.mo3127a(i, i2, iArr, iArr2, i3);
    }

    public NestedScrollView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.f572c = new Rect();
        this.f577h = true;
        this.f578i = false;
        this.f579j = null;
        this.f580k = false;
        this.f583n = true;
        this.f587r = -1;
        this.f588s = new int[2];
        this.f589t = new int[2];
        this.f573d = new OverScroller(getContext());
        setFocusable(true);
        setDescendantFocusability(Http1ExchangeCodec.HEADER_LIMIT);
        setWillNotDraw(false);
        ViewConfiguration viewConfiguration = ViewConfiguration.get(getContext());
        this.f584o = viewConfiguration.getScaledTouchSlop();
        this.f585p = viewConfiguration.getScaledMinimumFlingVelocity();
        this.f586q = viewConfiguration.getScaledMaximumFlingVelocity();
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, f569C, i, 0);
        setFillViewport(obtainStyledAttributes.getBoolean(0, false));
        obtainStyledAttributes.recycle();
        this.f593x = new NestedScrollingParentHelper();
        this.f594y = new NestedScrollingChildHelper(this);
        setNestedScrollingEnabled(true);
        ViewCompat.m1938a((View) this, (AccessibilityDelegateCompat) f568B);
    }

    /* renamed from: a */
    public void mo181a(View view, int i, int i2, int i3, int i4, int i5, int[] iArr) {
        mo650a(i4, i5, iArr);
    }

    /* renamed from: a */
    public final void mo650a(int i, int i2, int[] iArr) {
        int scrollY = getScrollY();
        scrollBy(0, i);
        int scrollY2 = getScrollY() - scrollY;
        if (iArr != null) {
            iArr[1] = iArr[1] + scrollY2;
        }
        this.f594y.mo3122a(0, scrollY2, 0, i - scrollY2, (int[]) null, i2, iArr);
    }

    public void addView(View view, int i) {
        if (getChildCount() <= 0) {
            super.addView(view, i);
            return;
        }
        throw new IllegalStateException("ScrollView can host only one direct child");
    }

    /* renamed from: b */
    public final void mo665b() {
        this.f580k = false;
        mo676d();
        this.f594y.mo3130c(0);
        EdgeEffect edgeEffect = this.f574e;
        if (edgeEffect != null) {
            edgeEffect.onRelease();
            this.f575f.onRelease();
        }
    }

    /* renamed from: c */
    public final void mo667c() {
        if (getOverScrollMode() == 2) {
            this.f574e = null;
            this.f575f = null;
        } else if (this.f574e == null) {
            Context context = getContext();
            this.f574e = new EdgeEffect(context);
            this.f575f = new EdgeEffect(context);
        }
    }

    /* renamed from: d */
    public boolean mo677d(int i) {
        int childCount;
        boolean z = i == 130;
        int height = getHeight();
        Rect rect = this.f572c;
        rect.top = 0;
        rect.bottom = height;
        if (z && (childCount = getChildCount()) > 0) {
            View childAt = getChildAt(childCount - 1);
            this.f572c.bottom = getPaddingBottom() + childAt.getBottom() + ((FrameLayout.LayoutParams) childAt.getLayoutParams()).bottomMargin;
            Rect rect2 = this.f572c;
            rect2.top = rect2.bottom - height;
        }
        Rect rect3 = this.f572c;
        return mo656a(i, rect3.top, rect3.bottom);
    }

    public void addView(View view, ViewGroup.LayoutParams layoutParams) {
        if (getChildCount() <= 0) {
            super.addView(view, layoutParams);
            return;
        }
        throw new IllegalStateException("ScrollView can host only one direct child");
    }

    /* renamed from: a */
    public void mo183a(View view, View view2, int i, int i2) {
        NestedScrollingParentHelper kVar = this.f593x;
        if (i2 == 1) {
            kVar.f2516b = i;
        } else {
            kVar.f2515a = i;
        }
        mo655a(2, i2);
    }

    public void addView(View view, int i, ViewGroup.LayoutParams layoutParams) {
        if (getChildCount() <= 0) {
            super.addView(view, i, layoutParams);
            return;
        }
        throw new IllegalStateException("ScrollView can host only one direct child");
    }

    /* renamed from: a */
    public void mo179a(View view, int i) {
        NestedScrollingParentHelper kVar = this.f593x;
        if (i == 1) {
            kVar.f2516b = 0;
        } else {
            kVar.f2515a = 0;
        }
        this.f594y.mo3130c(i);
    }

    /* renamed from: androidx.core.widget.NestedScrollView$a */
    public static class C0083a extends AccessibilityDelegateCompat {
        /* renamed from: a */
        public void mo725a(View view, AccessibilityNodeInfoCompat bVar) {
            int scrollRange;
            this.f2500a.onInitializeAccessibilityNodeInfo(view, bVar.f2546a);
            NestedScrollView nestedScrollView = (NestedScrollView) view;
            bVar.f2546a.setClassName(ScrollView.class.getName());
            if (nestedScrollView.isEnabled() && (scrollRange = nestedScrollView.getScrollRange()) > 0) {
                bVar.f2546a.setScrollable(true);
                if (nestedScrollView.getScrollY() > 0) {
                    bVar.mo3167a(AccessibilityNodeInfoCompat.C0411a.f2551g);
                    bVar.mo3167a(AccessibilityNodeInfoCompat.C0411a.f2555k);
                }
                if (nestedScrollView.getScrollY() < scrollRange) {
                    bVar.mo3167a(AccessibilityNodeInfoCompat.C0411a.f2550f);
                    bVar.mo3167a(AccessibilityNodeInfoCompat.C0411a.f2556l);
                }
            }
        }

        /* renamed from: b */
        public void mo727b(View view, AccessibilityEvent accessibilityEvent) {
            this.f2500a.onInitializeAccessibilityEvent(view, accessibilityEvent);
            NestedScrollView nestedScrollView = (NestedScrollView) view;
            accessibilityEvent.setClassName(ScrollView.class.getName());
            accessibilityEvent.setScrollable(nestedScrollView.getScrollRange() > 0);
            accessibilityEvent.setScrollX(nestedScrollView.getScrollX());
            accessibilityEvent.setScrollY(nestedScrollView.getScrollY());
            accessibilityEvent.setMaxScrollX(nestedScrollView.getScrollX());
            accessibilityEvent.setMaxScrollY(nestedScrollView.getScrollRange());
        }

        /* renamed from: a */
        public boolean mo726a(View view, int i, Bundle bundle) {
            if (super.mo726a(view, i, bundle)) {
                return true;
            }
            NestedScrollView nestedScrollView = (NestedScrollView) view;
            if (!nestedScrollView.isEnabled()) {
                return false;
            }
            if (i != 4096) {
                if (i == 8192 || i == 16908344) {
                    int max = Math.max(nestedScrollView.getScrollY() - ((nestedScrollView.getHeight() - nestedScrollView.getPaddingBottom()) - nestedScrollView.getPaddingTop()), 0);
                    if (max == nestedScrollView.getScrollY()) {
                        return false;
                    }
                    nestedScrollView.mo649a(0 - nestedScrollView.getScrollX(), max - nestedScrollView.getScrollY(), 250, true);
                    return true;
                } else if (i != 16908346) {
                    return false;
                }
            }
            int min = Math.min(nestedScrollView.getScrollY() + ((nestedScrollView.getHeight() - nestedScrollView.getPaddingBottom()) - nestedScrollView.getPaddingTop()), nestedScrollView.getScrollRange());
            if (min == nestedScrollView.getScrollY()) {
                return false;
            }
            nestedScrollView.mo649a(0 - nestedScrollView.getScrollX(), min - nestedScrollView.getScrollY(), 250, true);
            return true;
        }
    }

    /* renamed from: a */
    public void mo180a(View view, int i, int i2, int i3, int i4, int i5) {
        mo650a(i4, i5, (int[]) null);
    }

    /* renamed from: a */
    public void mo182a(View view, int i, int i2, int[] iArr, int i3) {
        mo658a(i, i2, iArr, (int[]) null, i3);
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0038  */
    /* renamed from: a */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean mo659a(android.view.KeyEvent r7) {
        /*
            r6 = this;
            android.graphics.Rect r0 = r6.f572c
            r0.setEmpty()
            int r0 = r6.getChildCount()
            r1 = 1
            r2 = 0
            if (r0 <= 0) goto L_0x0033
            android.view.View r0 = r6.getChildAt(r2)
            android.view.ViewGroup$LayoutParams r3 = r0.getLayoutParams()
            android.widget.FrameLayout$LayoutParams r3 = (android.widget.FrameLayout.LayoutParams) r3
            int r0 = r0.getHeight()
            int r4 = r3.topMargin
            int r0 = r0 + r4
            int r3 = r3.bottomMargin
            int r0 = r0 + r3
            int r3 = r6.getHeight()
            int r4 = r6.getPaddingTop()
            int r3 = r3 - r4
            int r4 = r6.getPaddingBottom()
            int r3 = r3 - r4
            if (r0 <= r3) goto L_0x0033
            r0 = 1
            goto L_0x0034
        L_0x0033:
            r0 = 0
        L_0x0034:
            r3 = 130(0x82, float:1.82E-43)
            if (r0 != 0) goto L_0x0062
            boolean r0 = r6.isFocused()
            if (r0 == 0) goto L_0x0061
            int r7 = r7.getKeyCode()
            r0 = 4
            if (r7 == r0) goto L_0x0061
            android.view.View r7 = r6.findFocus()
            if (r7 != r6) goto L_0x004c
            r7 = 0
        L_0x004c:
            android.view.FocusFinder r0 = android.view.FocusFinder.getInstance()
            android.view.View r7 = r0.findNextFocus(r6, r7, r3)
            if (r7 == 0) goto L_0x005f
            if (r7 == r6) goto L_0x005f
            boolean r7 = r7.requestFocus(r3)
            if (r7 == 0) goto L_0x005f
            goto L_0x0060
        L_0x005f:
            r1 = 0
        L_0x0060:
            return r1
        L_0x0061:
            return r2
        L_0x0062:
            int r0 = r7.getAction()
            if (r0 != 0) goto L_0x00fc
            int r0 = r7.getKeyCode()
            r4 = 19
            r5 = 33
            if (r0 == r4) goto L_0x00ed
            r4 = 20
            if (r0 == r4) goto L_0x00dd
            r4 = 62
            if (r0 == r4) goto L_0x007c
            goto L_0x00fc
        L_0x007c:
            boolean r7 = r7.isShiftPressed()
            if (r7 == 0) goto L_0x0083
            goto L_0x0085
        L_0x0083:
            r5 = 130(0x82, float:1.82E-43)
        L_0x0085:
            if (r5 != r3) goto L_0x0089
            r7 = 1
            goto L_0x008a
        L_0x0089:
            r7 = 0
        L_0x008a:
            int r0 = r6.getHeight()
            if (r7 == 0) goto L_0x00c1
            android.graphics.Rect r7 = r6.f572c
            int r3 = r6.getScrollY()
            int r3 = r3 + r0
            r7.top = r3
            int r7 = r6.getChildCount()
            if (r7 <= 0) goto L_0x00d2
            int r7 = r7 - r1
            android.view.View r7 = r6.getChildAt(r7)
            android.view.ViewGroup$LayoutParams r1 = r7.getLayoutParams()
            android.widget.FrameLayout$LayoutParams r1 = (android.widget.FrameLayout.LayoutParams) r1
            int r7 = r7.getBottom()
            int r1 = r1.bottomMargin
            int r7 = r7 + r1
            int r1 = r6.getPaddingBottom()
            int r1 = r1 + r7
            android.graphics.Rect r7 = r6.f572c
            int r3 = r7.top
            int r3 = r3 + r0
            if (r3 <= r1) goto L_0x00d2
            int r1 = r1 - r0
            r7.top = r1
            goto L_0x00d2
        L_0x00c1:
            android.graphics.Rect r7 = r6.f572c
            int r1 = r6.getScrollY()
            int r1 = r1 - r0
            r7.top = r1
            android.graphics.Rect r7 = r6.f572c
            int r1 = r7.top
            if (r1 >= 0) goto L_0x00d2
            r7.top = r2
        L_0x00d2:
            android.graphics.Rect r7 = r6.f572c
            int r1 = r7.top
            int r0 = r0 + r1
            r7.bottom = r0
            r6.mo656a((int) r5, (int) r1, (int) r0)
            goto L_0x00fc
        L_0x00dd:
            boolean r7 = r7.isAltPressed()
            if (r7 != 0) goto L_0x00e8
            boolean r2 = r6.mo654a((int) r3)
            goto L_0x00fc
        L_0x00e8:
            boolean r2 = r6.mo677d(r3)
            goto L_0x00fc
        L_0x00ed:
            boolean r7 = r7.isAltPressed()
            if (r7 != 0) goto L_0x00f8
            boolean r2 = r6.mo654a((int) r5)
            goto L_0x00fc
        L_0x00f8:
            boolean r2 = r6.mo677d(r5)
        L_0x00fc:
            return r2
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.core.widget.NestedScrollView.mo659a(android.view.KeyEvent):boolean");
    }

    /* renamed from: a */
    public final void mo651a(MotionEvent motionEvent) {
        int actionIndex = motionEvent.getActionIndex();
        if (motionEvent.getPointerId(actionIndex) == this.f587r) {
            int i = actionIndex == 0 ? 1 : 0;
            this.f576g = (int) motionEvent.getY(i);
            this.f587r = motionEvent.getPointerId(i);
            VelocityTracker velocityTracker = this.f581l;
            if (velocityTracker != null) {
                velocityTracker.clear();
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:34:0x0057  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x0083 A[ADDED_TO_REGION] */
    /* renamed from: a */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean mo657a(int r13, int r14, int r15, int r16, int r17, int r18, int r19, int r20) {
        /*
            r12 = this;
            r0 = r12
            int r1 = r12.getOverScrollMode()
            int r2 = super.computeHorizontalScrollRange()
            int r3 = super.computeHorizontalScrollExtent()
            r4 = 0
            r5 = 1
            if (r2 <= r3) goto L_0x0013
            r2 = 1
            goto L_0x0014
        L_0x0013:
            r2 = 0
        L_0x0014:
            int r3 = r12.computeVerticalScrollRange()
            int r6 = super.computeVerticalScrollExtent()
            if (r3 <= r6) goto L_0x0020
            r3 = 1
            goto L_0x0021
        L_0x0020:
            r3 = 0
        L_0x0021:
            if (r1 == 0) goto L_0x002a
            if (r1 != r5) goto L_0x0028
            if (r2 == 0) goto L_0x0028
            goto L_0x002a
        L_0x0028:
            r2 = 0
            goto L_0x002b
        L_0x002a:
            r2 = 1
        L_0x002b:
            if (r1 == 0) goto L_0x0034
            if (r1 != r5) goto L_0x0032
            if (r3 == 0) goto L_0x0032
            goto L_0x0034
        L_0x0032:
            r1 = 0
            goto L_0x0035
        L_0x0034:
            r1 = 1
        L_0x0035:
            int r3 = r15 + r13
            if (r2 != 0) goto L_0x003b
            r2 = 0
            goto L_0x003d
        L_0x003b:
            r2 = r19
        L_0x003d:
            int r6 = r16 + r14
            if (r1 != 0) goto L_0x0043
            r1 = 0
            goto L_0x0045
        L_0x0043:
            r1 = r20
        L_0x0045:
            int r7 = -r2
            int r2 = r2 + r17
            int r8 = -r1
            int r1 = r1 + r18
            if (r3 <= r2) goto L_0x0050
            r3 = r2
        L_0x004e:
            r2 = 1
            goto L_0x0055
        L_0x0050:
            if (r3 >= r7) goto L_0x0054
            r3 = r7
            goto L_0x004e
        L_0x0054:
            r2 = 0
        L_0x0055:
            if (r6 <= r1) goto L_0x005a
            r6 = r1
        L_0x0058:
            r1 = 1
            goto L_0x005f
        L_0x005a:
            if (r6 >= r8) goto L_0x005e
            r6 = r8
            goto L_0x0058
        L_0x005e:
            r1 = 0
        L_0x005f:
            if (r1 == 0) goto L_0x007e
            boolean r7 = r12.mo684e(r5)
            if (r7 != 0) goto L_0x007e
            android.widget.OverScroller r7 = r0.f573d
            r8 = 0
            r9 = 0
            r10 = 0
            int r11 = r12.getScrollRange()
            r13 = r7
            r14 = r3
            r15 = r6
            r16 = r8
            r17 = r9
            r18 = r10
            r19 = r11
            r13.springBack(r14, r15, r16, r17, r18, r19)
        L_0x007e:
            super.scrollTo(r3, r6)
            if (r2 != 0) goto L_0x0085
            if (r1 == 0) goto L_0x0086
        L_0x0085:
            r4 = 1
        L_0x0086:
            return r4
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.core.widget.NestedScrollView.mo657a(int, int, int, int, int, int, int, int):boolean");
    }

    /* renamed from: a */
    public final boolean mo656a(int i, int i2, int i3) {
        boolean z;
        int i4 = i;
        int i5 = i2;
        int i6 = i3;
        int height = getHeight();
        int scrollY = getScrollY();
        int i7 = height + scrollY;
        boolean z2 = i4 == 33;
        ArrayList focusables = getFocusables(2);
        int size = focusables.size();
        View view = null;
        boolean z3 = false;
        for (int i8 = 0; i8 < size; i8++) {
            View view2 = (View) focusables.get(i8);
            int top = view2.getTop();
            int bottom = view2.getBottom();
            if (i5 < bottom && top < i6) {
                boolean z4 = i5 < top && bottom < i6;
                if (view == null) {
                    view = view2;
                    z3 = z4;
                } else {
                    boolean z5 = (z2 && top < view.getTop()) || (!z2 && bottom > view.getBottom());
                    if (z3) {
                        if (z4) {
                            if (!z5) {
                            }
                        }
                    } else if (z4) {
                        view = view2;
                        z3 = true;
                    } else if (!z5) {
                    }
                    view = view2;
                }
            }
        }
        if (view == null) {
            view = this;
        }
        if (i5 < scrollY || i6 > i7) {
            mo666b(z2 ? i5 - scrollY : i6 - i7);
            z = true;
        } else {
            z = false;
        }
        if (view != findFocus()) {
            view.requestFocus(i4);
        }
        return z;
    }

    /* renamed from: a */
    public boolean mo654a(int i) {
        View findFocus = findFocus();
        if (findFocus == this) {
            findFocus = null;
        }
        View findNextFocus = FocusFinder.getInstance().findNextFocus(this, findFocus, i);
        int maxScrollAmount = getMaxScrollAmount();
        if (findNextFocus == null || !mo660a(findNextFocus, maxScrollAmount, getHeight())) {
            if (i == 33 && getScrollY() < maxScrollAmount) {
                maxScrollAmount = getScrollY();
            } else if (i == 130 && getChildCount() > 0) {
                View childAt = getChildAt(0);
                maxScrollAmount = Math.min((childAt.getBottom() + ((FrameLayout.LayoutParams) childAt.getLayoutParams()).bottomMargin) - ((getHeight() + getScrollY()) - getPaddingBottom()), maxScrollAmount);
            }
            if (maxScrollAmount == 0) {
                return false;
            }
            if (i != 130) {
                maxScrollAmount = -maxScrollAmount;
            }
            mo666b(maxScrollAmount);
        } else {
            findNextFocus.getDrawingRect(this.f572c);
            offsetDescendantRectToMyCoords(findNextFocus, this.f572c);
            mo666b(mo647a(this.f572c));
            findNextFocus.requestFocus(i);
        }
        if (findFocus != null && findFocus.isFocused() && (!mo660a(findFocus, 0, getHeight()))) {
            int descendantFocusability = getDescendantFocusability();
            setDescendantFocusability(131072);
            requestFocus();
            setDescendantFocusability(descendantFocusability);
        }
        return true;
    }

    /* renamed from: a */
    public final boolean mo660a(View view, int i, int i2) {
        view.getDrawingRect(this.f572c);
        offsetDescendantRectToMyCoords(view, this.f572c);
        return this.f572c.bottom + i >= getScrollY() && this.f572c.top - i <= getScrollY() + i2;
    }

    /* renamed from: a */
    public final void mo649a(int i, int i2, int i3, boolean z) {
        if (getChildCount() != 0) {
            if (AnimationUtils.currentAnimationTimeMillis() - this.f571b > 250) {
                View childAt = getChildAt(0);
                FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
                int scrollY = getScrollY();
                OverScroller overScroller = this.f573d;
                int scrollX = getScrollX();
                overScroller.startScroll(scrollX, scrollY, 0, Math.max(0, Math.min(i2 + scrollY, Math.max(0, ((childAt.getHeight() + layoutParams.topMargin) + layoutParams.bottomMargin) - ((getHeight() - getPaddingTop()) - getPaddingBottom())))) - scrollY, i3);
                mo653a(z);
            } else {
                if (!this.f573d.isFinished()) {
                    mo648a();
                }
                scrollBy(i, i2);
            }
            this.f571b = AnimationUtils.currentAnimationTimeMillis();
        }
    }

    /* renamed from: a */
    public final void mo653a(boolean z) {
        if (z) {
            mo655a(2, 1);
        } else {
            this.f594y.mo3130c(1);
        }
        this.f591v = getScrollY();
        ViewCompat.m1922A(this);
    }

    /* renamed from: a */
    public final void mo648a() {
        this.f573d.abortAnimation();
        this.f594y.mo3130c(1);
    }

    /* renamed from: a */
    public final void mo652a(View view) {
        view.getDrawingRect(this.f572c);
        offsetDescendantRectToMyCoords(view, this.f572c);
        int a = mo647a(this.f572c);
        if (a != 0) {
            scrollBy(0, a);
        }
    }

    /* renamed from: a */
    public int mo647a(Rect rect) {
        int i;
        int i2;
        if (getChildCount() == 0) {
            return 0;
        }
        int height = getHeight();
        int scrollY = getScrollY();
        int i3 = scrollY + height;
        int verticalFadingEdgeLength = getVerticalFadingEdgeLength();
        if (rect.top > 0) {
            scrollY += verticalFadingEdgeLength;
        }
        View childAt = getChildAt(0);
        FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) childAt.getLayoutParams();
        int i4 = rect.bottom < (childAt.getHeight() + layoutParams.topMargin) + layoutParams.bottomMargin ? i3 - verticalFadingEdgeLength : i3;
        if (rect.bottom > i4 && rect.top > scrollY) {
            if (rect.height() > height) {
                i2 = rect.top - scrollY;
            } else {
                i2 = rect.bottom - i4;
            }
            return Math.min(i2 + 0, (childAt.getBottom() + layoutParams.bottomMargin) - i3);
        } else if (rect.top >= scrollY || rect.bottom >= i4) {
            return 0;
        } else {
            if (rect.height() > height) {
                i = 0 - (i4 - rect.bottom);
            } else {
                i = 0 - (scrollY - rect.top);
            }
            return Math.max(i, -getScrollY());
        }
    }

    /* renamed from: a */
    public static boolean m312a(View view, View view2) {
        if (view == view2) {
            return true;
        }
        ViewParent parent = view.getParent();
        if (!(parent instanceof ViewGroup) || !m312a((View) parent, view2)) {
            return false;
        }
        return true;
    }
}
