package androidx.recyclerview.widget;

import android.animation.LayoutTransition;
import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.database.Observable;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.StateListDrawable;
import android.os.Build;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.SystemClock;
import android.os.Trace;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.view.Display;
import android.view.FocusFinder;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.ViewPropertyAnimator;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.animation.Interpolator;
import android.widget.EdgeEffect;
import android.widget.OverScroller;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.harvest.HarvestConfiguration;
import com.newrelic.agent.android.harvest.HarvestConnection;
import java.lang.ref.WeakReference;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import okhttp3.internal.http1.Http1ExchangeCodec;
import p008b.p033h.p041i.TraceCompat;
import p008b.p033h.p045m.AccessibilityDelegateCompat;
import p008b.p033h.p045m.NestedScrollingChild2;
import p008b.p033h.p045m.NestedScrollingChild3;
import p008b.p033h.p045m.NestedScrollingChildHelper;
import p008b.p033h.p045m.ViewCompat;
import p008b.p033h.p045m.ViewConfigurationCompat;
import p008b.p033h.p045m.p046x.AccessibilityNodeInfoCompat;
import p008b.p050j.p051a.AbsSavedState;
import p008b.p071s.C0543a;
import p008b.p071s.C0544b;
import p008b.p071s.C0545c;
import p008b.p071s.p072d.AdapterHelper;
import p008b.p071s.p072d.C0550d;
import p008b.p071s.p072d.C0551e;
import p008b.p071s.p072d.C0552f;
import p008b.p071s.p072d.C0557k;
import p008b.p071s.p072d.ChildHelper;
import p008b.p071s.p072d.DefaultItemAnimator;
import p008b.p071s.p072d.FastScroller;
import p008b.p071s.p072d.GapWorker;
import p008b.p071s.p072d.LinearSmoothScroller;
import p008b.p071s.p072d.RecyclerViewAccessibilityDelegate;
import p008b.p071s.p072d.SimpleItemAnimator;
import p008b.p071s.p072d.ViewBoundsCheck;
import p008b.p071s.p072d.ViewInfoStore;
import p085c.p086a.p087a.p088a.outline;

public class RecyclerView extends ViewGroup implements NestedScrollingChild2, NestedScrollingChild3 {
    public static final boolean ALLOW_SIZE_IN_UNSPECIFIED_SPEC = (Build.VERSION.SDK_INT >= 23);
    public static final boolean ALLOW_THREAD_GAP_WORK = true;
    public static final boolean DEBUG = false;
    public static final int DEFAULT_ORIENTATION = 1;
    public static final boolean DISPATCH_TEMP_DETACH = false;
    public static final boolean FORCE_ABS_FOCUS_SEARCH_DIRECTION = false;
    public static final boolean FORCE_INVALIDATE_DISPLAY_LIST = false;
    public static final long FOREVER_NS = Long.MAX_VALUE;
    public static final int HORIZONTAL = 0;
    public static final boolean IGNORE_DETACHED_FOCUSED_CHILD = false;
    public static final int INVALID_POINTER = -1;
    public static final int INVALID_TYPE = -1;
    public static final Class<?>[] LAYOUT_MANAGER_CONSTRUCTOR_SIGNATURE;
    public static final int MAX_SCROLL_DURATION = 2000;
    public static final int[] NESTED_SCROLLING_ATTRS = {16843830};
    public static final long NO_ID = -1;
    public static final int NO_POSITION = -1;
    public static final boolean POST_UPDATES_ON_ANIMATION = true;
    public static final int SCROLL_STATE_DRAGGING = 1;
    public static final int SCROLL_STATE_IDLE = 0;
    public static final int SCROLL_STATE_SETTLING = 2;
    public static final String TAG = "RecyclerView";
    public static final int TOUCH_SLOP_DEFAULT = 0;
    public static final int TOUCH_SLOP_PAGING = 1;
    public static final String TRACE_BIND_VIEW_TAG = "RV OnBindView";
    public static final String TRACE_CREATE_VIEW_TAG = "RV CreateView";
    public static final String TRACE_HANDLE_ADAPTER_UPDATES_TAG = "RV PartialInvalidate";
    public static final String TRACE_NESTED_PREFETCH_TAG = "RV Nested Prefetch";
    public static final String TRACE_ON_DATA_SET_CHANGE_LAYOUT_TAG = "RV FullInvalidate";
    public static final String TRACE_ON_LAYOUT_TAG = "RV OnLayout";
    public static final String TRACE_PREFETCH_TAG = "RV Prefetch";
    public static final String TRACE_SCROLL_TAG = "RV Scroll";
    public static final int UNDEFINED_DURATION = Integer.MIN_VALUE;
    public static final boolean VERBOSE_TRACING = false;
    public static final int VERTICAL = 1;
    public static final Interpolator sQuinticInterpolator = new C0131c();
    public RecyclerViewAccessibilityDelegate mAccessibilityDelegate;
    public final AccessibilityManager mAccessibilityManager;
    public C0137g mAdapter;
    public AdapterHelper mAdapterHelper;
    public boolean mAdapterUpdateDuringMeasure;
    public EdgeEffect mBottomGlow;
    public C0140j mChildDrawingOrderCallback;
    public ChildHelper mChildHelper;
    public boolean mClipToPadding;
    public boolean mDataSetHasChangedAfterLayout;
    public boolean mDispatchItemsChangedEvent;
    public int mDispatchScrollCounter;
    public int mEatenAccessibilityChangeFlags;
    public C0141k mEdgeEffectFactory;
    public boolean mEnableFastScroller;
    public boolean mFirstLayoutComplete;
    public GapWorker mGapWorker;
    public boolean mHasFixedSize;
    public boolean mIgnoreMotionEventTillDown;
    public int mInitialTouchX;
    public int mInitialTouchY;
    public int mInterceptRequestLayoutDepth;
    public C0156s mInterceptingOnItemTouchListener;
    public boolean mIsAttached;
    public C0142l mItemAnimator;
    public C0142l.C0144b mItemAnimatorListener;
    public Runnable mItemAnimatorRunner;
    public final ArrayList<C0147n> mItemDecorations;
    public boolean mItemsAddedOrRemoved;
    public boolean mItemsChanged;
    public int mLastTouchX;
    public int mLastTouchY;
    public C0148o mLayout;
    public int mLayoutOrScrollCounter;
    public boolean mLayoutSuppressed;
    public boolean mLayoutWasDefered;
    public EdgeEffect mLeftGlow;
    public final int mMaxFlingVelocity;
    public final int mMinFlingVelocity;
    public final int[] mMinMaxLayoutPositions;
    public final int[] mNestedOffsets;
    public final C0162x mObserver;
    public List<C0154q> mOnChildAttachStateListeners;
    public C0155r mOnFlingListener;
    public final ArrayList<C0156s> mOnItemTouchListeners;
    public final List<C0134d0> mPendingAccessibilityImportanceChange;
    public C0163y mPendingSavedState;
    public boolean mPostedAnimatorRunner;
    public GapWorker.C0565b mPrefetchRegistry;
    public boolean mPreserveFocusAfterLayout;
    public final C0160v mRecycler;
    public C0161w mRecyclerListener;
    public final int[] mReusableIntPair;
    public EdgeEffect mRightGlow;
    public float mScaledHorizontalScrollFactor;
    public float mScaledVerticalScrollFactor;
    public C0157t mScrollListener;
    public List<C0157t> mScrollListeners;
    public final int[] mScrollOffset;
    public int mScrollPointerId;
    public int mScrollState;
    public NestedScrollingChildHelper mScrollingChildHelper;
    public final C0128a0 mState;
    public final Rect mTempRect;
    public final Rect mTempRect2;
    public final RectF mTempRectF;
    public EdgeEffect mTopGlow;
    public int mTouchSlop;
    public final Runnable mUpdateChildViewsRunnable;
    public VelocityTracker mVelocityTracker;
    public final C0132c0 mViewFlinger;
    public final ViewInfoStore.C0576b mViewInfoProcessCallback;
    public final ViewInfoStore mViewInfoStore;

    /* renamed from: androidx.recyclerview.widget.RecyclerView$a */
    public class C0127a implements Runnable {
        public C0127a() {
        }

        public void run() {
            RecyclerView recyclerView = RecyclerView.this;
            if (recyclerView.mFirstLayoutComplete && !recyclerView.isLayoutRequested()) {
                RecyclerView recyclerView2 = RecyclerView.this;
                if (!recyclerView2.mIsAttached) {
                    recyclerView2.requestLayout();
                } else if (recyclerView2.mLayoutSuppressed) {
                    recyclerView2.mLayoutWasDefered = true;
                } else {
                    recyclerView2.consumePendingUpdateOperations();
                }
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$b */
    public class C0129b implements Runnable {
        public C0129b() {
        }

        public void run() {
            C0142l lVar = RecyclerView.this.mItemAnimator;
            if (lVar != null) {
                C0557k kVar = (C0557k) lVar;
                boolean z = !kVar.f3146h.isEmpty();
                boolean z2 = !kVar.f3148j.isEmpty();
                boolean z3 = !kVar.f3149k.isEmpty();
                boolean z4 = !kVar.f3147i.isEmpty();
                if (z || z2 || z4 || z3) {
                    Iterator<C0134d0> it = kVar.f3146h.iterator();
                    while (it.hasNext()) {
                        C0134d0 next = it.next();
                        View view = next.f802a;
                        ViewPropertyAnimator animate = view.animate();
                        kVar.f3155q.add(next);
                        animate.setDuration(kVar.f827d).alpha(0.0f).setListener(new C0552f(kVar, next, animate, view)).start();
                    }
                    kVar.f3146h.clear();
                    if (z2) {
                        ArrayList arrayList = new ArrayList();
                        arrayList.addAll(kVar.f3148j);
                        kVar.f3151m.add(arrayList);
                        kVar.f3148j.clear();
                        DefaultItemAnimator cVar = new DefaultItemAnimator(kVar, arrayList);
                        if (z) {
                            ViewCompat.m1943a(((C0557k.C0559b) arrayList.get(0)).f3163a.f802a, (Runnable) cVar, kVar.f827d);
                        } else {
                            cVar.run();
                        }
                    }
                    if (z3) {
                        ArrayList arrayList2 = new ArrayList();
                        arrayList2.addAll(kVar.f3149k);
                        kVar.f3152n.add(arrayList2);
                        kVar.f3149k.clear();
                        C0550d dVar = new C0550d(kVar, arrayList2);
                        if (z) {
                            ViewCompat.m1943a(((C0557k.C0558a) arrayList2.get(0)).f3157a.f802a, (Runnable) dVar, kVar.f827d);
                        } else {
                            dVar.run();
                        }
                    }
                    if (z4) {
                        ArrayList arrayList3 = new ArrayList();
                        arrayList3.addAll(kVar.f3147i);
                        kVar.f3150l.add(arrayList3);
                        kVar.f3147i.clear();
                        C0551e eVar = new C0551e(kVar, arrayList3);
                        if (z || z2 || z3) {
                            long j = 0;
                            long j2 = z ? kVar.f827d : 0;
                            long j3 = z2 ? kVar.f828e : 0;
                            if (z3) {
                                j = kVar.f829f;
                            }
                            ViewCompat.m1943a(((C0134d0) arrayList3.get(0)).f802a, (Runnable) eVar, Math.max(j3, j) + j2);
                        } else {
                            eVar.run();
                        }
                    }
                }
            }
            RecyclerView.this.mPostedAnimatorRunner = false;
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$b0 */
    public static abstract class C0130b0 {
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$c */
    public static class C0131c implements Interpolator {
        public float getInterpolation(float f) {
            float f2 = f - 1.0f;
            return (f2 * f2 * f2 * f2 * f2) + 1.0f;
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$d */
    public class C0133d implements ViewInfoStore.C0576b {
        public C0133d() {
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$d0 */
    public static abstract class C0134d0 {

        /* renamed from: s */
        public static final List<Object> f801s = Collections.emptyList();

        /* renamed from: a */
        public final View f802a;

        /* renamed from: b */
        public WeakReference<RecyclerView> f803b;

        /* renamed from: c */
        public int f804c = -1;

        /* renamed from: d */
        public int f805d = -1;

        /* renamed from: e */
        public long f806e = -1;

        /* renamed from: f */
        public int f807f = -1;

        /* renamed from: g */
        public int f808g = -1;

        /* renamed from: h */
        public C0134d0 f809h = null;

        /* renamed from: i */
        public C0134d0 f810i = null;

        /* renamed from: j */
        public int f811j;

        /* renamed from: k */
        public List<Object> f812k = null;

        /* renamed from: l */
        public List<Object> f813l = null;

        /* renamed from: m */
        public int f814m = 0;

        /* renamed from: n */
        public C0160v f815n = null;

        /* renamed from: o */
        public boolean f816o = false;

        /* renamed from: p */
        public int f817p = 0;

        /* renamed from: q */
        public int f818q = -1;

        /* renamed from: r */
        public RecyclerView f819r;

        public C0134d0(View view) {
            if (view != null) {
                this.f802a = view;
                return;
            }
            throw new IllegalArgumentException("itemView may not be null");
        }

        /* renamed from: a */
        public void mo1311a(int i, boolean z) {
            if (this.f805d == -1) {
                this.f805d = this.f804c;
            }
            if (this.f808g == -1) {
                this.f808g = this.f804c;
            }
            if (z) {
                this.f808g += i;
            }
            this.f804c += i;
            if (this.f802a.getLayoutParams() != null) {
                ((C0153p) this.f802a.getLayoutParams()).f859c = true;
            }
        }

        /* renamed from: b */
        public void mo1314b() {
            this.f811j &= -33;
        }

        /* renamed from: c */
        public final int mo1316c() {
            RecyclerView recyclerView = this.f819r;
            if (recyclerView == null) {
                return -1;
            }
            return recyclerView.getAdapterPositionFor(this);
        }

        /* renamed from: d */
        public final int mo1317d() {
            int i = this.f808g;
            return i == -1 ? this.f804c : i;
        }

        /* renamed from: e */
        public List<Object> mo1318e() {
            if ((this.f811j & 1024) != 0) {
                return f801s;
            }
            List<Object> list = this.f812k;
            if (list == null || list.size() == 0) {
                return f801s;
            }
            return this.f813l;
        }

        /* renamed from: f */
        public boolean mo1319f() {
            return (this.f802a.getParent() == null || this.f802a.getParent() == this.f819r) ? false : true;
        }

        /* renamed from: g */
        public boolean mo1320g() {
            return (this.f811j & 1) != 0;
        }

        /* renamed from: h */
        public boolean mo1321h() {
            return (this.f811j & 4) != 0;
        }

        /* renamed from: i */
        public final boolean mo1322i() {
            return (this.f811j & 16) == 0 && !ViewCompat.m1976u(this.f802a);
        }

        /* renamed from: j */
        public boolean mo1323j() {
            return (this.f811j & 8) != 0;
        }

        /* renamed from: k */
        public boolean mo1324k() {
            return this.f815n != null;
        }

        /* renamed from: l */
        public boolean mo1325l() {
            return (this.f811j & AnalyticAttribute.ATTRIBUTE_NAME_MAX_LENGTH) != 0;
        }

        /* renamed from: m */
        public boolean mo1326m() {
            return (this.f811j & 2) != 0;
        }

        /* renamed from: n */
        public void mo1327n() {
            this.f811j = 0;
            this.f804c = -1;
            this.f805d = -1;
            this.f806e = -1;
            this.f808g = -1;
            this.f814m = 0;
            this.f809h = null;
            this.f810i = null;
            List<Object> list = this.f812k;
            if (list != null) {
                list.clear();
            }
            this.f811j &= -1025;
            this.f817p = 0;
            this.f818q = -1;
            RecyclerView.clearNestedRecyclerViewIfNotNested(this);
        }

        /* renamed from: o */
        public boolean mo1328o() {
            return (this.f811j & 128) != 0;
        }

        /* renamed from: p */
        public boolean mo1329p() {
            return (this.f811j & 32) != 0;
        }

        public String toString() {
            StringBuilder a = outline.m2938a(getClass().isAnonymousClass() ? "ViewHolder" : getClass().getSimpleName(), "{");
            a.append(Integer.toHexString(hashCode()));
            a.append(" position=");
            a.append(this.f804c);
            a.append(" id=");
            a.append(this.f806e);
            a.append(", oldPos=");
            a.append(this.f805d);
            a.append(", pLpos:");
            a.append(this.f808g);
            StringBuilder sb = new StringBuilder(a.toString());
            if (mo1324k()) {
                sb.append(" scrap ");
                sb.append(this.f816o ? "[changeScrap]" : "[attachedScrap]");
            }
            if (mo1321h()) {
                sb.append(" invalid");
            }
            if (!mo1320g()) {
                sb.append(" unbound");
            }
            boolean z = false;
            if ((this.f811j & 2) != 0) {
                sb.append(" update");
            }
            if (mo1323j()) {
                sb.append(" removed");
            }
            if (mo1328o()) {
                sb.append(" ignored");
            }
            if (mo1325l()) {
                sb.append(" tmpDetached");
            }
            if (!mo1322i()) {
                StringBuilder a2 = outline.m2937a(" not recyclable(");
                a2.append(this.f814m);
                a2.append(")");
                sb.append(a2.toString());
            }
            if ((this.f811j & HarvestConnection.MAX_PLAINTEXT_MESSAGE_SIZE) != 0 || mo1321h()) {
                z = true;
            }
            if (z) {
                sb.append(" undefined adapter position");
            }
            if (this.f802a.getParent() == null) {
                sb.append(" no parent");
            }
            sb.append("}");
            return sb.toString();
        }

        /* renamed from: b */
        public boolean mo1315b(int i) {
            return (i & this.f811j) != 0;
        }

        /* renamed from: a */
        public void mo1308a() {
            this.f805d = -1;
            this.f808g = -1;
        }

        /* renamed from: a */
        public void mo1310a(int i, int i2) {
            this.f811j = (i & i2) | (this.f811j & (~i2));
        }

        /* renamed from: a */
        public void mo1309a(int i) {
            this.f811j = i | this.f811j;
        }

        /* renamed from: a */
        public void mo1312a(Object obj) {
            if (obj == null) {
                mo1309a(1024);
            } else if ((1024 & this.f811j) == 0) {
                if (this.f812k == null) {
                    ArrayList arrayList = new ArrayList();
                    this.f812k = arrayList;
                    this.f813l = Collections.unmodifiableList(arrayList);
                }
                this.f812k.add(obj);
            }
        }

        /* renamed from: a */
        public final void mo1313a(boolean z) {
            int i = this.f814m;
            int i2 = z ? i - 1 : i + 1;
            this.f814m = i2;
            if (i2 < 0) {
                this.f814m = 0;
                Log.e("View", "isRecyclable decremented below 0: unmatched pair of setIsRecyable() calls for " + this);
            } else if (!z && i2 == 1) {
                this.f811j |= 16;
            } else if (z && this.f814m == 0) {
                this.f811j &= -17;
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$e */
    public class C0135e implements ChildHelper.C0549b {
        public C0135e() {
        }

        /* renamed from: a */
        public int mo1331a() {
            return RecyclerView.this.getChildCount();
        }

        /* renamed from: b */
        public void mo1333b(int i) {
            View childAt = RecyclerView.this.getChildAt(i);
            if (childAt != null) {
                RecyclerView.this.dispatchChildDetached(childAt);
                childAt.clearAnimation();
            }
            RecyclerView.this.removeViewAt(i);
        }

        /* renamed from: a */
        public View mo1332a(int i) {
            return RecyclerView.this.getChildAt(i);
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$g */
    public static abstract class C0137g<VH extends C0134d0> {

        /* renamed from: a */
        public final C0138h f822a = new C0138h();

        /* renamed from: b */
        public boolean f823b = false;

        /* renamed from: a */
        public abstract int mo1337a();

        /* renamed from: a */
        public long mo1338a(int i) {
            return -1;
        }

        /* renamed from: a */
        public abstract VH mo1339a(ViewGroup viewGroup, int i);

        /* renamed from: a */
        public abstract void mo1340a(VH vh, int i);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$h */
    public static class C0138h extends Observable<C0139i> {
        /* renamed from: a */
        public boolean mo1341a() {
            return !this.mObservers.isEmpty();
        }

        /* renamed from: b */
        public void mo1342b() {
            for (int size = this.mObservers.size() - 1; size >= 0; size--) {
                C0162x xVar = (C0162x) ((C0139i) this.mObservers.get(size));
                RecyclerView.this.assertNotInLayoutOrScroll((String) null);
                RecyclerView recyclerView = RecyclerView.this;
                recyclerView.mState.f782f = true;
                recyclerView.processDataSetCompletelyChanged(true);
                if (!RecyclerView.this.mAdapterHelper.mo3665c()) {
                    RecyclerView.this.requestLayout();
                }
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$i */
    public static abstract class C0139i {
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$j */
    public interface C0140j {
        /* renamed from: a */
        int mo1343a(int i, int i2);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$k */
    public static class C0141k {
        /* renamed from: a */
        public EdgeEffect mo1344a(RecyclerView recyclerView) {
            return new EdgeEffect(recyclerView.getContext());
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$m */
    public class C0146m implements C0142l.C0144b {
        public C0146m() {
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$n */
    public static abstract class C0147n {
        /* renamed from: a */
        public void mo1354a(Canvas canvas, RecyclerView recyclerView, C0128a0 a0Var) {
        }

        /* renamed from: b */
        public void mo1355b(Canvas canvas, RecyclerView recyclerView, C0128a0 a0Var) {
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$o */
    public static abstract class C0148o {

        /* renamed from: a */
        public ChildHelper f833a;

        /* renamed from: b */
        public RecyclerView f834b;

        /* renamed from: c */
        public final ViewBoundsCheck.C0574b f835c = new C0149a();

        /* renamed from: d */
        public final ViewBoundsCheck.C0574b f836d = new C0150b();

        /* renamed from: e */
        public ViewBoundsCheck f837e = new ViewBoundsCheck(this.f835c);

        /* renamed from: f */
        public ViewBoundsCheck f838f = new ViewBoundsCheck(this.f836d);

        /* renamed from: g */
        public C0165z f839g;

        /* renamed from: h */
        public boolean f840h = false;

        /* renamed from: i */
        public boolean f841i = false;

        /* renamed from: j */
        public boolean f842j = false;

        /* renamed from: k */
        public boolean f843k = true;

        /* renamed from: l */
        public boolean f844l = true;

        /* renamed from: m */
        public int f845m;

        /* renamed from: n */
        public boolean f846n;

        /* renamed from: o */
        public int f847o;

        /* renamed from: p */
        public int f848p;

        /* renamed from: q */
        public int f849q;

        /* renamed from: r */
        public int f850r;

        /* renamed from: androidx.recyclerview.widget.RecyclerView$o$a */
        public class C0149a implements ViewBoundsCheck.C0574b {
            public C0149a() {
            }

            /* renamed from: a */
            public View mo1399a(int i) {
                return C0148o.this.mo1374c(i);
            }

            /* renamed from: b */
            public int mo1400b() {
                return C0148o.this.mo1393j();
            }

            /* renamed from: a */
            public int mo1397a() {
                C0148o oVar = C0148o.this;
                return oVar.f849q - oVar.mo1394k();
            }

            /* renamed from: b */
            public int mo1401b(View view) {
                return C0148o.this.mo1378d(view) - ((C0153p) view.getLayoutParams()).leftMargin;
            }

            /* renamed from: a */
            public int mo1398a(View view) {
                return C0148o.this.mo1387g(view) + ((C0153p) view.getLayoutParams()).rightMargin;
            }
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$o$b */
        public class C0150b implements ViewBoundsCheck.C0574b {
            public C0150b() {
            }

            /* renamed from: a */
            public View mo1399a(int i) {
                return C0148o.this.mo1374c(i);
            }

            /* renamed from: b */
            public int mo1400b() {
                return C0148o.this.mo1395l();
            }

            /* renamed from: a */
            public int mo1397a() {
                C0148o oVar = C0148o.this;
                return oVar.f850r - oVar.mo1391i();
            }

            /* renamed from: b */
            public int mo1401b(View view) {
                return C0148o.this.mo1390h(view) - ((C0153p) view.getLayoutParams()).topMargin;
            }

            /* renamed from: a */
            public int mo1398a(View view) {
                return C0148o.this.mo1373c(view) + ((C0153p) view.getLayoutParams()).bottomMargin;
            }
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$o$c */
        public interface C0151c {
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$o$d */
        public static class C0152d {

            /* renamed from: a */
            public int f853a;

            /* renamed from: b */
            public int f854b;

            /* renamed from: c */
            public boolean f855c;

            /* renamed from: d */
            public boolean f856d;
        }

        /* renamed from: a */
        public int mo1008a(int i, C0160v vVar, C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: a */
        public int mo1049a(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: a */
        public View mo1011a(View view, int i, C0160v vVar, C0128a0 a0Var) {
            return null;
        }

        /* renamed from: a */
        public void mo1356a(int i, int i2) {
            this.f849q = View.MeasureSpec.getSize(i);
            int mode = View.MeasureSpec.getMode(i);
            this.f847o = mode;
            if (mode == 0 && !RecyclerView.ALLOW_SIZE_IN_UNSPECIFIED_SPEC) {
                this.f849q = 0;
            }
            this.f850r = View.MeasureSpec.getSize(i2);
            int mode2 = View.MeasureSpec.getMode(i2);
            this.f848p = mode2;
            if (mode2 == 0 && !RecyclerView.ALLOW_SIZE_IN_UNSPECIFIED_SPEC) {
                this.f850r = 0;
            }
        }

        /* renamed from: a */
        public void mo1054a(int i, int i2, C0128a0 a0Var, C0151c cVar) {
        }

        /* renamed from: a */
        public void mo1056a(int i, C0151c cVar) {
        }

        /* renamed from: a */
        public void mo1057a(Parcelable parcelable) {
        }

        /* renamed from: a */
        public void mo1021a(RecyclerView recyclerView) {
        }

        /* renamed from: a */
        public void mo1022a(RecyclerView recyclerView, int i, int i2) {
        }

        /* renamed from: a */
        public void mo1023a(RecyclerView recyclerView, int i, int i2, int i3) {
        }

        /* renamed from: a */
        public void mo1024a(RecyclerView recyclerView, int i, int i2, Object obj) {
        }

        /* renamed from: a */
        public void mo1063a(RecyclerView recyclerView, C0160v vVar) {
        }

        /* renamed from: a */
        public boolean mo1065a() {
            return false;
        }

        /* renamed from: a */
        public boolean mo1026a(C0153p pVar) {
            return pVar != null;
        }

        /* renamed from: b */
        public int mo1027b(int i, C0160v vVar, C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: b */
        public int mo1028b(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: b */
        public void mo1369b(int i, int i2) {
            int d = mo1377d();
            if (d == 0) {
                this.f834b.defaultOnMeasure(i, i2);
                return;
            }
            int i3 = Integer.MAX_VALUE;
            int i4 = Integer.MAX_VALUE;
            int i5 = RecyclerView.UNDEFINED_DURATION;
            int i6 = RecyclerView.UNDEFINED_DURATION;
            for (int i7 = 0; i7 < d; i7++) {
                View c = mo1374c(i7);
                Rect rect = this.f834b.mTempRect;
                RecyclerView.getDecoratedBoundsWithMarginsInt(c, rect);
                int i8 = rect.left;
                if (i8 < i3) {
                    i3 = i8;
                }
                int i9 = rect.right;
                if (i9 > i5) {
                    i5 = i9;
                }
                int i10 = rect.top;
                if (i10 < i4) {
                    i4 = i10;
                }
                int i11 = rect.bottom;
                if (i11 > i6) {
                    i6 = i11;
                }
            }
            this.f834b.mTempRect.set(i3, i4, i5, i6);
            mo1015a(this.f834b.mTempRect, i, i2);
        }

        /* renamed from: b */
        public void mo1032b(RecyclerView recyclerView, int i, int i2) {
        }

        /* renamed from: b */
        public boolean mo1069b() {
            return false;
        }

        /* renamed from: c */
        public int mo1033c(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: c */
        public abstract C0153p mo1035c();

        /* renamed from: c */
        public void mo1375c(C0160v vVar) {
            int size = vVar.f867a.size();
            for (int i = size - 1; i >= 0; i--) {
                View view = vVar.f867a.get(i).f802a;
                C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(view);
                if (!childViewHolderInt.mo1328o()) {
                    childViewHolderInt.mo1313a(false);
                    if (childViewHolderInt.mo1325l()) {
                        this.f834b.removeDetachedView(view, false);
                    }
                    C0142l lVar = this.f834b.mItemAnimator;
                    if (lVar != null) {
                        lVar.mo1350b(childViewHolderInt);
                    }
                    childViewHolderInt.mo1313a(true);
                    C0134d0 childViewHolderInt2 = RecyclerView.getChildViewHolderInt(view);
                    childViewHolderInt2.f815n = null;
                    childViewHolderInt2.f816o = false;
                    childViewHolderInt2.mo1314b();
                    vVar.mo1419a(childViewHolderInt2);
                }
            }
            vVar.f867a.clear();
            ArrayList<C0134d0> arrayList = vVar.f868b;
            if (arrayList != null) {
                arrayList.clear();
            }
            if (size > 0) {
                this.f834b.invalidate();
            }
        }

        /* renamed from: d */
        public int mo1377d() {
            ChildHelper bVar = this.f833a;
            if (bVar != null) {
                return bVar.mo3670a();
            }
            return 0;
        }

        /* renamed from: d */
        public int mo1072d(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: e */
        public int mo1037e(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: e */
        public View mo1381e() {
            View focusedChild;
            RecyclerView recyclerView = this.f834b;
            if (recyclerView == null || (focusedChild = recyclerView.getFocusedChild()) == null || this.f833a.f3114c.contains(focusedChild)) {
                return null;
            }
            return focusedChild;
        }

        /* renamed from: f */
        public int mo1383f() {
            return ViewCompat.m1966k(this.f834b);
        }

        /* renamed from: f */
        public int mo1039f(C0128a0 a0Var) {
            return 0;
        }

        /* renamed from: f */
        public void mo1385f(int i) {
        }

        /* JADX WARNING: Code restructure failed: missing block: B:2:0x0006, code lost:
            r0 = r3.f833a;
            r4 = r0.mo3678c(r4);
         */
        /* renamed from: g */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public void mo1388g(int r4) {
            /*
                r3 = this;
                android.view.View r0 = r3.mo1374c((int) r4)
                if (r0 == 0) goto L_0x0029
                b.s.d.b r0 = r3.f833a
                int r4 = r0.mo3678c((int) r4)
                b.s.d.b$b r1 = r0.f3112a
                androidx.recyclerview.widget.RecyclerView$e r1 = (androidx.recyclerview.widget.RecyclerView.C0135e) r1
                android.view.View r1 = r1.mo1332a(r4)
                if (r1 != 0) goto L_0x0017
                goto L_0x0029
            L_0x0017:
                b.s.d.b$a r2 = r0.f3113b
                boolean r2 = r2.mo3689d(r4)
                if (r2 == 0) goto L_0x0022
                r0.mo3681d((android.view.View) r1)
            L_0x0022:
                b.s.d.b$b r0 = r0.f3112a
                androidx.recyclerview.widget.RecyclerView$e r0 = (androidx.recyclerview.widget.RecyclerView.C0135e) r0
                r0.mo1333b(r4)
            L_0x0029:
                return
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.C0148o.mo1388g(int):void");
        }

        /* renamed from: g */
        public void mo1040g(C0128a0 a0Var) {
        }

        /* renamed from: h */
        public int mo1390h(View view) {
            return view.getTop() - ((C0153p) view.getLayoutParams()).f858b.top;
        }

        /* renamed from: h */
        public void mo1078h(int i) {
        }

        /* renamed from: i */
        public int mo1392i(View view) {
            return ((C0153p) view.getLayoutParams()).mo1402a();
        }

        /* renamed from: j */
        public int mo1393j() {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                return recyclerView.getPaddingLeft();
            }
            return 0;
        }

        /* renamed from: k */
        public int mo1394k() {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                return recyclerView.getPaddingRight();
            }
            return 0;
        }

        /* renamed from: l */
        public int mo1395l() {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                return recyclerView.getPaddingTop();
            }
            return 0;
        }

        /* renamed from: m */
        public boolean mo1083m() {
            return this.f842j;
        }

        /* renamed from: n */
        public Parcelable mo1084n() {
            return null;
        }

        /* renamed from: o */
        public void mo1396o() {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                recyclerView.requestLayout();
            }
        }

        /* renamed from: p */
        public boolean mo1085p() {
            return false;
        }

        /* renamed from: q */
        public boolean mo1043q() {
            return false;
        }

        /* renamed from: d */
        public void mo1379d(int i) {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                recyclerView.offsetChildrenHorizontal(i);
            }
        }

        /* renamed from: f */
        public int mo1384f(View view) {
            Rect rect = ((C0153p) view.getLayoutParams()).f858b;
            return view.getMeasuredWidth() + rect.left + rect.right;
        }

        /* renamed from: i */
        public int mo1391i() {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                return recyclerView.getPaddingBottom();
            }
            return 0;
        }

        /* renamed from: h */
        public int mo1389h() {
            return ViewCompat.m1968m(this.f834b);
        }

        /* renamed from: d */
        public int mo1378d(View view) {
            return view.getLeft() - ((C0153p) view.getLayoutParams()).f858b.left;
        }

        /* renamed from: e */
        public void mo1382e(int i) {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                recyclerView.offsetChildrenVertical(i);
            }
        }

        /* renamed from: e */
        public int mo1380e(View view) {
            Rect rect = ((C0153p) view.getLayoutParams()).f858b;
            return view.getMeasuredHeight() + rect.top + rect.bottom;
        }

        /* renamed from: g */
        public int mo1387g(View view) {
            return view.getRight() + ((C0153p) view.getLayoutParams()).f858b.right;
        }

        /* renamed from: a */
        public void mo1015a(Rect rect, int i, int i2) {
            int k = mo1394k() + mo1393j() + rect.width();
            int i3 = mo1391i() + mo1395l() + rect.height();
            this.f834b.setMeasuredDimension(m587a(i, k, mo1389h()), m587a(i2, i3, mo1386g()));
        }

        /* renamed from: g */
        public int mo1386g() {
            return ViewCompat.m1967l(this.f834b);
        }

        /* renamed from: b */
        public View mo1368b(View view) {
            View findContainingItemView;
            RecyclerView recyclerView = this.f834b;
            if (recyclerView == null || (findContainingItemView = recyclerView.findContainingItemView(view)) == null || this.f833a.f3114c.contains(findContainingItemView)) {
                return null;
            }
            return findContainingItemView;
        }

        /* renamed from: a */
        public static int m587a(int i, int i2, int i3) {
            int mode = View.MeasureSpec.getMode(i);
            int size = View.MeasureSpec.getSize(i);
            if (mode != Integer.MIN_VALUE) {
                return mode != 1073741824 ? Math.max(i2, i3) : size;
            }
            return Math.min(size, Math.max(i2, i3));
        }

        /* renamed from: b */
        public View mo1067b(int i) {
            int d = mo1377d();
            for (int i2 = 0; i2 < d; i2++) {
                View c = mo1374c(i2);
                C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(c);
                if (childViewHolderInt != null && childViewHolderInt.mo1317d() == i && !childViewHolderInt.mo1328o() && (this.f834b.mState.f783g || !childViewHolderInt.mo1323j())) {
                    return c;
                }
            }
            return null;
        }

        /* renamed from: a */
        public void mo1064a(String str) {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView != null) {
                recyclerView.assertNotInLayoutOrScroll(str);
            }
        }

        /* renamed from: a */
        public C0153p mo1014a(ViewGroup.LayoutParams layoutParams) {
            if (layoutParams instanceof C0153p) {
                return new C0153p((C0153p) layoutParams);
            }
            if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
                return new C0153p((ViewGroup.MarginLayoutParams) layoutParams);
            }
            return new C0153p(layoutParams);
        }

        /* renamed from: c */
        public void mo1376c(RecyclerView recyclerView) {
            if (recyclerView == null) {
                this.f834b = null;
                this.f833a = null;
                this.f849q = 0;
                this.f850r = 0;
            } else {
                this.f834b = recyclerView;
                this.f833a = recyclerView.mChildHelper;
                this.f849q = recyclerView.getWidth();
                this.f850r = recyclerView.getHeight();
            }
            this.f847o = 1073741824;
            this.f848p = 1073741824;
        }

        /* renamed from: b */
        public boolean mo1372b(View view, int i, int i2, C0153p pVar) {
            return !this.f843k || !m590b(view.getMeasuredWidth(), i, pVar.width) || !m590b(view.getMeasuredHeight(), i2, pVar.height);
        }

        /* renamed from: b */
        public static boolean m590b(int i, int i2, int i3) {
            int mode = View.MeasureSpec.getMode(i2);
            int size = View.MeasureSpec.getSize(i2);
            if (i3 > 0 && i != i3) {
                return false;
            }
            if (mode == Integer.MIN_VALUE) {
                return size >= i;
            }
            if (mode != 0) {
                return mode == 1073741824 && size == i;
            }
            return true;
        }

        /* renamed from: a */
        public C0153p mo1013a(Context context, AttributeSet attributeSet) {
            return new C0153p(context, attributeSet);
        }

        /* renamed from: a */
        public void mo1062a(RecyclerView recyclerView, C0128a0 a0Var, int i) {
            Log.e(RecyclerView.TAG, "You must override smoothScrollToPosition to support smooth scrolling");
        }

        /* renamed from: a */
        public void mo1365a(C0165z zVar) {
            C0165z zVar2 = this.f839g;
            if (!(zVar2 == null || zVar == zVar2 || !zVar2.f881e)) {
                zVar2.mo1432a();
            }
            this.f839g = zVar;
            RecyclerView recyclerView = this.f834b;
            if (zVar != null) {
                recyclerView.mViewFlinger.mo1306b();
                if (zVar.f884h) {
                    StringBuilder a = outline.m2937a("An instance of ");
                    a.append(zVar.getClass().getSimpleName());
                    a.append(" was started more than once. Each instance of");
                    a.append(zVar.getClass().getSimpleName());
                    a.append(" is intended to only be used once. You should create a new instance for each use.");
                    Log.w(RecyclerView.TAG, a.toString());
                }
                zVar.f878b = recyclerView;
                zVar.f879c = this;
                int i = zVar.f877a;
                if (i != -1) {
                    recyclerView.mState.f777a = i;
                    zVar.f881e = true;
                    zVar.f880d = true;
                    zVar.f882f = recyclerView.mLayout.mo1067b(i);
                    zVar.f878b.mViewFlinger.mo1304a();
                    zVar.f884h = true;
                    return;
                }
                throw new IllegalArgumentException("Invalid target position");
            }
            throw null;
        }

        /* renamed from: b */
        public void mo1370b(C0160v vVar) {
            for (int d = mo1377d() - 1; d >= 0; d--) {
                if (!RecyclerView.getChildViewHolderInt(mo1374c(d)).mo1328o()) {
                    mo1357a(d, vVar);
                }
            }
        }

        /* renamed from: c */
        public void mo1036c(C0160v vVar, C0128a0 a0Var) {
            Log.e(RecyclerView.TAG, "You must override onLayoutChildren(Recycler recycler, State state) ");
        }

        /* renamed from: b */
        public int mo1029b(C0160v vVar, C0128a0 a0Var) {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView == null || recyclerView.mAdapter == null || !mo1069b()) {
                return 1;
            }
            return this.f834b.mAdapter.mo1337a();
        }

        /* renamed from: c */
        public View mo1374c(int i) {
            ChildHelper bVar = this.f833a;
            if (bVar == null) {
                return null;
            }
            return ((C0135e) bVar.f3112a).mo1332a(bVar.mo3678c(i));
        }

        /* renamed from: b */
        public void mo1371b(RecyclerView recyclerView) {
            mo1356a(View.MeasureSpec.makeMeasureSpec(recyclerView.getWidth(), 1073741824), View.MeasureSpec.makeMeasureSpec(recyclerView.getHeight(), 1073741824));
        }

        /* renamed from: c */
        public int mo1373c(View view) {
            return view.getBottom() + ((C0153p) view.getLayoutParams()).f858b.bottom;
        }

        /* renamed from: a */
        public void mo1358a(View view) {
            mo1360a(view, -1, false);
        }

        /* renamed from: a */
        public final void mo1360a(View view, int i, boolean z) {
            C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(view);
            if (z || childViewHolderInt.mo1323j()) {
                this.f834b.mViewInfoStore.mo3765a(childViewHolderInt);
            } else {
                this.f834b.mViewInfoStore.mo3769c(childViewHolderInt);
            }
            C0153p pVar = (C0153p) view.getLayoutParams();
            if (childViewHolderInt.mo1329p() || childViewHolderInt.mo1324k()) {
                if (childViewHolderInt.mo1324k()) {
                    childViewHolderInt.f815n.mo1424b(childViewHolderInt);
                } else {
                    childViewHolderInt.mo1314b();
                }
                this.f833a.mo3673a(view, i, view.getLayoutParams(), false);
            } else if (view.getParent() == this.f834b) {
                int b = this.f833a.mo3676b(view);
                if (i == -1) {
                    i = this.f833a.mo3670a();
                }
                if (b == -1) {
                    StringBuilder a = outline.m2937a("Added View has RecyclerView as parent but view is not a real child. Unfiltered index:");
                    a.append(this.f834b.indexOfChild(view));
                    throw new IllegalStateException(outline.m2929a(this.f834b, a));
                } else if (b != i) {
                    C0148o oVar = this.f834b.mLayout;
                    View c = oVar.mo1374c(b);
                    if (c != null) {
                        oVar.mo1374c(b);
                        oVar.f833a.mo3671a(b);
                        C0153p pVar2 = (C0153p) c.getLayoutParams();
                        C0134d0 childViewHolderInt2 = RecyclerView.getChildViewHolderInt(c);
                        if (childViewHolderInt2.mo1323j()) {
                            oVar.f834b.mViewInfoStore.mo3765a(childViewHolderInt2);
                        } else {
                            oVar.f834b.mViewInfoStore.mo3769c(childViewHolderInt2);
                        }
                        oVar.f833a.mo3673a(c, i, pVar2, childViewHolderInt2.mo1323j());
                    } else {
                        throw new IllegalArgumentException("Cannot move a child from non-existing index:" + b + oVar.f834b.toString());
                    }
                }
            } else {
                this.f833a.mo3674a(view, i, false);
                pVar.f859c = true;
                C0165z zVar = this.f839g;
                if (zVar != null && zVar.f881e && zVar.f878b.getChildLayoutPosition(view) == zVar.f877a) {
                    zVar.f882f = view;
                }
            }
            if (pVar.f860d) {
                childViewHolderInt.f802a.invalidate();
                pVar.f860d = false;
            }
        }

        /* renamed from: a */
        public void mo1361a(View view, C0160v vVar) {
            ChildHelper bVar = this.f833a;
            int indexOfChild = RecyclerView.this.indexOfChild(view);
            if (indexOfChild >= 0) {
                if (bVar.f3113b.mo3689d(indexOfChild)) {
                    bVar.mo3681d(view);
                }
                ((C0135e) bVar.f3112a).mo1333b(indexOfChild);
            }
            vVar.mo1417a(view);
        }

        /* renamed from: a */
        public void mo1357a(int i, C0160v vVar) {
            View c = mo1374c(i);
            mo1388g(i);
            vVar.mo1417a(c);
        }

        /* renamed from: a */
        public void mo1364a(C0160v vVar) {
            for (int d = mo1377d() - 1; d >= 0; d--) {
                View c = mo1374c(d);
                C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(c);
                if (!childViewHolderInt.mo1328o()) {
                    if (!childViewHolderInt.mo1321h() || childViewHolderInt.mo1323j() || this.f834b.mAdapter.f823b) {
                        mo1374c(d);
                        this.f833a.mo3671a(d);
                        vVar.mo1423b(c);
                        this.f834b.mViewInfoStore.mo3769c(childViewHolderInt);
                    } else {
                        mo1388g(d);
                        vVar.mo1419a(childViewHolderInt);
                    }
                }
            }
        }

        /* renamed from: a */
        public boolean mo1366a(View view, int i, int i2, C0153p pVar) {
            return view.isLayoutRequested() || !this.f843k || !m590b(view.getWidth(), i, pVar.width) || !m590b(view.getHeight(), i2, pVar.height);
        }

        /* JADX WARNING: Code restructure failed: missing block: B:6:0x0017, code lost:
            if (r5 == 1073741824) goto L_0x0021;
         */
        /* renamed from: a */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public static int m588a(int r4, int r5, int r6, int r7, boolean r8) {
            /*
                int r4 = r4 - r6
                r6 = 0
                int r4 = java.lang.Math.max(r6, r4)
                r0 = -2
                r1 = -1
                r2 = -2147483648(0xffffffff80000000, float:-0.0)
                r3 = 1073741824(0x40000000, float:2.0)
                if (r8 == 0) goto L_0x001a
                if (r7 < 0) goto L_0x0011
                goto L_0x001c
            L_0x0011:
                if (r7 != r1) goto L_0x002f
                if (r5 == r2) goto L_0x0021
                if (r5 == 0) goto L_0x002f
                if (r5 == r3) goto L_0x0021
                goto L_0x002f
            L_0x001a:
                if (r7 < 0) goto L_0x001f
            L_0x001c:
                r5 = 1073741824(0x40000000, float:2.0)
                goto L_0x0031
            L_0x001f:
                if (r7 != r1) goto L_0x0023
            L_0x0021:
                r7 = r4
                goto L_0x0031
            L_0x0023:
                if (r7 != r0) goto L_0x002f
                if (r5 == r2) goto L_0x002c
                if (r5 != r3) goto L_0x002a
                goto L_0x002c
            L_0x002a:
                r5 = 0
                goto L_0x0021
            L_0x002c:
                r5 = -2147483648(0xffffffff80000000, float:-0.0)
                goto L_0x0021
            L_0x002f:
                r5 = 0
                r7 = 0
            L_0x0031:
                int r4 = android.view.View.MeasureSpec.makeMeasureSpec(r7, r5)
                return r4
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.C0148o.m588a(int, int, int, int, boolean):int");
        }

        /* renamed from: a */
        public void mo1359a(View view, int i, int i2, int i3, int i4) {
            C0153p pVar = (C0153p) view.getLayoutParams();
            Rect rect = pVar.f858b;
            view.layout(i + rect.left + pVar.leftMargin, i2 + rect.top + pVar.topMargin, (i3 - rect.right) - pVar.rightMargin, (i4 - rect.bottom) - pVar.bottomMargin);
        }

        /* renamed from: a */
        public void mo1363a(View view, boolean z, Rect rect) {
            Matrix matrix;
            if (z) {
                Rect rect2 = ((C0153p) view.getLayoutParams()).f858b;
                rect.set(-rect2.left, -rect2.top, view.getWidth() + rect2.right, view.getHeight() + rect2.bottom);
            } else {
                rect.set(0, 0, view.getWidth(), view.getHeight());
            }
            if (!(this.f834b == null || (matrix = view.getMatrix()) == null || matrix.isIdentity())) {
                RectF rectF = this.f834b.mTempRectF;
                rectF.set(rect);
                matrix.mapRect(rectF);
                rect.set((int) Math.floor((double) rectF.left), (int) Math.floor((double) rectF.top), (int) Math.ceil((double) rectF.right), (int) Math.ceil((double) rectF.bottom));
            }
            rect.offset(view.getLeft(), view.getTop());
        }

        /* JADX WARNING: Code restructure failed: missing block: B:23:0x00b3, code lost:
            if (r14 == false) goto L_0x00ba;
         */
        /* renamed from: a */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public boolean mo1367a(androidx.recyclerview.widget.RecyclerView r10, android.view.View r11, android.graphics.Rect r12, boolean r13, boolean r14) {
            /*
                r9 = this;
                r0 = 2
                int[] r0 = new int[r0]
                int r1 = r9.mo1393j()
                int r2 = r9.mo1395l()
                int r3 = r9.f849q
                int r4 = r9.mo1394k()
                int r3 = r3 - r4
                int r4 = r9.f850r
                int r5 = r9.mo1391i()
                int r4 = r4 - r5
                int r5 = r11.getLeft()
                int r6 = r12.left
                int r5 = r5 + r6
                int r6 = r11.getScrollX()
                int r5 = r5 - r6
                int r6 = r11.getTop()
                int r7 = r12.top
                int r6 = r6 + r7
                int r11 = r11.getScrollY()
                int r6 = r6 - r11
                int r11 = r12.width()
                int r11 = r11 + r5
                int r12 = r12.height()
                int r12 = r12 + r6
                int r5 = r5 - r1
                r1 = 0
                int r7 = java.lang.Math.min(r1, r5)
                int r6 = r6 - r2
                int r2 = java.lang.Math.min(r1, r6)
                int r11 = r11 - r3
                int r3 = java.lang.Math.max(r1, r11)
                int r12 = r12 - r4
                int r12 = java.lang.Math.max(r1, r12)
                int r4 = r9.mo1383f()
                r8 = 1
                if (r4 != r8) goto L_0x005f
                if (r3 == 0) goto L_0x005a
                goto L_0x0067
            L_0x005a:
                int r3 = java.lang.Math.max(r7, r11)
                goto L_0x0067
            L_0x005f:
                if (r7 == 0) goto L_0x0062
                goto L_0x0066
            L_0x0062:
                int r7 = java.lang.Math.min(r5, r3)
            L_0x0066:
                r3 = r7
            L_0x0067:
                if (r2 == 0) goto L_0x006a
                goto L_0x006e
            L_0x006a:
                int r2 = java.lang.Math.min(r6, r12)
            L_0x006e:
                r0[r1] = r3
                r0[r8] = r2
                r11 = r0[r1]
                r12 = r0[r8]
                if (r14 == 0) goto L_0x00b5
                android.view.View r14 = r10.getFocusedChild()
                if (r14 != 0) goto L_0x0080
            L_0x007e:
                r14 = 0
                goto L_0x00b3
            L_0x0080:
                int r0 = r9.mo1393j()
                int r2 = r9.mo1395l()
                int r3 = r9.f849q
                int r4 = r9.mo1394k()
                int r3 = r3 - r4
                int r4 = r9.f850r
                int r5 = r9.mo1391i()
                int r4 = r4 - r5
                androidx.recyclerview.widget.RecyclerView r5 = r9.f834b
                android.graphics.Rect r5 = r5.mTempRect
                androidx.recyclerview.widget.RecyclerView.getDecoratedBoundsWithMarginsInt(r14, r5)
                int r14 = r5.left
                int r14 = r14 - r11
                if (r14 >= r3) goto L_0x007e
                int r14 = r5.right
                int r14 = r14 - r11
                if (r14 <= r0) goto L_0x007e
                int r14 = r5.top
                int r14 = r14 - r12
                if (r14 >= r4) goto L_0x007e
                int r14 = r5.bottom
                int r14 = r14 - r12
                if (r14 > r2) goto L_0x00b2
                goto L_0x007e
            L_0x00b2:
                r14 = 1
            L_0x00b3:
                if (r14 == 0) goto L_0x00ba
            L_0x00b5:
                if (r11 != 0) goto L_0x00bb
                if (r12 == 0) goto L_0x00ba
                goto L_0x00bb
            L_0x00ba:
                return r1
            L_0x00bb:
                if (r13 == 0) goto L_0x00c1
                r10.scrollBy(r11, r12)
                goto L_0x00c4
            L_0x00c1:
                r10.smoothScrollBy(r11, r12)
            L_0x00c4:
                return r8
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.C0148o.mo1367a(androidx.recyclerview.widget.RecyclerView, android.view.View, android.graphics.Rect, boolean, boolean):boolean");
        }

        /* renamed from: a */
        public void mo1058a(AccessibilityEvent accessibilityEvent) {
            RecyclerView recyclerView = this.f834b;
            C0160v vVar = recyclerView.mRecycler;
            C0128a0 a0Var = recyclerView.mState;
            if (recyclerView != null && accessibilityEvent != null) {
                boolean z = true;
                if (!recyclerView.canScrollVertically(1) && !this.f834b.canScrollVertically(-1) && !this.f834b.canScrollHorizontally(-1) && !this.f834b.canScrollHorizontally(1)) {
                    z = false;
                }
                accessibilityEvent.setScrollable(z);
                C0137g gVar = this.f834b.mAdapter;
                if (gVar != null) {
                    accessibilityEvent.setItemCount(gVar.mo1337a());
                }
            }
        }

        /* renamed from: a */
        public void mo1362a(View view, AccessibilityNodeInfoCompat bVar) {
            C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(view);
            if (childViewHolderInt != null && !childViewHolderInt.mo1323j() && !this.f833a.mo3679c(childViewHolderInt.f802a)) {
                RecyclerView recyclerView = this.f834b;
                mo1018a(recyclerView.mRecycler, recyclerView.mState, view, bVar);
            }
        }

        /* renamed from: a */
        public void mo1018a(C0160v vVar, C0128a0 a0Var, View view, AccessibilityNodeInfoCompat bVar) {
            bVar.mo3171b((Object) AccessibilityNodeInfoCompat.C0413c.m2033a(mo1069b() ? mo1392i(view) : 0, 1, mo1065a() ? mo1392i(view) : 0, 1, false, false));
        }

        /* renamed from: a */
        public int mo1009a(C0160v vVar, C0128a0 a0Var) {
            RecyclerView recyclerView = this.f834b;
            if (recyclerView == null || recyclerView.mAdapter == null || !mo1065a()) {
                return 1;
            }
            return this.f834b.mAdapter.mo1337a();
        }

        /* renamed from: a */
        public static C0152d m589a(Context context, AttributeSet attributeSet, int i, int i2) {
            C0152d dVar = new C0152d();
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, C0545c.RecyclerView, i, i2);
            dVar.f853a = obtainStyledAttributes.getInt(C0545c.RecyclerView_android_orientation, 1);
            dVar.f854b = obtainStyledAttributes.getInt(C0545c.RecyclerView_spanCount, 1);
            dVar.f855c = obtainStyledAttributes.getBoolean(C0545c.RecyclerView_reverseLayout, false);
            dVar.f856d = obtainStyledAttributes.getBoolean(C0545c.RecyclerView_stackFromEnd, false);
            obtainStyledAttributes.recycle();
            return dVar;
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$q */
    public interface C0154q {
        /* renamed from: a */
        void mo1405a(View view);

        /* renamed from: b */
        void mo1406b(View view);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$r */
    public static abstract class C0155r {
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$s */
    public interface C0156s {
        /* renamed from: a */
        void mo1407a(boolean z);

        /* renamed from: a */
        boolean mo1408a(RecyclerView recyclerView, MotionEvent motionEvent);

        /* renamed from: b */
        void mo1409b(RecyclerView recyclerView, MotionEvent motionEvent);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$t */
    public static abstract class C0157t {
        /* renamed from: a */
        public void mo1410a(RecyclerView recyclerView, int i) {
        }

        /* renamed from: a */
        public void mo1411a(RecyclerView recyclerView, int i, int i2) {
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$u */
    public static class C0158u {

        /* renamed from: a */
        public SparseArray<C0159a> f861a = new SparseArray<>();

        /* renamed from: b */
        public int f862b = 0;

        /* renamed from: androidx.recyclerview.widget.RecyclerView$u$a */
        public static class C0159a {

            /* renamed from: a */
            public final ArrayList<C0134d0> f863a = new ArrayList<>();

            /* renamed from: b */
            public int f864b = 5;

            /* renamed from: c */
            public long f865c = 0;

            /* renamed from: d */
            public long f866d = 0;
        }

        /* renamed from: a */
        public long mo1412a(long j, long j2) {
            if (j == 0) {
                return j2;
            }
            return (j2 / 4) + ((j / 4) * 3);
        }

        /* renamed from: a */
        public final C0159a mo1413a(int i) {
            C0159a aVar = this.f861a.get(i);
            if (aVar != null) {
                return aVar;
            }
            C0159a aVar2 = new C0159a();
            this.f861a.put(i, aVar2);
            return aVar2;
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$w */
    public interface C0161w {
        /* renamed from: a */
        void mo1427a(C0134d0 d0Var);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$x */
    public class C0162x extends C0139i {
        public C0162x() {
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r1v4, resolved type: java.lang.Class<?>[]} */
    /* JADX WARNING: Multi-variable type inference failed */
    static {
        /*
            r0 = 1
            int[] r1 = new int[r0]
            r2 = 16843830(0x1010436, float:2.369658E-38)
            r3 = 0
            r1[r3] = r2
            NESTED_SCROLLING_ATTRS = r1
            int r1 = android.os.Build.VERSION.SDK_INT
            r2 = 23
            if (r1 < r2) goto L_0x0013
            r1 = 1
            goto L_0x0014
        L_0x0013:
            r1 = 0
        L_0x0014:
            ALLOW_SIZE_IN_UNSPECIFIED_SPEC = r1
            POST_UPDATES_ON_ANIMATION = r0
            ALLOW_THREAD_GAP_WORK = r0
            FORCE_ABS_FOCUS_SEARCH_DIRECTION = r3
            IGNORE_DETACHED_FOCUSED_CHILD = r3
            r1 = 4
            java.lang.Class[] r1 = new java.lang.Class[r1]
            java.lang.Class<android.content.Context> r2 = android.content.Context.class
            r1[r3] = r2
            java.lang.Class<android.util.AttributeSet> r2 = android.util.AttributeSet.class
            r1[r0] = r2
            r0 = 2
            java.lang.Class r2 = java.lang.Integer.TYPE
            r1[r0] = r2
            r0 = 3
            r1[r0] = r2
            LAYOUT_MANAGER_CONSTRUCTOR_SIGNATURE = r1
            androidx.recyclerview.widget.RecyclerView$c r0 = new androidx.recyclerview.widget.RecyclerView$c
            r0.<init>()
            sQuinticInterpolator = r0
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.<clinit>():void");
    }

    public RecyclerView(Context context) {
        this(context, (AttributeSet) null);
    }

    private void addAnimatingView(C0134d0 d0Var) {
        View view = d0Var.f802a;
        boolean z = view.getParent() == this;
        this.mRecycler.mo1424b(getChildViewHolder(view));
        if (d0Var.mo1325l()) {
            this.mChildHelper.mo3673a(view, -1, view.getLayoutParams(), true);
        } else if (!z) {
            this.mChildHelper.mo3674a(view, -1, true);
        } else {
            ChildHelper bVar = this.mChildHelper;
            int indexOfChild = RecyclerView.this.indexOfChild(view);
            if (indexOfChild >= 0) {
                bVar.f3113b.mo3690e(indexOfChild);
                bVar.mo3672a(view);
                return;
            }
            throw new IllegalArgumentException("view is not a child, cannot hide " + view);
        }
    }

    private void animateChange(C0134d0 d0Var, C0134d0 d0Var2, C0142l.C0145c cVar, C0142l.C0145c cVar2, boolean z, boolean z2) {
        d0Var.mo1313a(false);
        if (z) {
            addAnimatingView(d0Var);
        }
        if (d0Var != d0Var2) {
            if (z2) {
                addAnimatingView(d0Var2);
            }
            d0Var.f809h = d0Var2;
            addAnimatingView(d0Var);
            this.mRecycler.mo1424b(d0Var);
            d0Var2.mo1313a(false);
            d0Var2.f810i = d0Var;
        }
        if (this.mItemAnimator.mo1347a(d0Var, d0Var2, cVar, cVar2)) {
            postAnimationRunner();
        }
    }

    private void cancelScroll() {
        resetScroll();
        setScrollState(0);
    }

    public static void clearNestedRecyclerViewIfNotNested(C0134d0 d0Var) {
        WeakReference<RecyclerView> weakReference = d0Var.f803b;
        if (weakReference != null) {
            View view = (View) weakReference.get();
            while (view != null) {
                if (view != d0Var.f802a) {
                    ViewParent parent = view.getParent();
                    view = parent instanceof View ? (View) parent : null;
                } else {
                    return;
                }
            }
            d0Var.f803b = null;
        }
    }

    private void createLayoutManager(Context context, String str, AttributeSet attributeSet, int i, int i2) {
        ClassLoader classLoader;
        Constructor<? extends U> constructor;
        if (str != null) {
            String trim = str.trim();
            if (!trim.isEmpty()) {
                String fullClassName = getFullClassName(context, trim);
                try {
                    if (isInEditMode()) {
                        classLoader = getClass().getClassLoader();
                    } else {
                        classLoader = context.getClassLoader();
                    }
                    Class<? extends U> asSubclass = Class.forName(fullClassName, false, classLoader).asSubclass(C0148o.class);
                    Object[] objArr = null;
                    try {
                        constructor = asSubclass.getConstructor(LAYOUT_MANAGER_CONSTRUCTOR_SIGNATURE);
                        objArr = new Object[]{context, attributeSet, Integer.valueOf(i), Integer.valueOf(i2)};
                    } catch (NoSuchMethodException e) {
                        constructor = asSubclass.getConstructor(new Class[0]);
                    }
                    constructor.setAccessible(true);
                    setLayoutManager((C0148o) constructor.newInstance(objArr));
                } catch (NoSuchMethodException e2) {
                    e2.initCause(e);
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Error creating LayoutManager " + fullClassName, e2);
                } catch (ClassNotFoundException e3) {
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Unable to find LayoutManager " + fullClassName, e3);
                } catch (InvocationTargetException e4) {
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Could not instantiate the LayoutManager: " + fullClassName, e4);
                } catch (InstantiationException e5) {
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Could not instantiate the LayoutManager: " + fullClassName, e5);
                } catch (IllegalAccessException e6) {
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Cannot access non-public constructor " + fullClassName, e6);
                } catch (ClassCastException e7) {
                    throw new IllegalStateException(attributeSet.getPositionDescription() + ": Class is not a LayoutManager " + fullClassName, e7);
                }
            }
        }
    }

    private boolean didChildRangeChange(int i, int i2) {
        findMinMaxChildLayoutPositions(this.mMinMaxLayoutPositions);
        int[] iArr = this.mMinMaxLayoutPositions;
        return (iArr[0] == i && iArr[1] == i2) ? false : true;
    }

    private void dispatchContentChangedIfNecessary() {
        int i = this.mEatenAccessibilityChangeFlags;
        this.mEatenAccessibilityChangeFlags = 0;
        if (i != 0 && isAccessibilityEnabled()) {
            AccessibilityEvent obtain = AccessibilityEvent.obtain();
            obtain.setEventType(HarvestConfiguration.DEFAULT_RESPONSE_BODY_LIMIT);
            obtain.setContentChangeTypes(i);
            sendAccessibilityEventUnchecked(obtain);
        }
    }

    private void dispatchLayoutStep1() {
        this.mState.mo1300a(1);
        fillRemainingScrollValues(this.mState);
        this.mState.f785i = false;
        startInterceptRequestLayout();
        ViewInfoStore zVar = this.mViewInfoStore;
        zVar.f3260a.clear();
        zVar.f3261b.mo2720a();
        onEnterLayoutOrScroll();
        processAdapterUpdatesAndSetAnimationFlags();
        saveFocusInfo();
        C0128a0 a0Var = this.mState;
        a0Var.f784h = a0Var.f786j && this.mItemsChanged;
        this.mItemsChanged = false;
        this.mItemsAddedOrRemoved = false;
        C0128a0 a0Var2 = this.mState;
        a0Var2.f783g = a0Var2.f787k;
        a0Var2.f781e = this.mAdapter.mo1337a();
        findMinMaxChildLayoutPositions(this.mMinMaxLayoutPositions);
        if (this.mState.f786j) {
            int a = this.mChildHelper.mo3670a();
            for (int i = 0; i < a; i++) {
                C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3677b(i));
                if (!childViewHolderInt.mo1328o() && (!childViewHolderInt.mo1321h() || this.mAdapter.f823b)) {
                    C0142l lVar = this.mItemAnimator;
                    C0142l.m575d(childViewHolderInt);
                    childViewHolderInt.mo1318e();
                    this.mViewInfoStore.mo3767b(childViewHolderInt, lVar.mo1351c(childViewHolderInt));
                    if (this.mState.f784h && childViewHolderInt.mo1326m() && !childViewHolderInt.mo1323j() && !childViewHolderInt.mo1328o() && !childViewHolderInt.mo1321h()) {
                        this.mViewInfoStore.f3261b.mo2725c(getChangedHolderKey(childViewHolderInt), childViewHolderInt);
                    }
                }
            }
        }
        if (this.mState.f787k) {
            saveOldPositions();
            C0128a0 a0Var3 = this.mState;
            boolean z = a0Var3.f782f;
            a0Var3.f782f = false;
            this.mLayout.mo1036c(this.mRecycler, a0Var3);
            this.mState.f782f = z;
            for (int i2 = 0; i2 < this.mChildHelper.mo3670a(); i2++) {
                C0134d0 childViewHolderInt2 = getChildViewHolderInt(this.mChildHelper.mo3677b(i2));
                if (!childViewHolderInt2.mo1328o()) {
                    ViewInfoStore.C0575a orDefault = this.mViewInfoStore.f3260a.getOrDefault(childViewHolderInt2, null);
                    if (!((orDefault == null || (orDefault.f3263a & 4) == 0) ? false : true)) {
                        C0142l.m575d(childViewHolderInt2);
                        boolean b = childViewHolderInt2.mo1315b(HarvestConnection.RESPONSE_BUFFER_SIZE);
                        C0142l lVar2 = this.mItemAnimator;
                        childViewHolderInt2.mo1318e();
                        C0142l.C0145c c = lVar2.mo1351c(childViewHolderInt2);
                        if (b) {
                            recordAnimationInfoIfBouncedHiddenView(childViewHolderInt2, c);
                        } else {
                            ViewInfoStore zVar2 = this.mViewInfoStore;
                            ViewInfoStore.C0575a orDefault2 = zVar2.f3260a.getOrDefault(childViewHolderInt2, null);
                            if (orDefault2 == null) {
                                orDefault2 = ViewInfoStore.C0575a.m2653a();
                                zVar2.f3260a.put(childViewHolderInt2, orDefault2);
                            }
                            orDefault2.f3263a |= 2;
                            orDefault2.f3264b = c;
                        }
                    }
                }
            }
            clearOldPositions();
        } else {
            clearOldPositions();
        }
        onExitLayoutOrScroll();
        stopInterceptRequestLayout(false);
        this.mState.f780d = 2;
    }

    private void dispatchLayoutStep2() {
        startInterceptRequestLayout();
        onEnterLayoutOrScroll();
        this.mState.mo1300a(6);
        this.mAdapterHelper.mo3662b();
        this.mState.f781e = this.mAdapter.mo1337a();
        C0128a0 a0Var = this.mState;
        a0Var.f779c = 0;
        a0Var.f783g = false;
        this.mLayout.mo1036c(this.mRecycler, a0Var);
        C0128a0 a0Var2 = this.mState;
        a0Var2.f782f = false;
        this.mPendingSavedState = null;
        a0Var2.f786j = a0Var2.f786j && this.mItemAnimator != null;
        this.mState.f780d = 4;
        onExitLayoutOrScroll();
        stopInterceptRequestLayout(false);
    }

    private void dispatchLayoutStep3() {
        boolean z;
        this.mState.mo1300a(4);
        startInterceptRequestLayout();
        onEnterLayoutOrScroll();
        C0128a0 a0Var = this.mState;
        a0Var.f780d = 1;
        if (a0Var.f786j) {
            for (int a = this.mChildHelper.mo3670a() - 1; a >= 0; a--) {
                C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3677b(a));
                if (!childViewHolderInt.mo1328o()) {
                    long changedHolderKey = getChangedHolderKey(childViewHolderInt);
                    if (this.mItemAnimator != null) {
                        C0142l.C0145c cVar = new C0142l.C0145c();
                        View view = childViewHolderInt.f802a;
                        cVar.f830a = view.getLeft();
                        cVar.f831b = view.getTop();
                        view.getRight();
                        view.getBottom();
                        C0134d0 b = this.mViewInfoStore.f3261b.mo2722b(changedHolderKey, null);
                        if (b == null || b.mo1328o()) {
                            this.mViewInfoStore.mo3766a(childViewHolderInt, cVar);
                        } else {
                            boolean b2 = this.mViewInfoStore.mo3768b(b);
                            boolean b3 = this.mViewInfoStore.mo3768b(childViewHolderInt);
                            if (!b2 || b != childViewHolderInt) {
                                C0142l.C0145c a2 = this.mViewInfoStore.mo3764a(b, 4);
                                this.mViewInfoStore.mo3766a(childViewHolderInt, cVar);
                                C0142l.C0145c a3 = this.mViewInfoStore.mo3764a(childViewHolderInt, 8);
                                if (a2 == null) {
                                    handleMissingPreInfoForChangeError(changedHolderKey, childViewHolderInt, b);
                                } else {
                                    animateChange(b, childViewHolderInt, a2, a3, b2, b3);
                                }
                            } else {
                                this.mViewInfoStore.mo3766a(childViewHolderInt, cVar);
                            }
                        }
                    } else {
                        throw null;
                    }
                }
            }
            ViewInfoStore zVar = this.mViewInfoStore;
            ViewInfoStore.C0576b bVar = this.mViewInfoProcessCallback;
            int i = zVar.f3260a.f1923d;
            while (true) {
                i--;
                if (i < 0) {
                    break;
                }
                C0134d0 c = zVar.f3260a.mo2797c(i);
                ViewInfoStore.C0575a d = zVar.f3260a.mo2801d(i);
                int i2 = d.f3263a;
                if ((i2 & 3) == 3) {
                    RecyclerView recyclerView = RecyclerView.this;
                    recyclerView.mLayout.mo1361a(c.f802a, recyclerView.mRecycler);
                } else if ((i2 & 1) != 0) {
                    C0142l.C0145c cVar2 = d.f3264b;
                    if (cVar2 == null) {
                        RecyclerView recyclerView2 = RecyclerView.this;
                        recyclerView2.mLayout.mo1361a(c.f802a, recyclerView2.mRecycler);
                    } else {
                        C0142l.C0145c cVar3 = d.f3265c;
                        C0133d dVar = (C0133d) bVar;
                        RecyclerView.this.mRecycler.mo1424b(c);
                        RecyclerView.this.animateDisappearance(c, cVar2, cVar3);
                    }
                } else if ((i2 & 14) == 14) {
                    RecyclerView.this.animateAppearance(c, d.f3264b, d.f3265c);
                } else if ((i2 & 12) == 12) {
                    C0142l.C0145c cVar4 = d.f3264b;
                    C0142l.C0145c cVar5 = d.f3265c;
                    C0133d dVar2 = (C0133d) bVar;
                    if (dVar2 != null) {
                        c.mo1313a(false);
                        RecyclerView recyclerView3 = RecyclerView.this;
                        if (!recyclerView3.mDataSetHasChangedAfterLayout) {
                            SimpleItemAnimator vVar = (SimpleItemAnimator) recyclerView3.mItemAnimator;
                            if (vVar != null) {
                                if (cVar4.f830a == cVar5.f830a && cVar4.f831b == cVar5.f831b) {
                                    vVar.mo1346a(c);
                                    z = false;
                                } else {
                                    z = vVar.mo3709a(c, cVar4.f830a, cVar4.f831b, cVar5.f830a, cVar5.f831b);
                                }
                                if (z) {
                                    RecyclerView.this.postAnimationRunner();
                                }
                            } else {
                                throw null;
                            }
                        } else if (recyclerView3.mItemAnimator.mo1347a(c, c, cVar4, cVar5)) {
                            RecyclerView.this.postAnimationRunner();
                        }
                    } else {
                        throw null;
                    }
                } else if ((i2 & 4) != 0) {
                    C0142l.C0145c cVar6 = d.f3264b;
                    C0133d dVar3 = (C0133d) bVar;
                    RecyclerView.this.mRecycler.mo1424b(c);
                    RecyclerView.this.animateDisappearance(c, cVar6, (C0142l.C0145c) null);
                } else if ((i2 & 8) != 0) {
                    RecyclerView.this.animateAppearance(c, d.f3264b, d.f3265c);
                }
                ViewInfoStore.C0575a.m2654a(d);
            }
        }
        this.mLayout.mo1375c(this.mRecycler);
        C0128a0 a0Var2 = this.mState;
        a0Var2.f778b = a0Var2.f781e;
        this.mDataSetHasChangedAfterLayout = false;
        this.mDispatchItemsChangedEvent = false;
        a0Var2.f786j = false;
        a0Var2.f787k = false;
        this.mLayout.f840h = false;
        ArrayList<C0134d0> arrayList = this.mRecycler.f868b;
        if (arrayList != null) {
            arrayList.clear();
        }
        C0148o oVar = this.mLayout;
        if (oVar.f846n) {
            oVar.f845m = 0;
            oVar.f846n = false;
            this.mRecycler.mo1426d();
        }
        this.mLayout.mo1040g(this.mState);
        onExitLayoutOrScroll();
        stopInterceptRequestLayout(false);
        ViewInfoStore zVar2 = this.mViewInfoStore;
        zVar2.f3260a.clear();
        zVar2.f3261b.mo2720a();
        int[] iArr = this.mMinMaxLayoutPositions;
        if (didChildRangeChange(iArr[0], iArr[1])) {
            dispatchOnScrolled(0, 0);
        }
        recoverFocusFromState();
        resetFocusInfo();
    }

    private boolean dispatchToOnItemTouchListeners(MotionEvent motionEvent) {
        C0156s sVar = this.mInterceptingOnItemTouchListener;
        if (sVar != null) {
            sVar.mo1409b(this, motionEvent);
            int action = motionEvent.getAction();
            if (action == 3 || action == 1) {
                this.mInterceptingOnItemTouchListener = null;
            }
            return true;
        } else if (motionEvent.getAction() == 0) {
            return false;
        } else {
            return findInterceptingOnItemTouchListener(motionEvent);
        }
    }

    private boolean findInterceptingOnItemTouchListener(MotionEvent motionEvent) {
        int action = motionEvent.getAction();
        int size = this.mOnItemTouchListeners.size();
        int i = 0;
        while (i < size) {
            C0156s sVar = this.mOnItemTouchListeners.get(i);
            if (!sVar.mo1408a(this, motionEvent) || action == 3) {
                i++;
            } else {
                this.mInterceptingOnItemTouchListener = sVar;
                return true;
            }
        }
        return false;
    }

    private void findMinMaxChildLayoutPositions(int[] iArr) {
        int a = this.mChildHelper.mo3670a();
        if (a == 0) {
            iArr[0] = -1;
            iArr[1] = -1;
            return;
        }
        int i = Integer.MAX_VALUE;
        int i2 = UNDEFINED_DURATION;
        for (int i3 = 0; i3 < a; i3++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3677b(i3));
            if (!childViewHolderInt.mo1328o()) {
                int d = childViewHolderInt.mo1317d();
                if (d < i) {
                    i = d;
                }
                if (d > i2) {
                    i2 = d;
                }
            }
        }
        iArr[0] = i;
        iArr[1] = i2;
    }

    public static RecyclerView findNestedRecyclerView(View view) {
        if (!(view instanceof ViewGroup)) {
            return null;
        }
        if (view instanceof RecyclerView) {
            return (RecyclerView) view;
        }
        ViewGroup viewGroup = (ViewGroup) view;
        int childCount = viewGroup.getChildCount();
        for (int i = 0; i < childCount; i++) {
            RecyclerView findNestedRecyclerView = findNestedRecyclerView(viewGroup.getChildAt(i));
            if (findNestedRecyclerView != null) {
                return findNestedRecyclerView;
            }
        }
        return null;
    }

    private View findNextViewToFocus() {
        C0134d0 findViewHolderForAdapterPosition;
        int i = this.mState.f788l;
        if (i == -1) {
            i = 0;
        }
        int a = this.mState.mo1299a();
        int i2 = i;
        while (i2 < a) {
            C0134d0 findViewHolderForAdapterPosition2 = findViewHolderForAdapterPosition(i2);
            if (findViewHolderForAdapterPosition2 == null) {
                break;
            } else if (findViewHolderForAdapterPosition2.f802a.hasFocusable()) {
                return findViewHolderForAdapterPosition2.f802a;
            } else {
                i2++;
            }
        }
        int min = Math.min(a, i);
        while (true) {
            min--;
            if (min < 0 || (findViewHolderForAdapterPosition = findViewHolderForAdapterPosition(min)) == null) {
                return null;
            }
            if (findViewHolderForAdapterPosition.f802a.hasFocusable()) {
                return findViewHolderForAdapterPosition.f802a;
            }
        }
    }

    public static C0134d0 getChildViewHolderInt(View view) {
        if (view == null) {
            return null;
        }
        return ((C0153p) view.getLayoutParams()).f857a;
    }

    public static void getDecoratedBoundsWithMarginsInt(View view, Rect rect) {
        C0153p pVar = (C0153p) view.getLayoutParams();
        Rect rect2 = pVar.f858b;
        rect.set((view.getLeft() - rect2.left) - pVar.leftMargin, (view.getTop() - rect2.top) - pVar.topMargin, view.getRight() + rect2.right + pVar.rightMargin, view.getBottom() + rect2.bottom + pVar.bottomMargin);
    }

    private int getDeepestFocusedViewWithId(View view) {
        int id = view.getId();
        while (!view.isFocused() && (view instanceof ViewGroup) && view.hasFocus()) {
            view = ((ViewGroup) view).getFocusedChild();
            if (view.getId() != -1) {
                id = view.getId();
            }
        }
        return id;
    }

    private String getFullClassName(Context context, String str) {
        if (str.charAt(0) == '.') {
            return context.getPackageName() + str;
        } else if (str.contains(".")) {
            return str;
        } else {
            return RecyclerView.class.getPackage().getName() + '.' + str;
        }
    }

    private NestedScrollingChildHelper getScrollingChildHelper() {
        if (this.mScrollingChildHelper == null) {
            this.mScrollingChildHelper = new NestedScrollingChildHelper(this);
        }
        return this.mScrollingChildHelper;
    }

    private void handleMissingPreInfoForChangeError(long j, C0134d0 d0Var, C0134d0 d0Var2) {
        int a = this.mChildHelper.mo3670a();
        for (int i = 0; i < a; i++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3677b(i));
            if (childViewHolderInt != d0Var && getChangedHolderKey(childViewHolderInt) == j) {
                C0137g gVar = this.mAdapter;
                if (gVar == null || !gVar.f823b) {
                    StringBuilder sb = new StringBuilder();
                    sb.append("Two different ViewHolders have the same change ID. This might happen due to inconsistent Adapter update events or if the LayoutManager lays out the same View multiple times.\n ViewHolder 1:");
                    sb.append(childViewHolderInt);
                    sb.append(" \n View Holder 2:");
                    sb.append(d0Var);
                    throw new IllegalStateException(outline.m2929a(this, sb));
                }
                StringBuilder sb2 = new StringBuilder();
                sb2.append("Two different ViewHolders have the same stable ID. Stable IDs in your adapter MUST BE unique and SHOULD NOT change.\n ViewHolder 1:");
                sb2.append(childViewHolderInt);
                sb2.append(" \n View Holder 2:");
                sb2.append(d0Var);
                throw new IllegalStateException(outline.m2929a(this, sb2));
            }
        }
        Log.e(TAG, "Problem while matching changed view holders with the newones. The pre-layout information for the change holder " + d0Var2 + " cannot be found but it is necessary for " + d0Var + exceptionLabel());
    }

    private boolean hasUpdatedView() {
        int a = this.mChildHelper.mo3670a();
        for (int i = 0; i < a; i++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3677b(i));
            if (childViewHolderInt != null && !childViewHolderInt.mo1328o() && childViewHolderInt.mo1326m()) {
                return true;
            }
        }
        return false;
    }

    @SuppressLint({"InlinedApi"})
    private void initAutofill() {
        if (ViewCompat.m1965j(this) == 0 && Build.VERSION.SDK_INT >= 26) {
            setImportantForAutofill(8);
        }
    }

    private void initChildrenHelper() {
        this.mChildHelper = new ChildHelper(new C0135e());
    }

    private boolean isPreferredNextFocus(View view, View view2, int i) {
        int i2;
        if (view2 == null || view2 == this || findContainingItemView(view2) == null) {
            return false;
        }
        if (view == null || findContainingItemView(view) == null) {
            return true;
        }
        this.mTempRect.set(0, 0, view.getWidth(), view.getHeight());
        this.mTempRect2.set(0, 0, view2.getWidth(), view2.getHeight());
        offsetDescendantRectToMyCoords(view, this.mTempRect);
        offsetDescendantRectToMyCoords(view2, this.mTempRect2);
        char c = 65535;
        int i3 = this.mLayout.mo1383f() == 1 ? -1 : 1;
        Rect rect = this.mTempRect;
        int i4 = rect.left;
        int i5 = this.mTempRect2.left;
        if ((i4 < i5 || rect.right <= i5) && this.mTempRect.right < this.mTempRect2.right) {
            i2 = 1;
        } else {
            Rect rect2 = this.mTempRect;
            int i6 = rect2.right;
            int i7 = this.mTempRect2.right;
            i2 = ((i6 > i7 || rect2.left >= i7) && this.mTempRect.left > this.mTempRect2.left) ? -1 : 0;
        }
        Rect rect3 = this.mTempRect;
        int i8 = rect3.top;
        int i9 = this.mTempRect2.top;
        if ((i8 < i9 || rect3.bottom <= i9) && this.mTempRect.bottom < this.mTempRect2.bottom) {
            c = 1;
        } else {
            Rect rect4 = this.mTempRect;
            int i10 = rect4.bottom;
            int i11 = this.mTempRect2.bottom;
            if ((i10 <= i11 && rect4.top < i11) || this.mTempRect.top <= this.mTempRect2.top) {
                c = 0;
            }
        }
        if (i != 1) {
            if (i != 2) {
                if (i != 17) {
                    if (i != 33) {
                        if (i != 66) {
                            if (i != 130) {
                                StringBuilder sb = new StringBuilder();
                                sb.append("Invalid direction: ");
                                sb.append(i);
                                throw new IllegalArgumentException(outline.m2929a(this, sb));
                            } else if (c > 0) {
                                return true;
                            } else {
                                return false;
                            }
                        } else if (i2 > 0) {
                            return true;
                        } else {
                            return false;
                        }
                    } else if (c < 0) {
                        return true;
                    } else {
                        return false;
                    }
                } else if (i2 < 0) {
                    return true;
                } else {
                    return false;
                }
            } else if (c > 0 || (c == 0 && i2 * i3 >= 0)) {
                return true;
            } else {
                return false;
            }
        } else if (c < 0 || (c == 0 && i2 * i3 <= 0)) {
            return true;
        } else {
            return false;
        }
    }

    private void onPointerUp(MotionEvent motionEvent) {
        int actionIndex = motionEvent.getActionIndex();
        if (motionEvent.getPointerId(actionIndex) == this.mScrollPointerId) {
            int i = actionIndex == 0 ? 1 : 0;
            this.mScrollPointerId = motionEvent.getPointerId(i);
            int x = (int) (motionEvent.getX(i) + 0.5f);
            this.mLastTouchX = x;
            this.mInitialTouchX = x;
            int y = (int) (motionEvent.getY(i) + 0.5f);
            this.mLastTouchY = y;
            this.mInitialTouchY = y;
        }
    }

    private boolean predictiveItemAnimationsEnabled() {
        return this.mItemAnimator != null && this.mLayout.mo1043q();
    }

    private void processAdapterUpdatesAndSetAnimationFlags() {
        boolean z = false;
        if (this.mDataSetHasChangedAfterLayout) {
            AdapterHelper aVar = this.mAdapterHelper;
            aVar.mo3659a((List<AdapterHelper.C0547b>) aVar.f3102b);
            aVar.mo3659a((List<AdapterHelper.C0547b>) aVar.f3103c);
            aVar.f3107g = 0;
            if (this.mDispatchItemsChangedEvent) {
                this.mLayout.mo1021a(this);
            }
        }
        if (predictiveItemAnimationsEnabled()) {
            this.mAdapterHelper.mo3666d();
        } else {
            this.mAdapterHelper.mo3662b();
        }
        boolean z2 = this.mItemsAddedOrRemoved || this.mItemsChanged;
        this.mState.f786j = this.mFirstLayoutComplete && this.mItemAnimator != null && (this.mDataSetHasChangedAfterLayout || z2 || this.mLayout.f840h) && (!this.mDataSetHasChangedAfterLayout || this.mAdapter.f823b);
        C0128a0 a0Var = this.mState;
        if (a0Var.f786j && z2 && !this.mDataSetHasChangedAfterLayout && predictiveItemAnimationsEnabled()) {
            z = true;
        }
        a0Var.f787k = z;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x0056  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x007c  */
    /* JADX WARNING: Removed duplicated region for block: B:22:? A[RETURN, SYNTHETIC] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private void pullGlows(float r7, float r8, float r9, float r10) {
        /*
            r6 = this;
            r0 = 1065353216(0x3f800000, float:1.0)
            r1 = 1
            r2 = 0
            int r3 = (r8 > r2 ? 1 : (r8 == r2 ? 0 : -1))
            if (r3 >= 0) goto L_0x0021
            r6.ensureLeftGlow()
            android.widget.EdgeEffect r3 = r6.mLeftGlow
            float r4 = -r8
            int r5 = r6.getWidth()
            float r5 = (float) r5
            float r4 = r4 / r5
            int r5 = r6.getHeight()
            float r5 = (float) r5
            float r9 = r9 / r5
            float r9 = r0 - r9
            r3.onPull(r4, r9)
        L_0x001f:
            r9 = 1
            goto L_0x003c
        L_0x0021:
            int r3 = (r8 > r2 ? 1 : (r8 == r2 ? 0 : -1))
            if (r3 <= 0) goto L_0x003b
            r6.ensureRightGlow()
            android.widget.EdgeEffect r3 = r6.mRightGlow
            int r4 = r6.getWidth()
            float r4 = (float) r4
            float r4 = r8 / r4
            int r5 = r6.getHeight()
            float r5 = (float) r5
            float r9 = r9 / r5
            r3.onPull(r4, r9)
            goto L_0x001f
        L_0x003b:
            r9 = 0
        L_0x003c:
            int r3 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1))
            if (r3 >= 0) goto L_0x0056
            r6.ensureTopGlow()
            android.widget.EdgeEffect r9 = r6.mTopGlow
            float r0 = -r10
            int r3 = r6.getHeight()
            float r3 = (float) r3
            float r0 = r0 / r3
            int r3 = r6.getWidth()
            float r3 = (float) r3
            float r7 = r7 / r3
            r9.onPull(r0, r7)
            goto L_0x0072
        L_0x0056:
            int r3 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1))
            if (r3 <= 0) goto L_0x0071
            r6.ensureBottomGlow()
            android.widget.EdgeEffect r9 = r6.mBottomGlow
            int r3 = r6.getHeight()
            float r3 = (float) r3
            float r3 = r10 / r3
            int r4 = r6.getWidth()
            float r4 = (float) r4
            float r7 = r7 / r4
            float r0 = r0 - r7
            r9.onPull(r3, r0)
            goto L_0x0072
        L_0x0071:
            r1 = r9
        L_0x0072:
            if (r1 != 0) goto L_0x007c
            int r7 = (r8 > r2 ? 1 : (r8 == r2 ? 0 : -1))
            if (r7 != 0) goto L_0x007c
            int r7 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1))
            if (r7 == 0) goto L_0x007f
        L_0x007c:
            p008b.p033h.p045m.ViewCompat.m1922A(r6)
        L_0x007f:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.pullGlows(float, float, float, float):void");
    }

    private void recoverFocusFromState() {
        View findViewById;
        if (this.mPreserveFocusAfterLayout && this.mAdapter != null && hasFocus() && getDescendantFocusability() != 393216) {
            if (getDescendantFocusability() != 131072 || !isFocused()) {
                if (!isFocused()) {
                    View focusedChild = getFocusedChild();
                    if (!IGNORE_DETACHED_FOCUSED_CHILD || (focusedChild.getParent() != null && focusedChild.hasFocus())) {
                        if (!this.mChildHelper.mo3679c(focusedChild)) {
                            return;
                        }
                    } else if (this.mChildHelper.mo3670a() == 0) {
                        requestFocus();
                        return;
                    }
                }
                long j = this.mState.f789m;
                View view = null;
                C0134d0 findViewHolderForItemId = (j == -1 || !this.mAdapter.f823b) ? null : findViewHolderForItemId(j);
                if (findViewHolderForItemId != null && !this.mChildHelper.mo3679c(findViewHolderForItemId.f802a) && findViewHolderForItemId.f802a.hasFocusable()) {
                    view = findViewHolderForItemId.f802a;
                } else if (this.mChildHelper.mo3670a() > 0) {
                    view = findNextViewToFocus();
                }
                if (view != null) {
                    int i = this.mState.f790n;
                    if (!(((long) i) == -1 || (findViewById = view.findViewById(i)) == null || !findViewById.isFocusable())) {
                        view = findViewById;
                    }
                    view.requestFocus();
                }
            }
        }
    }

    private void releaseGlows() {
        boolean z;
        EdgeEffect edgeEffect = this.mLeftGlow;
        if (edgeEffect != null) {
            edgeEffect.onRelease();
            z = this.mLeftGlow.isFinished();
        } else {
            z = false;
        }
        EdgeEffect edgeEffect2 = this.mTopGlow;
        if (edgeEffect2 != null) {
            edgeEffect2.onRelease();
            z |= this.mTopGlow.isFinished();
        }
        EdgeEffect edgeEffect3 = this.mRightGlow;
        if (edgeEffect3 != null) {
            edgeEffect3.onRelease();
            z |= this.mRightGlow.isFinished();
        }
        EdgeEffect edgeEffect4 = this.mBottomGlow;
        if (edgeEffect4 != null) {
            edgeEffect4.onRelease();
            z |= this.mBottomGlow.isFinished();
        }
        if (z) {
            ViewCompat.m1922A(this);
        }
    }

    private void requestChildOnScreen(View view, View view2) {
        View view3 = view2 != null ? view2 : view;
        this.mTempRect.set(0, 0, view3.getWidth(), view3.getHeight());
        ViewGroup.LayoutParams layoutParams = view3.getLayoutParams();
        if (layoutParams instanceof C0153p) {
            C0153p pVar = (C0153p) layoutParams;
            if (!pVar.f859c) {
                Rect rect = pVar.f858b;
                Rect rect2 = this.mTempRect;
                rect2.left -= rect.left;
                rect2.right += rect.right;
                rect2.top -= rect.top;
                rect2.bottom += rect.bottom;
            }
        }
        if (view2 != null) {
            offsetDescendantRectToMyCoords(view2, this.mTempRect);
            offsetRectIntoDescendantCoords(view, this.mTempRect);
        }
        this.mLayout.mo1367a(this, view, this.mTempRect, !this.mFirstLayoutComplete, view2 == null);
    }

    private void resetFocusInfo() {
        C0128a0 a0Var = this.mState;
        a0Var.f789m = -1;
        a0Var.f788l = -1;
        a0Var.f790n = -1;
    }

    private void resetScroll() {
        VelocityTracker velocityTracker = this.mVelocityTracker;
        if (velocityTracker != null) {
            velocityTracker.clear();
        }
        stopNestedScroll(0);
        releaseGlows();
    }

    private void saveFocusInfo() {
        int i;
        C0134d0 d0Var = null;
        View focusedChild = (!this.mPreserveFocusAfterLayout || !hasFocus() || this.mAdapter == null) ? null : getFocusedChild();
        if (focusedChild != null) {
            d0Var = findContainingViewHolder(focusedChild);
        }
        if (d0Var == null) {
            resetFocusInfo();
            return;
        }
        this.mState.f789m = this.mAdapter.f823b ? d0Var.f806e : -1;
        C0128a0 a0Var = this.mState;
        if (this.mDataSetHasChangedAfterLayout) {
            i = -1;
        } else if (d0Var.mo1323j()) {
            i = d0Var.f805d;
        } else {
            i = d0Var.mo1316c();
        }
        a0Var.f788l = i;
        this.mState.f790n = getDeepestFocusedViewWithId(d0Var.f802a);
    }

    private void setAdapterInternal(C0137g gVar, boolean z, boolean z2) {
        C0137g gVar2 = this.mAdapter;
        if (gVar2 != null) {
            gVar2.f822a.unregisterObserver(this.mObserver);
            if (this.mAdapter == null) {
                throw null;
            }
        }
        if (!z || z2) {
            removeAndRecycleViews();
        }
        AdapterHelper aVar = this.mAdapterHelper;
        aVar.mo3659a((List<AdapterHelper.C0547b>) aVar.f3102b);
        aVar.mo3659a((List<AdapterHelper.C0547b>) aVar.f3103c);
        aVar.f3107g = 0;
        C0137g gVar3 = this.mAdapter;
        this.mAdapter = gVar;
        if (gVar != null) {
            gVar.f822a.registerObserver(this.mObserver);
        }
        C0148o oVar = this.mLayout;
        C0160v vVar = this.mRecycler;
        C0137g gVar4 = this.mAdapter;
        vVar.mo1416a();
        C0158u b = vVar.mo1421b();
        if (b != null) {
            if (gVar3 != null) {
                b.f862b--;
            }
            if (!z && b.f862b == 0) {
                for (int i = 0; i < b.f861a.size(); i++) {
                    b.f861a.valueAt(i).f863a.clear();
                }
            }
            if (gVar4 != null) {
                b.f862b++;
            }
            this.mState.f782f = true;
            return;
        }
        throw null;
    }

    private void stopScrollersInternal() {
        C0165z zVar;
        this.mViewFlinger.mo1306b();
        C0148o oVar = this.mLayout;
        if (oVar != null && (zVar = oVar.f839g) != null) {
            zVar.mo1432a();
        }
    }

    public void absorbGlows(int i, int i2) {
        if (i < 0) {
            ensureLeftGlow();
            if (this.mLeftGlow.isFinished()) {
                this.mLeftGlow.onAbsorb(-i);
            }
        } else if (i > 0) {
            ensureRightGlow();
            if (this.mRightGlow.isFinished()) {
                this.mRightGlow.onAbsorb(i);
            }
        }
        if (i2 < 0) {
            ensureTopGlow();
            if (this.mTopGlow.isFinished()) {
                this.mTopGlow.onAbsorb(-i2);
            }
        } else if (i2 > 0) {
            ensureBottomGlow();
            if (this.mBottomGlow.isFinished()) {
                this.mBottomGlow.onAbsorb(i2);
            }
        }
        if (i != 0 || i2 != 0) {
            ViewCompat.m1922A(this);
        }
    }

    public void addFocusables(ArrayList<View> arrayList, int i, int i2) {
        C0148o oVar = this.mLayout;
        if (oVar == null || oVar != null) {
            super.addFocusables(arrayList, i, i2);
            return;
        }
        throw null;
    }

    public void addItemDecoration(C0147n nVar, int i) {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            oVar.mo1064a("Cannot add item decoration during a scroll  or layout");
        }
        if (this.mItemDecorations.isEmpty()) {
            setWillNotDraw(false);
        }
        if (i < 0) {
            this.mItemDecorations.add(nVar);
        } else {
            this.mItemDecorations.add(i, nVar);
        }
        markItemDecorInsetsDirty();
        requestLayout();
    }

    public void addOnChildAttachStateChangeListener(C0154q qVar) {
        if (this.mOnChildAttachStateListeners == null) {
            this.mOnChildAttachStateListeners = new ArrayList();
        }
        this.mOnChildAttachStateListeners.add(qVar);
    }

    public void addOnItemTouchListener(C0156s sVar) {
        this.mOnItemTouchListeners.add(sVar);
    }

    public void addOnScrollListener(C0157t tVar) {
        if (this.mScrollListeners == null) {
            this.mScrollListeners = new ArrayList();
        }
        this.mScrollListeners.add(tVar);
    }

    public void animateAppearance(C0134d0 d0Var, C0142l.C0145c cVar, C0142l.C0145c cVar2) {
        boolean z;
        d0Var.mo1313a(false);
        SimpleItemAnimator vVar = (SimpleItemAnimator) this.mItemAnimator;
        if (vVar != null) {
            if (cVar == null || (cVar.f830a == cVar2.f830a && cVar.f831b == cVar2.f831b)) {
                C0557k kVar = (C0557k) vVar;
                kVar.mo3712e(d0Var);
                d0Var.f802a.setAlpha(0.0f);
                kVar.f3147i.add(d0Var);
                z = true;
            } else {
                z = vVar.mo3709a(d0Var, cVar.f830a, cVar.f831b, cVar2.f830a, cVar2.f831b);
            }
            if (z) {
                postAnimationRunner();
                return;
            }
            return;
        }
        throw null;
    }

    public void animateDisappearance(C0134d0 d0Var, C0142l.C0145c cVar, C0142l.C0145c cVar2) {
        boolean z;
        addAnimatingView(d0Var);
        d0Var.mo1313a(false);
        SimpleItemAnimator vVar = (SimpleItemAnimator) this.mItemAnimator;
        if (vVar != null) {
            int i = cVar.f830a;
            int i2 = cVar.f831b;
            View view = d0Var.f802a;
            int left = cVar2 == null ? view.getLeft() : cVar2.f830a;
            int top = cVar2 == null ? view.getTop() : cVar2.f831b;
            if (d0Var.mo1323j() || (i == left && i2 == top)) {
                C0557k kVar = (C0557k) vVar;
                kVar.mo3712e(d0Var);
                kVar.f3146h.add(d0Var);
                z = true;
            } else {
                view.layout(left, top, view.getWidth() + left, view.getHeight() + top);
                z = vVar.mo3709a(d0Var, i, i2, left, top);
            }
            if (z) {
                postAnimationRunner();
                return;
            }
            return;
        }
        throw null;
    }

    public void assertInLayoutOrScroll(String str) {
        if (isComputingLayout()) {
            return;
        }
        if (str == null) {
            throw new IllegalStateException(outline.m2929a(this, outline.m2937a("Cannot call this method unless RecyclerView is computing a layout or scrolling")));
        }
        throw new IllegalStateException(outline.m2929a(this, outline.m2937a(str)));
    }

    public void assertNotInLayoutOrScroll(String str) {
        if (isComputingLayout()) {
            if (str == null) {
                throw new IllegalStateException(outline.m2929a(this, outline.m2937a("Cannot call this method while RecyclerView is computing a layout or scrolling")));
            }
            throw new IllegalStateException(str);
        } else if (this.mDispatchScrollCounter > 0) {
            Log.w(TAG, "Cannot call this method in a scroll callback. Scroll callbacks mightbe run during a measure & layout pass where you cannot change theRecyclerView data. Any method call that might change the structureof the RecyclerView or the adapter contents should be postponed tothe next frame.", new IllegalStateException(outline.m2929a(this, outline.m2937a(""))));
        }
    }

    public boolean canReuseUpdatedViewHolder(C0134d0 d0Var) {
        C0142l lVar = this.mItemAnimator;
        return lVar == null || lVar.mo1348a(d0Var, d0Var.mo1318e());
    }

    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return (layoutParams instanceof C0153p) && this.mLayout.mo1026a((C0153p) layoutParams);
    }

    public void clearOldPositions() {
        int b = this.mChildHelper.mo3675b();
        for (int i = 0; i < b; i++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i));
            if (!childViewHolderInt.mo1328o()) {
                childViewHolderInt.mo1308a();
            }
        }
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        for (int i2 = 0; i2 < size; i2++) {
            vVar.f869c.get(i2).mo1308a();
        }
        int size2 = vVar.f867a.size();
        for (int i3 = 0; i3 < size2; i3++) {
            vVar.f867a.get(i3).mo1308a();
        }
        ArrayList<C0134d0> arrayList = vVar.f868b;
        if (arrayList != null) {
            int size3 = arrayList.size();
            for (int i4 = 0; i4 < size3; i4++) {
                vVar.f868b.get(i4).mo1308a();
            }
        }
    }

    public void clearOnChildAttachStateChangeListeners() {
        List<C0154q> list = this.mOnChildAttachStateListeners;
        if (list != null) {
            list.clear();
        }
    }

    public void clearOnScrollListeners() {
        List<C0157t> list = this.mScrollListeners;
        if (list != null) {
            list.clear();
        }
    }

    public int computeHorizontalScrollExtent() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1065a()) {
            return this.mLayout.mo1049a(this.mState);
        }
        return 0;
    }

    public int computeHorizontalScrollOffset() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1065a()) {
            return this.mLayout.mo1028b(this.mState);
        }
        return 0;
    }

    public int computeHorizontalScrollRange() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1065a()) {
            return this.mLayout.mo1033c(this.mState);
        }
        return 0;
    }

    public int computeVerticalScrollExtent() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1069b()) {
            return this.mLayout.mo1072d(this.mState);
        }
        return 0;
    }

    public int computeVerticalScrollOffset() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1069b()) {
            return this.mLayout.mo1037e(this.mState);
        }
        return 0;
    }

    public int computeVerticalScrollRange() {
        C0148o oVar = this.mLayout;
        if (oVar != null && oVar.mo1069b()) {
            return this.mLayout.mo1039f(this.mState);
        }
        return 0;
    }

    public void considerReleasingGlowsOnScroll(int i, int i2) {
        boolean z;
        EdgeEffect edgeEffect = this.mLeftGlow;
        if (edgeEffect == null || edgeEffect.isFinished() || i <= 0) {
            z = false;
        } else {
            this.mLeftGlow.onRelease();
            z = this.mLeftGlow.isFinished();
        }
        EdgeEffect edgeEffect2 = this.mRightGlow;
        if (edgeEffect2 != null && !edgeEffect2.isFinished() && i < 0) {
            this.mRightGlow.onRelease();
            z |= this.mRightGlow.isFinished();
        }
        EdgeEffect edgeEffect3 = this.mTopGlow;
        if (edgeEffect3 != null && !edgeEffect3.isFinished() && i2 > 0) {
            this.mTopGlow.onRelease();
            z |= this.mTopGlow.isFinished();
        }
        EdgeEffect edgeEffect4 = this.mBottomGlow;
        if (edgeEffect4 != null && !edgeEffect4.isFinished() && i2 < 0) {
            this.mBottomGlow.onRelease();
            z |= this.mBottomGlow.isFinished();
        }
        if (z) {
            ViewCompat.m1922A(this);
        }
    }

    public void consumePendingUpdateOperations() {
        if (!this.mFirstLayoutComplete || this.mDataSetHasChangedAfterLayout) {
            TraceCompat.m1852a(TRACE_ON_DATA_SET_CHANGE_LAYOUT_TAG);
            dispatchLayout();
            Trace.endSection();
        } else if (this.mAdapterHelper.mo3665c()) {
            boolean z = false;
            if ((this.mAdapterHelper.f3107g & 4) != 0) {
                if ((this.mAdapterHelper.f3107g & 11) != 0) {
                    z = true;
                }
                if (!z) {
                    TraceCompat.m1852a(TRACE_HANDLE_ADAPTER_UPDATES_TAG);
                    startInterceptRequestLayout();
                    onEnterLayoutOrScroll();
                    this.mAdapterHelper.mo3666d();
                    if (!this.mLayoutWasDefered) {
                        if (hasUpdatedView()) {
                            dispatchLayout();
                        } else {
                            this.mAdapterHelper.mo3656a();
                        }
                    }
                    stopInterceptRequestLayout(true);
                    onExitLayoutOrScroll();
                    Trace.endSection();
                    return;
                }
            }
            if (this.mAdapterHelper.mo3665c()) {
                TraceCompat.m1852a(TRACE_ON_DATA_SET_CHANGE_LAYOUT_TAG);
                dispatchLayout();
                Trace.endSection();
            }
        }
    }

    public void defaultOnMeasure(int i, int i2) {
        setMeasuredDimension(C0148o.m587a(i, getPaddingRight() + getPaddingLeft(), ViewCompat.m1968m(this)), C0148o.m587a(i2, getPaddingBottom() + getPaddingTop(), getMinimumHeight()));
    }

    public void dispatchChildAttached(View view) {
        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
        onChildAttachedToWindow(view);
        C0137g gVar = this.mAdapter;
        if (gVar == null || childViewHolderInt == null || gVar != null) {
            List<C0154q> list = this.mOnChildAttachStateListeners;
            if (list != null) {
                for (int size = list.size() - 1; size >= 0; size--) {
                    this.mOnChildAttachStateListeners.get(size).mo1405a(view);
                }
                return;
            }
            return;
        }
        throw null;
    }

    public void dispatchChildDetached(View view) {
        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
        onChildDetachedFromWindow(view);
        C0137g gVar = this.mAdapter;
        if (gVar == null || childViewHolderInt == null || gVar != null) {
            List<C0154q> list = this.mOnChildAttachStateListeners;
            if (list != null) {
                for (int size = list.size() - 1; size >= 0; size--) {
                    this.mOnChildAttachStateListeners.get(size).mo1406b(view);
                }
                return;
            }
            return;
        }
        throw null;
    }

    public void dispatchLayout() {
        if (this.mAdapter == null) {
            Log.e(TAG, "No adapter attached; skipping layout");
        } else if (this.mLayout == null) {
            Log.e(TAG, "No layout manager attached; skipping layout");
        } else {
            C0128a0 a0Var = this.mState;
            boolean z = false;
            a0Var.f785i = false;
            if (a0Var.f780d == 1) {
                dispatchLayoutStep1();
                this.mLayout.mo1371b(this);
                dispatchLayoutStep2();
            } else {
                AdapterHelper aVar = this.mAdapterHelper;
                if (!aVar.f3103c.isEmpty() && !aVar.f3102b.isEmpty()) {
                    z = true;
                }
                if (!z && this.mLayout.f849q == getWidth() && this.mLayout.f850r == getHeight()) {
                    this.mLayout.mo1371b(this);
                } else {
                    this.mLayout.mo1371b(this);
                    dispatchLayoutStep2();
                }
            }
            dispatchLayoutStep3();
        }
    }

    public boolean dispatchNestedFling(float f, float f2, boolean z) {
        return getScrollingChildHelper().mo3124a(f, f2, z);
    }

    public boolean dispatchNestedPreFling(float f, float f2) {
        return getScrollingChildHelper().mo3123a(f, f2);
    }

    public boolean dispatchNestedPreScroll(int i, int i2, int[] iArr, int[] iArr2) {
        return getScrollingChildHelper().mo3127a(i, i2, iArr, iArr2, 0);
    }

    public boolean dispatchNestedScroll(int i, int i2, int i3, int i4, int[] iArr) {
        return getScrollingChildHelper().mo3126a(i, i2, i3, i4, iArr);
    }

    public void dispatchOnScrollStateChanged(int i) {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            oVar.mo1385f(i);
        }
        onScrollStateChanged(i);
        C0157t tVar = this.mScrollListener;
        if (tVar != null) {
            tVar.mo1410a(this, i);
        }
        List<C0157t> list = this.mScrollListeners;
        if (list != null) {
            for (int size = list.size() - 1; size >= 0; size--) {
                this.mScrollListeners.get(size).mo1410a(this, i);
            }
        }
    }

    public void dispatchOnScrolled(int i, int i2) {
        this.mDispatchScrollCounter++;
        int scrollX = getScrollX();
        int scrollY = getScrollY();
        onScrollChanged(scrollX, scrollY, scrollX - i, scrollY - i2);
        onScrolled(i, i2);
        C0157t tVar = this.mScrollListener;
        if (tVar != null) {
            tVar.mo1411a(this, i, i2);
        }
        List<C0157t> list = this.mScrollListeners;
        if (list != null) {
            for (int size = list.size() - 1; size >= 0; size--) {
                this.mScrollListeners.get(size).mo1411a(this, i, i2);
            }
        }
        this.mDispatchScrollCounter--;
    }

    public void dispatchPendingImportantForAccessibilityChanges() {
        int i;
        for (int size = this.mPendingAccessibilityImportanceChange.size() - 1; size >= 0; size--) {
            C0134d0 d0Var = this.mPendingAccessibilityImportanceChange.get(size);
            if (d0Var.f802a.getParent() == this && !d0Var.mo1328o() && (i = d0Var.f818q) != -1) {
                ViewCompat.m1962h(d0Var.f802a, i);
                d0Var.f818q = -1;
            }
        }
        this.mPendingAccessibilityImportanceChange.clear();
    }

    public boolean dispatchPopulateAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        onPopulateAccessibilityEvent(accessibilityEvent);
        return true;
    }

    public void dispatchRestoreInstanceState(SparseArray<Parcelable> sparseArray) {
        dispatchThawSelfOnly(sparseArray);
    }

    public void dispatchSaveInstanceState(SparseArray<Parcelable> sparseArray) {
        dispatchFreezeSelfOnly(sparseArray);
    }

    public void draw(Canvas canvas) {
        boolean z;
        super.draw(canvas);
        int size = this.mItemDecorations.size();
        boolean z2 = false;
        for (int i = 0; i < size; i++) {
            this.mItemDecorations.get(i).mo1355b(canvas, this, this.mState);
        }
        EdgeEffect edgeEffect = this.mLeftGlow;
        boolean z3 = true;
        if (edgeEffect == null || edgeEffect.isFinished()) {
            z = false;
        } else {
            int save = canvas.save();
            int paddingBottom = this.mClipToPadding ? getPaddingBottom() : 0;
            canvas.rotate(270.0f);
            canvas.translate((float) ((-getHeight()) + paddingBottom), 0.0f);
            EdgeEffect edgeEffect2 = this.mLeftGlow;
            z = edgeEffect2 != null && edgeEffect2.draw(canvas);
            canvas.restoreToCount(save);
        }
        EdgeEffect edgeEffect3 = this.mTopGlow;
        if (edgeEffect3 != null && !edgeEffect3.isFinished()) {
            int save2 = canvas.save();
            if (this.mClipToPadding) {
                canvas.translate((float) getPaddingLeft(), (float) getPaddingTop());
            }
            EdgeEffect edgeEffect4 = this.mTopGlow;
            z |= edgeEffect4 != null && edgeEffect4.draw(canvas);
            canvas.restoreToCount(save2);
        }
        EdgeEffect edgeEffect5 = this.mRightGlow;
        if (edgeEffect5 != null && !edgeEffect5.isFinished()) {
            int save3 = canvas.save();
            int width = getWidth();
            int paddingTop = this.mClipToPadding ? getPaddingTop() : 0;
            canvas.rotate(90.0f);
            canvas.translate((float) (-paddingTop), (float) (-width));
            EdgeEffect edgeEffect6 = this.mRightGlow;
            z |= edgeEffect6 != null && edgeEffect6.draw(canvas);
            canvas.restoreToCount(save3);
        }
        EdgeEffect edgeEffect7 = this.mBottomGlow;
        if (edgeEffect7 != null && !edgeEffect7.isFinished()) {
            int save4 = canvas.save();
            canvas.rotate(180.0f);
            if (this.mClipToPadding) {
                canvas.translate((float) (getPaddingRight() + (-getWidth())), (float) (getPaddingBottom() + (-getHeight())));
            } else {
                canvas.translate((float) (-getWidth()), (float) (-getHeight()));
            }
            EdgeEffect edgeEffect8 = this.mBottomGlow;
            if (edgeEffect8 != null && edgeEffect8.draw(canvas)) {
                z2 = true;
            }
            z |= z2;
            canvas.restoreToCount(save4);
        }
        if (z || this.mItemAnimator == null || this.mItemDecorations.size() <= 0 || !this.mItemAnimator.mo1352c()) {
            z3 = z;
        }
        if (z3) {
            ViewCompat.m1922A(this);
        }
    }

    public boolean drawChild(Canvas canvas, View view, long j) {
        return super.drawChild(canvas, view, j);
    }

    public void ensureBottomGlow() {
        if (this.mBottomGlow == null) {
            EdgeEffect a = this.mEdgeEffectFactory.mo1344a(this);
            this.mBottomGlow = a;
            if (this.mClipToPadding) {
                a.setSize((getMeasuredWidth() - getPaddingLeft()) - getPaddingRight(), (getMeasuredHeight() - getPaddingTop()) - getPaddingBottom());
            } else {
                a.setSize(getMeasuredWidth(), getMeasuredHeight());
            }
        }
    }

    public void ensureLeftGlow() {
        if (this.mLeftGlow == null) {
            EdgeEffect a = this.mEdgeEffectFactory.mo1344a(this);
            this.mLeftGlow = a;
            if (this.mClipToPadding) {
                a.setSize((getMeasuredHeight() - getPaddingTop()) - getPaddingBottom(), (getMeasuredWidth() - getPaddingLeft()) - getPaddingRight());
            } else {
                a.setSize(getMeasuredHeight(), getMeasuredWidth());
            }
        }
    }

    public void ensureRightGlow() {
        if (this.mRightGlow == null) {
            EdgeEffect a = this.mEdgeEffectFactory.mo1344a(this);
            this.mRightGlow = a;
            if (this.mClipToPadding) {
                a.setSize((getMeasuredHeight() - getPaddingTop()) - getPaddingBottom(), (getMeasuredWidth() - getPaddingLeft()) - getPaddingRight());
            } else {
                a.setSize(getMeasuredHeight(), getMeasuredWidth());
            }
        }
    }

    public void ensureTopGlow() {
        if (this.mTopGlow == null) {
            EdgeEffect a = this.mEdgeEffectFactory.mo1344a(this);
            this.mTopGlow = a;
            if (this.mClipToPadding) {
                a.setSize((getMeasuredWidth() - getPaddingLeft()) - getPaddingRight(), (getMeasuredHeight() - getPaddingTop()) - getPaddingBottom());
            } else {
                a.setSize(getMeasuredWidth(), getMeasuredHeight());
            }
        }
    }

    public String exceptionLabel() {
        StringBuilder a = outline.m2937a(" ");
        a.append(super.toString());
        a.append(", adapter:");
        a.append(this.mAdapter);
        a.append(", layout:");
        a.append(this.mLayout);
        a.append(", context:");
        a.append(getContext());
        return a.toString();
    }

    public final void fillRemainingScrollValues(C0128a0 a0Var) {
        if (getScrollState() == 2) {
            OverScroller overScroller = this.mViewFlinger.f795d;
            a0Var.f791o = overScroller.getFinalX() - overScroller.getCurrX();
            overScroller.getFinalY();
            overScroller.getCurrY();
            return;
        }
        a0Var.f791o = 0;
    }

    public View findChildViewUnder(float f, float f2) {
        for (int a = this.mChildHelper.mo3670a() - 1; a >= 0; a--) {
            View b = this.mChildHelper.mo3677b(a);
            float translationX = b.getTranslationX();
            float translationY = b.getTranslationY();
            if (f >= ((float) b.getLeft()) + translationX && f <= ((float) b.getRight()) + translationX && f2 >= ((float) b.getTop()) + translationY && f2 <= ((float) b.getBottom()) + translationY) {
                return b;
            }
        }
        return null;
    }

    public View findContainingItemView(View view) {
        ViewParent parent = view.getParent();
        while (parent != null && parent != this && (parent instanceof View)) {
            view = (View) parent;
            parent = view.getParent();
        }
        if (parent == this) {
            return view;
        }
        return null;
    }

    public C0134d0 findContainingViewHolder(View view) {
        View findContainingItemView = findContainingItemView(view);
        if (findContainingItemView == null) {
            return null;
        }
        return getChildViewHolder(findContainingItemView);
    }

    public C0134d0 findViewHolderForAdapterPosition(int i) {
        C0134d0 d0Var = null;
        if (this.mDataSetHasChangedAfterLayout) {
            return null;
        }
        int b = this.mChildHelper.mo3675b();
        for (int i2 = 0; i2 < b; i2++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i2));
            if (childViewHolderInt != null && !childViewHolderInt.mo1323j() && getAdapterPositionFor(childViewHolderInt) == i) {
                if (!this.mChildHelper.mo3679c(childViewHolderInt.f802a)) {
                    return childViewHolderInt;
                }
                d0Var = childViewHolderInt;
            }
        }
        return d0Var;
    }

    public C0134d0 findViewHolderForItemId(long j) {
        C0137g gVar = this.mAdapter;
        C0134d0 d0Var = null;
        if (gVar != null && gVar.f823b) {
            int b = this.mChildHelper.mo3675b();
            for (int i = 0; i < b; i++) {
                C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i));
                if (childViewHolderInt != null && !childViewHolderInt.mo1323j() && childViewHolderInt.f806e == j) {
                    if (!this.mChildHelper.mo3679c(childViewHolderInt.f802a)) {
                        return childViewHolderInt;
                    }
                    d0Var = childViewHolderInt;
                }
            }
        }
        return d0Var;
    }

    public C0134d0 findViewHolderForLayoutPosition(int i) {
        return findViewHolderForPosition(i, false);
    }

    @Deprecated
    public C0134d0 findViewHolderForPosition(int i) {
        return findViewHolderForPosition(i, false);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:57:0x00c2, code lost:
        r15 = r10 - 1;
     */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0117  */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x011f  */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x0124 A[RETURN] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean fling(int r19, int r20) {
        /*
            r18 = this;
            r0 = r18
            androidx.recyclerview.widget.RecyclerView$o r1 = r0.mLayout
            r2 = 0
            if (r1 != 0) goto L_0x000f
            java.lang.String r1 = "RecyclerView"
            java.lang.String r3 = "Cannot fling without a LayoutManager set. Call setLayoutManager with a non-null argument."
            android.util.Log.e(r1, r3)
            return r2
        L_0x000f:
            boolean r3 = r0.mLayoutSuppressed
            if (r3 == 0) goto L_0x0014
            return r2
        L_0x0014:
            boolean r1 = r1.mo1065a()
            androidx.recyclerview.widget.RecyclerView$o r3 = r0.mLayout
            boolean r3 = r3.mo1069b()
            if (r1 == 0) goto L_0x002c
            int r4 = java.lang.Math.abs(r19)
            int r5 = r0.mMinFlingVelocity
            if (r4 >= r5) goto L_0x0029
            goto L_0x002c
        L_0x0029:
            r4 = r19
            goto L_0x002d
        L_0x002c:
            r4 = 0
        L_0x002d:
            if (r3 == 0) goto L_0x003b
            int r5 = java.lang.Math.abs(r20)
            int r6 = r0.mMinFlingVelocity
            if (r5 >= r6) goto L_0x0038
            goto L_0x003b
        L_0x0038:
            r5 = r20
            goto L_0x003c
        L_0x003b:
            r5 = 0
        L_0x003c:
            if (r4 != 0) goto L_0x0041
            if (r5 != 0) goto L_0x0041
            return r2
        L_0x0041:
            float r6 = (float) r4
            float r7 = (float) r5
            boolean r8 = r0.dispatchNestedPreFling(r6, r7)
            if (r8 != 0) goto L_0x0184
            if (r1 != 0) goto L_0x0050
            if (r3 == 0) goto L_0x004e
            goto L_0x0050
        L_0x004e:
            r9 = 0
            goto L_0x0051
        L_0x0050:
            r9 = 1
        L_0x0051:
            r0.dispatchNestedFling(r6, r7, r9)
            androidx.recyclerview.widget.RecyclerView$r r6 = r0.mOnFlingListener
            if (r6 == 0) goto L_0x0126
            b.s.d.w r6 = (p008b.p071s.p072d.SnapHelper) r6
            androidx.recyclerview.widget.RecyclerView r7 = r6.f3247a
            androidx.recyclerview.widget.RecyclerView$o r7 = r7.getLayoutManager()
            if (r7 != 0) goto L_0x0064
            goto L_0x0121
        L_0x0064:
            androidx.recyclerview.widget.RecyclerView r10 = r6.f3247a
            androidx.recyclerview.widget.RecyclerView$g r10 = r10.getAdapter()
            if (r10 != 0) goto L_0x006e
            goto L_0x0121
        L_0x006e:
            androidx.recyclerview.widget.RecyclerView r10 = r6.f3247a
            int r10 = r10.getMinFlingVelocity()
            int r11 = java.lang.Math.abs(r5)
            if (r11 > r10) goto L_0x0080
            int r11 = java.lang.Math.abs(r4)
            if (r11 <= r10) goto L_0x0121
        L_0x0080:
            boolean r10 = r7 instanceof androidx.recyclerview.widget.RecyclerView.C0165z.C0167b
            if (r10 != 0) goto L_0x0086
            goto L_0x0115
        L_0x0086:
            r11 = 0
            if (r10 != 0) goto L_0x008b
            r12 = r11
            goto L_0x0096
        L_0x008b:
            b.s.d.x r12 = new b.s.d.x
            androidx.recyclerview.widget.RecyclerView r13 = r6.f3247a
            android.content.Context r13 = r13.getContext()
            r12.<init>(r6, r13)
        L_0x0096:
            if (r12 != 0) goto L_0x009a
            goto L_0x0115
        L_0x009a:
            b.s.d.p r6 = (p008b.p071s.p072d.LinearSnapHelper) r6
            r13 = -1
            if (r10 != 0) goto L_0x00a1
            goto L_0x0107
        L_0x00a1:
            androidx.recyclerview.widget.RecyclerView r10 = r7.f834b
            if (r10 == 0) goto L_0x00a9
            androidx.recyclerview.widget.RecyclerView$g r11 = r10.getAdapter()
        L_0x00a9:
            if (r11 == 0) goto L_0x00b0
            int r10 = r11.mo1337a()
            goto L_0x00b1
        L_0x00b0:
            r10 = 0
        L_0x00b1:
            if (r10 != 0) goto L_0x00b4
            goto L_0x0107
        L_0x00b4:
            android.view.View r11 = r6.mo3738a(r7)
            if (r11 != 0) goto L_0x00bb
            goto L_0x0107
        L_0x00bb:
            int r11 = r7.mo1392i(r11)
            if (r11 != r13) goto L_0x00c2
            goto L_0x0107
        L_0x00c2:
            r14 = r7
            androidx.recyclerview.widget.RecyclerView$z$b r14 = (androidx.recyclerview.widget.RecyclerView.C0165z.C0167b) r14
            int r15 = r10 + -1
            android.graphics.PointF r14 = r14.mo1051a(r15)
            if (r14 != 0) goto L_0x00ce
            goto L_0x0107
        L_0x00ce:
            boolean r16 = r7.mo1065a()
            r17 = 0
            if (r16 == 0) goto L_0x00e6
            b.s.d.t r8 = r6.mo3741b(r7)
            int r8 = r6.mo3737a(r7, r8, r4, r2)
            float r13 = r14.x
            int r13 = (r13 > r17 ? 1 : (r13 == r17 ? 0 : -1))
            if (r13 >= 0) goto L_0x00e7
            int r8 = -r8
            goto L_0x00e7
        L_0x00e6:
            r8 = 0
        L_0x00e7:
            boolean r13 = r7.mo1069b()
            if (r13 == 0) goto L_0x00fd
            b.s.d.t r13 = r6.mo3742c(r7)
            int r6 = r6.mo3737a(r7, r13, r2, r5)
            float r13 = r14.y
            int r13 = (r13 > r17 ? 1 : (r13 == r17 ? 0 : -1))
            if (r13 >= 0) goto L_0x00fe
            int r6 = -r6
            goto L_0x00fe
        L_0x00fd:
            r6 = 0
        L_0x00fe:
            boolean r13 = r7.mo1069b()
            if (r13 == 0) goto L_0x0105
            r8 = r6
        L_0x0105:
            if (r8 != 0) goto L_0x010a
        L_0x0107:
            r6 = -1
            r15 = -1
            goto L_0x0113
        L_0x010a:
            int r11 = r11 + r8
            if (r11 >= 0) goto L_0x010e
            r11 = 0
        L_0x010e:
            if (r11 < r10) goto L_0x0111
            goto L_0x0112
        L_0x0111:
            r15 = r11
        L_0x0112:
            r6 = -1
        L_0x0113:
            if (r15 != r6) goto L_0x0117
        L_0x0115:
            r6 = 0
            goto L_0x011d
        L_0x0117:
            r12.f877a = r15
            r7.mo1365a((androidx.recyclerview.widget.RecyclerView.C0165z) r12)
            r6 = 1
        L_0x011d:
            if (r6 == 0) goto L_0x0121
            r6 = 1
            goto L_0x0122
        L_0x0121:
            r6 = 0
        L_0x0122:
            if (r6 == 0) goto L_0x0126
            r6 = 1
            return r6
        L_0x0126:
            if (r9 == 0) goto L_0x0184
            if (r1 == 0) goto L_0x012c
            r1 = 1
            goto L_0x012d
        L_0x012c:
            r1 = 0
        L_0x012d:
            if (r3 == 0) goto L_0x0131
            r1 = r1 | 2
        L_0x0131:
            r3 = 1
            r0.startNestedScroll(r1, r3)
            int r1 = r0.mMaxFlingVelocity
            int r3 = -r1
            int r1 = java.lang.Math.min(r4, r1)
            int r9 = java.lang.Math.max(r3, r1)
            int r1 = r0.mMaxFlingVelocity
            int r3 = -r1
            int r1 = java.lang.Math.min(r5, r1)
            int r10 = java.lang.Math.max(r3, r1)
            androidx.recyclerview.widget.RecyclerView$c0 r1 = r0.mViewFlinger
            androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
            r4 = 2
            r3.setScrollState(r4)
            r1.f794c = r2
            r1.f793b = r2
            android.view.animation.Interpolator r2 = r1.f796e
            android.view.animation.Interpolator r3 = sQuinticInterpolator
            if (r2 == r3) goto L_0x016e
            r1.f796e = r3
            android.widget.OverScroller r2 = new android.widget.OverScroller
            androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
            android.content.Context r3 = r3.getContext()
            android.view.animation.Interpolator r4 = sQuinticInterpolator
            r2.<init>(r3, r4)
            r1.f795d = r2
        L_0x016e:
            android.widget.OverScroller r6 = r1.f795d
            r7 = 0
            r8 = 0
            r11 = -2147483648(0xffffffff80000000, float:-0.0)
            r12 = 2147483647(0x7fffffff, float:NaN)
            r13 = -2147483648(0xffffffff80000000, float:-0.0)
            r14 = 2147483647(0x7fffffff, float:NaN)
            r6.fling(r7, r8, r9, r10, r11, r12, r13, r14)
            r1.mo1304a()
            r1 = 1
            return r1
        L_0x0184:
            return r2
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.fling(int, int):boolean");
    }

    public View focusSearch(View view, int i) {
        View view2;
        boolean z;
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            boolean z2 = true;
            boolean z3 = this.mAdapter != null && oVar != null && !isComputingLayout() && !this.mLayoutSuppressed;
            FocusFinder instance = FocusFinder.getInstance();
            if (!z3 || !(i == 2 || i == 1)) {
                View findNextFocus = instance.findNextFocus(this, view, i);
                if (findNextFocus != null || !z3) {
                    view2 = findNextFocus;
                } else {
                    consumePendingUpdateOperations();
                    if (findContainingItemView(view) == null) {
                        return null;
                    }
                    startInterceptRequestLayout();
                    view2 = this.mLayout.mo1011a(view, i, this.mRecycler, this.mState);
                    stopInterceptRequestLayout(false);
                }
            } else {
                if (this.mLayout.mo1069b()) {
                    int i2 = i == 2 ? 130 : 33;
                    z = instance.findNextFocus(this, view, i2) == null;
                    if (FORCE_ABS_FOCUS_SEARCH_DIRECTION) {
                        i = i2;
                    }
                } else {
                    z = false;
                }
                if (!z && this.mLayout.mo1065a()) {
                    int i3 = (this.mLayout.mo1383f() == 1) ^ (i == 2) ? 66 : 17;
                    if (instance.findNextFocus(this, view, i3) != null) {
                        z2 = false;
                    }
                    if (FORCE_ABS_FOCUS_SEARCH_DIRECTION) {
                        i = i3;
                    }
                    z = z2;
                }
                if (z) {
                    consumePendingUpdateOperations();
                    if (findContainingItemView(view) == null) {
                        return null;
                    }
                    startInterceptRequestLayout();
                    this.mLayout.mo1011a(view, i, this.mRecycler, this.mState);
                    stopInterceptRequestLayout(false);
                }
                view2 = instance.findNextFocus(this, view, i);
            }
            if (view2 == null || view2.hasFocusable()) {
                return isPreferredNextFocus(view, view2, i) ? view2 : super.focusSearch(view, i);
            }
            if (getFocusedChild() == null) {
                return super.focusSearch(view, i);
            }
            requestChildOnScreen(view2, (View) null);
            return view;
        }
        throw null;
    }

    public ViewGroup.LayoutParams generateDefaultLayoutParams() {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            return oVar.mo1035c();
        }
        throw new IllegalStateException(outline.m2929a(this, outline.m2937a("RecyclerView has no LayoutManager")));
    }

    public ViewGroup.LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            return oVar.mo1013a(getContext(), attributeSet);
        }
        throw new IllegalStateException(outline.m2929a(this, outline.m2937a("RecyclerView has no LayoutManager")));
    }

    public CharSequence getAccessibilityClassName() {
        return "androidx.recyclerview.widget.RecyclerView";
    }

    public C0137g getAdapter() {
        return this.mAdapter;
    }

    public int getAdapterPositionFor(C0134d0 d0Var) {
        if (d0Var.mo1315b(524) || !d0Var.mo1320g()) {
            return -1;
        }
        AdapterHelper aVar = this.mAdapterHelper;
        int i = d0Var.f804c;
        int size = aVar.f3102b.size();
        for (int i2 = 0; i2 < size; i2++) {
            AdapterHelper.C0547b bVar = aVar.f3102b.get(i2);
            int i3 = bVar.f3108a;
            if (i3 != 1) {
                if (i3 == 2) {
                    int i4 = bVar.f3109b;
                    if (i4 <= i) {
                        int i5 = bVar.f3111d;
                        if (i4 + i5 > i) {
                            return -1;
                        }
                        i -= i5;
                    } else {
                        continue;
                    }
                } else if (i3 == 8) {
                    int i6 = bVar.f3109b;
                    if (i6 == i) {
                        i = bVar.f3111d;
                    } else {
                        if (i6 < i) {
                            i--;
                        }
                        if (bVar.f3111d <= i) {
                            i++;
                        }
                    }
                }
            } else if (bVar.f3109b <= i) {
                i += bVar.f3111d;
            }
        }
        return i;
    }

    public int getBaseline() {
        C0148o oVar = this.mLayout;
        if (oVar == null) {
            return super.getBaseline();
        }
        if (oVar != null) {
            return -1;
        }
        throw null;
    }

    public long getChangedHolderKey(C0134d0 d0Var) {
        if (this.mAdapter.f823b) {
            return d0Var.f806e;
        }
        return (long) d0Var.f804c;
    }

    public int getChildAdapterPosition(View view) {
        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
        if (childViewHolderInt != null) {
            return childViewHolderInt.mo1316c();
        }
        return -1;
    }

    public int getChildDrawingOrder(int i, int i2) {
        C0140j jVar = this.mChildDrawingOrderCallback;
        if (jVar == null) {
            return super.getChildDrawingOrder(i, i2);
        }
        return jVar.mo1343a(i, i2);
    }

    public long getChildItemId(View view) {
        C0134d0 childViewHolderInt;
        C0137g gVar = this.mAdapter;
        if (gVar == null || !gVar.f823b || (childViewHolderInt = getChildViewHolderInt(view)) == null) {
            return -1;
        }
        return childViewHolderInt.f806e;
    }

    public int getChildLayoutPosition(View view) {
        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
        if (childViewHolderInt != null) {
            return childViewHolderInt.mo1317d();
        }
        return -1;
    }

    @Deprecated
    public int getChildPosition(View view) {
        return getChildAdapterPosition(view);
    }

    public C0134d0 getChildViewHolder(View view) {
        ViewParent parent = view.getParent();
        if (parent == null || parent == this) {
            return getChildViewHolderInt(view);
        }
        throw new IllegalArgumentException("View " + view + " is not a direct child of " + this);
    }

    public boolean getClipToPadding() {
        return this.mClipToPadding;
    }

    public RecyclerViewAccessibilityDelegate getCompatAccessibilityDelegate() {
        return this.mAccessibilityDelegate;
    }

    public void getDecoratedBoundsWithMargins(View view, Rect rect) {
        getDecoratedBoundsWithMarginsInt(view, rect);
    }

    public C0141k getEdgeEffectFactory() {
        return this.mEdgeEffectFactory;
    }

    public C0142l getItemAnimator() {
        return this.mItemAnimator;
    }

    public Rect getItemDecorInsetsForChild(View view) {
        C0153p pVar = (C0153p) view.getLayoutParams();
        if (!pVar.f859c) {
            return pVar.f858b;
        }
        if (this.mState.f783g && (pVar.mo1403b() || pVar.f857a.mo1321h())) {
            return pVar.f858b;
        }
        Rect rect = pVar.f858b;
        rect.set(0, 0, 0, 0);
        int size = this.mItemDecorations.size();
        int i = 0;
        while (i < size) {
            this.mTempRect.set(0, 0, 0, 0);
            C0147n nVar = this.mItemDecorations.get(i);
            Rect rect2 = this.mTempRect;
            if (nVar != null) {
                ((C0153p) view.getLayoutParams()).mo1402a();
                rect2.set(0, 0, 0, 0);
                int i2 = rect.left;
                Rect rect3 = this.mTempRect;
                rect.left = i2 + rect3.left;
                rect.top += rect3.top;
                rect.right += rect3.right;
                rect.bottom += rect3.bottom;
                i++;
            } else {
                throw null;
            }
        }
        pVar.f859c = false;
        return rect;
    }

    public C0147n getItemDecorationAt(int i) {
        int itemDecorationCount = getItemDecorationCount();
        if (i >= 0 && i < itemDecorationCount) {
            return this.mItemDecorations.get(i);
        }
        throw new IndexOutOfBoundsException(i + " is an invalid index for size " + itemDecorationCount);
    }

    public int getItemDecorationCount() {
        return this.mItemDecorations.size();
    }

    public C0148o getLayoutManager() {
        return this.mLayout;
    }

    public int getMaxFlingVelocity() {
        return this.mMaxFlingVelocity;
    }

    public int getMinFlingVelocity() {
        return this.mMinFlingVelocity;
    }

    public long getNanoTime() {
        if (ALLOW_THREAD_GAP_WORK) {
            return System.nanoTime();
        }
        return 0;
    }

    public C0155r getOnFlingListener() {
        return this.mOnFlingListener;
    }

    public boolean getPreserveFocusAfterLayout() {
        return this.mPreserveFocusAfterLayout;
    }

    public C0158u getRecycledViewPool() {
        return this.mRecycler.mo1421b();
    }

    public int getScrollState() {
        return this.mScrollState;
    }

    public boolean hasFixedSize() {
        return this.mHasFixedSize;
    }

    public boolean hasNestedScrollingParent() {
        return getScrollingChildHelper().mo3128b(0);
    }

    public boolean hasPendingAdapterUpdates() {
        return !this.mFirstLayoutComplete || this.mDataSetHasChangedAfterLayout || this.mAdapterHelper.mo3665c();
    }

    public void initAdapterManager() {
        this.mAdapterHelper = new AdapterHelper(new C0136f());
    }

    public void initFastScroller(StateListDrawable stateListDrawable, Drawable drawable, StateListDrawable stateListDrawable2, Drawable drawable2) {
        if (stateListDrawable == null || drawable == null || stateListDrawable2 == null || drawable2 == null) {
            throw new IllegalArgumentException(outline.m2929a(this, outline.m2937a("Trying to set fast scroller without both required drawables.")));
        }
        Resources resources = getContext().getResources();
        new FastScroller(this, stateListDrawable, drawable, stateListDrawable2, drawable2, resources.getDimensionPixelSize(C0544b.fastscroll_default_thickness), resources.getDimensionPixelSize(C0544b.fastscroll_minimum_range), resources.getDimensionPixelOffset(C0544b.fastscroll_margin));
    }

    public void invalidateGlows() {
        this.mBottomGlow = null;
        this.mTopGlow = null;
        this.mRightGlow = null;
        this.mLeftGlow = null;
    }

    public void invalidateItemDecorations() {
        if (this.mItemDecorations.size() != 0) {
            C0148o oVar = this.mLayout;
            if (oVar != null) {
                oVar.mo1064a("Cannot invalidate item decorations during a scroll or layout");
            }
            markItemDecorInsetsDirty();
            requestLayout();
        }
    }

    public boolean isAccessibilityEnabled() {
        AccessibilityManager accessibilityManager = this.mAccessibilityManager;
        return accessibilityManager != null && accessibilityManager.isEnabled();
    }

    public boolean isAnimating() {
        C0142l lVar = this.mItemAnimator;
        return lVar != null && lVar.mo1352c();
    }

    public boolean isAttachedToWindow() {
        return this.mIsAttached;
    }

    public boolean isComputingLayout() {
        return this.mLayoutOrScrollCounter > 0;
    }

    @Deprecated
    public boolean isLayoutFrozen() {
        return isLayoutSuppressed();
    }

    public final boolean isLayoutSuppressed() {
        return this.mLayoutSuppressed;
    }

    public boolean isNestedScrollingEnabled() {
        return getScrollingChildHelper().f2513d;
    }

    public void jumpToPositionForSmoothScroller(int i) {
        if (this.mLayout != null) {
            setScrollState(2);
            this.mLayout.mo1078h(i);
            awakenScrollBars();
        }
    }

    public void markItemDecorInsetsDirty() {
        int b = this.mChildHelper.mo3675b();
        for (int i = 0; i < b; i++) {
            ((C0153p) this.mChildHelper.mo3680d(i).getLayoutParams()).f859c = true;
        }
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        for (int i2 = 0; i2 < size; i2++) {
            C0153p pVar = (C0153p) vVar.f869c.get(i2).f802a.getLayoutParams();
            if (pVar != null) {
                pVar.f859c = true;
            }
        }
    }

    public void markKnownViewsInvalid() {
        int b = this.mChildHelper.mo3675b();
        for (int i = 0; i < b; i++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i));
            if (childViewHolderInt != null && !childViewHolderInt.mo1328o()) {
                childViewHolderInt.mo1309a(6);
            }
        }
        markItemDecorInsetsDirty();
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        for (int i2 = 0; i2 < size; i2++) {
            C0134d0 d0Var = vVar.f869c.get(i2);
            if (d0Var != null) {
                d0Var.mo1309a(6);
                d0Var.mo1312a((Object) null);
            }
        }
        C0137g gVar = RecyclerView.this.mAdapter;
        if (gVar == null || !gVar.f823b) {
            vVar.mo1425c();
        }
    }

    public void offsetChildrenHorizontal(int i) {
        int a = this.mChildHelper.mo3670a();
        for (int i2 = 0; i2 < a; i2++) {
            this.mChildHelper.mo3677b(i2).offsetLeftAndRight(i);
        }
    }

    public void offsetChildrenVertical(int i) {
        int a = this.mChildHelper.mo3670a();
        for (int i2 = 0; i2 < a; i2++) {
            this.mChildHelper.mo3677b(i2).offsetTopAndBottom(i);
        }
    }

    public void offsetPositionRecordsForInsert(int i, int i2) {
        int b = this.mChildHelper.mo3675b();
        for (int i3 = 0; i3 < b; i3++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i3));
            if (childViewHolderInt != null && !childViewHolderInt.mo1328o() && childViewHolderInt.f804c >= i) {
                childViewHolderInt.mo1311a(i2, false);
                this.mState.f782f = true;
            }
        }
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        for (int i4 = 0; i4 < size; i4++) {
            C0134d0 d0Var = vVar.f869c.get(i4);
            if (d0Var != null && d0Var.f804c >= i) {
                d0Var.mo1311a(i2, true);
            }
        }
        requestLayout();
    }

    public void offsetPositionRecordsForMove(int i, int i2) {
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int b = this.mChildHelper.mo3675b();
        int i10 = -1;
        if (i < i2) {
            i5 = i;
            i4 = i2;
            i3 = -1;
        } else {
            i4 = i;
            i5 = i2;
            i3 = 1;
        }
        for (int i11 = 0; i11 < b; i11++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i11));
            if (childViewHolderInt != null && (i9 = childViewHolderInt.f804c) >= i5 && i9 <= i4) {
                if (i9 == i) {
                    childViewHolderInt.mo1311a(i2 - i, false);
                } else {
                    childViewHolderInt.mo1311a(i3, false);
                }
                this.mState.f782f = true;
            }
        }
        C0160v vVar = this.mRecycler;
        if (i < i2) {
            i7 = i;
            i6 = i2;
        } else {
            i6 = i;
            i7 = i2;
            i10 = 1;
        }
        int size = vVar.f869c.size();
        for (int i12 = 0; i12 < size; i12++) {
            C0134d0 d0Var = vVar.f869c.get(i12);
            if (d0Var != null && (i8 = d0Var.f804c) >= i7 && i8 <= i6) {
                if (i8 == i) {
                    d0Var.mo1311a(i2 - i, false);
                } else {
                    d0Var.mo1311a(i10, false);
                }
            }
        }
        requestLayout();
    }

    public void offsetPositionRecordsForRemove(int i, int i2, boolean z) {
        int i3 = i + i2;
        int b = this.mChildHelper.mo3675b();
        for (int i4 = 0; i4 < b; i4++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i4));
            if (childViewHolderInt != null && !childViewHolderInt.mo1328o()) {
                int i5 = childViewHolderInt.f804c;
                if (i5 >= i3) {
                    childViewHolderInt.mo1311a(-i2, z);
                    this.mState.f782f = true;
                } else if (i5 >= i) {
                    childViewHolderInt.mo1309a(8);
                    childViewHolderInt.mo1311a(-i2, z);
                    childViewHolderInt.f804c = i - 1;
                    this.mState.f782f = true;
                }
            }
        }
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        while (true) {
            size--;
            if (size >= 0) {
                C0134d0 d0Var = vVar.f869c.get(size);
                if (d0Var != null) {
                    int i6 = d0Var.f804c;
                    if (i6 >= i3) {
                        d0Var.mo1311a(-i2, z);
                    } else if (i6 >= i) {
                        d0Var.mo1309a(8);
                        vVar.mo1422b(size);
                    }
                }
            } else {
                requestLayout();
                return;
            }
        }
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mLayoutOrScrollCounter = 0;
        this.mIsAttached = true;
        this.mFirstLayoutComplete = this.mFirstLayoutComplete && !isLayoutRequested();
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            oVar.f841i = true;
        }
        this.mPostedAnimatorRunner = false;
        if (ALLOW_THREAD_GAP_WORK) {
            GapWorker mVar = GapWorker.f3204f.get();
            this.mGapWorker = mVar;
            if (mVar == null) {
                this.mGapWorker = new GapWorker();
                Display f = ViewCompat.m1958f(this);
                float f2 = 60.0f;
                if (!isInEditMode() && f != null) {
                    float refreshRate = f.getRefreshRate();
                    if (refreshRate >= 30.0f) {
                        f2 = refreshRate;
                    }
                }
                GapWorker mVar2 = this.mGapWorker;
                mVar2.f3208d = (long) (1.0E9f / f2);
                GapWorker.f3204f.set(mVar2);
            }
            this.mGapWorker.f3206b.add(this);
        }
    }

    public void onChildAttachedToWindow(View view) {
    }

    public void onChildDetachedFromWindow(View view) {
    }

    public void onDetachedFromWindow() {
        GapWorker mVar;
        super.onDetachedFromWindow();
        C0142l lVar = this.mItemAnimator;
        if (lVar != null) {
            lVar.mo1349b();
        }
        stopScroll();
        this.mIsAttached = false;
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            C0160v vVar = this.mRecycler;
            oVar.f841i = false;
            oVar.mo1063a(this, vVar);
        }
        this.mPendingAccessibilityImportanceChange.clear();
        removeCallbacks(this.mItemAnimatorRunner);
        if (this.mViewInfoStore != null) {
            do {
            } while (ViewInfoStore.C0575a.f3262d.mo3103a() != null);
            if (ALLOW_THREAD_GAP_WORK && (mVar = this.mGapWorker) != null) {
                mVar.f3206b.remove(this);
                this.mGapWorker = null;
                return;
            }
            return;
        }
        throw null;
    }

    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        int size = this.mItemDecorations.size();
        for (int i = 0; i < size; i++) {
            this.mItemDecorations.get(i).mo1354a(canvas, this, this.mState);
        }
    }

    public void onEnterLayoutOrScroll() {
        this.mLayoutOrScrollCounter++;
    }

    public void onExitLayoutOrScroll() {
        onExitLayoutOrScroll(true);
    }

    public boolean onGenericMotionEvent(MotionEvent motionEvent) {
        float f;
        float f2;
        if (this.mLayout != null && !this.mLayoutSuppressed && motionEvent.getAction() == 8) {
            if ((motionEvent.getSource() & 2) != 0) {
                f2 = this.mLayout.mo1069b() ? -motionEvent.getAxisValue(9) : 0.0f;
                if (this.mLayout.mo1065a()) {
                    f = motionEvent.getAxisValue(10);
                    if (!(f2 == 0.0f && f == 0.0f)) {
                        scrollByInternal((int) (f * this.mScaledHorizontalScrollFactor), (int) (f2 * this.mScaledVerticalScrollFactor), motionEvent);
                    }
                }
            } else {
                if ((motionEvent.getSource() & 4194304) != 0) {
                    float axisValue = motionEvent.getAxisValue(26);
                    if (this.mLayout.mo1069b()) {
                        f2 = -axisValue;
                    } else if (this.mLayout.mo1065a()) {
                        f = axisValue;
                        f2 = 0.0f;
                        scrollByInternal((int) (f * this.mScaledHorizontalScrollFactor), (int) (f2 * this.mScaledVerticalScrollFactor), motionEvent);
                    }
                }
                f2 = 0.0f;
            }
            f = 0.0f;
            scrollByInternal((int) (f * this.mScaledHorizontalScrollFactor), (int) (f2 * this.mScaledVerticalScrollFactor), motionEvent);
        }
        return false;
    }

    public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
        boolean z;
        if (this.mLayoutSuppressed) {
            return false;
        }
        this.mInterceptingOnItemTouchListener = null;
        if (findInterceptingOnItemTouchListener(motionEvent)) {
            cancelScroll();
            return true;
        }
        C0148o oVar = this.mLayout;
        if (oVar == null) {
            return false;
        }
        boolean a = oVar.mo1065a();
        boolean b = this.mLayout.mo1069b();
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        this.mVelocityTracker.addMovement(motionEvent);
        int actionMasked = motionEvent.getActionMasked();
        int actionIndex = motionEvent.getActionIndex();
        if (actionMasked == 0) {
            if (this.mIgnoreMotionEventTillDown) {
                this.mIgnoreMotionEventTillDown = false;
            }
            this.mScrollPointerId = motionEvent.getPointerId(0);
            int x = (int) (motionEvent.getX() + 0.5f);
            this.mLastTouchX = x;
            this.mInitialTouchX = x;
            int y = (int) (motionEvent.getY() + 0.5f);
            this.mLastTouchY = y;
            this.mInitialTouchY = y;
            if (this.mScrollState == 2) {
                getParent().requestDisallowInterceptTouchEvent(true);
                setScrollState(1);
                stopNestedScroll(1);
            }
            int[] iArr = this.mNestedOffsets;
            iArr[1] = 0;
            iArr[0] = 0;
            int i = a ? 1 : 0;
            if (b) {
                i |= 2;
            }
            startNestedScroll(i, 0);
        } else if (actionMasked == 1) {
            this.mVelocityTracker.clear();
            stopNestedScroll(0);
        } else if (actionMasked == 2) {
            int findPointerIndex = motionEvent.findPointerIndex(this.mScrollPointerId);
            if (findPointerIndex < 0) {
                StringBuilder a2 = outline.m2937a("Error processing scroll; pointer index for id ");
                a2.append(this.mScrollPointerId);
                a2.append(" not found. Did any MotionEvents get skipped?");
                Log.e(TAG, a2.toString());
                return false;
            }
            int x2 = (int) (motionEvent.getX(findPointerIndex) + 0.5f);
            int y2 = (int) (motionEvent.getY(findPointerIndex) + 0.5f);
            if (this.mScrollState != 1) {
                int i2 = x2 - this.mInitialTouchX;
                int i3 = y2 - this.mInitialTouchY;
                if (!a || Math.abs(i2) <= this.mTouchSlop) {
                    z = false;
                } else {
                    this.mLastTouchX = x2;
                    z = true;
                }
                if (b && Math.abs(i3) > this.mTouchSlop) {
                    this.mLastTouchY = y2;
                    z = true;
                }
                if (z) {
                    setScrollState(1);
                }
            }
        } else if (actionMasked == 3) {
            cancelScroll();
        } else if (actionMasked == 5) {
            this.mScrollPointerId = motionEvent.getPointerId(actionIndex);
            int x3 = (int) (motionEvent.getX(actionIndex) + 0.5f);
            this.mLastTouchX = x3;
            this.mInitialTouchX = x3;
            int y3 = (int) (motionEvent.getY(actionIndex) + 0.5f);
            this.mLastTouchY = y3;
            this.mInitialTouchY = y3;
        } else if (actionMasked == 6) {
            onPointerUp(motionEvent);
        }
        if (this.mScrollState == 1) {
            return true;
        }
        return false;
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        TraceCompat.m1852a(TRACE_ON_LAYOUT_TAG);
        dispatchLayout();
        Trace.endSection();
        this.mFirstLayoutComplete = true;
    }

    public void onMeasure(int i, int i2) {
        C0148o oVar = this.mLayout;
        if (oVar == null) {
            defaultOnMeasure(i, i2);
            return;
        }
        boolean z = false;
        if (oVar.mo1083m()) {
            int mode = View.MeasureSpec.getMode(i);
            int mode2 = View.MeasureSpec.getMode(i2);
            this.mLayout.f834b.defaultOnMeasure(i, i2);
            if (mode == 1073741824 && mode2 == 1073741824) {
                z = true;
            }
            if (!z && this.mAdapter != null) {
                if (this.mState.f780d == 1) {
                    dispatchLayoutStep1();
                }
                this.mLayout.mo1356a(i, i2);
                this.mState.f785i = true;
                dispatchLayoutStep2();
                this.mLayout.mo1369b(i, i2);
                if (this.mLayout.mo1085p()) {
                    this.mLayout.mo1356a(View.MeasureSpec.makeMeasureSpec(getMeasuredWidth(), 1073741824), View.MeasureSpec.makeMeasureSpec(getMeasuredHeight(), 1073741824));
                    this.mState.f785i = true;
                    dispatchLayoutStep2();
                    this.mLayout.mo1369b(i, i2);
                }
            }
        } else if (this.mHasFixedSize) {
            this.mLayout.f834b.defaultOnMeasure(i, i2);
        } else {
            if (this.mAdapterUpdateDuringMeasure) {
                startInterceptRequestLayout();
                onEnterLayoutOrScroll();
                processAdapterUpdatesAndSetAnimationFlags();
                onExitLayoutOrScroll();
                C0128a0 a0Var = this.mState;
                if (a0Var.f787k) {
                    a0Var.f783g = true;
                } else {
                    this.mAdapterHelper.mo3662b();
                    this.mState.f783g = false;
                }
                this.mAdapterUpdateDuringMeasure = false;
                stopInterceptRequestLayout(false);
            } else if (this.mState.f787k) {
                setMeasuredDimension(getMeasuredWidth(), getMeasuredHeight());
                return;
            }
            C0137g gVar = this.mAdapter;
            if (gVar != null) {
                this.mState.f781e = gVar.mo1337a();
            } else {
                this.mState.f781e = 0;
            }
            startInterceptRequestLayout();
            this.mLayout.f834b.defaultOnMeasure(i, i2);
            stopInterceptRequestLayout(false);
            this.mState.f783g = false;
        }
    }

    public boolean onRequestFocusInDescendants(int i, Rect rect) {
        if (isComputingLayout()) {
            return false;
        }
        return super.onRequestFocusInDescendants(i, rect);
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        Parcelable parcelable2;
        if (!(parcelable instanceof C0163y)) {
            super.onRestoreInstanceState(parcelable);
            return;
        }
        C0163y yVar = (C0163y) parcelable;
        this.mPendingSavedState = yVar;
        super.onRestoreInstanceState(yVar.f2617b);
        C0148o oVar = this.mLayout;
        if (oVar != null && (parcelable2 = this.mPendingSavedState.f876d) != null) {
            oVar.mo1057a(parcelable2);
        }
    }

    public Parcelable onSaveInstanceState() {
        C0163y yVar = new C0163y(super.onSaveInstanceState());
        C0163y yVar2 = this.mPendingSavedState;
        if (yVar2 != null) {
            yVar.f876d = yVar2.f876d;
        } else {
            C0148o oVar = this.mLayout;
            if (oVar != null) {
                yVar.f876d = oVar.mo1084n();
            } else {
                yVar.f876d = null;
            }
        }
        return yVar;
    }

    public void onScrollStateChanged(int i) {
    }

    public void onScrolled(int i, int i2) {
    }

    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        if (i != i3 || i2 != i4) {
            invalidateGlows();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:45:0x00de  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00f4  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean onTouchEvent(android.view.MotionEvent r18) {
        /*
            r17 = this;
            r6 = r17
            r7 = r18
            boolean r0 = r6.mLayoutSuppressed
            r8 = 0
            if (r0 != 0) goto L_0x01e6
            boolean r0 = r6.mIgnoreMotionEventTillDown
            if (r0 == 0) goto L_0x000f
            goto L_0x01e6
        L_0x000f:
            boolean r0 = r17.dispatchToOnItemTouchListeners(r18)
            r9 = 1
            if (r0 == 0) goto L_0x001a
            r17.cancelScroll()
            return r9
        L_0x001a:
            androidx.recyclerview.widget.RecyclerView$o r0 = r6.mLayout
            if (r0 != 0) goto L_0x001f
            return r8
        L_0x001f:
            boolean r10 = r0.mo1065a()
            androidx.recyclerview.widget.RecyclerView$o r0 = r6.mLayout
            boolean r11 = r0.mo1069b()
            android.view.VelocityTracker r0 = r6.mVelocityTracker
            if (r0 != 0) goto L_0x0033
            android.view.VelocityTracker r0 = android.view.VelocityTracker.obtain()
            r6.mVelocityTracker = r0
        L_0x0033:
            int r0 = r18.getActionMasked()
            int r1 = r18.getActionIndex()
            if (r0 != 0) goto L_0x0043
            int[] r2 = r6.mNestedOffsets
            r2[r9] = r8
            r2[r8] = r8
        L_0x0043:
            android.view.MotionEvent r12 = android.view.MotionEvent.obtain(r18)
            int[] r2 = r6.mNestedOffsets
            r3 = r2[r8]
            float r3 = (float) r3
            r2 = r2[r9]
            float r2 = (float) r2
            r12.offsetLocation(r3, r2)
            r2 = 1056964608(0x3f000000, float:0.5)
            if (r0 == 0) goto L_0x01b5
            if (r0 == r9) goto L_0x0173
            r3 = 2
            if (r0 == r3) goto L_0x008c
            r3 = 3
            if (r0 == r3) goto L_0x0087
            r3 = 5
            if (r0 == r3) goto L_0x006b
            r1 = 6
            if (r0 == r1) goto L_0x0066
            goto L_0x01db
        L_0x0066:
            r17.onPointerUp(r18)
            goto L_0x01db
        L_0x006b:
            int r0 = r7.getPointerId(r1)
            r6.mScrollPointerId = r0
            float r0 = r7.getX(r1)
            float r0 = r0 + r2
            int r0 = (int) r0
            r6.mLastTouchX = r0
            r6.mInitialTouchX = r0
            float r0 = r7.getY(r1)
            float r0 = r0 + r2
            int r0 = (int) r0
            r6.mLastTouchY = r0
            r6.mInitialTouchY = r0
            goto L_0x01db
        L_0x0087:
            r17.cancelScroll()
            goto L_0x01db
        L_0x008c:
            int r0 = r6.mScrollPointerId
            int r0 = r7.findPointerIndex(r0)
            if (r0 >= 0) goto L_0x00ae
            java.lang.String r0 = "Error processing scroll; pointer index for id "
            java.lang.StringBuilder r0 = p085c.p086a.p087a.p088a.outline.m2937a(r0)
            int r1 = r6.mScrollPointerId
            r0.append(r1)
            java.lang.String r1 = " not found. Did any MotionEvents get skipped?"
            r0.append(r1)
            java.lang.String r0 = r0.toString()
            java.lang.String r1 = "RecyclerView"
            android.util.Log.e(r1, r0)
            return r8
        L_0x00ae:
            float r1 = r7.getX(r0)
            float r1 = r1 + r2
            int r13 = (int) r1
            float r0 = r7.getY(r0)
            float r0 = r0 + r2
            int r14 = (int) r0
            int r0 = r6.mLastTouchX
            int r0 = r0 - r13
            int r1 = r6.mLastTouchY
            int r1 = r1 - r14
            int r2 = r6.mScrollState
            if (r2 == r9) goto L_0x00f7
            if (r10 == 0) goto L_0x00db
            if (r0 <= 0) goto L_0x00d0
            int r2 = r6.mTouchSlop
            int r0 = r0 - r2
            int r0 = java.lang.Math.max(r8, r0)
            goto L_0x00d7
        L_0x00d0:
            int r2 = r6.mTouchSlop
            int r0 = r0 + r2
            int r0 = java.lang.Math.min(r8, r0)
        L_0x00d7:
            if (r0 == 0) goto L_0x00db
            r2 = 1
            goto L_0x00dc
        L_0x00db:
            r2 = 0
        L_0x00dc:
            if (r11 == 0) goto L_0x00f2
            if (r1 <= 0) goto L_0x00e8
            int r3 = r6.mTouchSlop
            int r1 = r1 - r3
            int r1 = java.lang.Math.max(r8, r1)
            goto L_0x00ef
        L_0x00e8:
            int r3 = r6.mTouchSlop
            int r1 = r1 + r3
            int r1 = java.lang.Math.min(r8, r1)
        L_0x00ef:
            if (r1 == 0) goto L_0x00f2
            r2 = 1
        L_0x00f2:
            if (r2 == 0) goto L_0x00f7
            r6.setScrollState(r9)
        L_0x00f7:
            r15 = r0
            r16 = r1
            int r0 = r6.mScrollState
            if (r0 != r9) goto L_0x01db
            int[] r0 = r6.mReusableIntPair
            r0[r8] = r8
            r0[r9] = r8
            if (r10 == 0) goto L_0x0108
            r1 = r15
            goto L_0x010a
        L_0x0108:
            r0 = 0
            r1 = 0
        L_0x010a:
            if (r11 == 0) goto L_0x010f
            r2 = r16
            goto L_0x0111
        L_0x010f:
            r0 = 0
            r2 = 0
        L_0x0111:
            int[] r3 = r6.mReusableIntPair
            int[] r4 = r6.mScrollOffset
            r5 = 0
            r0 = r17
            boolean r0 = r0.dispatchNestedPreScroll(r1, r2, r3, r4, r5)
            if (r0 == 0) goto L_0x0140
            int[] r0 = r6.mReusableIntPair
            r1 = r0[r8]
            int r15 = r15 - r1
            r0 = r0[r9]
            int r16 = r16 - r0
            int[] r0 = r6.mNestedOffsets
            r1 = r0[r8]
            int[] r2 = r6.mScrollOffset
            r3 = r2[r8]
            int r1 = r1 + r3
            r0[r8] = r1
            r1 = r0[r9]
            r2 = r2[r9]
            int r1 = r1 + r2
            r0[r9] = r1
            android.view.ViewParent r0 = r17.getParent()
            r0.requestDisallowInterceptTouchEvent(r9)
        L_0x0140:
            r0 = r16
            int[] r1 = r6.mScrollOffset
            r2 = r1[r8]
            int r13 = r13 - r2
            r6.mLastTouchX = r13
            r1 = r1[r9]
            int r14 = r14 - r1
            r6.mLastTouchY = r14
            if (r10 == 0) goto L_0x0152
            r1 = r15
            goto L_0x0153
        L_0x0152:
            r1 = 0
        L_0x0153:
            if (r11 == 0) goto L_0x0157
            r2 = r0
            goto L_0x0158
        L_0x0157:
            r2 = 0
        L_0x0158:
            boolean r1 = r6.scrollByInternal(r1, r2, r7)
            if (r1 == 0) goto L_0x0165
            android.view.ViewParent r1 = r17.getParent()
            r1.requestDisallowInterceptTouchEvent(r9)
        L_0x0165:
            b.s.d.m r1 = r6.mGapWorker
            if (r1 == 0) goto L_0x01db
            if (r15 != 0) goto L_0x016d
            if (r0 == 0) goto L_0x01db
        L_0x016d:
            b.s.d.m r1 = r6.mGapWorker
            r1.mo3726a((androidx.recyclerview.widget.RecyclerView) r6, (int) r15, (int) r0)
            goto L_0x01db
        L_0x0173:
            android.view.VelocityTracker r0 = r6.mVelocityTracker
            r0.addMovement(r12)
            android.view.VelocityTracker r0 = r6.mVelocityTracker
            r1 = 1000(0x3e8, float:1.401E-42)
            int r2 = r6.mMaxFlingVelocity
            float r2 = (float) r2
            r0.computeCurrentVelocity(r1, r2)
            r0 = 0
            if (r10 == 0) goto L_0x018f
            android.view.VelocityTracker r1 = r6.mVelocityTracker
            int r2 = r6.mScrollPointerId
            float r1 = r1.getXVelocity(r2)
            float r1 = -r1
            goto L_0x0190
        L_0x018f:
            r1 = 0
        L_0x0190:
            if (r11 == 0) goto L_0x019c
            android.view.VelocityTracker r2 = r6.mVelocityTracker
            int r3 = r6.mScrollPointerId
            float r2 = r2.getYVelocity(r3)
            float r2 = -r2
            goto L_0x019d
        L_0x019c:
            r2 = 0
        L_0x019d:
            int r3 = (r1 > r0 ? 1 : (r1 == r0 ? 0 : -1))
            if (r3 != 0) goto L_0x01a5
            int r0 = (r2 > r0 ? 1 : (r2 == r0 ? 0 : -1))
            if (r0 == 0) goto L_0x01ad
        L_0x01a5:
            int r0 = (int) r1
            int r1 = (int) r2
            boolean r0 = r6.fling(r0, r1)
            if (r0 != 0) goto L_0x01b0
        L_0x01ad:
            r6.setScrollState(r8)
        L_0x01b0:
            r17.resetScroll()
            r8 = 1
            goto L_0x01db
        L_0x01b5:
            int r0 = r7.getPointerId(r8)
            r6.mScrollPointerId = r0
            float r0 = r18.getX()
            float r0 = r0 + r2
            int r0 = (int) r0
            r6.mLastTouchX = r0
            r6.mInitialTouchX = r0
            float r0 = r18.getY()
            float r0 = r0 + r2
            int r0 = (int) r0
            r6.mLastTouchY = r0
            r6.mInitialTouchY = r0
            if (r10 == 0) goto L_0x01d3
            r0 = 1
            goto L_0x01d4
        L_0x01d3:
            r0 = 0
        L_0x01d4:
            if (r11 == 0) goto L_0x01d8
            r0 = r0 | 2
        L_0x01d8:
            r6.startNestedScroll(r0, r8)
        L_0x01db:
            if (r8 != 0) goto L_0x01e2
            android.view.VelocityTracker r0 = r6.mVelocityTracker
            r0.addMovement(r12)
        L_0x01e2:
            r12.recycle()
            return r9
        L_0x01e6:
            return r8
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.onTouchEvent(android.view.MotionEvent):boolean");
    }

    public void postAnimationRunner() {
        if (!this.mPostedAnimatorRunner && this.mIsAttached) {
            ViewCompat.m1942a((View) this, this.mItemAnimatorRunner);
            this.mPostedAnimatorRunner = true;
        }
    }

    public void processDataSetCompletelyChanged(boolean z) {
        this.mDispatchItemsChangedEvent = z | this.mDispatchItemsChangedEvent;
        this.mDataSetHasChangedAfterLayout = true;
        markKnownViewsInvalid();
    }

    public void recordAnimationInfoIfBouncedHiddenView(C0134d0 d0Var, C0142l.C0145c cVar) {
        d0Var.mo1310a(0, (int) HarvestConnection.RESPONSE_BUFFER_SIZE);
        if (this.mState.f784h && d0Var.mo1326m() && !d0Var.mo1323j() && !d0Var.mo1328o()) {
            this.mViewInfoStore.f3261b.mo2725c(getChangedHolderKey(d0Var), d0Var);
        }
        this.mViewInfoStore.mo3767b(d0Var, cVar);
    }

    public void removeAndRecycleViews() {
        C0142l lVar = this.mItemAnimator;
        if (lVar != null) {
            lVar.mo1349b();
        }
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            oVar.mo1370b(this.mRecycler);
            this.mLayout.mo1375c(this.mRecycler);
        }
        this.mRecycler.mo1416a();
    }

    public boolean removeAnimatingView(View view) {
        startInterceptRequestLayout();
        ChildHelper bVar = this.mChildHelper;
        int indexOfChild = RecyclerView.this.indexOfChild(view);
        boolean z = true;
        if (indexOfChild == -1) {
            bVar.mo3681d(view);
        } else if (bVar.f3113b.mo3688c(indexOfChild)) {
            bVar.f3113b.mo3689d(indexOfChild);
            bVar.mo3681d(view);
            ((C0135e) bVar.f3112a).mo1333b(indexOfChild);
        } else {
            z = false;
        }
        if (z) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(view);
            this.mRecycler.mo1424b(childViewHolderInt);
            this.mRecycler.mo1419a(childViewHolderInt);
        }
        stopInterceptRequestLayout(!z);
        return z;
    }

    public void removeDetachedView(View view, boolean z) {
        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
        if (childViewHolderInt != null) {
            if (childViewHolderInt.mo1325l()) {
                childViewHolderInt.f811j &= -257;
            } else if (!childViewHolderInt.mo1328o()) {
                StringBuilder sb = new StringBuilder();
                sb.append("Called removeDetachedView with a view which is not flagged as tmp detached.");
                sb.append(childViewHolderInt);
                throw new IllegalArgumentException(outline.m2929a(this, sb));
            }
        }
        view.clearAnimation();
        dispatchChildDetached(view);
        super.removeDetachedView(view, z);
    }

    public void removeItemDecoration(C0147n nVar) {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            oVar.mo1064a("Cannot remove item decoration during a scroll  or layout");
        }
        this.mItemDecorations.remove(nVar);
        if (this.mItemDecorations.isEmpty()) {
            setWillNotDraw(getOverScrollMode() == 2);
        }
        markItemDecorInsetsDirty();
        requestLayout();
    }

    public void removeItemDecorationAt(int i) {
        int itemDecorationCount = getItemDecorationCount();
        if (i < 0 || i >= itemDecorationCount) {
            throw new IndexOutOfBoundsException(i + " is an invalid index for size " + itemDecorationCount);
        }
        removeItemDecoration(getItemDecorationAt(i));
    }

    public void removeOnChildAttachStateChangeListener(C0154q qVar) {
        List<C0154q> list = this.mOnChildAttachStateListeners;
        if (list != null) {
            list.remove(qVar);
        }
    }

    public void removeOnItemTouchListener(C0156s sVar) {
        this.mOnItemTouchListeners.remove(sVar);
        if (this.mInterceptingOnItemTouchListener == sVar) {
            this.mInterceptingOnItemTouchListener = null;
        }
    }

    public void removeOnScrollListener(C0157t tVar) {
        List<C0157t> list = this.mScrollListeners;
        if (list != null) {
            list.remove(tVar);
        }
    }

    public void repositionShadowingViews() {
        C0134d0 d0Var;
        int a = this.mChildHelper.mo3670a();
        for (int i = 0; i < a; i++) {
            View b = this.mChildHelper.mo3677b(i);
            C0134d0 childViewHolder = getChildViewHolder(b);
            if (!(childViewHolder == null || (d0Var = childViewHolder.f810i) == null)) {
                View view = d0Var.f802a;
                int left = b.getLeft();
                int top = b.getTop();
                if (left != view.getLeft() || top != view.getTop()) {
                    view.layout(left, top, view.getWidth() + left, view.getHeight() + top);
                }
            }
        }
    }

    public void requestChildFocus(View view, View view2) {
        C0165z zVar = this.mLayout.f839g;
        boolean z = true;
        if (!(zVar != null && zVar.f881e) && !isComputingLayout()) {
            z = false;
        }
        if (!z && view2 != null) {
            requestChildOnScreen(view, view2);
        }
        super.requestChildFocus(view, view2);
    }

    public boolean requestChildRectangleOnScreen(View view, Rect rect, boolean z) {
        return this.mLayout.mo1367a(this, view, rect, z, false);
    }

    public void requestDisallowInterceptTouchEvent(boolean z) {
        int size = this.mOnItemTouchListeners.size();
        for (int i = 0; i < size; i++) {
            this.mOnItemTouchListeners.get(i).mo1407a(z);
        }
        super.requestDisallowInterceptTouchEvent(z);
    }

    public void requestLayout() {
        if (this.mInterceptRequestLayoutDepth != 0 || this.mLayoutSuppressed) {
            this.mLayoutWasDefered = true;
        } else {
            super.requestLayout();
        }
    }

    public void saveOldPositions() {
        int b = this.mChildHelper.mo3675b();
        for (int i = 0; i < b; i++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i));
            if (!childViewHolderInt.mo1328o() && childViewHolderInt.f805d == -1) {
                childViewHolderInt.f805d = childViewHolderInt.f804c;
            }
        }
    }

    public void scrollBy(int i, int i2) {
        C0148o oVar = this.mLayout;
        if (oVar == null) {
            Log.e(TAG, "Cannot scroll without a LayoutManager set. Call setLayoutManager with a non-null argument.");
        } else if (!this.mLayoutSuppressed) {
            boolean a = oVar.mo1065a();
            boolean b = this.mLayout.mo1069b();
            if (a || b) {
                if (!a) {
                    i = 0;
                }
                if (!b) {
                    i2 = 0;
                }
                scrollByInternal(i, i2, (MotionEvent) null);
            }
        }
    }

    public boolean scrollByInternal(int i, int i2, MotionEvent motionEvent) {
        int i3;
        int i4;
        int i5;
        int i6;
        int i7 = i;
        int i8 = i2;
        consumePendingUpdateOperations();
        if (this.mAdapter != null) {
            int[] iArr = this.mReusableIntPair;
            iArr[0] = 0;
            iArr[1] = 0;
            scrollStep(i7, i8, iArr);
            int[] iArr2 = this.mReusableIntPair;
            int i9 = iArr2[0];
            int i10 = iArr2[1];
            i6 = i10;
            i5 = i9;
            i4 = i7 - i9;
            i3 = i8 - i10;
        } else {
            i6 = 0;
            i5 = 0;
            i4 = 0;
            i3 = 0;
        }
        if (!this.mItemDecorations.isEmpty()) {
            invalidate();
        }
        int[] iArr3 = this.mReusableIntPair;
        iArr3[0] = 0;
        iArr3[1] = 0;
        dispatchNestedScroll(i5, i6, i4, i3, this.mScrollOffset, 0, iArr3);
        int[] iArr4 = this.mReusableIntPair;
        int i11 = i4 - iArr4[0];
        int i12 = i3 - iArr4[1];
        boolean z = (iArr4[0] == 0 && iArr4[1] == 0) ? false : true;
        int i13 = this.mLastTouchX;
        int[] iArr5 = this.mScrollOffset;
        this.mLastTouchX = i13 - iArr5[0];
        this.mLastTouchY -= iArr5[1];
        int[] iArr6 = this.mNestedOffsets;
        iArr6[0] = iArr6[0] + iArr5[0];
        iArr6[1] = iArr6[1] + iArr5[1];
        if (getOverScrollMode() != 2) {
            if (motionEvent != null) {
                if (!((motionEvent.getSource() & 8194) == 8194)) {
                    pullGlows(motionEvent.getX(), (float) i11, motionEvent.getY(), (float) i12);
                }
            }
            considerReleasingGlowsOnScroll(i, i2);
        }
        if (!(i5 == 0 && i6 == 0)) {
            dispatchOnScrolled(i5, i6);
        }
        if (!awakenScrollBars()) {
            invalidate();
        }
        if (!z && i5 == 0 && i6 == 0) {
            return false;
        }
        return true;
    }

    public void scrollStep(int i, int i2, int[] iArr) {
        startInterceptRequestLayout();
        onEnterLayoutOrScroll();
        TraceCompat.m1852a(TRACE_SCROLL_TAG);
        fillRemainingScrollValues(this.mState);
        int a = i != 0 ? this.mLayout.mo1008a(i, this.mRecycler, this.mState) : 0;
        int b = i2 != 0 ? this.mLayout.mo1027b(i2, this.mRecycler, this.mState) : 0;
        Trace.endSection();
        repositionShadowingViews();
        onExitLayoutOrScroll();
        stopInterceptRequestLayout(false);
        if (iArr != null) {
            iArr[0] = a;
            iArr[1] = b;
        }
    }

    public void scrollTo(int i, int i2) {
        Log.w(TAG, "RecyclerView does not support scrolling to an absolute position. Use scrollToPosition instead");
    }

    public void scrollToPosition(int i) {
        if (!this.mLayoutSuppressed) {
            stopScroll();
            C0148o oVar = this.mLayout;
            if (oVar == null) {
                Log.e(TAG, "Cannot scroll to position a LayoutManager set. Call setLayoutManager with a non-null argument.");
                return;
            }
            oVar.mo1078h(i);
            awakenScrollBars();
        }
    }

    public void sendAccessibilityEventUnchecked(AccessibilityEvent accessibilityEvent) {
        if (!shouldDeferAccessibilityEvent(accessibilityEvent)) {
            super.sendAccessibilityEventUnchecked(accessibilityEvent);
        }
    }

    public void setAccessibilityDelegateCompat(RecyclerViewAccessibilityDelegate uVar) {
        this.mAccessibilityDelegate = uVar;
        ViewCompat.m1938a((View) this, (AccessibilityDelegateCompat) uVar);
    }

    public void setAdapter(C0137g gVar) {
        setLayoutFrozen(false);
        setAdapterInternal(gVar, false, true);
        processDataSetCompletelyChanged(false);
        requestLayout();
    }

    public void setChildDrawingOrderCallback(C0140j jVar) {
        if (jVar != this.mChildDrawingOrderCallback) {
            this.mChildDrawingOrderCallback = jVar;
            setChildrenDrawingOrderEnabled(jVar != null);
        }
    }

    public boolean setChildImportantForAccessibilityInternal(C0134d0 d0Var, int i) {
        if (isComputingLayout()) {
            d0Var.f818q = i;
            this.mPendingAccessibilityImportanceChange.add(d0Var);
            return false;
        }
        ViewCompat.m1962h(d0Var.f802a, i);
        return true;
    }

    public void setClipToPadding(boolean z) {
        if (z != this.mClipToPadding) {
            invalidateGlows();
        }
        this.mClipToPadding = z;
        super.setClipToPadding(z);
        if (this.mFirstLayoutComplete) {
            requestLayout();
        }
    }

    public void setEdgeEffectFactory(C0141k kVar) {
        if (kVar != null) {
            this.mEdgeEffectFactory = kVar;
            invalidateGlows();
            return;
        }
        throw null;
    }

    public void setHasFixedSize(boolean z) {
        this.mHasFixedSize = z;
    }

    public void setItemAnimator(C0142l lVar) {
        C0142l lVar2 = this.mItemAnimator;
        if (lVar2 != null) {
            lVar2.mo1349b();
            this.mItemAnimator.f824a = null;
        }
        this.mItemAnimator = lVar;
        if (lVar != null) {
            lVar.f824a = this.mItemAnimatorListener;
        }
    }

    public void setItemViewCacheSize(int i) {
        C0160v vVar = this.mRecycler;
        vVar.f871e = i;
        vVar.mo1426d();
    }

    @Deprecated
    public void setLayoutFrozen(boolean z) {
        suppressLayout(z);
    }

    public void setLayoutManager(C0148o oVar) {
        if (oVar != this.mLayout) {
            stopScroll();
            if (this.mLayout != null) {
                C0142l lVar = this.mItemAnimator;
                if (lVar != null) {
                    lVar.mo1349b();
                }
                this.mLayout.mo1370b(this.mRecycler);
                this.mLayout.mo1375c(this.mRecycler);
                this.mRecycler.mo1416a();
                if (this.mIsAttached) {
                    C0148o oVar2 = this.mLayout;
                    C0160v vVar = this.mRecycler;
                    oVar2.f841i = false;
                    oVar2.mo1063a(this, vVar);
                }
                this.mLayout.mo1376c((RecyclerView) null);
                this.mLayout = null;
            } else {
                this.mRecycler.mo1416a();
            }
            ChildHelper bVar = this.mChildHelper;
            ChildHelper.C0548a aVar = bVar.f3113b;
            aVar.f3115a = 0;
            ChildHelper.C0548a aVar2 = aVar.f3116b;
            if (aVar2 != null) {
                aVar2.mo3687b();
            }
            int size = bVar.f3114c.size();
            while (true) {
                size--;
                if (size >= 0) {
                    ChildHelper.C0549b bVar2 = bVar.f3112a;
                    View view = bVar.f3114c.get(size);
                    C0135e eVar = (C0135e) bVar2;
                    if (eVar != null) {
                        C0134d0 childViewHolderInt = getChildViewHolderInt(view);
                        if (childViewHolderInt != null) {
                            RecyclerView.this.setChildImportantForAccessibilityInternal(childViewHolderInt, childViewHolderInt.f817p);
                            childViewHolderInt.f817p = 0;
                        }
                        bVar.f3114c.remove(size);
                    } else {
                        throw null;
                    }
                } else {
                    C0135e eVar2 = (C0135e) bVar.f3112a;
                    int a = eVar2.mo1331a();
                    for (int i = 0; i < a; i++) {
                        View a2 = eVar2.mo1332a(i);
                        RecyclerView.this.dispatchChildDetached(a2);
                        a2.clearAnimation();
                    }
                    RecyclerView.this.removeAllViews();
                    this.mLayout = oVar;
                    if (oVar != null) {
                        if (oVar.f834b == null) {
                            oVar.mo1376c(this);
                            if (this.mIsAttached) {
                                this.mLayout.f841i = true;
                            }
                        } else {
                            StringBuilder sb = new StringBuilder();
                            sb.append("LayoutManager ");
                            sb.append(oVar);
                            sb.append(" is already attached to a RecyclerView:");
                            throw new IllegalArgumentException(outline.m2929a(oVar.f834b, sb));
                        }
                    }
                    this.mRecycler.mo1426d();
                    requestLayout();
                    return;
                }
            }
        }
    }

    @Deprecated
    public void setLayoutTransition(LayoutTransition layoutTransition) {
        if (layoutTransition == null) {
            super.setLayoutTransition((LayoutTransition) null);
            return;
        }
        throw new IllegalArgumentException("Providing a LayoutTransition into RecyclerView is not supported. Please use setItemAnimator() instead for animating changes to the items in this RecyclerView");
    }

    public void setNestedScrollingEnabled(boolean z) {
        NestedScrollingChildHelper scrollingChildHelper = getScrollingChildHelper();
        if (scrollingChildHelper.f2513d) {
            ViewCompat.m1924C(scrollingChildHelper.f2512c);
        }
        scrollingChildHelper.f2513d = z;
    }

    public void setOnFlingListener(C0155r rVar) {
        this.mOnFlingListener = rVar;
    }

    @Deprecated
    public void setOnScrollListener(C0157t tVar) {
        this.mScrollListener = tVar;
    }

    public void setPreserveFocusAfterLayout(boolean z) {
        this.mPreserveFocusAfterLayout = z;
    }

    public void setRecycledViewPool(C0158u uVar) {
        C0160v vVar = this.mRecycler;
        C0158u uVar2 = vVar.f873g;
        if (uVar2 != null) {
            uVar2.f862b--;
        }
        vVar.f873g = uVar;
        if (uVar != null && RecyclerView.this.getAdapter() != null) {
            vVar.f873g.f862b++;
        }
    }

    public void setRecyclerListener(C0161w wVar) {
        this.mRecyclerListener = wVar;
    }

    public void setScrollState(int i) {
        if (i != this.mScrollState) {
            this.mScrollState = i;
            if (i != 2) {
                stopScrollersInternal();
            }
            dispatchOnScrollStateChanged(i);
        }
    }

    public void setScrollingTouchSlop(int i) {
        ViewConfiguration viewConfiguration = ViewConfiguration.get(getContext());
        if (i != 0) {
            if (i != 1) {
                Log.w(TAG, "setScrollingTouchSlop(): bad argument constant " + i + "; using default value");
            } else {
                this.mTouchSlop = viewConfiguration.getScaledPagingTouchSlop();
                return;
            }
        }
        this.mTouchSlop = viewConfiguration.getScaledTouchSlop();
    }

    public void setViewCacheExtension(C0130b0 b0Var) {
    }

    public boolean shouldDeferAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        int i = 0;
        if (!isComputingLayout()) {
            return false;
        }
        int contentChangeTypes = accessibilityEvent != null ? accessibilityEvent.getContentChangeTypes() : 0;
        if (contentChangeTypes != 0) {
            i = contentChangeTypes;
        }
        this.mEatenAccessibilityChangeFlags |= i;
        return true;
    }

    public void smoothScrollBy(int i, int i2) {
        smoothScrollBy(i, i2, (Interpolator) null);
    }

    public void smoothScrollToPosition(int i) {
        if (!this.mLayoutSuppressed) {
            C0148o oVar = this.mLayout;
            if (oVar == null) {
                Log.e(TAG, "Cannot smooth scroll without a LayoutManager set. Call setLayoutManager with a non-null argument.");
            } else {
                oVar.mo1062a(this, this.mState, i);
            }
        }
    }

    public void startInterceptRequestLayout() {
        int i = this.mInterceptRequestLayoutDepth + 1;
        this.mInterceptRequestLayoutDepth = i;
        if (i == 1 && !this.mLayoutSuppressed) {
            this.mLayoutWasDefered = false;
        }
    }

    public boolean startNestedScroll(int i) {
        return getScrollingChildHelper().mo3125a(i, 0);
    }

    public void stopInterceptRequestLayout(boolean z) {
        if (this.mInterceptRequestLayoutDepth < 1) {
            this.mInterceptRequestLayoutDepth = 1;
        }
        if (!z && !this.mLayoutSuppressed) {
            this.mLayoutWasDefered = false;
        }
        if (this.mInterceptRequestLayoutDepth == 1) {
            if (z && this.mLayoutWasDefered && !this.mLayoutSuppressed && this.mLayout != null && this.mAdapter != null) {
                dispatchLayout();
            }
            if (!this.mLayoutSuppressed) {
                this.mLayoutWasDefered = false;
            }
        }
        this.mInterceptRequestLayoutDepth--;
    }

    public void stopNestedScroll() {
        getScrollingChildHelper().mo3130c(0);
    }

    public void stopScroll() {
        setScrollState(0);
        stopScrollersInternal();
    }

    public final void suppressLayout(boolean z) {
        if (z != this.mLayoutSuppressed) {
            assertNotInLayoutOrScroll("Do not suppressLayout in layout or scroll");
            if (!z) {
                this.mLayoutSuppressed = false;
                if (!(!this.mLayoutWasDefered || this.mLayout == null || this.mAdapter == null)) {
                    requestLayout();
                }
                this.mLayoutWasDefered = false;
                return;
            }
            long uptimeMillis = SystemClock.uptimeMillis();
            onTouchEvent(MotionEvent.obtain(uptimeMillis, uptimeMillis, 3, 0.0f, 0.0f, 0));
            this.mLayoutSuppressed = true;
            this.mIgnoreMotionEventTillDown = true;
            stopScroll();
        }
    }

    public void swapAdapter(C0137g gVar, boolean z) {
        setLayoutFrozen(false);
        setAdapterInternal(gVar, true, z);
        processDataSetCompletelyChanged(true);
        requestLayout();
    }

    public void viewRangeUpdate(int i, int i2, Object obj) {
        int i3;
        int i4;
        int b = this.mChildHelper.mo3675b();
        int i5 = i2 + i;
        for (int i6 = 0; i6 < b; i6++) {
            View d = this.mChildHelper.mo3680d(i6);
            C0134d0 childViewHolderInt = getChildViewHolderInt(d);
            if (childViewHolderInt != null && !childViewHolderInt.mo1328o() && (i4 = childViewHolderInt.f804c) >= i && i4 < i5) {
                childViewHolderInt.mo1309a(2);
                childViewHolderInt.mo1312a(obj);
                ((C0153p) d.getLayoutParams()).f859c = true;
            }
        }
        C0160v vVar = this.mRecycler;
        int size = vVar.f869c.size();
        while (true) {
            size--;
            if (size >= 0) {
                C0134d0 d0Var = vVar.f869c.get(size);
                if (d0Var != null && (i3 = d0Var.f804c) >= i && i3 < i5) {
                    d0Var.mo1309a(2);
                    vVar.mo1422b(size);
                }
            } else {
                return;
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$f */
    public class C0136f implements AdapterHelper.C0546a {
        public C0136f() {
        }

        /* renamed from: a */
        public C0134d0 mo1334a(int i) {
            C0134d0 findViewHolderForPosition = RecyclerView.this.findViewHolderForPosition(i, true);
            if (findViewHolderForPosition != null && !RecyclerView.this.mChildHelper.mo3679c(findViewHolderForPosition.f802a)) {
                return findViewHolderForPosition;
            }
            return null;
        }

        /* renamed from: a */
        public void mo1335a(int i, int i2, Object obj) {
            RecyclerView.this.viewRangeUpdate(i, i2, obj);
            RecyclerView.this.mItemsChanged = true;
        }

        /* renamed from: a */
        public void mo1336a(AdapterHelper.C0547b bVar) {
            int i = bVar.f3108a;
            if (i == 1) {
                RecyclerView recyclerView = RecyclerView.this;
                recyclerView.mLayout.mo1022a(recyclerView, bVar.f3109b, bVar.f3111d);
            } else if (i == 2) {
                RecyclerView recyclerView2 = RecyclerView.this;
                recyclerView2.mLayout.mo1032b(recyclerView2, bVar.f3109b, bVar.f3111d);
            } else if (i == 4) {
                RecyclerView recyclerView3 = RecyclerView.this;
                recyclerView3.mLayout.mo1024a(recyclerView3, bVar.f3109b, bVar.f3111d, bVar.f3110c);
            } else if (i == 8) {
                RecyclerView recyclerView4 = RecyclerView.this;
                recyclerView4.mLayout.mo1023a(recyclerView4, bVar.f3109b, bVar.f3111d, 1);
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$v */
    public final class C0160v {

        /* renamed from: a */
        public final ArrayList<C0134d0> f867a = new ArrayList<>();

        /* renamed from: b */
        public ArrayList<C0134d0> f868b = null;

        /* renamed from: c */
        public final ArrayList<C0134d0> f869c = new ArrayList<>();

        /* renamed from: d */
        public final List<C0134d0> f870d = Collections.unmodifiableList(this.f867a);

        /* renamed from: e */
        public int f871e = 2;

        /* renamed from: f */
        public int f872f = 2;

        /* renamed from: g */
        public C0158u f873g;

        public C0160v() {
        }

        /* renamed from: a */
        public void mo1416a() {
            this.f867a.clear();
            mo1425c();
        }

        /* renamed from: b */
        public void mo1422b(int i) {
            mo1420a(this.f869c.get(i), true);
            this.f869c.remove(i);
        }

        /* renamed from: c */
        public void mo1425c() {
            for (int size = this.f869c.size() - 1; size >= 0; size--) {
                mo1422b(size);
            }
            this.f869c.clear();
            if (RecyclerView.ALLOW_THREAD_GAP_WORK) {
                GapWorker.C0565b bVar = RecyclerView.this.mPrefetchRegistry;
                int[] iArr = bVar.f3212c;
                if (iArr != null) {
                    Arrays.fill(iArr, -1);
                }
                bVar.f3213d = 0;
            }
        }

        /* renamed from: d */
        public void mo1426d() {
            C0148o oVar = RecyclerView.this.mLayout;
            this.f872f = this.f871e + (oVar != null ? oVar.f845m : 0);
            for (int size = this.f869c.size() - 1; size >= 0 && this.f869c.size() > this.f872f; size--) {
                mo1422b(size);
            }
        }

        /* renamed from: a */
        public int mo1414a(int i) {
            if (i < 0 || i >= RecyclerView.this.mState.mo1299a()) {
                StringBuilder sb = new StringBuilder();
                sb.append("invalid position ");
                sb.append(i);
                sb.append(". State item count is ");
                sb.append(RecyclerView.this.mState.mo1299a());
                throw new IndexOutOfBoundsException(outline.m2929a(RecyclerView.this, sb));
            }
            RecyclerView recyclerView = RecyclerView.this;
            if (!recyclerView.mState.f783g) {
                return i;
            }
            return recyclerView.mAdapterHelper.mo3654a(i, 0);
        }

        /* renamed from: b */
        public void mo1423b(View view) {
            C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(view);
            if (!childViewHolderInt.mo1315b(12) && childViewHolderInt.mo1326m() && !RecyclerView.this.canReuseUpdatedViewHolder(childViewHolderInt)) {
                if (this.f868b == null) {
                    this.f868b = new ArrayList<>();
                }
                childViewHolderInt.f815n = this;
                childViewHolderInt.f816o = true;
                this.f868b.add(childViewHolderInt);
            } else if (!childViewHolderInt.mo1321h() || childViewHolderInt.mo1323j() || RecyclerView.this.mAdapter.f823b) {
                childViewHolderInt.f815n = this;
                childViewHolderInt.f816o = false;
                this.f867a.add(childViewHolderInt);
            } else {
                throw new IllegalArgumentException(outline.m2929a(RecyclerView.this, outline.m2937a("Called scrap view with an invalid view. Invalid views cannot be reused from scrap, they should rebound from recycler pool.")));
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:107:0x01e5, code lost:
            if (r7.f807f != 0) goto L_0x01fe;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:245:0x044f, code lost:
            if (r7.mo1321h() == false) goto L_0x0485;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:254:0x0483, code lost:
            if ((r11 == 0 || r11 + r9 < r19) == false) goto L_0x0485;
         */
        /* JADX WARNING: Removed duplicated region for block: B:130:0x0248  */
        /* JADX WARNING: Removed duplicated region for block: B:231:0x0417  */
        /* JADX WARNING: Removed duplicated region for block: B:236:0x0438  */
        /* JADX WARNING: Removed duplicated region for block: B:237:0x043b  */
        /* JADX WARNING: Removed duplicated region for block: B:289:0x0529  */
        /* JADX WARNING: Removed duplicated region for block: B:290:0x0537  */
        /* JADX WARNING: Removed duplicated region for block: B:34:0x0089  */
        /* JADX WARNING: Removed duplicated region for block: B:39:0x0090  */
        /* renamed from: a */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public androidx.recyclerview.widget.RecyclerView.C0134d0 mo1415a(int r17, boolean r18, long r19) {
            /*
                r16 = this;
                r1 = r16
                r0 = r17
                if (r0 < 0) goto L_0x055a
                androidx.recyclerview.widget.RecyclerView r2 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r2 = r2.mState
                int r2 = r2.mo1299a()
                if (r0 >= r2) goto L_0x055a
                androidx.recyclerview.widget.RecyclerView r2 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r2 = r2.mState
                boolean r2 = r2.f783g
                r3 = 32
                r4 = 0
                r5 = 0
                if (r2 == 0) goto L_0x008b
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r2 = r1.f868b
                if (r2 == 0) goto L_0x0086
                int r2 = r2.size()
                if (r2 != 0) goto L_0x0027
                goto L_0x0086
            L_0x0027:
                r6 = 0
            L_0x0028:
                if (r6 >= r2) goto L_0x0045
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f868b
                java.lang.Object r7 = r7.get(r6)
                androidx.recyclerview.widget.RecyclerView$d0 r7 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r7
                boolean r8 = r7.mo1329p()
                if (r8 != 0) goto L_0x0042
                int r8 = r7.mo1317d()
                if (r8 != r0) goto L_0x0042
                r7.mo1309a((int) r3)
                goto L_0x0087
            L_0x0042:
                int r6 = r6 + 1
                goto L_0x0028
            L_0x0045:
                androidx.recyclerview.widget.RecyclerView r6 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r7 = r6.mAdapter
                boolean r7 = r7.f823b
                if (r7 == 0) goto L_0x0086
                b.s.d.a r6 = r6.mAdapterHelper
                int r6 = r6.mo3654a((int) r0, (int) r5)
                if (r6 <= 0) goto L_0x0086
                androidx.recyclerview.widget.RecyclerView r7 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r7 = r7.mAdapter
                int r7 = r7.mo1337a()
                if (r6 >= r7) goto L_0x0086
                androidx.recyclerview.widget.RecyclerView r7 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r7 = r7.mAdapter
                long r6 = r7.mo1338a(r6)
                r8 = 0
            L_0x0068:
                if (r8 >= r2) goto L_0x0086
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r9 = r1.f868b
                java.lang.Object r9 = r9.get(r8)
                androidx.recyclerview.widget.RecyclerView$d0 r9 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r9
                boolean r10 = r9.mo1329p()
                if (r10 != 0) goto L_0x0083
                long r10 = r9.f806e
                int r12 = (r10 > r6 ? 1 : (r10 == r6 ? 0 : -1))
                if (r12 != 0) goto L_0x0083
                r9.mo1309a((int) r3)
                r7 = r9
                goto L_0x0087
            L_0x0083:
                int r8 = r8 + 1
                goto L_0x0068
            L_0x0086:
                r7 = r4
            L_0x0087:
                if (r7 == 0) goto L_0x008c
                r2 = 1
                goto L_0x008d
            L_0x008b:
                r7 = r4
            L_0x008c:
                r2 = 0
            L_0x008d:
                r6 = -1
                if (r7 != 0) goto L_0x0245
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f867a
                int r7 = r7.size()
                r8 = 0
            L_0x0097:
                if (r8 >= r7) goto L_0x00c9
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r9 = r1.f867a
                java.lang.Object r9 = r9.get(r8)
                androidx.recyclerview.widget.RecyclerView$d0 r9 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r9
                boolean r10 = r9.mo1329p()
                if (r10 != 0) goto L_0x00c6
                int r10 = r9.mo1317d()
                if (r10 != r0) goto L_0x00c6
                boolean r10 = r9.mo1321h()
                if (r10 != 0) goto L_0x00c6
                androidx.recyclerview.widget.RecyclerView r10 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r10 = r10.mState
                boolean r10 = r10.f783g
                if (r10 != 0) goto L_0x00c1
                boolean r10 = r9.mo1323j()
                if (r10 != 0) goto L_0x00c6
            L_0x00c1:
                r9.mo1309a((int) r3)
                goto L_0x01b4
            L_0x00c6:
                int r8 = r8 + 1
                goto L_0x0097
            L_0x00c9:
                if (r18 != 0) goto L_0x018a
                androidx.recyclerview.widget.RecyclerView r7 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.b r7 = r7.mChildHelper
                java.util.List<android.view.View> r8 = r7.f3114c
                int r8 = r8.size()
                r9 = 0
            L_0x00d6:
                if (r9 >= r8) goto L_0x0101
                java.util.List<android.view.View> r10 = r7.f3114c
                java.lang.Object r10 = r10.get(r9)
                android.view.View r10 = (android.view.View) r10
                b.s.d.b$b r11 = r7.f3112a
                androidx.recyclerview.widget.RecyclerView$e r11 = (androidx.recyclerview.widget.RecyclerView.C0135e) r11
                if (r11 == 0) goto L_0x0100
                androidx.recyclerview.widget.RecyclerView$d0 r11 = androidx.recyclerview.widget.RecyclerView.getChildViewHolderInt(r10)
                int r12 = r11.mo1317d()
                if (r12 != r0) goto L_0x00fd
                boolean r12 = r11.mo1321h()
                if (r12 != 0) goto L_0x00fd
                boolean r11 = r11.mo1323j()
                if (r11 != 0) goto L_0x00fd
                goto L_0x0102
            L_0x00fd:
                int r9 = r9 + 1
                goto L_0x00d6
            L_0x0100:
                throw r4
            L_0x0101:
                r10 = r4
            L_0x0102:
                if (r10 == 0) goto L_0x018a
                androidx.recyclerview.widget.RecyclerView$d0 r7 = androidx.recyclerview.widget.RecyclerView.getChildViewHolderInt(r10)
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.b r8 = r8.mChildHelper
                b.s.d.b$b r9 = r8.f3112a
                androidx.recyclerview.widget.RecyclerView$e r9 = (androidx.recyclerview.widget.RecyclerView.C0135e) r9
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.this
                int r9 = r9.indexOfChild(r10)
                if (r9 < 0) goto L_0x0173
                b.s.d.b$a r11 = r8.f3113b
                boolean r11 = r11.mo3688c(r9)
                if (r11 == 0) goto L_0x015c
                b.s.d.b$a r11 = r8.f3113b
                r11.mo3684a(r9)
                r8.mo3681d((android.view.View) r10)
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.b r8 = r8.mChildHelper
                int r8 = r8.mo3676b((android.view.View) r10)
                if (r8 == r6) goto L_0x0143
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.b r9 = r9.mChildHelper
                r9.mo3671a((int) r8)
                r1.mo1423b((android.view.View) r10)
                r8 = 8224(0x2020, float:1.1524E-41)
                r7.mo1309a((int) r8)
                goto L_0x01ba
            L_0x0143:
                java.lang.IllegalStateException r0 = new java.lang.IllegalStateException
                java.lang.StringBuilder r2 = new java.lang.StringBuilder
                r2.<init>()
                java.lang.String r3 = "layout index should not be -1 after unhiding a view:"
                r2.append(r3)
                r2.append(r7)
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                java.lang.String r2 = p085c.p086a.p087a.p088a.outline.m2929a((androidx.recyclerview.widget.RecyclerView) r3, (java.lang.StringBuilder) r2)
                r0.<init>(r2)
                throw r0
            L_0x015c:
                java.lang.RuntimeException r0 = new java.lang.RuntimeException
                java.lang.StringBuilder r2 = new java.lang.StringBuilder
                r2.<init>()
                java.lang.String r3 = "trying to unhide a view that was not hidden"
                r2.append(r3)
                r2.append(r10)
                java.lang.String r2 = r2.toString()
                r0.<init>(r2)
                throw r0
            L_0x0173:
                java.lang.IllegalArgumentException r0 = new java.lang.IllegalArgumentException
                java.lang.StringBuilder r2 = new java.lang.StringBuilder
                r2.<init>()
                java.lang.String r3 = "view is not a child, cannot hide "
                r2.append(r3)
                r2.append(r10)
                java.lang.String r2 = r2.toString()
                r0.<init>(r2)
                throw r0
            L_0x018a:
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f869c
                int r7 = r7.size()
                r8 = 0
            L_0x0191:
                if (r8 >= r7) goto L_0x01b9
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r9 = r1.f869c
                java.lang.Object r9 = r9.get(r8)
                androidx.recyclerview.widget.RecyclerView$d0 r9 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r9
                boolean r10 = r9.mo1321h()
                if (r10 != 0) goto L_0x01b6
                int r10 = r9.mo1317d()
                if (r10 != r0) goto L_0x01b6
                boolean r10 = r9.mo1319f()
                if (r10 != 0) goto L_0x01b6
                if (r18 != 0) goto L_0x01b4
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f869c
                r7.remove(r8)
            L_0x01b4:
                r7 = r9
                goto L_0x01ba
            L_0x01b6:
                int r8 = r8 + 1
                goto L_0x0191
            L_0x01b9:
                r7 = r4
            L_0x01ba:
                if (r7 == 0) goto L_0x0245
                boolean r8 = r7.mo1323j()
                if (r8 == 0) goto L_0x01c9
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r8 = r8.mState
                boolean r8 = r8.f783g
                goto L_0x0201
            L_0x01c9:
                int r8 = r7.f804c
                if (r8 < 0) goto L_0x022c
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r9 = r9.mAdapter
                int r9 = r9.mo1337a()
                if (r8 >= r9) goto L_0x022c
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r9 = r8.mState
                boolean r9 = r9.f783g
                if (r9 != 0) goto L_0x01e9
                androidx.recyclerview.widget.RecyclerView$g r8 = r8.mAdapter
                if (r8 == 0) goto L_0x01e8
                int r8 = r7.f807f
                if (r8 == 0) goto L_0x01e9
                goto L_0x01fe
            L_0x01e8:
                throw r4
            L_0x01e9:
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r8 = r8.mAdapter
                boolean r9 = r8.f823b
                if (r9 == 0) goto L_0x0200
                long r9 = r7.f806e
                int r11 = r7.f804c
                long r11 = r8.mo1338a(r11)
                int r8 = (r9 > r11 ? 1 : (r9 == r11 ? 0 : -1))
                if (r8 != 0) goto L_0x01fe
                goto L_0x0200
            L_0x01fe:
                r8 = 0
                goto L_0x0201
            L_0x0200:
                r8 = 1
            L_0x0201:
                if (r8 != 0) goto L_0x022a
                if (r18 != 0) goto L_0x0228
                r8 = 4
                r7.mo1309a((int) r8)
                boolean r8 = r7.mo1324k()
                if (r8 == 0) goto L_0x021c
                androidx.recyclerview.widget.RecyclerView r8 = androidx.recyclerview.widget.RecyclerView.this
                android.view.View r9 = r7.f802a
                r8.removeDetachedView(r9, r5)
                androidx.recyclerview.widget.RecyclerView$v r8 = r7.f815n
                r8.mo1424b((androidx.recyclerview.widget.RecyclerView.C0134d0) r7)
                goto L_0x0225
            L_0x021c:
                boolean r8 = r7.mo1329p()
                if (r8 == 0) goto L_0x0225
                r7.mo1314b()
            L_0x0225:
                r1.mo1419a((androidx.recyclerview.widget.RecyclerView.C0134d0) r7)
            L_0x0228:
                r7 = r4
                goto L_0x0245
            L_0x022a:
                r2 = 1
                goto L_0x0245
            L_0x022c:
                java.lang.IndexOutOfBoundsException r0 = new java.lang.IndexOutOfBoundsException
                java.lang.StringBuilder r2 = new java.lang.StringBuilder
                r2.<init>()
                java.lang.String r3 = "Inconsistency detected. Invalid view holder adapter position"
                r2.append(r3)
                r2.append(r7)
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                java.lang.String r2 = p085c.p086a.p087a.p088a.outline.m2929a((androidx.recyclerview.widget.RecyclerView) r3, (java.lang.StringBuilder) r2)
                r0.<init>(r2)
                throw r0
            L_0x0245:
                r8 = 2
                if (r7 != 0) goto L_0x03fa
                androidx.recyclerview.widget.RecyclerView r11 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.a r11 = r11.mAdapterHelper
                int r11 = r11.mo3654a((int) r0, (int) r5)
                if (r11 < 0) goto L_0x03c9
                androidx.recyclerview.widget.RecyclerView r12 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r12 = r12.mAdapter
                int r12 = r12.mo1337a()
                if (r11 >= r12) goto L_0x03c9
                androidx.recyclerview.widget.RecyclerView r12 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r12 = r12.mAdapter
                if (r12 == 0) goto L_0x03c8
                boolean r13 = r12.f823b
                if (r13 == 0) goto L_0x02fc
                long r12 = r12.mo1338a(r11)
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f867a
                int r7 = r7.size()
                int r7 = r7 + r6
            L_0x0271:
                if (r7 < 0) goto L_0x02c4
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r14 = r1.f867a
                java.lang.Object r14 = r14.get(r7)
                androidx.recyclerview.widget.RecyclerView$d0 r14 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r14
                long r9 = r14.f806e
                int r15 = (r9 > r12 ? 1 : (r9 == r12 ? 0 : -1))
                if (r15 != 0) goto L_0x02c1
                boolean r9 = r14.mo1329p()
                if (r9 != 0) goto L_0x02c1
                int r9 = r14.f807f
                if (r9 != 0) goto L_0x02a3
                r14.mo1309a((int) r3)
                boolean r3 = r14.mo1323j()
                if (r3 == 0) goto L_0x02a1
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r3 = r3.mState
                boolean r3 = r3.f783g
                if (r3 != 0) goto L_0x02a1
                r3 = 14
                r14.mo1310a((int) r8, (int) r3)
            L_0x02a1:
                r7 = r14
                goto L_0x02f7
            L_0x02a3:
                if (r18 != 0) goto L_0x02c1
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r9 = r1.f867a
                r9.remove(r7)
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.this
                android.view.View r10 = r14.f802a
                r9.removeDetachedView(r10, r5)
                android.view.View r9 = r14.f802a
                androidx.recyclerview.widget.RecyclerView$d0 r9 = androidx.recyclerview.widget.RecyclerView.getChildViewHolderInt(r9)
                r9.f815n = r4
                r9.f816o = r5
                r9.mo1314b()
                r1.mo1419a((androidx.recyclerview.widget.RecyclerView.C0134d0) r9)
            L_0x02c1:
                int r7 = r7 + -1
                goto L_0x0271
            L_0x02c4:
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r3 = r1.f869c
                int r3 = r3.size()
                int r3 = r3 + r6
            L_0x02cb:
                if (r3 < 0) goto L_0x02f6
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r1.f869c
                java.lang.Object r7 = r7.get(r3)
                androidx.recyclerview.widget.RecyclerView$d0 r7 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r7
                long r9 = r7.f806e
                int r14 = (r9 > r12 ? 1 : (r9 == r12 ? 0 : -1))
                if (r14 != 0) goto L_0x02f3
                boolean r9 = r7.mo1319f()
                if (r9 != 0) goto L_0x02f3
                int r9 = r7.f807f
                if (r9 != 0) goto L_0x02ed
                if (r18 != 0) goto L_0x02f7
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r9 = r1.f869c
                r9.remove(r3)
                goto L_0x02f7
            L_0x02ed:
                if (r18 != 0) goto L_0x02f3
                r1.mo1422b((int) r3)
                goto L_0x02f6
            L_0x02f3:
                int r3 = r3 + -1
                goto L_0x02cb
            L_0x02f6:
                r7 = r4
            L_0x02f7:
                if (r7 == 0) goto L_0x02fc
                r7.f804c = r11
                r2 = 1
            L_0x02fc:
                if (r7 != 0) goto L_0x0349
                androidx.recyclerview.widget.RecyclerView$u r3 = r16.mo1421b()
                android.util.SparseArray<androidx.recyclerview.widget.RecyclerView$u$a> r3 = r3.f861a
                java.lang.Object r3 = r3.get(r5)
                androidx.recyclerview.widget.RecyclerView$u$a r3 = (androidx.recyclerview.widget.RecyclerView.C0158u.C0159a) r3
                if (r3 == 0) goto L_0x0333
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r7 = r3.f863a
                boolean r7 = r7.isEmpty()
                if (r7 != 0) goto L_0x0333
                java.util.ArrayList<androidx.recyclerview.widget.RecyclerView$d0> r3 = r3.f863a
                int r7 = r3.size()
                int r7 = r7 + r6
            L_0x031b:
                if (r7 < 0) goto L_0x0333
                java.lang.Object r6 = r3.get(r7)
                androidx.recyclerview.widget.RecyclerView$d0 r6 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r6
                boolean r6 = r6.mo1319f()
                if (r6 != 0) goto L_0x0330
                java.lang.Object r3 = r3.remove(r7)
                androidx.recyclerview.widget.RecyclerView$d0 r3 = (androidx.recyclerview.widget.RecyclerView.C0134d0) r3
                goto L_0x0334
            L_0x0330:
                int r7 = r7 + -1
                goto L_0x031b
            L_0x0333:
                r3 = r4
            L_0x0334:
                if (r3 == 0) goto L_0x0348
                r3.mo1327n()
                boolean r6 = androidx.recyclerview.widget.RecyclerView.FORCE_INVALIDATE_DISPLAY_LIST
                if (r6 == 0) goto L_0x0348
                android.view.View r6 = r3.f802a
                boolean r7 = r6 instanceof android.view.ViewGroup
                if (r7 == 0) goto L_0x0348
                android.view.ViewGroup r6 = (android.view.ViewGroup) r6
                r1.mo1418a((android.view.ViewGroup) r6, (boolean) r5)
            L_0x0348:
                r7 = r3
            L_0x0349:
                if (r7 != 0) goto L_0x03fa
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                long r6 = r3.getNanoTime()
                r9 = 9223372036854775807(0x7fffffffffffffff, double:NaN)
                int r3 = (r19 > r9 ? 1 : (r19 == r9 ? 0 : -1))
                if (r3 == 0) goto L_0x0374
                androidx.recyclerview.widget.RecyclerView$u r3 = r1.f873g
                androidx.recyclerview.widget.RecyclerView$u$a r3 = r3.mo1413a(r5)
                long r9 = r3.f865c
                r11 = 0
                int r3 = (r9 > r11 ? 1 : (r9 == r11 ? 0 : -1))
                if (r3 == 0) goto L_0x0370
                long r9 = r9 + r6
                int r3 = (r9 > r19 ? 1 : (r9 == r19 ? 0 : -1))
                if (r3 >= 0) goto L_0x036e
                goto L_0x0370
            L_0x036e:
                r3 = 0
                goto L_0x0371
            L_0x0370:
                r3 = 1
            L_0x0371:
                if (r3 != 0) goto L_0x0374
                return r4
            L_0x0374:
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r9 = r3.mAdapter
                if (r9 == 0) goto L_0x03c7
                java.lang.String r10 = "RV CreateView"
                p008b.p033h.p041i.TraceCompat.m1852a(r10)     // Catch:{ all -> 0x03c2 }
                androidx.recyclerview.widget.RecyclerView$d0 r3 = r9.mo1339a((android.view.ViewGroup) r3, (int) r5)     // Catch:{ all -> 0x03c2 }
                android.view.View r9 = r3.f802a     // Catch:{ all -> 0x03c2 }
                android.view.ViewParent r9 = r9.getParent()     // Catch:{ all -> 0x03c2 }
                if (r9 != 0) goto L_0x03ba
                r3.f807f = r5     // Catch:{ all -> 0x03c2 }
                android.os.Trace.endSection()
                boolean r9 = androidx.recyclerview.widget.RecyclerView.ALLOW_THREAD_GAP_WORK
                if (r9 == 0) goto L_0x03a3
                android.view.View r9 = r3.f802a
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.findNestedRecyclerView(r9)
                if (r9 == 0) goto L_0x03a3
                java.lang.ref.WeakReference r10 = new java.lang.ref.WeakReference
                r10.<init>(r9)
                r3.f803b = r10
            L_0x03a3:
                androidx.recyclerview.widget.RecyclerView r9 = androidx.recyclerview.widget.RecyclerView.this
                long r9 = r9.getNanoTime()
                androidx.recyclerview.widget.RecyclerView$u r11 = r1.f873g
                long r9 = r9 - r6
                androidx.recyclerview.widget.RecyclerView$u$a r6 = r11.mo1413a(r5)
                long r12 = r6.f865c
                long r9 = r11.mo1412a(r12, r9)
                r6.f865c = r9
                r7 = r3
                goto L_0x03fa
            L_0x03ba:
                java.lang.IllegalStateException r0 = new java.lang.IllegalStateException     // Catch:{ all -> 0x03c2 }
                java.lang.String r2 = "ViewHolder views must not be attached when created. Ensure that you are not passing 'true' to the attachToRoot parameter of LayoutInflater.inflate(..., boolean attachToRoot)"
                r0.<init>(r2)     // Catch:{ all -> 0x03c2 }
                throw r0     // Catch:{ all -> 0x03c2 }
            L_0x03c2:
                r0 = move-exception
                p008b.p033h.p041i.TraceCompat.m1851a()
                throw r0
            L_0x03c7:
                throw r4
            L_0x03c8:
                throw r4
            L_0x03c9:
                java.lang.IndexOutOfBoundsException r2 = new java.lang.IndexOutOfBoundsException
                java.lang.StringBuilder r3 = new java.lang.StringBuilder
                r3.<init>()
                java.lang.String r4 = "Inconsistency detected. Invalid item position "
                r3.append(r4)
                r3.append(r0)
                java.lang.String r0 = "(offset:"
                r3.append(r0)
                r3.append(r11)
                java.lang.String r0 = ").state:"
                r3.append(r0)
                androidx.recyclerview.widget.RecyclerView r0 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r0 = r0.mState
                int r0 = r0.mo1299a()
                r3.append(r0)
                androidx.recyclerview.widget.RecyclerView r0 = androidx.recyclerview.widget.RecyclerView.this
                java.lang.String r0 = p085c.p086a.p087a.p088a.outline.m2929a((androidx.recyclerview.widget.RecyclerView) r0, (java.lang.StringBuilder) r3)
                r2.<init>(r0)
                throw r2
            L_0x03fa:
                if (r2 == 0) goto L_0x042a
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r3 = r3.mState
                boolean r3 = r3.f783g
                if (r3 != 0) goto L_0x042a
                r3 = 8192(0x2000, float:1.14794E-41)
                boolean r6 = r7.mo1315b(r3)
                if (r6 == 0) goto L_0x042a
                r7.mo1310a((int) r5, (int) r3)
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r3 = r3.mState
                boolean r3 = r3.f786j
                if (r3 == 0) goto L_0x042a
                androidx.recyclerview.widget.RecyclerView.C0142l.m575d(r7)
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$l r3 = r3.mItemAnimator
                r7.mo1318e()
                androidx.recyclerview.widget.RecyclerView$l$c r3 = r3.mo1351c(r7)
                androidx.recyclerview.widget.RecyclerView r6 = androidx.recyclerview.widget.RecyclerView.this
                r6.recordAnimationInfoIfBouncedHiddenView(r7, r3)
            L_0x042a:
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r3 = r3.mState
                boolean r3 = r3.f783g
                if (r3 == 0) goto L_0x043b
                boolean r3 = r7.mo1320g()
                if (r3 == 0) goto L_0x043b
                r7.f808g = r0
                goto L_0x0485
            L_0x043b:
                boolean r3 = r7.mo1320g()
                if (r3 == 0) goto L_0x0451
                int r3 = r7.f811j
                r3 = r3 & r8
                if (r3 == 0) goto L_0x0448
                r3 = 1
                goto L_0x0449
            L_0x0448:
                r3 = 0
            L_0x0449:
                if (r3 != 0) goto L_0x0451
                boolean r3 = r7.mo1321h()
                if (r3 == 0) goto L_0x0485
            L_0x0451:
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.a r3 = r3.mAdapterHelper
                int r3 = r3.mo3654a((int) r0, (int) r5)
                androidx.recyclerview.widget.RecyclerView r6 = androidx.recyclerview.widget.RecyclerView.this
                r7.f819r = r6
                int r8 = r7.f807f
                long r9 = r6.getNanoTime()
                r11 = 9223372036854775807(0x7fffffffffffffff, double:NaN)
                int r6 = (r19 > r11 ? 1 : (r19 == r11 ? 0 : -1))
                if (r6 == 0) goto L_0x0488
                androidx.recyclerview.widget.RecyclerView$u r6 = r1.f873g
                androidx.recyclerview.widget.RecyclerView$u$a r6 = r6.mo1413a(r8)
                long r11 = r6.f866d
                r13 = 0
                int r6 = (r11 > r13 ? 1 : (r11 == r13 ? 0 : -1))
                if (r6 == 0) goto L_0x0482
                long r11 = r11 + r9
                int r6 = (r11 > r19 ? 1 : (r11 == r19 ? 0 : -1))
                if (r6 >= 0) goto L_0x0480
                goto L_0x0482
            L_0x0480:
                r6 = 0
                goto L_0x0483
            L_0x0482:
                r6 = 1
            L_0x0483:
                if (r6 != 0) goto L_0x0488
            L_0x0485:
                r0 = 0
                goto L_0x0521
            L_0x0488:
                androidx.recyclerview.widget.RecyclerView r6 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$g r6 = r6.mAdapter
                if (r6 == 0) goto L_0x0559
                r7.f804c = r3
                boolean r8 = r6.f823b
                if (r8 == 0) goto L_0x049a
                long r11 = r6.mo1338a(r3)
                r7.f806e = r11
            L_0x049a:
                r8 = 519(0x207, float:7.27E-43)
                r11 = 1
                r7.mo1310a((int) r11, (int) r8)
                java.lang.String r8 = "RV OnBindView"
                p008b.p033h.p041i.TraceCompat.m1852a(r8)
                r7.mo1318e()
                r6.mo1340a(r7, (int) r3)
                java.util.List<java.lang.Object> r3 = r7.f812k
                if (r3 == 0) goto L_0x04b2
                r3.clear()
            L_0x04b2:
                int r3 = r7.f811j
                r3 = r3 & -1025(0xfffffffffffffbff, float:NaN)
                r7.f811j = r3
                android.view.View r3 = r7.f802a
                android.view.ViewGroup$LayoutParams r3 = r3.getLayoutParams()
                boolean r6 = r3 instanceof androidx.recyclerview.widget.RecyclerView.C0153p
                if (r6 == 0) goto L_0x04c7
                androidx.recyclerview.widget.RecyclerView$p r3 = (androidx.recyclerview.widget.RecyclerView.C0153p) r3
                r6 = 1
                r3.f859c = r6
            L_0x04c7:
                android.os.Trace.endSection()
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                long r11 = r3.getNanoTime()
                androidx.recyclerview.widget.RecyclerView$u r3 = r1.f873g
                int r6 = r7.f807f
                long r11 = r11 - r9
                androidx.recyclerview.widget.RecyclerView$u$a r6 = r3.mo1413a(r6)
                long r8 = r6.f866d
                long r8 = r3.mo1412a(r8, r11)
                r6.f866d = r8
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                boolean r3 = r3.isAccessibilityEnabled()
                if (r3 == 0) goto L_0x0516
                android.view.View r3 = r7.f802a
                int r6 = p008b.p033h.p045m.ViewCompat.m1964i(r3)
                r8 = 1
                if (r6 != 0) goto L_0x04f5
                r3.setImportantForAccessibility(r8)
            L_0x04f5:
                androidx.recyclerview.widget.RecyclerView r6 = androidx.recyclerview.widget.RecyclerView.this
                b.s.d.u r6 = r6.mAccessibilityDelegate
                if (r6 != 0) goto L_0x04fc
                goto L_0x0516
            L_0x04fc:
                b.s.d.u$a r6 = r6.f3243e
                boolean r8 = r6 instanceof p008b.p071s.p072d.RecyclerViewAccessibilityDelegate.C0570a
                if (r8 == 0) goto L_0x0513
                if (r6 == 0) goto L_0x0512
                b.h.m.a r4 = p008b.p033h.p045m.ViewCompat.m1948b(r3)
                if (r4 == 0) goto L_0x0513
                if (r4 == r6) goto L_0x0513
                java.util.Map<android.view.View, b.h.m.a> r8 = r6.f3245e
                r8.put(r3, r4)
                goto L_0x0513
            L_0x0512:
                throw r4
            L_0x0513:
                p008b.p033h.p045m.ViewCompat.m1938a((android.view.View) r3, (p008b.p033h.p045m.AccessibilityDelegateCompat) r6)
            L_0x0516:
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r3 = r3.mState
                boolean r3 = r3.f783g
                if (r3 == 0) goto L_0x0520
                r7.f808g = r0
            L_0x0520:
                r0 = 1
            L_0x0521:
                android.view.View r3 = r7.f802a
                android.view.ViewGroup$LayoutParams r3 = r3.getLayoutParams()
                if (r3 != 0) goto L_0x0537
                androidx.recyclerview.widget.RecyclerView r3 = androidx.recyclerview.widget.RecyclerView.this
                android.view.ViewGroup$LayoutParams r3 = r3.generateDefaultLayoutParams()
                androidx.recyclerview.widget.RecyclerView$p r3 = (androidx.recyclerview.widget.RecyclerView.C0153p) r3
                android.view.View r4 = r7.f802a
                r4.setLayoutParams(r3)
                goto L_0x054f
            L_0x0537:
                androidx.recyclerview.widget.RecyclerView r4 = androidx.recyclerview.widget.RecyclerView.this
                boolean r4 = r4.checkLayoutParams(r3)
                if (r4 != 0) goto L_0x054d
                androidx.recyclerview.widget.RecyclerView r4 = androidx.recyclerview.widget.RecyclerView.this
                android.view.ViewGroup$LayoutParams r3 = r4.generateLayoutParams((android.view.ViewGroup.LayoutParams) r3)
                androidx.recyclerview.widget.RecyclerView$p r3 = (androidx.recyclerview.widget.RecyclerView.C0153p) r3
                android.view.View r4 = r7.f802a
                r4.setLayoutParams(r3)
                goto L_0x054f
            L_0x054d:
                androidx.recyclerview.widget.RecyclerView$p r3 = (androidx.recyclerview.widget.RecyclerView.C0153p) r3
            L_0x054f:
                r3.f857a = r7
                if (r2 == 0) goto L_0x0556
                if (r0 == 0) goto L_0x0556
                r5 = 1
            L_0x0556:
                r3.f860d = r5
                return r7
            L_0x0559:
                throw r4
            L_0x055a:
                java.lang.IndexOutOfBoundsException r2 = new java.lang.IndexOutOfBoundsException
                java.lang.StringBuilder r3 = new java.lang.StringBuilder
                r3.<init>()
                java.lang.String r4 = "Invalid item position "
                r3.append(r4)
                r3.append(r0)
                java.lang.String r4 = "("
                r3.append(r4)
                r3.append(r0)
                java.lang.String r0 = "). Item count:"
                r3.append(r0)
                androidx.recyclerview.widget.RecyclerView r0 = androidx.recyclerview.widget.RecyclerView.this
                androidx.recyclerview.widget.RecyclerView$a0 r0 = r0.mState
                int r0 = r0.mo1299a()
                r3.append(r0)
                androidx.recyclerview.widget.RecyclerView r0 = androidx.recyclerview.widget.RecyclerView.this
                java.lang.String r0 = p085c.p086a.p087a.p088a.outline.m2929a((androidx.recyclerview.widget.RecyclerView) r0, (java.lang.StringBuilder) r3)
                r2.<init>(r0)
                throw r2
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.RecyclerView.C0160v.mo1415a(int, boolean, long):androidx.recyclerview.widget.RecyclerView$d0");
        }

        /* renamed from: b */
        public void mo1424b(C0134d0 d0Var) {
            if (d0Var.f816o) {
                this.f868b.remove(d0Var);
            } else {
                this.f867a.remove(d0Var);
            }
            d0Var.f815n = null;
            d0Var.f816o = false;
            d0Var.mo1314b();
        }

        /* renamed from: b */
        public C0158u mo1421b() {
            if (this.f873g == null) {
                this.f873g = new C0158u();
            }
            return this.f873g;
        }

        /* renamed from: a */
        public final void mo1418a(ViewGroup viewGroup, boolean z) {
            for (int childCount = viewGroup.getChildCount() - 1; childCount >= 0; childCount--) {
                View childAt = viewGroup.getChildAt(childCount);
                if (childAt instanceof ViewGroup) {
                    mo1418a((ViewGroup) childAt, true);
                }
            }
            if (z) {
                if (viewGroup.getVisibility() == 4) {
                    viewGroup.setVisibility(0);
                    viewGroup.setVisibility(4);
                    return;
                }
                int visibility = viewGroup.getVisibility();
                viewGroup.setVisibility(4);
                viewGroup.setVisibility(visibility);
            }
        }

        /* renamed from: a */
        public void mo1417a(View view) {
            C0134d0 childViewHolderInt = RecyclerView.getChildViewHolderInt(view);
            if (childViewHolderInt.mo1325l()) {
                RecyclerView.this.removeDetachedView(view, false);
            }
            if (childViewHolderInt.mo1324k()) {
                childViewHolderInt.f815n.mo1424b(childViewHolderInt);
            } else if (childViewHolderInt.mo1329p()) {
                childViewHolderInt.mo1314b();
            }
            mo1419a(childViewHolderInt);
            if (RecyclerView.this.mItemAnimator != null && !childViewHolderInt.mo1322i()) {
                RecyclerView.this.mItemAnimator.mo1350b(childViewHolderInt);
            }
        }

        /* renamed from: a */
        public void mo1419a(C0134d0 d0Var) {
            boolean z = false;
            boolean z2 = true;
            if (d0Var.mo1324k() || d0Var.f802a.getParent() != null) {
                StringBuilder a = outline.m2937a("Scrapped or attached views may not be recycled. isScrap:");
                a.append(d0Var.mo1324k());
                a.append(" isAttached:");
                if (d0Var.f802a.getParent() != null) {
                    z = true;
                }
                a.append(z);
                throw new IllegalArgumentException(outline.m2929a(RecyclerView.this, a));
            } else if (d0Var.mo1325l()) {
                StringBuilder sb = new StringBuilder();
                sb.append("Tmp detached view should be removed from RecyclerView before it can be recycled: ");
                sb.append(d0Var);
                throw new IllegalArgumentException(outline.m2929a(RecyclerView.this, sb));
            } else if (!d0Var.mo1328o()) {
                boolean z3 = (d0Var.f811j & 16) == 0 && ViewCompat.m1976u(d0Var.f802a);
                C0137g gVar = RecyclerView.this.mAdapter;
                if (gVar == null || !z3 || gVar != null) {
                    if (d0Var.mo1322i()) {
                        if (this.f872f <= 0 || d0Var.mo1315b(526)) {
                            z = false;
                        } else {
                            int size = this.f869c.size();
                            if (size >= this.f872f && size > 0) {
                                mo1422b(0);
                                size--;
                            }
                            if (RecyclerView.ALLOW_THREAD_GAP_WORK && size > 0 && !RecyclerView.this.mPrefetchRegistry.mo3731a(d0Var.f804c)) {
                                do {
                                    size--;
                                    if (size < 0) {
                                        break;
                                    }
                                } while (RecyclerView.this.mPrefetchRegistry.mo3731a(this.f869c.get(size).f804c));
                                size++;
                            }
                            this.f869c.add(size, d0Var);
                            z = true;
                        }
                        if (!z) {
                            mo1420a(d0Var, true);
                            RecyclerView.this.mViewInfoStore.mo3770d(d0Var);
                            if (!z && !z2 && z3) {
                                d0Var.f819r = null;
                                return;
                            }
                            return;
                        }
                    }
                    z2 = false;
                    RecyclerView.this.mViewInfoStore.mo3770d(d0Var);
                    if (!z) {
                        return;
                    }
                    return;
                }
                throw null;
            } else {
                throw new IllegalArgumentException(outline.m2929a(RecyclerView.this, outline.m2937a("Trying to recycle an ignored view holder. You should first call stopIgnoringView(view) before calling recycle.")));
            }
        }

        /* renamed from: a */
        public void mo1420a(C0134d0 d0Var, boolean z) {
            RecyclerView.clearNestedRecyclerViewIfNotNested(d0Var);
            View view = d0Var.f802a;
            RecyclerViewAccessibilityDelegate uVar = RecyclerView.this.mAccessibilityDelegate;
            if (uVar != null) {
                RecyclerViewAccessibilityDelegate.C0570a aVar = uVar.f3243e;
                ViewCompat.m1938a(view, aVar instanceof RecyclerViewAccessibilityDelegate.C0570a ? aVar.f3245e.remove(view) : null);
            }
            if (z) {
                C0161w wVar = RecyclerView.this.mRecyclerListener;
                if (wVar != null) {
                    wVar.mo1427a(d0Var);
                }
                C0137g gVar = RecyclerView.this.mAdapter;
                RecyclerView recyclerView = RecyclerView.this;
                if (recyclerView.mState != null) {
                    recyclerView.mViewInfoStore.mo3770d(d0Var);
                }
            }
            d0Var.f819r = null;
            C0158u b = mo1421b();
            if (b != null) {
                int i = d0Var.f807f;
                ArrayList<C0134d0> arrayList = b.mo1413a(i).f863a;
                if (b.f861a.get(i).f864b > arrayList.size()) {
                    d0Var.mo1327n();
                    arrayList.add(d0Var);
                    return;
                }
                return;
            }
            throw null;
        }
    }

    public RecyclerView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, C0543a.recyclerViewStyle);
    }

    public boolean dispatchNestedScroll(int i, int i2, int i3, int i4, int[] iArr, int i5) {
        return getScrollingChildHelper().mo3129b(i, i2, i3, i4, iArr, i5, (int[]) null);
    }

    public C0134d0 findViewHolderForPosition(int i, boolean z) {
        int b = this.mChildHelper.mo3675b();
        C0134d0 d0Var = null;
        for (int i2 = 0; i2 < b; i2++) {
            C0134d0 childViewHolderInt = getChildViewHolderInt(this.mChildHelper.mo3680d(i2));
            if (childViewHolderInt != null && !childViewHolderInt.mo1323j()) {
                if (z) {
                    if (childViewHolderInt.f804c != i) {
                        continue;
                    }
                } else if (childViewHolderInt.mo1317d() != i) {
                    continue;
                }
                if (!this.mChildHelper.mo3679c(childViewHolderInt.f802a)) {
                    return childViewHolderInt;
                }
                d0Var = childViewHolderInt;
            }
        }
        return d0Var;
    }

    public void onExitLayoutOrScroll(boolean z) {
        int i = this.mLayoutOrScrollCounter - 1;
        this.mLayoutOrScrollCounter = i;
        if (i < 1) {
            this.mLayoutOrScrollCounter = 0;
            if (z) {
                dispatchContentChangedIfNecessary();
                dispatchPendingImportantForAccessibilityChanges();
            }
        }
    }

    public void smoothScrollBy(int i, int i2, Interpolator interpolator) {
        smoothScrollBy(i, i2, interpolator, UNDEFINED_DURATION);
    }

    public RecyclerView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        float f;
        this.mObserver = new C0162x();
        this.mRecycler = new C0160v();
        this.mViewInfoStore = new ViewInfoStore();
        this.mUpdateChildViewsRunnable = new C0127a();
        this.mTempRect = new Rect();
        this.mTempRect2 = new Rect();
        this.mTempRectF = new RectF();
        this.mItemDecorations = new ArrayList<>();
        this.mOnItemTouchListeners = new ArrayList<>();
        this.mInterceptRequestLayoutDepth = 0;
        this.mDataSetHasChangedAfterLayout = false;
        this.mDispatchItemsChangedEvent = false;
        this.mLayoutOrScrollCounter = 0;
        this.mDispatchScrollCounter = 0;
        this.mEdgeEffectFactory = new C0141k();
        this.mItemAnimator = new C0557k();
        this.mScrollState = 0;
        this.mScrollPointerId = -1;
        this.mScaledHorizontalScrollFactor = Float.MIN_VALUE;
        this.mScaledVerticalScrollFactor = Float.MIN_VALUE;
        this.mPreserveFocusAfterLayout = true;
        this.mViewFlinger = new C0132c0();
        this.mPrefetchRegistry = ALLOW_THREAD_GAP_WORK ? new GapWorker.C0565b() : null;
        this.mState = new C0128a0();
        this.mItemsAddedOrRemoved = false;
        this.mItemsChanged = false;
        this.mItemAnimatorListener = new C0146m();
        this.mPostedAnimatorRunner = false;
        this.mMinMaxLayoutPositions = new int[2];
        this.mScrollOffset = new int[2];
        this.mNestedOffsets = new int[2];
        this.mReusableIntPair = new int[2];
        this.mPendingAccessibilityImportanceChange = new ArrayList();
        this.mItemAnimatorRunner = new C0129b();
        this.mViewInfoProcessCallback = new C0133d();
        setScrollContainer(true);
        setFocusableInTouchMode(true);
        ViewConfiguration viewConfiguration = ViewConfiguration.get(context);
        this.mTouchSlop = viewConfiguration.getScaledTouchSlop();
        this.mScaledHorizontalScrollFactor = ViewConfigurationCompat.m2003b(viewConfiguration, context);
        if (Build.VERSION.SDK_INT >= 26) {
            f = viewConfiguration.getScaledVerticalScrollFactor();
        } else {
            f = ViewConfigurationCompat.m2001a(viewConfiguration, context);
        }
        this.mScaledVerticalScrollFactor = f;
        this.mMinFlingVelocity = viewConfiguration.getScaledMinimumFlingVelocity();
        this.mMaxFlingVelocity = viewConfiguration.getScaledMaximumFlingVelocity();
        setWillNotDraw(getOverScrollMode() == 2);
        this.mItemAnimator.f824a = this.mItemAnimatorListener;
        initAdapterManager();
        initChildrenHelper();
        initAutofill();
        if (ViewCompat.m1964i(this) == 0) {
            setImportantForAccessibility(1);
        }
        this.mAccessibilityManager = (AccessibilityManager) getContext().getSystemService("accessibility");
        setAccessibilityDelegateCompat(new RecyclerViewAccessibilityDelegate(this));
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, C0545c.RecyclerView, i, 0);
        if (Build.VERSION.SDK_INT >= 29) {
            saveAttributeDataForStyleable(context, C0545c.RecyclerView, attributeSet, obtainStyledAttributes, i, 0);
        }
        String string = obtainStyledAttributes.getString(C0545c.RecyclerView_layoutManager);
        if (obtainStyledAttributes.getInt(C0545c.RecyclerView_android_descendantFocusability, -1) == -1) {
            setDescendantFocusability(Http1ExchangeCodec.HEADER_LIMIT);
        }
        this.mClipToPadding = obtainStyledAttributes.getBoolean(C0545c.RecyclerView_android_clipToPadding, true);
        boolean z = obtainStyledAttributes.getBoolean(C0545c.RecyclerView_fastScrollEnabled, false);
        this.mEnableFastScroller = z;
        if (z) {
            initFastScroller((StateListDrawable) obtainStyledAttributes.getDrawable(C0545c.RecyclerView_fastScrollVerticalThumbDrawable), obtainStyledAttributes.getDrawable(C0545c.RecyclerView_fastScrollVerticalTrackDrawable), (StateListDrawable) obtainStyledAttributes.getDrawable(C0545c.RecyclerView_fastScrollHorizontalThumbDrawable), obtainStyledAttributes.getDrawable(C0545c.RecyclerView_fastScrollHorizontalTrackDrawable));
        }
        obtainStyledAttributes.recycle();
        createLayoutManager(context, string, attributeSet, i, 0);
        TypedArray obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, NESTED_SCROLLING_ATTRS, i, 0);
        if (Build.VERSION.SDK_INT >= 29) {
            saveAttributeDataForStyleable(context, NESTED_SCROLLING_ATTRS, attributeSet, obtainStyledAttributes2, i, 0);
        }
        boolean z2 = obtainStyledAttributes2.getBoolean(0, true);
        obtainStyledAttributes2.recycle();
        setNestedScrollingEnabled(z2);
    }

    public boolean dispatchNestedPreScroll(int i, int i2, int[] iArr, int[] iArr2, int i3) {
        return getScrollingChildHelper().mo3127a(i, i2, iArr, iArr2, i3);
    }

    public boolean hasNestedScrollingParent(int i) {
        return getScrollingChildHelper().mo3121a(i) != null;
    }

    public void smoothScrollBy(int i, int i2, Interpolator interpolator, int i3) {
        smoothScrollBy(i, i2, interpolator, i3, false);
    }

    public boolean startNestedScroll(int i, int i2) {
        return getScrollingChildHelper().mo3125a(i, i2);
    }

    public void stopNestedScroll(int i) {
        getScrollingChildHelper().mo3130c(i);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$a0 */
    public static class C0128a0 {

        /* renamed from: a */
        public int f777a = -1;

        /* renamed from: b */
        public int f778b = 0;

        /* renamed from: c */
        public int f779c = 0;

        /* renamed from: d */
        public int f780d = 1;

        /* renamed from: e */
        public int f781e = 0;

        /* renamed from: f */
        public boolean f782f = false;

        /* renamed from: g */
        public boolean f783g = false;

        /* renamed from: h */
        public boolean f784h = false;

        /* renamed from: i */
        public boolean f785i = false;

        /* renamed from: j */
        public boolean f786j = false;

        /* renamed from: k */
        public boolean f787k = false;

        /* renamed from: l */
        public int f788l;

        /* renamed from: m */
        public long f789m;

        /* renamed from: n */
        public int f790n;

        /* renamed from: o */
        public int f791o;

        /* renamed from: a */
        public void mo1300a(int i) {
            if ((this.f780d & i) == 0) {
                StringBuilder a = outline.m2937a("Layout state should be one of ");
                a.append(Integer.toBinaryString(i));
                a.append(" but it is ");
                a.append(Integer.toBinaryString(this.f780d));
                throw new IllegalStateException(a.toString());
            }
        }

        public String toString() {
            StringBuilder a = outline.m2937a("State{mTargetPosition=");
            a.append(this.f777a);
            a.append(", mData=");
            a.append((Object) null);
            a.append(", mItemCount=");
            a.append(this.f781e);
            a.append(", mIsMeasuring=");
            a.append(this.f785i);
            a.append(", mPreviousLayoutItemCount=");
            a.append(this.f778b);
            a.append(", mDeletedInvisibleItemCountSincePreviousLayout=");
            a.append(this.f779c);
            a.append(", mStructureChanged=");
            a.append(this.f782f);
            a.append(", mInPreLayout=");
            a.append(this.f783g);
            a.append(", mRunSimpleAnimations=");
            a.append(this.f786j);
            a.append(", mRunPredictiveAnimations=");
            a.append(this.f787k);
            a.append('}');
            return a.toString();
        }

        /* renamed from: a */
        public int mo1299a() {
            return this.f783g ? this.f778b - this.f779c : this.f781e;
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$c0 */
    public class C0132c0 implements Runnable {

        /* renamed from: b */
        public int f793b;

        /* renamed from: c */
        public int f794c;

        /* renamed from: d */
        public OverScroller f795d;

        /* renamed from: e */
        public Interpolator f796e = RecyclerView.sQuinticInterpolator;

        /* renamed from: f */
        public boolean f797f = false;

        /* renamed from: g */
        public boolean f798g = false;

        public C0132c0() {
            this.f795d = new OverScroller(RecyclerView.this.getContext(), RecyclerView.sQuinticInterpolator);
        }

        /* renamed from: a */
        public void mo1304a() {
            if (this.f797f) {
                this.f798g = true;
                return;
            }
            RecyclerView.this.removeCallbacks(this);
            ViewCompat.m1942a((View) RecyclerView.this, (Runnable) this);
        }

        /* renamed from: b */
        public void mo1306b() {
            RecyclerView.this.removeCallbacks(this);
            this.f795d.abortAnimation();
        }

        public void run() {
            int i;
            int i2;
            RecyclerView recyclerView = RecyclerView.this;
            if (recyclerView.mLayout == null) {
                mo1306b();
                return;
            }
            this.f798g = false;
            this.f797f = true;
            recyclerView.consumePendingUpdateOperations();
            OverScroller overScroller = this.f795d;
            if (overScroller.computeScrollOffset()) {
                int currX = overScroller.getCurrX();
                int currY = overScroller.getCurrY();
                int i3 = currX - this.f793b;
                int i4 = currY - this.f794c;
                this.f793b = currX;
                this.f794c = currY;
                RecyclerView recyclerView2 = RecyclerView.this;
                int[] iArr = recyclerView2.mReusableIntPair;
                iArr[0] = 0;
                iArr[1] = 0;
                if (recyclerView2.dispatchNestedPreScroll(i3, i4, iArr, (int[]) null, 1)) {
                    int[] iArr2 = RecyclerView.this.mReusableIntPair;
                    i3 -= iArr2[0];
                    i4 -= iArr2[1];
                }
                if (RecyclerView.this.getOverScrollMode() != 2) {
                    RecyclerView.this.considerReleasingGlowsOnScroll(i3, i4);
                }
                RecyclerView recyclerView3 = RecyclerView.this;
                if (recyclerView3.mAdapter != null) {
                    int[] iArr3 = recyclerView3.mReusableIntPair;
                    iArr3[0] = 0;
                    iArr3[1] = 0;
                    recyclerView3.scrollStep(i3, i4, iArr3);
                    RecyclerView recyclerView4 = RecyclerView.this;
                    int[] iArr4 = recyclerView4.mReusableIntPair;
                    i = iArr4[0];
                    i2 = iArr4[1];
                    i3 -= i;
                    i4 -= i2;
                    C0165z zVar = recyclerView4.mLayout.f839g;
                    if (zVar != null && !zVar.f880d && zVar.f881e) {
                        int a = recyclerView4.mState.mo1299a();
                        if (a == 0) {
                            zVar.mo1432a();
                        } else if (zVar.f877a >= a) {
                            zVar.f877a = a - 1;
                            zVar.mo1433a(i, i2);
                        } else {
                            zVar.mo1433a(i, i2);
                        }
                    }
                } else {
                    i2 = 0;
                    i = 0;
                }
                if (!RecyclerView.this.mItemDecorations.isEmpty()) {
                    RecyclerView.this.invalidate();
                }
                RecyclerView recyclerView5 = RecyclerView.this;
                int[] iArr5 = recyclerView5.mReusableIntPair;
                iArr5[0] = 0;
                iArr5[1] = 0;
                recyclerView5.dispatchNestedScroll(i, i2, i3, i4, (int[]) null, 1, iArr5);
                int[] iArr6 = RecyclerView.this.mReusableIntPair;
                int i5 = i3 - iArr6[0];
                int i6 = i4 - iArr6[1];
                if (!(i == 0 && i2 == 0)) {
                    RecyclerView.this.dispatchOnScrolled(i, i2);
                }
                if (!RecyclerView.this.awakenScrollBars()) {
                    RecyclerView.this.invalidate();
                }
                boolean z = overScroller.isFinished() || (((overScroller.getCurrX() == overScroller.getFinalX()) || i5 != 0) && ((overScroller.getCurrY() == overScroller.getFinalY()) || i6 != 0));
                C0165z zVar2 = RecyclerView.this.mLayout.f839g;
                if ((zVar2 != null && zVar2.f880d) || !z) {
                    mo1304a();
                    RecyclerView recyclerView6 = RecyclerView.this;
                    GapWorker mVar = recyclerView6.mGapWorker;
                    if (mVar != null) {
                        mVar.mo3726a(recyclerView6, i, i2);
                    }
                } else {
                    if (RecyclerView.this.getOverScrollMode() != 2) {
                        int currVelocity = (int) overScroller.getCurrVelocity();
                        int i7 = i5 < 0 ? -currVelocity : i5 > 0 ? currVelocity : 0;
                        if (i6 < 0) {
                            currVelocity = -currVelocity;
                        } else if (i6 <= 0) {
                            currVelocity = 0;
                        }
                        RecyclerView.this.absorbGlows(i7, currVelocity);
                    }
                    if (RecyclerView.ALLOW_THREAD_GAP_WORK) {
                        GapWorker.C0565b bVar = RecyclerView.this.mPrefetchRegistry;
                        int[] iArr7 = bVar.f3212c;
                        if (iArr7 != null) {
                            Arrays.fill(iArr7, -1);
                        }
                        bVar.f3213d = 0;
                    }
                }
            }
            C0165z zVar3 = RecyclerView.this.mLayout.f839g;
            if (zVar3 != null && zVar3.f880d) {
                zVar3.mo1433a(0, 0);
            }
            this.f797f = false;
            if (this.f798g) {
                RecyclerView.this.removeCallbacks(this);
                ViewCompat.m1942a((View) RecyclerView.this, (Runnable) this);
                return;
            }
            RecyclerView.this.setScrollState(0);
            RecyclerView.this.stopNestedScroll(1);
        }

        /* renamed from: a */
        public void mo1305a(int i, int i2, int i3, Interpolator interpolator) {
            int i4;
            if (i3 == Integer.MIN_VALUE) {
                int abs = Math.abs(i);
                int abs2 = Math.abs(i2);
                boolean z = abs > abs2;
                int sqrt = (int) Math.sqrt((double) 0);
                int sqrt2 = (int) Math.sqrt((double) ((i2 * i2) + (i * i)));
                RecyclerView recyclerView = RecyclerView.this;
                int width = z ? recyclerView.getWidth() : recyclerView.getHeight();
                int i5 = width / 2;
                float f = (float) width;
                float f2 = (float) i5;
                float sin = (((float) Math.sin((double) ((Math.min(1.0f, (((float) sqrt2) * 1.0f) / f) - 0.5f) * 0.47123894f))) * f2) + f2;
                if (sqrt > 0) {
                    i4 = Math.round(Math.abs(sin / ((float) sqrt)) * 1000.0f) * 4;
                } else {
                    if (!z) {
                        abs = abs2;
                    }
                    i4 = (int) (((((float) abs) / f) + 1.0f) * 300.0f);
                }
                i3 = Math.min(i4, 2000);
            }
            int i6 = i3;
            if (interpolator == null) {
                interpolator = RecyclerView.sQuinticInterpolator;
            }
            if (this.f796e != interpolator) {
                this.f796e = interpolator;
                this.f795d = new OverScroller(RecyclerView.this.getContext(), interpolator);
            }
            this.f794c = 0;
            this.f793b = 0;
            RecyclerView.this.setScrollState(2);
            this.f795d.startScroll(0, 0, i, i2, i6);
            if (Build.VERSION.SDK_INT < 23) {
                this.f795d.computeScrollOffset();
            }
            mo1304a();
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$p */
    public static class C0153p extends ViewGroup.MarginLayoutParams {

        /* renamed from: a */
        public C0134d0 f857a;

        /* renamed from: b */
        public final Rect f858b = new Rect();

        /* renamed from: c */
        public boolean f859c = true;

        /* renamed from: d */
        public boolean f860d = false;

        public C0153p(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        /* renamed from: a */
        public int mo1402a() {
            return this.f857a.mo1317d();
        }

        /* renamed from: b */
        public boolean mo1403b() {
            return this.f857a.mo1326m();
        }

        /* renamed from: c */
        public boolean mo1404c() {
            return this.f857a.mo1323j();
        }

        public C0153p(int i, int i2) {
            super(i, i2);
        }

        public C0153p(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }

        public C0153p(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public C0153p(C0153p pVar) {
            super(pVar);
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$y */
    public static class C0163y extends AbsSavedState {
        public static final Parcelable.Creator<C0163y> CREATOR = new C0164a();

        /* renamed from: d */
        public Parcelable f876d;

        /* renamed from: androidx.recyclerview.widget.RecyclerView$y$a */
        public static class C0164a implements Parcelable.ClassLoaderCreator<C0163y> {
            public Object createFromParcel(Parcel parcel, ClassLoader classLoader) {
                return new C0163y(parcel, classLoader);
            }

            public Object[] newArray(int i) {
                return new C0163y[i];
            }

            public Object createFromParcel(Parcel parcel) {
                return new C0163y(parcel, (ClassLoader) null);
            }
        }

        public C0163y(Parcel parcel, ClassLoader classLoader) {
            super(parcel, classLoader);
            this.f876d = parcel.readParcelable(classLoader == null ? C0148o.class.getClassLoader() : classLoader);
        }

        public void writeToParcel(Parcel parcel, int i) {
            parcel.writeParcelable(this.f2617b, i);
            parcel.writeParcelable(this.f876d, 0);
        }

        public C0163y(Parcelable parcelable) {
            super(parcelable);
        }
    }

    public final void dispatchNestedScroll(int i, int i2, int i3, int i4, int[] iArr, int i5, int[] iArr2) {
        getScrollingChildHelper().mo3129b(i, i2, i3, i4, iArr, i5, iArr2);
    }

    public ViewGroup.LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        C0148o oVar = this.mLayout;
        if (oVar != null) {
            return oVar.mo1014a(layoutParams);
        }
        throw new IllegalStateException(outline.m2929a(this, outline.m2937a("RecyclerView has no LayoutManager")));
    }

    public void smoothScrollBy(int i, int i2, Interpolator interpolator, int i3, boolean z) {
        C0148o oVar = this.mLayout;
        if (oVar == null) {
            Log.e(TAG, "Cannot smooth scroll without a LayoutManager set. Call setLayoutManager with a non-null argument.");
        } else if (!this.mLayoutSuppressed) {
            int i4 = 0;
            if (!oVar.mo1065a()) {
                i = 0;
            }
            if (!this.mLayout.mo1069b()) {
                i2 = 0;
            }
            if (i != 0 || i2 != 0) {
                if (i3 == Integer.MIN_VALUE || i3 > 0) {
                    if (z) {
                        if (i != 0) {
                            i4 = 1;
                        }
                        if (i2 != 0) {
                            i4 |= 2;
                        }
                        startNestedScroll(i4, 1);
                    }
                    this.mViewFlinger.mo1305a(i, i2, i3, interpolator);
                    return;
                }
                scrollBy(i, i2);
            }
        }
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$z */
    public static abstract class C0165z {

        /* renamed from: a */
        public int f877a = -1;

        /* renamed from: b */
        public RecyclerView f878b;

        /* renamed from: c */
        public C0148o f879c;

        /* renamed from: d */
        public boolean f880d;

        /* renamed from: e */
        public boolean f881e;

        /* renamed from: f */
        public View f882f;

        /* renamed from: g */
        public final C0166a f883g = new C0166a(0, 0);

        /* renamed from: h */
        public boolean f884h;

        /* renamed from: androidx.recyclerview.widget.RecyclerView$z$b */
        public interface C0167b {
            /* renamed from: a */
            PointF mo1051a(int i);
        }

        /* renamed from: a */
        public PointF mo1431a(int i) {
            C0148o oVar = this.f879c;
            if (oVar instanceof C0167b) {
                return ((C0167b) oVar).mo1051a(i);
            }
            StringBuilder a = outline.m2937a("You should override computeScrollVectorForPosition when the LayoutManager does not implement ");
            a.append(C0167b.class.getCanonicalName());
            Log.w(RecyclerView.TAG, a.toString());
            return null;
        }

        /* renamed from: a */
        public abstract void mo1434a(View view, C0128a0 a0Var, C0166a aVar);

        /* renamed from: a */
        public final void mo1432a() {
            if (this.f881e) {
                this.f881e = false;
                LinearSmoothScroller oVar = (LinearSmoothScroller) this;
                oVar.f3235p = 0;
                oVar.f3234o = 0;
                oVar.f3230k = null;
                this.f878b.mState.f777a = -1;
                this.f882f = null;
                this.f877a = -1;
                this.f880d = false;
                C0148o oVar2 = this.f879c;
                if (oVar2.f839g == this) {
                    oVar2.f839g = null;
                }
                this.f879c = null;
                this.f878b = null;
            }
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$z$a */
        public static class C0166a {

            /* renamed from: a */
            public int f885a;

            /* renamed from: b */
            public int f886b;

            /* renamed from: c */
            public int f887c;

            /* renamed from: d */
            public int f888d = -1;

            /* renamed from: e */
            public Interpolator f889e;

            /* renamed from: f */
            public boolean f890f = false;

            /* renamed from: g */
            public int f891g = 0;

            public C0166a(int i, int i2) {
                this.f885a = i;
                this.f886b = i2;
                this.f887c = RecyclerView.UNDEFINED_DURATION;
                this.f889e = null;
            }

            /* renamed from: a */
            public void mo1436a(RecyclerView recyclerView) {
                int i = this.f888d;
                if (i >= 0) {
                    this.f888d = -1;
                    recyclerView.jumpToPositionForSmoothScroller(i);
                    this.f890f = false;
                } else if (!this.f890f) {
                    this.f891g = 0;
                } else if (this.f889e == null || this.f887c >= 1) {
                    int i2 = this.f887c;
                    if (i2 >= 1) {
                        recyclerView.mViewFlinger.mo1305a(this.f885a, this.f886b, i2, this.f889e);
                        int i3 = this.f891g + 1;
                        this.f891g = i3;
                        if (i3 > 10) {
                            Log.e(RecyclerView.TAG, "Smooth Scroll action is being updated too frequently. Make sure you are not changing it unless necessary");
                        }
                        this.f890f = false;
                        return;
                    }
                    throw new IllegalStateException("Scroll duration must be a positive number");
                } else {
                    throw new IllegalStateException("If you provide an interpolator, you must set a positive duration");
                }
            }

            /* renamed from: a */
            public void mo1435a(int i, int i2, int i3, Interpolator interpolator) {
                this.f885a = i;
                this.f886b = i2;
                this.f887c = i3;
                this.f889e = interpolator;
                this.f890f = true;
            }
        }

        /* renamed from: a */
        public void mo1433a(int i, int i2) {
            PointF a;
            RecyclerView recyclerView = this.f878b;
            if (this.f877a == -1 || recyclerView == null) {
                mo1432a();
            }
            if (!(!this.f880d || this.f882f != null || this.f879c == null || (a = mo1431a(this.f877a)) == null || (a.x == 0.0f && a.y == 0.0f))) {
                recyclerView.scrollStep((int) Math.signum(a.x), (int) Math.signum(a.y), (int[]) null);
            }
            boolean z = false;
            this.f880d = false;
            View view = this.f882f;
            if (view != null) {
                if (this.f878b.getChildLayoutPosition(view) == this.f877a) {
                    mo1434a(this.f882f, recyclerView.mState, this.f883g);
                    this.f883g.mo1436a(recyclerView);
                    mo1432a();
                } else {
                    Log.e(RecyclerView.TAG, "Passed over target position while smooth scrolling.");
                    this.f882f = null;
                }
            }
            if (this.f881e) {
                C0128a0 a0Var = recyclerView.mState;
                C0166a aVar = this.f883g;
                LinearSmoothScroller oVar = (LinearSmoothScroller) this;
                if (oVar.f878b.mLayout.mo1377d() == 0) {
                    oVar.mo1432a();
                } else {
                    int i3 = oVar.f3234o;
                    int i4 = i3 - i;
                    if (i3 * i4 <= 0) {
                        i4 = 0;
                    }
                    oVar.f3234o = i4;
                    int i5 = oVar.f3235p;
                    int i6 = i5 - i2;
                    if (i5 * i6 <= 0) {
                        i6 = 0;
                    }
                    oVar.f3235p = i6;
                    if (oVar.f3234o == 0 && i6 == 0) {
                        PointF a2 = oVar.mo1431a(oVar.f877a);
                        if (a2 == null || (a2.x == 0.0f && a2.y == 0.0f)) {
                            aVar.f888d = oVar.f877a;
                            oVar.mo1432a();
                        } else {
                            float f = a2.x;
                            float f2 = a2.y;
                            float sqrt = (float) Math.sqrt((double) ((f2 * f2) + (f * f)));
                            float f3 = a2.x / sqrt;
                            a2.x = f3;
                            float f4 = a2.y / sqrt;
                            a2.y = f4;
                            oVar.f3230k = a2;
                            oVar.f3234o = (int) (f3 * 10000.0f);
                            oVar.f3235p = (int) (f4 * 10000.0f);
                            aVar.mo1435a((int) (((float) oVar.f3234o) * 1.2f), (int) (((float) oVar.f3235p) * 1.2f), (int) (((float) oVar.mo3735b(10000)) * 1.2f), oVar.f3228i);
                        }
                    }
                }
                if (this.f883g.f888d >= 0) {
                    z = true;
                }
                this.f883g.mo1436a(recyclerView);
                if (z && this.f881e) {
                    this.f880d = true;
                    recyclerView.mViewFlinger.mo1304a();
                }
            }
        }
    }

    public void addItemDecoration(C0147n nVar) {
        addItemDecoration(nVar, -1);
    }

    /* renamed from: androidx.recyclerview.widget.RecyclerView$l */
    public static abstract class C0142l {

        /* renamed from: a */
        public C0144b f824a = null;

        /* renamed from: b */
        public ArrayList<C0143a> f825b = new ArrayList<>();

        /* renamed from: c */
        public long f826c = 120;

        /* renamed from: d */
        public long f827d = 120;

        /* renamed from: e */
        public long f828e = 250;

        /* renamed from: f */
        public long f829f = 250;

        /* renamed from: androidx.recyclerview.widget.RecyclerView$l$a */
        public interface C0143a {
            /* renamed from: a */
            void mo1353a();
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$l$b */
        public interface C0144b {
        }

        /* renamed from: androidx.recyclerview.widget.RecyclerView$l$c */
        public static class C0145c {

            /* renamed from: a */
            public int f830a;

            /* renamed from: b */
            public int f831b;
        }

        /* renamed from: d */
        public static int m575d(C0134d0 d0Var) {
            int i = d0Var.f811j & 14;
            if (d0Var.mo1321h()) {
                return 4;
            }
            if ((i & 4) != 0) {
                return i;
            }
            int i2 = d0Var.f805d;
            int c = d0Var.mo1316c();
            return (i2 == -1 || c == -1 || i2 == c) ? i : i | HarvestConfiguration.DEFAULT_RESPONSE_BODY_LIMIT;
        }

        /* renamed from: a */
        public final void mo1346a(C0134d0 d0Var) {
            C0144b bVar = this.f824a;
            if (bVar != null) {
                C0146m mVar = (C0146m) bVar;
                if (mVar != null) {
                    boolean z = true;
                    d0Var.mo1313a(true);
                    if (d0Var.f809h != null && d0Var.f810i == null) {
                        d0Var.f809h = null;
                    }
                    d0Var.f810i = null;
                    if ((d0Var.f811j & 16) == 0) {
                        z = false;
                    }
                    if (!z && !RecyclerView.this.removeAnimatingView(d0Var.f802a) && d0Var.mo1325l()) {
                        RecyclerView.this.removeDetachedView(d0Var.f802a, false);
                        return;
                    }
                    return;
                }
                throw null;
            }
        }

        /* renamed from: a */
        public abstract boolean mo1347a(C0134d0 d0Var, C0134d0 d0Var2, C0145c cVar, C0145c cVar2);

        /* renamed from: b */
        public abstract void mo1349b();

        /* renamed from: b */
        public abstract void mo1350b(C0134d0 d0Var);

        /* renamed from: c */
        public C0145c mo1351c(C0134d0 d0Var) {
            C0145c cVar = new C0145c();
            View view = d0Var.f802a;
            cVar.f830a = view.getLeft();
            cVar.f831b = view.getTop();
            view.getRight();
            view.getBottom();
            return cVar;
        }

        /* renamed from: c */
        public abstract boolean mo1352c();

        /* renamed from: a */
        public boolean mo1348a(C0134d0 d0Var, List<Object> list) {
            return !((SimpleItemAnimator) this).f3246g || d0Var.mo1321h();
        }

        /* renamed from: a */
        public final void mo1345a() {
            int size = this.f825b.size();
            for (int i = 0; i < size; i++) {
                this.f825b.get(i).mo1353a();
            }
            this.f825b.clear();
        }
    }
}
