package com.globant.pasaportesanitario.flujos.pantallaprincipal;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Log;
import androidx.lifecycle.LiveData;
import com.globant.pasaportesanitario.data.NombreEstado;
import com.globant.pasaportesanitario.data.local.modelo.PermisoCirculacionBD;
import com.globant.pasaportesanitario.data.local.modelo.UsuarioBD;
import com.globant.pasaportesanitario.data.repositorios.RepositorioLogout;
import com.globant.pasaportesanitario.flujos.BaseViewModel;
import java.util.concurrent.Callable;
import p008b.p063o.MutableLiveData;
import p085c.p118c.p119a.p123d.LanzadorDeServicioDeRastreo;
import p085c.p118c.p119a.p125e.p128e.EventoUnico;
import p229e.p230a.Completable;
import p229e.p230a.CompletableObserver;
import p229e.p230a.Single;
import p229e.p230a.p231j.p232a.AndroidSchedulers;
import p229e.p230a.p233k.CompositeDisposable;
import p229e.p230a.p235m.Action;
import p229e.p230a.p235m.Consumer;
import p229e.p230a.p236n.p240d.EmptyCompletableObserver;
import p229e.p230a.p249p.Schedulers;

public class PantallaPrincipalViewModel extends BaseViewModel {
    public final CompositeDisposable disposables = new CompositeDisposable();
    public MutableLiveData<EventoUnico<Integer>> eventoErrorBackend = new MutableLiveData<>();
    public MutableLiveData<EventoUnico<Boolean>> eventoLoadingDialog = new MutableLiveData<>();
    public MutableLiveData<EventoUnico<NavegacionDestinosPantallaPrincipal>> eventosDeNavegacion = new MutableLiveData<>();
    public MutableLiveData<EventoUnico<Intent>> levantarWebPermisoCirculacion = new MutableLiveData<>();
    public PantallaPrincipalRepository pantallaPrincipalRepository;
    public boolean permitirNavegar;
    public RepositorioLogout repositorioLogout;
    public UsuarioBD usuarioActual;
    public MutableLiveData<UsuarioBD> usuarioLiveData = new MutableLiveData<>();

    public enum NavegacionDestinosPantallaPrincipal {
        CIRCULAR,
        INFECTADO,
        NO_INFECTADO,
        DERIVADO_A_SALUD_LOCAL,
        DEBE_AUTODIAGNOSTICARSE,
        DESLOGUEAR
    }

    public PantallaPrincipalViewModel(PantallaPrincipalRepository pantallaPrincipalRepository2, RepositorioLogout repositorioLogout2, LanzadorDeServicioDeRastreo aVar) {
        super(aVar, pantallaPrincipalRepository2);
        this.pantallaPrincipalRepository = pantallaPrincipalRepository2;
        this.repositorioLogout = repositorioLogout2;
    }

    public void actualizarDatosUsuario() {
        this.disposables.mo9153c(Single.m5579a(new Callable<UsuarioBD>() {
            public UsuarioBD call() throws Exception {
                return PantallaPrincipalViewModel.this.pantallaPrincipalRepository.getUsuario();
            }
        }).mo9143b(Schedulers.f7556b).mo9140a(AndroidSchedulers.m5588a()).mo9141a(new Consumer<UsuarioBD>() {
            public void accept(UsuarioBD usuarioBD) throws Exception {
                UsuarioBD unused = PantallaPrincipalViewModel.this.usuarioActual = usuarioBD;
                PantallaPrincipalViewModel.this.usuarioLiveData.mo973b(usuarioBD);
                PantallaPrincipalViewModel.this.evaluarUltimoEstadoDelUsuario(usuarioBD);
            }
        }, new Consumer<Throwable>() {
            public void accept(Throwable th) throws Exception {
                Log.w("UserUpdate", "Error actualizando los datos de usuario");
            }
        }));
    }

    public void despacharEventoErrorBackend(Integer num) {
        this.eventoErrorBackend.mo973b(new EventoUnico(num));
    }

    public void despacharEventoNavegacion() {
        if (this.permitirNavegar) {
            UsuarioBD usuarioBD = this.usuarioActual;
            if (usuarioBD == null) {
                obtenerNavegador(NavegacionDestinosPantallaPrincipal.DESLOGUEAR);
                return;
            }
            String str = usuarioBD.estadoActual.nombreEstado;
            this.eventoLoadingDialog.mo973b(new EventoUnico(true));
            char c = 65535;
            switch (str.hashCode()) {
                case -794967207:
                    if (str.equals(NombreEstado.NO_INFECTADO)) {
                        c = 3;
                        break;
                    }
                    break;
                case -559334313:
                    if (str.equals(NombreEstado.INFECTADO)) {
                        c = 0;
                        break;
                    }
                    break;
                case -541344566:
                    if (str.equals(NombreEstado.DERIVADO_A_SALUD_LOCAL)) {
                        c = 1;
                        break;
                    }
                    break;
                case 1656715636:
                    if (str.equals(NombreEstado.DEBE_AUTODIAGNOSTICARSE)) {
                        c = 4;
                        break;
                    }
                    break;
                case 1913666072:
                    if (str.equals(NombreEstado.NO_CONTAGIOSO)) {
                        c = 2;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                obtenerNavegador(NavegacionDestinosPantallaPrincipal.INFECTADO);
            } else if (c == 1) {
                obtenerNavegador(NavegacionDestinosPantallaPrincipal.DERIVADO_A_SALUD_LOCAL);
            } else if (c == 2 || c == 3) {
                PermisoCirculacionBD permisoCirculacionBD = this.usuarioActual.estadoActual.permisoCirculacionBD;
                if (permisoCirculacionBD == null || TextUtils.isEmpty(permisoCirculacionBD.permisoQr)) {
                    obtenerNavegador(NavegacionDestinosPantallaPrincipal.NO_INFECTADO);
                } else {
                    obtenerNavegador(NavegacionDestinosPantallaPrincipal.CIRCULAR);
                }
            } else if (c == 4) {
                obtenerNavegador(NavegacionDestinosPantallaPrincipal.DEBE_AUTODIAGNOSTICARSE);
            }
            this.eventoLoadingDialog.mo973b(new EventoUnico(false));
        }
    }

    @SuppressLint({"CheckResult"})
    public void habilitarCirculacion() {
        this.eventoLoadingDialog.mo973b(new EventoUnico(true));
        Single.m5579a(new Callable<UsuarioBD>() {
            public UsuarioBD call() throws Exception {
                return PantallaPrincipalViewModel.this.pantallaPrincipalRepository.getUsuario();
            }
        }).mo9143b(Schedulers.f7556b).mo9140a(AndroidSchedulers.m5588a()).mo9141a(new Consumer<UsuarioBD>() {
            public void accept(UsuarioBD usuarioBD) throws Exception {
                UsuarioBD unused = PantallaPrincipalViewModel.this.usuarioActual = usuarioBD;
                PantallaPrincipalViewModel.this.eventoLoadingDialog.mo973b(new EventoUnico(false));
                if (usuarioBD.estadoActual.permisoCirculacionBD.permisoQr.isEmpty()) {
                    Intent intent = new Intent("android.intent.action.VIEW");
                    intent.setData(Uri.parse("https://www.argentina.gob.ar/solicitar-certificado-unico-habilitante-para-circulacion-emergencia-covid-19"));
                    PantallaPrincipalViewModel.this.levantarWebPermisoCirculacion.mo973b(new EventoUnico(intent));
                    return;
                }
                PantallaPrincipalViewModel.this.despacharEventoNavegacion();
            }
        }, new Consumer<Throwable>() {
            public void accept(Throwable th) throws Exception {
                PantallaPrincipalViewModel.this.eventoLoadingDialog.mo973b(new EventoUnico(false));
            }
        });
    }

    public void limpiarUsuarioActual() {
        this.permitirNavegar = false;
        this.usuarioActual = null;
    }

    public void logout() {
        Completable.m5553a((Action) new Action() {
            public void run() throws Exception {
                PantallaPrincipalViewModel.this.repositorioLogout.Logout();
            }
        }).mo9115a(Schedulers.f7556b).mo9116a((CompletableObserver) new EmptyCompletableObserver());
    }

    public LiveData<EventoUnico<Integer>> obtenerErrorBackend() {
        return this.eventoErrorBackend;
    }

    public LiveData<EventoUnico<Boolean>> obtenerEventoDeDialogo() {
        return this.eventoLoadingDialog;
    }

    public LiveData<EventoUnico<NavegacionDestinosPantallaPrincipal>> obtenerEventosDeNavegacionLiveData() {
        return this.eventosDeNavegacion;
    }

    public LiveData<EventoUnico<Intent>> obtenerLevantarWebLiveData() {
        return this.levantarWebPermisoCirculacion;
    }

    @SuppressLint({"CheckResult"})
    public void obtenerNavegador(NavegacionDestinosPantallaPrincipal navegacionDestinosPantallaPrincipal) {
        this.eventosDeNavegacion.mo973b(new EventoUnico(navegacionDestinosPantallaPrincipal));
    }

    @SuppressLint({"CheckResult"})
    public void obtenerUltimoEstadoDeBackend() {
        this.eventoLoadingDialog.mo973b(new EventoUnico(true));
        Single.m5579a(new Callable<UsuarioBD>() {
            public UsuarioBD call() throws Exception {
                return PantallaPrincipalViewModel.this.pantallaPrincipalRepository.getUsuario();
            }
        }).mo9143b(Schedulers.f7556b).mo9140a(AndroidSchedulers.m5588a()).mo9141a(new Consumer<UsuarioBD>() {
            public void accept(UsuarioBD usuarioBD) throws Exception {
                UsuarioBD unused = PantallaPrincipalViewModel.this.usuarioActual = usuarioBD;
                PantallaPrincipalViewModel pantallaPrincipalViewModel = PantallaPrincipalViewModel.this;
                pantallaPrincipalViewModel.permitirNavegar = true;
                pantallaPrincipalViewModel.usuarioLiveData.mo973b(usuarioBD);
                PantallaPrincipalViewModel.this.eventoLoadingDialog.mo973b(new EventoUnico(false));
                PantallaPrincipalViewModel.this.revisarEstadoDelUsuario(usuarioBD);
            }
        }, new Consumer<Throwable>() {
            public void accept(Throwable th) throws Exception {
                PantallaPrincipalViewModel.this.despacharEventoErrorBackend(0);
            }
        });
    }

    public LiveData<UsuarioBD> obtenerUltimoEstadoLiveData() {
        return this.usuarioLiveData;
    }

    @SuppressLint({"CheckResult"})
    public void obtenerUsuarioDeLaBD() {
        Single.m5579a(new Callable<UsuarioBD>() {
            public UsuarioBD call() throws Exception {
                return PantallaPrincipalViewModel.this.pantallaPrincipalRepository.getUsuario();
            }
        }).mo9143b(Schedulers.f7556b).mo9140a(AndroidSchedulers.m5588a()).mo9141a(new Consumer<UsuarioBD>() {
            public void accept(UsuarioBD usuarioBD) throws Exception {
                UsuarioBD unused = PantallaPrincipalViewModel.this.usuarioActual = usuarioBD;
                PantallaPrincipalViewModel pantallaPrincipalViewModel = PantallaPrincipalViewModel.this;
                pantallaPrincipalViewModel.permitirNavegar = true;
                pantallaPrincipalViewModel.usuarioLiveData.mo973b(usuarioBD);
                PantallaPrincipalViewModel.this.despacharEventoNavegacion();
            }
        }, new Consumer<Throwable>() {
            public void accept(Throwable th) throws Exception {
                Log.d("PantallaPrincipal", "Error al obtener el ultimo estado");
            }
        });
    }

    public void onCleared() {
        super.onCleared();
        this.disposables.mo9149a();
    }
}
