package com.google.android.material.appbar;

import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Interpolator;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.ScrollView;
import androidx.coordinatorlayout.widget.CoordinatorLayout;
import com.newrelic.agent.android.harvest.HarvestConfiguration;
import java.lang.ref.WeakReference;
import java.util.List;
import java.util.Objects;
import p000a.p001a.p002a.p004b.MediaDescriptionCompatApi21;
import p008b.p010b.p012l.p013a.AppCompatResources;
import p008b.p033h.p045m.NestedScrollingChild;
import p008b.p033h.p045m.OnApplyWindowInsetsListener;
import p008b.p033h.p045m.ViewCompat;
import p008b.p033h.p045m.WindowInsetsCompat;
import p008b.p033h.p045m.p046x.AccessibilityNodeInfoCompat;
import p008b.p050j.p051a.AbsSavedState;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p085c.p132d.p133a.p156b.C1161b;
import p085c.p132d.p133a.p156b.C1163d;
import p085c.p132d.p133a.p156b.C1194g;
import p085c.p132d.p133a.p156b.C1221j;
import p085c.p132d.p133a.p156b.C1224k;
import p085c.p132d.p133a.p156b.p160d0.MaterialShapeDrawable;
import p085c.p132d.p133a.p156b.p168l.AnimationUtils;
import p085c.p132d.p133a.p156b.p169m.C1225b;
import p085c.p132d.p133a.p156b.p169m.C1226c;
import p085c.p132d.p133a.p156b.p169m.C1227d;
import p085c.p132d.p133a.p156b.p169m.HeaderBehavior;
import p085c.p132d.p133a.p156b.p169m.HeaderScrollingViewBehavior;
import p085c.p132d.p133a.p156b.p169m.ViewUtilsLollipop;

public class AppBarLayout extends LinearLayout implements CoordinatorLayout.C0073b {

    /* renamed from: q */
    public static final int f6709q = C1221j.Widget_Design_AppBarLayout;

    /* renamed from: b */
    public int f6710b;

    /* renamed from: c */
    public int f6711c;

    /* renamed from: d */
    public int f6712d;

    /* renamed from: e */
    public int f6713e;

    /* renamed from: f */
    public boolean f6714f;

    /* renamed from: g */
    public int f6715g;

    /* renamed from: h */
    public WindowInsetsCompat f6716h;

    /* renamed from: i */
    public boolean f6717i;

    /* renamed from: j */
    public boolean f6718j;

    /* renamed from: k */
    public boolean f6719k;

    /* renamed from: l */
    public int f6720l;

    /* renamed from: m */
    public WeakReference<View> f6721m;

    /* renamed from: n */
    public ValueAnimator f6722n;

    /* renamed from: o */
    public int[] f6723o;

    /* renamed from: p */
    public Drawable f6724p;

    public static class Behavior extends BaseBehavior<AppBarLayout> {
        public Behavior() {
        }

        public Behavior(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }
    }

    public static class ScrollingViewBehavior extends HeaderScrollingViewBehavior {
        public ScrollingViewBehavior() {
        }

        /* renamed from: a */
        public boolean mo619a(CoordinatorLayout coordinatorLayout, View view, View view2) {
            return view2 instanceof AppBarLayout;
        }

        /* renamed from: b */
        public boolean mo623b(CoordinatorLayout coordinatorLayout, View view, View view2) {
            CoordinatorLayout.C0074c cVar = ((CoordinatorLayout.C0077f) view2.getLayoutParams()).f533a;
            if (cVar instanceof BaseBehavior) {
                ViewCompat.m1957e(view, (((view2.getBottom() - view.getTop()) + ((BaseBehavior) cVar).f6725k) + this.f5470f) - mo5287a(view2));
            }
            if (!(view2 instanceof AppBarLayout)) {
                return false;
            }
            AppBarLayout appBarLayout = (AppBarLayout) view2;
            if (!appBarLayout.f6719k) {
                return false;
            }
            appBarLayout.mo6455a(appBarLayout.mo6454a(view));
            return false;
        }

        /* renamed from: c */
        public void mo624c(CoordinatorLayout coordinatorLayout, View view, View view2) {
            if (view2 instanceof AppBarLayout) {
                ViewCompat.m1959f(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2550f.mo3176a());
                ViewCompat.m1959f(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2551g.mo3176a());
            }
        }

        public ScrollingViewBehavior(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, C1224k.ScrollingViewBehavior_Layout);
            this.f5471g = obtainStyledAttributes.getDimensionPixelSize(C1224k.ScrollingViewBehavior_Layout_behavior_overlapTop, 0);
            obtainStyledAttributes.recycle();
        }

        /* renamed from: a */
        public boolean mo617a(CoordinatorLayout coordinatorLayout, View view, Rect rect, boolean z) {
            AppBarLayout a = mo6498a(coordinatorLayout.mo551a(view));
            if (a != null) {
                rect.offset(view.getLeft(), view.getTop());
                Rect rect2 = this.f5468d;
                rect2.set(0, 0, coordinatorLayout.getWidth(), coordinatorLayout.getHeight());
                if (!rect2.contains(rect)) {
                    a.mo6452a(false, !z, true);
                    return true;
                }
            }
            return false;
        }

        /* renamed from: a */
        public AppBarLayout mo6498a(List<View> list) {
            int size = list.size();
            for (int i = 0; i < size; i++) {
                View view = list.get(i);
                if (view instanceof AppBarLayout) {
                    return (AppBarLayout) view;
                }
            }
            return null;
        }
    }

    /* renamed from: com.google.android.material.appbar.AppBarLayout$a */
    public class C1580a implements OnApplyWindowInsetsListener {
        public C1580a() {
        }

        /* renamed from: a */
        public WindowInsetsCompat mo605a(View view, WindowInsetsCompat wVar) {
            AppBarLayout appBarLayout = AppBarLayout.this;
            WindowInsetsCompat wVar2 = null;
            if (appBarLayout != null) {
                if (ViewCompat.m1963h(appBarLayout)) {
                    wVar2 = wVar;
                }
                if (!Objects.equals(appBarLayout.f6716h, wVar2)) {
                    appBarLayout.f6716h = wVar2;
                    appBarLayout.mo6456b();
                    appBarLayout.requestLayout();
                }
                return wVar;
            }
            throw null;
        }
    }

    public AppBarLayout(Context context) {
        this(context, (AttributeSet) null);
    }

    /* renamed from: a */
    public final void mo6452a(boolean z, boolean z2, boolean z3) {
        int i = 0;
        int i2 = (z ? 1 : 2) | (z2 ? 4 : 0);
        if (z3) {
            i = 8;
        }
        this.f6715g = i2 | i;
        requestLayout();
    }

    /* renamed from: b */
    public final void mo6456b() {
        setWillNotDraw(!(this.f6724p != null && getTopInset() > 0));
    }

    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof C1581b;
    }

    public void draw(Canvas canvas) {
        super.draw(canvas);
        if (this.f6724p != null && getTopInset() > 0) {
            int save = canvas.save();
            canvas.translate(0.0f, (float) (-this.f6710b));
            this.f6724p.draw(canvas);
            canvas.restoreToCount(save);
        }
    }

    public void drawableStateChanged() {
        super.drawableStateChanged();
        int[] drawableState = getDrawableState();
        Drawable drawable = this.f6724p;
        if (drawable != null && drawable.isStateful() && drawable.setState(drawableState)) {
            invalidateDrawable(drawable);
        }
    }

    public ViewGroup.LayoutParams generateDefaultLayoutParams() {
        return new C1581b(-1, -2);
    }

    public CoordinatorLayout.C0074c<AppBarLayout> getBehavior() {
        return new Behavior();
    }

    public int getDownNestedPreScrollRange() {
        int i;
        int l;
        int i2 = this.f6712d;
        if (i2 != -1) {
            return i2;
        }
        int i3 = 0;
        for (int childCount = getChildCount() - 1; childCount >= 0; childCount--) {
            View childAt = getChildAt(childCount);
            C1581b bVar = (C1581b) childAt.getLayoutParams();
            int measuredHeight = childAt.getMeasuredHeight();
            int i4 = bVar.f6736a;
            if ((i4 & 5) == 5) {
                int i5 = bVar.topMargin + bVar.bottomMargin;
                if ((i4 & 8) != 0) {
                    l = ViewCompat.m1967l(childAt);
                } else if ((i4 & 2) != 0) {
                    l = measuredHeight - ViewCompat.m1967l(childAt);
                } else {
                    i = i5 + measuredHeight;
                    if (childCount == 0 && ViewCompat.m1963h(childAt)) {
                        i = Math.min(i, measuredHeight - getTopInset());
                    }
                    i3 += i;
                }
                i = l + i5;
                i = Math.min(i, measuredHeight - getTopInset());
                i3 += i;
            } else if (i3 > 0) {
                break;
            }
        }
        int max = Math.max(0, i3);
        this.f6712d = max;
        return max;
    }

    public int getDownNestedScrollRange() {
        int i = this.f6713e;
        if (i != -1) {
            return i;
        }
        int childCount = getChildCount();
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i2 >= childCount) {
                break;
            }
            View childAt = getChildAt(i2);
            C1581b bVar = (C1581b) childAt.getLayoutParams();
            int measuredHeight = bVar.topMargin + bVar.bottomMargin + childAt.getMeasuredHeight();
            int i4 = bVar.f6736a;
            if ((i4 & 1) == 0) {
                break;
            }
            i3 += measuredHeight;
            if ((i4 & 2) != 0) {
                i3 -= ViewCompat.m1967l(childAt);
                break;
            }
            i2++;
        }
        int max = Math.max(0, i3);
        this.f6713e = max;
        return max;
    }

    public int getLiftOnScrollTargetViewId() {
        return this.f6720l;
    }

    public final int getMinimumHeightForVisibleOverlappingContent() {
        int topInset = getTopInset();
        int l = ViewCompat.m1967l(this);
        if (l == 0) {
            int childCount = getChildCount();
            l = childCount >= 1 ? getChildAt(childCount - 1).getMinimumHeight() : 0;
            if (l == 0) {
                return getHeight() / 3;
            }
        }
        return (l * 2) + topInset;
    }

    public int getPendingAction() {
        return this.f6715g;
    }

    public Drawable getStatusBarForeground() {
        return this.f6724p;
    }

    @Deprecated
    public float getTargetElevation() {
        return 0.0f;
    }

    public final int getTopInset() {
        WindowInsetsCompat wVar = this.f6716h;
        if (wVar != null) {
            return wVar.mo3160d();
        }
        return 0;
    }

    public final int getTotalScrollRange() {
        int i = this.f6711c;
        if (i != -1) {
            return i;
        }
        int childCount = getChildCount();
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i2 >= childCount) {
                break;
            }
            View childAt = getChildAt(i2);
            C1581b bVar = (C1581b) childAt.getLayoutParams();
            int measuredHeight = childAt.getMeasuredHeight();
            int i4 = bVar.f6736a;
            if ((i4 & 1) == 0) {
                break;
            }
            int i5 = measuredHeight + bVar.topMargin + bVar.bottomMargin + i3;
            if (i2 == 0 && ViewCompat.m1963h(childAt)) {
                i5 -= getTopInset();
            }
            i3 = i5;
            if ((i4 & 2) != 0) {
                i3 -= ViewCompat.m1967l(childAt);
                break;
            }
            i2++;
        }
        int max = Math.max(0, i3);
        this.f6711c = max;
        return max;
    }

    public int getUpNestedPreScrollRange() {
        return getTotalScrollRange();
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        Drawable background = getBackground();
        if (background instanceof MaterialShapeDrawable) {
            C1050v.m4175a((View) this, (MaterialShapeDrawable) background);
        }
    }

    public int[] onCreateDrawableState(int i) {
        if (this.f6723o == null) {
            this.f6723o = new int[4];
        }
        int[] iArr = this.f6723o;
        int[] onCreateDrawableState = super.onCreateDrawableState(i + iArr.length);
        iArr[0] = this.f6717i ? C1161b.state_liftable : -C1161b.state_liftable;
        iArr[1] = (!this.f6717i || !this.f6718j) ? -C1161b.state_lifted : C1161b.state_lifted;
        iArr[2] = this.f6717i ? C1161b.state_collapsible : -C1161b.state_collapsible;
        iArr[3] = (!this.f6717i || !this.f6718j) ? -C1161b.state_collapsed : C1161b.state_collapsed;
        return LinearLayout.mergeDrawableStates(onCreateDrawableState, iArr);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        WeakReference<View> weakReference = this.f6721m;
        if (weakReference != null) {
            weakReference.clear();
        }
        this.f6721m = null;
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        boolean z2;
        super.onLayout(z, i, i2, i3, i4);
        boolean z3 = true;
        if (ViewCompat.m1963h(this) && mo6453a()) {
            int topInset = getTopInset();
            for (int childCount = getChildCount() - 1; childCount >= 0; childCount--) {
                ViewCompat.m1957e(getChildAt(childCount), topInset);
            }
        }
        this.f6711c = -1;
        this.f6712d = -1;
        this.f6713e = -1;
        this.f6714f = false;
        int childCount2 = getChildCount();
        int i5 = 0;
        while (true) {
            if (i5 >= childCount2) {
                break;
            } else if (((C1581b) getChildAt(i5).getLayoutParams()).f6737b != null) {
                this.f6714f = true;
                break;
            } else {
                i5++;
            }
        }
        Drawable drawable = this.f6724p;
        if (drawable != null) {
            drawable.setBounds(0, 0, getWidth(), getTopInset());
        }
        if (!this.f6719k) {
            int childCount3 = getChildCount();
            int i6 = 0;
            while (true) {
                if (i6 >= childCount3) {
                    z2 = false;
                    break;
                }
                int i7 = ((C1581b) getChildAt(i6).getLayoutParams()).f6736a;
                if ((i7 & 1) == 1 && (i7 & 10) != 0) {
                    z2 = true;
                    break;
                }
                i6++;
            }
            if (!z2) {
                z3 = false;
            }
        }
        if (this.f6717i != z3) {
            this.f6717i = z3;
            refreshDrawableState();
        }
    }

    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        int mode = View.MeasureSpec.getMode(i2);
        if (mode != 1073741824 && ViewCompat.m1963h(this) && mo6453a()) {
            int measuredHeight = getMeasuredHeight();
            if (mode == Integer.MIN_VALUE) {
                measuredHeight = MediaDescriptionCompatApi21.m5a(getTopInset() + getMeasuredHeight(), 0, View.MeasureSpec.getSize(i2));
            } else if (mode == 0) {
                measuredHeight += getTopInset();
            }
            setMeasuredDimension(getMeasuredWidth(), measuredHeight);
        }
        this.f6711c = -1;
        this.f6712d = -1;
        this.f6713e = -1;
    }

    public void setElevation(float f) {
        super.setElevation(f);
        C1050v.m4174a((View) this, f);
    }

    public void setExpanded(boolean z) {
        mo6452a(z, ViewCompat.m1978w(this), true);
    }

    public void setLiftOnScroll(boolean z) {
        this.f6719k = z;
    }

    public void setLiftOnScrollTargetViewId(int i) {
        this.f6720l = i;
        WeakReference<View> weakReference = this.f6721m;
        if (weakReference != null) {
            weakReference.clear();
        }
        this.f6721m = null;
    }

    public void setOrientation(int i) {
        if (i == 1) {
            super.setOrientation(i);
            return;
        }
        throw new IllegalArgumentException("AppBarLayout is always vertical and does not support horizontal orientation");
    }

    public void setStatusBarForeground(Drawable drawable) {
        Drawable drawable2 = this.f6724p;
        if (drawable2 != drawable) {
            Drawable drawable3 = null;
            if (drawable2 != null) {
                drawable2.setCallback((Drawable.Callback) null);
            }
            if (drawable != null) {
                drawable3 = drawable.mutate();
            }
            this.f6724p = drawable3;
            if (drawable3 != null) {
                if (drawable3.isStateful()) {
                    this.f6724p.setState(getDrawableState());
                }
                MediaDescriptionCompatApi21.m73a(this.f6724p, ViewCompat.m1966k(this));
                this.f6724p.setVisible(getVisibility() == 0, false);
                this.f6724p.setCallback(this);
            }
            mo6456b();
            ViewCompat.m1922A(this);
        }
    }

    public void setStatusBarForegroundColor(int i) {
        setStatusBarForeground(new ColorDrawable(i));
    }

    public void setStatusBarForegroundResource(int i) {
        setStatusBarForeground(AppCompatResources.m982c(getContext(), i));
    }

    @Deprecated
    public void setTargetElevation(float f) {
        ViewUtilsLollipop.m4484a(this, f);
    }

    public void setVisibility(int i) {
        super.setVisibility(i);
        boolean z = i == 0;
        Drawable drawable = this.f6724p;
        if (drawable != null) {
            drawable.setVisible(z, false);
        }
    }

    public boolean verifyDrawable(Drawable drawable) {
        return super.verifyDrawable(drawable) || drawable == this.f6724p;
    }

    public static class BaseBehavior<T extends AppBarLayout> extends HeaderBehavior<T> {

        /* renamed from: k */
        public int f6725k;

        /* renamed from: l */
        public int f6726l;

        /* renamed from: m */
        public ValueAnimator f6727m;

        /* renamed from: n */
        public int f6728n = -1;

        /* renamed from: o */
        public boolean f6729o;

        /* renamed from: p */
        public float f6730p;

        /* renamed from: q */
        public WeakReference<View> f6731q;

        public BaseBehavior() {
        }

        /* renamed from: a */
        public static boolean m5161a(int i, int i2) {
            return (i & i2) == i2;
        }

        /* renamed from: a */
        public boolean mo614a(CoordinatorLayout coordinatorLayout, View view, int i) {
            int i2;
            AppBarLayout appBarLayout = (AppBarLayout) view;
            super.mo614a(coordinatorLayout, appBarLayout, i);
            int pendingAction = appBarLayout.getPendingAction();
            int i3 = this.f6728n;
            if (i3 >= 0 && (pendingAction & 8) == 0) {
                View childAt = appBarLayout.getChildAt(i3);
                int i4 = -childAt.getBottom();
                if (this.f6729o) {
                    i2 = appBarLayout.getTopInset() + childAt.getMinimumHeight() + i4;
                } else {
                    i2 = Math.round(((float) childAt.getHeight()) * this.f6730p) + i4;
                }
                mo5285c(coordinatorLayout, appBarLayout, i2);
            } else if (pendingAction != 0) {
                boolean z = (pendingAction & 4) != 0;
                if ((pendingAction & 2) != 0) {
                    int i5 = -appBarLayout.getUpNestedPreScrollRange();
                    if (z) {
                        mo6491a(coordinatorLayout, appBarLayout, i5, 0.0f);
                    } else {
                        mo5285c(coordinatorLayout, appBarLayout, i5);
                    }
                } else if ((pendingAction & 1) != 0) {
                    if (z) {
                        mo6491a(coordinatorLayout, appBarLayout, 0, 0.0f);
                    } else {
                        mo5285c(coordinatorLayout, appBarLayout, 0);
                    }
                }
            }
            appBarLayout.f6715g = 0;
            this.f6728n = -1;
            mo5289a(MediaDescriptionCompatApi21.m5a(mo5290b(), -appBarLayout.getTotalScrollRange(), 0));
            mo6492a(coordinatorLayout, appBarLayout, mo5290b(), 0, true);
            appBarLayout.f6710b = mo5290b();
            if (!appBarLayout.willNotDraw()) {
                ViewCompat.m1922A(appBarLayout);
            }
            mo6494b(coordinatorLayout, appBarLayout);
            return true;
        }

        /* JADX WARNING: Removed duplicated region for block: B:38:0x00b0  */
        /* JADX WARNING: Removed duplicated region for block: B:44:0x00d2  */
        /* JADX WARNING: Removed duplicated region for block: B:46:0x00d7  */
        /* JADX WARNING: Removed duplicated region for block: B:47:0x00da  */
        /* renamed from: b */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public int mo5283b(androidx.coordinatorlayout.widget.CoordinatorLayout r8, android.view.View r9, int r10, int r11, int r12) {
            /*
                r7 = this;
                com.google.android.material.appbar.AppBarLayout r9 = (com.google.android.material.appbar.AppBarLayout) r9
                int r0 = r7.mo5284c()
                r1 = 0
                if (r11 == 0) goto L_0x00e5
                if (r0 < r11) goto L_0x00e5
                if (r0 > r12) goto L_0x00e5
                int r3 = p000a.p001a.p002a.p004b.MediaDescriptionCompatApi21.m5a((int) r10, (int) r11, (int) r12)
                if (r0 == r3) goto L_0x00e7
                boolean r10 = r9.f6714f
                if (r10 == 0) goto L_0x0086
                int r10 = java.lang.Math.abs(r3)
                int r11 = r9.getChildCount()
                r12 = 0
            L_0x0020:
                if (r12 >= r11) goto L_0x0086
                android.view.View r2 = r9.getChildAt(r12)
                android.view.ViewGroup$LayoutParams r4 = r2.getLayoutParams()
                com.google.android.material.appbar.AppBarLayout$b r4 = (com.google.android.material.appbar.AppBarLayout.C1581b) r4
                android.view.animation.Interpolator r5 = r4.f6737b
                int r6 = r2.getTop()
                if (r10 < r6) goto L_0x0083
                int r6 = r2.getBottom()
                if (r10 > r6) goto L_0x0083
                if (r5 == 0) goto L_0x0086
                int r11 = r4.f6736a
                r12 = r11 & 1
                if (r12 == 0) goto L_0x0057
                int r12 = r2.getHeight()
                int r6 = r4.topMargin
                int r12 = r12 + r6
                int r4 = r4.bottomMargin
                int r12 = r12 + r4
                int r12 = r12 + r1
                r11 = r11 & 2
                if (r11 == 0) goto L_0x0058
                int r11 = p008b.p033h.p045m.ViewCompat.m1967l(r2)
                int r12 = r12 - r11
                goto L_0x0058
            L_0x0057:
                r12 = 0
            L_0x0058:
                boolean r11 = p008b.p033h.p045m.ViewCompat.m1963h(r2)
                if (r11 == 0) goto L_0x0063
                int r11 = r9.getTopInset()
                int r12 = r12 - r11
            L_0x0063:
                if (r12 <= 0) goto L_0x0086
                int r11 = r2.getTop()
                int r10 = r10 - r11
                float r11 = (float) r12
                float r10 = (float) r10
                float r10 = r10 / r11
                float r10 = r5.getInterpolation(r10)
                float r10 = r10 * r11
                int r10 = java.lang.Math.round(r10)
                int r11 = java.lang.Integer.signum(r3)
                int r12 = r2.getTop()
                int r12 = r12 + r10
                int r12 = r12 * r11
                goto L_0x0087
            L_0x0083:
                int r12 = r12 + 1
                goto L_0x0020
            L_0x0086:
                r12 = r3
            L_0x0087:
                boolean r10 = r7.mo5289a(r12)
                int r11 = r0 - r3
                int r12 = r3 - r12
                r7.f6725k = r12
                if (r10 != 0) goto L_0x00c6
                boolean r10 = r9.f6714f
                if (r10 == 0) goto L_0x00c6
                b.g.d.a<android.view.View> r10 = r8.f513c
                b.e.h<T, java.util.ArrayList<T>> r10 = r10.f2263b
                r12 = 0
                java.lang.Object r10 = r10.getOrDefault(r9, r12)
                java.util.List r10 = (java.util.List) r10
                if (r10 == 0) goto L_0x00c6
                boolean r12 = r10.isEmpty()
                if (r12 != 0) goto L_0x00c6
            L_0x00aa:
                int r12 = r10.size()
                if (r1 >= r12) goto L_0x00c6
                java.lang.Object r12 = r10.get(r1)
                android.view.View r12 = (android.view.View) r12
                android.view.ViewGroup$LayoutParams r2 = r12.getLayoutParams()
                androidx.coordinatorlayout.widget.CoordinatorLayout$f r2 = (androidx.coordinatorlayout.widget.CoordinatorLayout.C0077f) r2
                androidx.coordinatorlayout.widget.CoordinatorLayout$c r2 = r2.f533a
                if (r2 == 0) goto L_0x00c3
                r2.mo623b((androidx.coordinatorlayout.widget.CoordinatorLayout) r8, r12, (android.view.View) r9)
            L_0x00c3:
                int r1 = r1 + 1
                goto L_0x00aa
            L_0x00c6:
                int r10 = r7.mo5290b()
                r9.f6710b = r10
                boolean r10 = r9.willNotDraw()
                if (r10 != 0) goto L_0x00d5
                p008b.p033h.p045m.ViewCompat.m1922A(r9)
            L_0x00d5:
                if (r3 >= r0) goto L_0x00da
                r10 = -1
                r4 = -1
                goto L_0x00dc
            L_0x00da:
                r10 = 1
                r4 = 1
            L_0x00dc:
                r5 = 0
                r0 = r7
                r1 = r8
                r2 = r9
                r0.mo6492a((androidx.coordinatorlayout.widget.CoordinatorLayout) r1, r2, (int) r3, (int) r4, (boolean) r5)
                r1 = r11
                goto L_0x00e7
            L_0x00e5:
                r7.f6725k = r1
            L_0x00e7:
                r7.mo6494b(r8, r9)
                return r1
            */
            throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.appbar.AppBarLayout.BaseBehavior.mo5283b(androidx.coordinatorlayout.widget.CoordinatorLayout, android.view.View, int, int, int):int");
        }

        /* renamed from: c */
        public int mo5284c() {
            return mo5290b() + this.f6725k;
        }

        public BaseBehavior(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        /* renamed from: com.google.android.material.appbar.AppBarLayout$BaseBehavior$a */
        public static class C1578a extends AbsSavedState {
            public static final Parcelable.Creator<C1578a> CREATOR = new C1579a();

            /* renamed from: d */
            public int f6732d;

            /* renamed from: e */
            public float f6733e;

            /* renamed from: f */
            public boolean f6734f;

            /* renamed from: com.google.android.material.appbar.AppBarLayout$BaseBehavior$a$a */
            public static class C1579a implements Parcelable.ClassLoaderCreator<C1578a> {
                public Object createFromParcel(Parcel parcel, ClassLoader classLoader) {
                    return new C1578a(parcel, classLoader);
                }

                public Object[] newArray(int i) {
                    return new C1578a[i];
                }

                public Object createFromParcel(Parcel parcel) {
                    return new C1578a(parcel, (ClassLoader) null);
                }
            }

            public C1578a(Parcel parcel, ClassLoader classLoader) {
                super(parcel, classLoader);
                this.f6732d = parcel.readInt();
                this.f6733e = parcel.readFloat();
                this.f6734f = parcel.readByte() != 0;
            }

            public void writeToParcel(Parcel parcel, int i) {
                parcel.writeParcelable(this.f2617b, i);
                parcel.writeInt(this.f6732d);
                parcel.writeFloat(this.f6733e);
                parcel.writeByte(this.f6734f ? (byte) 1 : 0);
            }

            public C1578a(Parcelable parcelable) {
                super(parcelable);
            }
        }

        /* renamed from: a */
        public boolean mo615a(CoordinatorLayout coordinatorLayout, View view, int i, int i2, int i3, int i4) {
            AppBarLayout appBarLayout = (AppBarLayout) view;
            if (((CoordinatorLayout.C0077f) appBarLayout.getLayoutParams()).height != -2) {
                return false;
            }
            coordinatorLayout.mo554a((View) appBarLayout, i, i2, View.MeasureSpec.makeMeasureSpec(0, 0), i4);
            return true;
        }

        /* renamed from: a */
        public /* bridge */ /* synthetic */ void mo613a(CoordinatorLayout coordinatorLayout, View view, View view2, int i, int i2, int[] iArr, int i3) {
            mo6493a(coordinatorLayout, (AppBarLayout) view, view2, i2, iArr);
        }

        /* renamed from: a */
        public void mo612a(CoordinatorLayout coordinatorLayout, View view, View view2, int i, int i2, int i3, int i4, int i5, int[] iArr) {
            AppBarLayout appBarLayout = (AppBarLayout) view;
            if (i4 < 0) {
                iArr[1] = mo5282a(coordinatorLayout, appBarLayout, i4, -appBarLayout.getDownNestedScrollRange(), 0);
            }
            if (i4 == 0) {
                mo6494b(coordinatorLayout, appBarLayout);
            }
        }

        /* renamed from: a */
        public void mo610a(CoordinatorLayout coordinatorLayout, View view, Parcelable parcelable) {
            AppBarLayout appBarLayout = (AppBarLayout) view;
            if (parcelable instanceof C1578a) {
                C1578a aVar = (C1578a) parcelable;
                Parcelable parcelable2 = aVar.f2617b;
                this.f6728n = aVar.f6732d;
                this.f6730p = aVar.f6733e;
                this.f6729o = aVar.f6734f;
                return;
            }
            this.f6728n = -1;
        }

        /* renamed from: b */
        public final void mo6494b(CoordinatorLayout coordinatorLayout, T t) {
            ViewCompat.m1959f(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2550f.mo3176a());
            ViewCompat.m1959f(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2551g.mo3176a());
            View a = mo6489a(coordinatorLayout);
            if (a != null && t.getTotalScrollRange() != 0 && (((CoordinatorLayout.C0077f) a.getLayoutParams()).f533a instanceof ScrollingViewBehavior)) {
                if (mo5284c() != (-t.getTotalScrollRange()) && a.canScrollVertically(1)) {
                    ViewCompat.m1940a(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2550f, (CharSequence) null, new C1227d(this, t, false));
                }
                if (mo5284c() == 0) {
                    return;
                }
                if (a.canScrollVertically(-1)) {
                    int i = -t.getDownNestedPreScrollRange();
                    if (i != 0) {
                        ViewCompat.m1940a(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2551g, (CharSequence) null, new C1226c(this, coordinatorLayout, t, a, i));
                        return;
                    }
                    return;
                }
                ViewCompat.m1940a(coordinatorLayout, AccessibilityNodeInfoCompat.C0411a.f2551g, (CharSequence) null, new C1227d(this, t, true));
            }
        }

        /* renamed from: a */
        public Parcelable mo607a(CoordinatorLayout coordinatorLayout, View view) {
            AppBarLayout appBarLayout = (AppBarLayout) view;
            android.view.AbsSavedState absSavedState = View.BaseSavedState.EMPTY_STATE;
            int b = mo5290b();
            int childCount = appBarLayout.getChildCount();
            boolean z = false;
            int i = 0;
            while (i < childCount) {
                View childAt = appBarLayout.getChildAt(i);
                int bottom = childAt.getBottom() + b;
                if (childAt.getTop() + b > 0 || bottom < 0) {
                    i++;
                } else {
                    C1578a aVar = new C1578a(absSavedState);
                    aVar.f6732d = i;
                    if (bottom == appBarLayout.getTopInset() + ViewCompat.m1967l(childAt)) {
                        z = true;
                    }
                    aVar.f6734f = z;
                    aVar.f6733e = ((float) bottom) / ((float) childAt.getHeight());
                    return aVar;
                }
            }
            return absSavedState;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:13:0x0029, code lost:
            if (((r3.getTotalScrollRange() != 0) && r2.getHeight() - r4.getHeight() <= r3.getHeight()) != false) goto L_0x002b;
         */
        /* renamed from: a */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public boolean mo621a(androidx.coordinatorlayout.widget.CoordinatorLayout r2, android.view.View r3, android.view.View r4, android.view.View r5, int r6, int r7) {
            /*
                r1 = this;
                com.google.android.material.appbar.AppBarLayout r3 = (com.google.android.material.appbar.AppBarLayout) r3
                r5 = r6 & 2
                r6 = 0
                r0 = 1
                if (r5 == 0) goto L_0x002c
                boolean r5 = r3.f6719k
                if (r5 != 0) goto L_0x002b
                int r5 = r3.getTotalScrollRange()
                if (r5 == 0) goto L_0x0014
                r5 = 1
                goto L_0x0015
            L_0x0014:
                r5 = 0
            L_0x0015:
                if (r5 == 0) goto L_0x0028
                int r2 = r2.getHeight()
                int r4 = r4.getHeight()
                int r2 = r2 - r4
                int r3 = r3.getHeight()
                if (r2 > r3) goto L_0x0028
                r2 = 1
                goto L_0x0029
            L_0x0028:
                r2 = 0
            L_0x0029:
                if (r2 == 0) goto L_0x002c
            L_0x002b:
                r6 = 1
            L_0x002c:
                if (r6 == 0) goto L_0x0035
                android.animation.ValueAnimator r2 = r1.f6727m
                if (r2 == 0) goto L_0x0035
                r2.cancel()
            L_0x0035:
                r2 = 0
                r1.f6731q = r2
                r1.f6726l = r7
                return r6
            */
            throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.appbar.AppBarLayout.BaseBehavior.mo621a(androidx.coordinatorlayout.widget.CoordinatorLayout, android.view.View, android.view.View, android.view.View, int, int):boolean");
        }

        /* renamed from: a */
        public void mo611a(CoordinatorLayout coordinatorLayout, View view, View view2, int i) {
            AppBarLayout appBarLayout = (AppBarLayout) view;
            if (this.f6726l == 0 || i == 1) {
                mo6490a(coordinatorLayout, appBarLayout);
                if (appBarLayout.f6719k) {
                    appBarLayout.mo6455a(appBarLayout.mo6454a(view2));
                }
            }
            this.f6731q = new WeakReference<>(view2);
        }

        /* renamed from: a */
        public void mo6493a(CoordinatorLayout coordinatorLayout, AppBarLayout appBarLayout, View view, int i, int[] iArr) {
            int i2;
            int i3;
            if (i != 0) {
                if (i < 0) {
                    int i4 = -appBarLayout.getTotalScrollRange();
                    i3 = i4;
                    i2 = appBarLayout.getDownNestedPreScrollRange() + i4;
                } else {
                    i3 = -appBarLayout.getUpNestedPreScrollRange();
                    i2 = 0;
                }
                if (i3 != i2) {
                    iArr[1] = mo5282a(coordinatorLayout, appBarLayout, i, i3, i2);
                }
            }
            if (appBarLayout.f6719k) {
                appBarLayout.mo6455a(appBarLayout.mo6454a(view));
            }
        }

        /* renamed from: a */
        public final void mo6491a(CoordinatorLayout coordinatorLayout, T t, int i, float f) {
            int i2;
            int abs = Math.abs(mo5284c() - i);
            float abs2 = Math.abs(f);
            if (abs2 > 0.0f) {
                i2 = Math.round((((float) abs) / abs2) * 1000.0f) * 3;
            } else {
                i2 = (int) (((((float) abs) / ((float) t.getHeight())) + 1.0f) * 150.0f);
            }
            int c = mo5284c();
            if (c == i) {
                ValueAnimator valueAnimator = this.f6727m;
                if (valueAnimator != null && valueAnimator.isRunning()) {
                    this.f6727m.cancel();
                    return;
                }
                return;
            }
            ValueAnimator valueAnimator2 = this.f6727m;
            if (valueAnimator2 == null) {
                ValueAnimator valueAnimator3 = new ValueAnimator();
                this.f6727m = valueAnimator3;
                valueAnimator3.setInterpolator(AnimationUtils.f5428e);
                this.f6727m.addUpdateListener(new C1225b(this, coordinatorLayout, t));
            } else {
                valueAnimator2.cancel();
            }
            this.f6727m.setDuration((long) Math.min(i2, HarvestConfiguration.DEFAULT_MAX_TRANSACTION_AGE));
            this.f6727m.setIntValues(new int[]{c, i});
            this.f6727m.start();
        }

        /* renamed from: a */
        public final void mo6490a(CoordinatorLayout coordinatorLayout, T t) {
            int c = mo5284c();
            int childCount = t.getChildCount();
            int i = 0;
            while (true) {
                if (i >= childCount) {
                    i = -1;
                    break;
                }
                View childAt = t.getChildAt(i);
                int top = childAt.getTop();
                int bottom = childAt.getBottom();
                C1581b bVar = (C1581b) childAt.getLayoutParams();
                if (m5161a(bVar.f6736a, 32)) {
                    top -= bVar.topMargin;
                    bottom += bVar.bottomMargin;
                }
                int i2 = -c;
                if (top <= i2 && bottom >= i2) {
                    break;
                }
                i++;
            }
            if (i >= 0) {
                View childAt2 = t.getChildAt(i);
                C1581b bVar2 = (C1581b) childAt2.getLayoutParams();
                int i3 = bVar2.f6736a;
                if ((i3 & 17) == 17) {
                    int i4 = -childAt2.getTop();
                    int i5 = -childAt2.getBottom();
                    if (i == t.getChildCount() - 1) {
                        i5 += t.getTopInset();
                    }
                    if (m5161a(i3, 2)) {
                        i5 += ViewCompat.m1967l(childAt2);
                    } else if (m5161a(i3, 5)) {
                        int l = ViewCompat.m1967l(childAt2) + i5;
                        if (c < l) {
                            i4 = l;
                        } else {
                            i5 = l;
                        }
                    }
                    if (m5161a(i3, 32)) {
                        i4 += bVar2.topMargin;
                        i5 -= bVar2.bottomMargin;
                    }
                    if (c < (i5 + i4) / 2) {
                        i4 = i5;
                    }
                    mo6491a(coordinatorLayout, t, MediaDescriptionCompatApi21.m5a(i4, -t.getTotalScrollRange(), 0), 0.0f);
                }
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:25:0x0061  */
        /* JADX WARNING: Removed duplicated region for block: B:28:0x006f  */
        /* renamed from: a */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final void mo6492a(androidx.coordinatorlayout.widget.CoordinatorLayout r7, T r8, int r9, int r10, boolean r11) {
            /*
                r6 = this;
                int r0 = java.lang.Math.abs(r9)
                int r1 = r8.getChildCount()
                r2 = 0
                r3 = 0
            L_0x000a:
                if (r3 >= r1) goto L_0x0020
                android.view.View r4 = r8.getChildAt(r3)
                int r5 = r4.getTop()
                if (r0 < r5) goto L_0x001d
                int r5 = r4.getBottom()
                if (r0 > r5) goto L_0x001d
                goto L_0x0021
            L_0x001d:
                int r3 = r3 + 1
                goto L_0x000a
            L_0x0020:
                r4 = 0
            L_0x0021:
                if (r4 == 0) goto L_0x009e
                android.view.ViewGroup$LayoutParams r0 = r4.getLayoutParams()
                com.google.android.material.appbar.AppBarLayout$b r0 = (com.google.android.material.appbar.AppBarLayout.C1581b) r0
                int r0 = r0.f6736a
                r1 = r0 & 1
                r3 = 1
                if (r1 == 0) goto L_0x0049
                int r1 = p008b.p033h.p045m.ViewCompat.m1967l(r4)
                if (r10 <= 0) goto L_0x004b
                r10 = r0 & 12
                if (r10 == 0) goto L_0x004b
                int r9 = -r9
                int r10 = r4.getBottom()
                int r10 = r10 - r1
                int r0 = r8.getTopInset()
                int r10 = r10 - r0
                if (r9 < r10) goto L_0x0049
            L_0x0047:
                r9 = 1
                goto L_0x005d
            L_0x0049:
                r9 = 0
                goto L_0x005d
            L_0x004b:
                r10 = r0 & 2
                if (r10 == 0) goto L_0x0049
                int r9 = -r9
                int r10 = r4.getBottom()
                int r10 = r10 - r1
                int r0 = r8.getTopInset()
                int r10 = r10 - r0
                if (r9 < r10) goto L_0x0049
                goto L_0x0047
            L_0x005d:
                boolean r10 = r8.f6719k
                if (r10 == 0) goto L_0x0069
                android.view.View r9 = r6.mo6489a(r7)
                boolean r9 = r8.mo6454a((android.view.View) r9)
            L_0x0069:
                boolean r9 = r8.mo6455a((boolean) r9)
                if (r11 != 0) goto L_0x009b
                if (r9 == 0) goto L_0x009e
                java.util.List r7 = r7.mo561b((android.view.View) r8)
                int r9 = r7.size()
                r10 = 0
            L_0x007a:
                if (r10 >= r9) goto L_0x0099
                java.lang.Object r11 = r7.get(r10)
                android.view.View r11 = (android.view.View) r11
                android.view.ViewGroup$LayoutParams r11 = r11.getLayoutParams()
                androidx.coordinatorlayout.widget.CoordinatorLayout$f r11 = (androidx.coordinatorlayout.widget.CoordinatorLayout.C0077f) r11
                androidx.coordinatorlayout.widget.CoordinatorLayout$c r11 = r11.f533a
                boolean r0 = r11 instanceof com.google.android.material.appbar.AppBarLayout.ScrollingViewBehavior
                if (r0 == 0) goto L_0x0096
                com.google.android.material.appbar.AppBarLayout$ScrollingViewBehavior r11 = (com.google.android.material.appbar.AppBarLayout.ScrollingViewBehavior) r11
                int r7 = r11.f5471g
                if (r7 == 0) goto L_0x0099
                r2 = 1
                goto L_0x0099
            L_0x0096:
                int r10 = r10 + 1
                goto L_0x007a
            L_0x0099:
                if (r2 == 0) goto L_0x009e
            L_0x009b:
                r8.jumpDrawablesToCurrentState()
            L_0x009e:
                return
            */
            throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.appbar.AppBarLayout.BaseBehavior.mo6492a(androidx.coordinatorlayout.widget.CoordinatorLayout, com.google.android.material.appbar.AppBarLayout, int, int, boolean):void");
        }

        /* renamed from: a */
        public final View mo6489a(CoordinatorLayout coordinatorLayout) {
            int childCount = coordinatorLayout.getChildCount();
            for (int i = 0; i < childCount; i++) {
                View childAt = coordinatorLayout.getChildAt(i);
                if ((childAt instanceof NestedScrollingChild) || (childAt instanceof ListView) || (childAt instanceof ScrollView)) {
                    return childAt;
                }
            }
            return null;
        }
    }

    public AppBarLayout(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, C1161b.appBarLayoutStyle);
    }

    /* renamed from: generateDefaultLayoutParams  reason: collision with other method in class */
    public LinearLayout.LayoutParams m6034generateDefaultLayoutParams() {
        return new C1581b(-1, -2);
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Illegal instructions before constructor call */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public AppBarLayout(android.content.Context r14, android.util.AttributeSet r15, int r16) {
        /*
            r13 = this;
            r1 = r13
            r0 = r15
            r8 = r16
            int r2 = f6709q
            r3 = r14
            android.content.Context r2 = p085c.p132d.p133a.p156b.p165i0.p166a.MaterialThemeOverlay.m4458a(r14, r15, r8, r2)
            r13.<init>(r2, r15, r8)
            r9 = -1
            r1.f6711c = r9
            r1.f6712d = r9
            r1.f6713e = r9
            r10 = 0
            r1.f6715g = r10
            android.content.Context r11 = r13.getContext()
            r2 = 1
            r13.setOrientation(r2)
            android.view.ViewOutlineProvider r2 = android.view.ViewOutlineProvider.BOUNDS
            r13.setOutlineProvider(r2)
            int r6 = f6709q
            android.content.Context r12 = r13.getContext()
            int[] r4 = p085c.p132d.p133a.p156b.p169m.ViewUtilsLollipop.f5482a
            int[] r7 = new int[r10]
            r2 = r12
            r3 = r15
            r5 = r16
            android.content.res.TypedArray r2 = p085c.p132d.p133a.p156b.p183z.ThemeEnforcement.m4671b(r2, r3, r4, r5, r6, r7)
            boolean r3 = r2.hasValue(r10)     // Catch:{ all -> 0x00ff }
            if (r3 == 0) goto L_0x0048
            int r3 = r2.getResourceId(r10, r10)     // Catch:{ all -> 0x00ff }
            android.animation.StateListAnimator r3 = android.animation.AnimatorInflater.loadStateListAnimator(r12, r3)     // Catch:{ all -> 0x00ff }
            r13.setStateListAnimator(r3)     // Catch:{ all -> 0x00ff }
        L_0x0048:
            r2.recycle()
            int[] r4 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout
            int r6 = f6709q
            int[] r7 = new int[r10]
            r2 = r11
            r3 = r15
            r5 = r16
            android.content.res.TypedArray r0 = p085c.p132d.p133a.p156b.p183z.ThemeEnforcement.m4671b(r2, r3, r4, r5, r6, r7)
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_android_background
            android.graphics.drawable.Drawable r2 = r0.getDrawable(r2)
            p008b.p033h.p045m.ViewCompat.m1937a((android.view.View) r13, (android.graphics.drawable.Drawable) r2)
            android.graphics.drawable.Drawable r2 = r13.getBackground()
            boolean r2 = r2 instanceof android.graphics.drawable.ColorDrawable
            if (r2 == 0) goto L_0x008f
            android.graphics.drawable.Drawable r2 = r13.getBackground()
            android.graphics.drawable.ColorDrawable r2 = (android.graphics.drawable.ColorDrawable) r2
            c.d.a.b.d0.g r3 = new c.d.a.b.d0.g
            r3.<init>()
            int r2 = r2.getColor()
            android.content.res.ColorStateList r2 = android.content.res.ColorStateList.valueOf(r2)
            r3.mo5119a((android.content.res.ColorStateList) r2)
            c.d.a.b.d0.g$b r2 = r3.f5186b
            c.d.a.b.w.a r4 = new c.d.a.b.w.a
            r4.<init>(r11)
            r2.f5210b = r4
            r3.mo5140i()
            r13.setBackground(r3)
        L_0x008f:
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_expanded
            boolean r2 = r0.hasValue(r2)
            if (r2 == 0) goto L_0x00a0
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_expanded
            boolean r2 = r0.getBoolean(r2, r10)
            r13.mo6452a(r2, r10, r10)
        L_0x00a0:
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_elevation
            boolean r2 = r0.hasValue(r2)
            if (r2 == 0) goto L_0x00b2
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_elevation
            int r2 = r0.getDimensionPixelSize(r2, r10)
            float r2 = (float) r2
            p085c.p132d.p133a.p156b.p169m.ViewUtilsLollipop.m4484a(r13, r2)
        L_0x00b2:
            int r2 = android.os.Build.VERSION.SDK_INT
            r3 = 26
            if (r2 < r3) goto L_0x00da
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_android_keyboardNavigationCluster
            boolean r2 = r0.hasValue(r2)
            if (r2 == 0) goto L_0x00c9
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_android_keyboardNavigationCluster
            boolean r2 = r0.getBoolean(r2, r10)
            r13.setKeyboardNavigationCluster(r2)
        L_0x00c9:
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_android_touchscreenBlocksFocus
            boolean r2 = r0.hasValue(r2)
            if (r2 == 0) goto L_0x00da
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_android_touchscreenBlocksFocus
            boolean r2 = r0.getBoolean(r2, r10)
            r13.setTouchscreenBlocksFocus(r2)
        L_0x00da:
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_liftOnScroll
            boolean r2 = r0.getBoolean(r2, r10)
            r1.f6719k = r2
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_liftOnScrollTargetViewId
            int r2 = r0.getResourceId(r2, r9)
            r1.f6720l = r2
            int r2 = p085c.p132d.p133a.p156b.C1224k.AppBarLayout_statusBarForeground
            android.graphics.drawable.Drawable r2 = r0.getDrawable(r2)
            r13.setStatusBarForeground(r2)
            r0.recycle()
            com.google.android.material.appbar.AppBarLayout$a r0 = new com.google.android.material.appbar.AppBarLayout$a
            r0.<init>()
            p008b.p033h.p045m.ViewCompat.m1939a((android.view.View) r13, (p008b.p033h.p045m.OnApplyWindowInsetsListener) r0)
            return
        L_0x00ff:
            r0 = move-exception
            r2.recycle()
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.appbar.AppBarLayout.<init>(android.content.Context, android.util.AttributeSet, int):void");
    }

    /* renamed from: a */
    public boolean mo6455a(boolean z) {
        if (this.f6718j == z) {
            return false;
        }
        this.f6718j = z;
        refreshDrawableState();
        if (this.f6719k && (getBackground() instanceof MaterialShapeDrawable)) {
            MaterialShapeDrawable gVar = (MaterialShapeDrawable) getBackground();
            float dimension = getResources().getDimension(C1163d.design_appbar_elevation);
            float f = z ? 0.0f : dimension;
            if (!z) {
                dimension = 0.0f;
            }
            ValueAnimator valueAnimator = this.f6722n;
            if (valueAnimator != null) {
                valueAnimator.cancel();
            }
            ValueAnimator ofFloat = ValueAnimator.ofFloat(new float[]{f, dimension});
            this.f6722n = ofFloat;
            ofFloat.setDuration((long) getResources().getInteger(C1194g.app_bar_elevation_anim_duration));
            this.f6722n.setInterpolator(AnimationUtils.f5424a);
            this.f6722n.addUpdateListener(new p085c.p132d.p133a.p156b.p169m.AppBarLayout(this, gVar));
            this.f6722n.start();
        }
        return true;
    }

    public ViewGroup.LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new C1581b(getContext(), attributeSet);
    }

    /* renamed from: generateLayoutParams  reason: collision with other method in class */
    public LinearLayout.LayoutParams m6035generateLayoutParams(AttributeSet attributeSet) {
        return new C1581b(getContext(), attributeSet);
    }

    public C1581b generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        if (layoutParams instanceof LinearLayout.LayoutParams) {
            return new C1581b((LinearLayout.LayoutParams) layoutParams);
        }
        if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
            return new C1581b((ViewGroup.MarginLayoutParams) layoutParams);
        }
        return new C1581b(layoutParams);
    }

    /* renamed from: com.google.android.material.appbar.AppBarLayout$b */
    public static class C1581b extends LinearLayout.LayoutParams {

        /* renamed from: a */
        public int f6736a = 1;

        /* renamed from: b */
        public Interpolator f6737b;

        public C1581b(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, C1224k.AppBarLayout_Layout);
            this.f6736a = obtainStyledAttributes.getInt(C1224k.AppBarLayout_Layout_layout_scrollFlags, 0);
            if (obtainStyledAttributes.hasValue(C1224k.AppBarLayout_Layout_layout_scrollInterpolator)) {
                this.f6737b = android.view.animation.AnimationUtils.loadInterpolator(context, obtainStyledAttributes.getResourceId(C1224k.AppBarLayout_Layout_layout_scrollInterpolator, 0));
            }
            obtainStyledAttributes.recycle();
        }

        public C1581b(int i, int i2) {
            super(i, i2);
        }

        public C1581b(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public C1581b(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }

        public C1581b(LinearLayout.LayoutParams layoutParams) {
            super(layoutParams);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r0v3, resolved type: java.lang.Object} */
    /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r1v2, resolved type: android.view.View} */
    /* JADX WARNING: Multi-variable type inference failed */
    /* renamed from: a */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public boolean mo6454a(android.view.View r5) {
        /*
            r4 = this;
            java.lang.ref.WeakReference<android.view.View> r0 = r4.f6721m
            r1 = 0
            r2 = -1
            if (r0 != 0) goto L_0x0031
            int r0 = r4.f6720l
            if (r0 == r2) goto L_0x0031
            if (r5 == 0) goto L_0x0011
            android.view.View r0 = r5.findViewById(r0)
            goto L_0x0012
        L_0x0011:
            r0 = r1
        L_0x0012:
            if (r0 != 0) goto L_0x0028
            android.view.ViewParent r3 = r4.getParent()
            boolean r3 = r3 instanceof android.view.ViewGroup
            if (r3 == 0) goto L_0x0028
            android.view.ViewParent r0 = r4.getParent()
            android.view.ViewGroup r0 = (android.view.ViewGroup) r0
            int r3 = r4.f6720l
            android.view.View r0 = r0.findViewById(r3)
        L_0x0028:
            if (r0 == 0) goto L_0x0031
            java.lang.ref.WeakReference r3 = new java.lang.ref.WeakReference
            r3.<init>(r0)
            r4.f6721m = r3
        L_0x0031:
            java.lang.ref.WeakReference<android.view.View> r0 = r4.f6721m
            if (r0 == 0) goto L_0x003c
            java.lang.Object r0 = r0.get()
            r1 = r0
            android.view.View r1 = (android.view.View) r1
        L_0x003c:
            if (r1 != 0) goto L_0x003f
            goto L_0x0040
        L_0x003f:
            r5 = r1
        L_0x0040:
            if (r5 == 0) goto L_0x0050
            boolean r0 = r5.canScrollVertically(r2)
            if (r0 != 0) goto L_0x004e
            int r5 = r5.getScrollY()
            if (r5 <= 0) goto L_0x0050
        L_0x004e:
            r5 = 1
            goto L_0x0051
        L_0x0050:
            r5 = 0
        L_0x0051:
            return r5
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.appbar.AppBarLayout.mo6454a(android.view.View):boolean");
    }

    /* renamed from: a */
    public final boolean mo6453a() {
        if (getChildCount() <= 0) {
            return false;
        }
        View childAt = getChildAt(0);
        if (childAt.getVisibility() == 8 || ViewCompat.m1963h(childAt)) {
            return false;
        }
        return true;
    }
}
