package com.newrelic.agent.android;

import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.connectivity.CatFacade;
import com.newrelic.agent.android.harvest.ApplicationInformation;
import com.newrelic.agent.android.harvest.DeviceInformation;
import com.newrelic.agent.android.harvest.EnvironmentInformation;
import com.newrelic.agent.android.stats.TicToc;
import com.newrelic.agent.android.util.Connectivity;
import com.newrelic.agent.android.util.Encoder;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.util.ArrayList;
import java.util.List;

public class NullAgentImpl implements AgentImpl {
    public static final NullAgentImpl instance = new NullAgentImpl();
    public int responseBodyLimit = 1024;
    public TicToc sessionDurationMillis = new TicToc();

    public void addTransactionData(TransactionData transactionData) {
    }

    public void disable() {
    }

    public List<TransactionData> getAndClearTransactionData() {
        return new ArrayList();
    }

    public ApplicationInformation getApplicationInformation() {
        return new ApplicationInformation(SafeJsonPrimitive.NULL_STRING, "0.0", SafeJsonPrimitive.NULL_STRING, "0");
    }

    public CatFacade getCatFacade() {
        return new CatFacade();
    }

    public String getCrossProcessId() {
        return null;
    }

    public DeviceInformation getDeviceInformation() {
        DeviceInformation deviceInformation = new DeviceInformation();
        deviceInformation.setOsName(Connectivity.ANDROID);
        deviceInformation.setOsVersion("2.3");
        deviceInformation.setOsBuild("a.b.c");
        deviceInformation.setManufacturer("Fake");
        deviceInformation.setModel("NullAgent");
        deviceInformation.setAgentName("AndroidAgent");
        deviceInformation.setAgentVersion("2.123");
        deviceInformation.setDeviceId("389C9738-A761-44DE-8A66-1668CFD67DA1");
        deviceInformation.setArchitecture("Fake Arch");
        deviceInformation.setRunTime("1.8.0");
        deviceInformation.setSize("Fake Size");
        return deviceInformation;
    }

    public Encoder getEncoder() {
        return new Encoder() {
            public String encode(byte[] bArr) {
                return new String(bArr);
            }

            public String encodeNoWrap(byte[] bArr) {
                return encode(bArr);
            }
        };
    }

    public EnvironmentInformation getEnvironmentInformation() {
        return new EnvironmentInformation(0, 1, "none", "none", new long[]{0, 0});
    }

    public String getNetworkCarrier() {
        return "unknown";
    }

    public String getNetworkWanType() {
        return "unknown";
    }

    public int getResponseBodyLimit() {
        return this.responseBodyLimit;
    }

    public long getSessionDurationMillis() {
        return this.sessionDurationMillis.peek();
    }

    public int getStackTraceLimit() {
        return 0;
    }

    public boolean hasReachableNetworkConnection(String str) {
        return true;
    }

    public boolean isDisabled() {
        return true;
    }

    public boolean isInstantApp() {
        return false;
    }

    public void mergeTransactionData(List<TransactionData> list) {
    }

    public void setLocation(String str, String str2) {
    }

    public void setResponseBodyLimit(int i) {
        this.responseBodyLimit = i;
    }

    public void start() {
        this.sessionDurationMillis.tic();
    }

    public void stop() {
        this.sessionDurationMillis.toc();
    }

    public boolean updateSavedConnectInformation() {
        return false;
    }
}
