package com.newrelic.agent.android.activity;

import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.measurement.Measurement;
import com.newrelic.agent.android.measurement.MeasurementException;
import com.newrelic.agent.android.measurement.MeasurementPool;
import com.newrelic.agent.android.measurement.ThreadInfo;
import com.newrelic.agent.android.tracing.TraceMachine;

public class BaseMeasuredActivity implements MeasuredActivity {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public boolean autoInstrumented;
    public long endTime;
    public Measurement endingMeasurement;
    public ThreadInfo endingThread;
    public boolean finished;
    public MeasurementPool measurementPool;
    public String name;
    public long startTime;
    public Measurement startingMeasurement;
    public ThreadInfo startingThread;

    private boolean logIfFinished() {
        if (this.finished) {
            log.warning("BaseMeasuredActivity: cannot modify finished Activity");
        }
        return this.finished;
    }

    private void throwIfFinished() {
        if (this.finished) {
            throw new MeasurementException("Attempted to modify finished Measurement");
        }
    }

    public void finish() {
        this.finished = true;
    }

    public String getBackgroundMetricName() {
        return TraceMachine.formatActivityBackgroundMetricName(this.name);
    }

    public long getEndTime() {
        return this.endTime;
    }

    public Measurement getEndingMeasurement() {
        return this.endingMeasurement;
    }

    public ThreadInfo getEndingThread() {
        return this.endingThread;
    }

    public MeasurementPool getMeasurementPool() {
        return this.measurementPool;
    }

    public String getMetricName() {
        return TraceMachine.formatActivityMetricName(this.name);
    }

    public String getName() {
        return this.name;
    }

    public long getStartTime() {
        return this.startTime;
    }

    public Measurement getStartingMeasurement() {
        return this.startingMeasurement;
    }

    public ThreadInfo getStartingThread() {
        return this.startingThread;
    }

    public boolean isAutoInstrumented() {
        return this.autoInstrumented;
    }

    public boolean isFinished() {
        return this.finished;
    }

    public void setAutoInstrumented(boolean z) {
        if (!logIfFinished()) {
            this.autoInstrumented = z;
        }
    }

    public void setEndTime(long j) {
        if (!logIfFinished()) {
            this.endTime = j;
        }
    }

    public void setEndingMeasurement(Measurement measurement) {
        if (!logIfFinished()) {
            this.endingMeasurement = measurement;
        }
    }

    public void setEndingThread(ThreadInfo threadInfo) {
        if (!logIfFinished()) {
            this.endingThread = threadInfo;
        }
    }

    public void setMeasurementPool(MeasurementPool measurementPool2) {
        if (!logIfFinished()) {
            this.measurementPool = measurementPool2;
        }
    }

    public void setName(String str) {
        if (!logIfFinished()) {
            this.name = str;
        }
    }

    public void setStartTime(long j) {
        if (!logIfFinished()) {
            this.startTime = j;
        }
    }

    public void setStartingMeasurement(Measurement measurement) {
        if (!logIfFinished()) {
            this.startingMeasurement = measurement;
        }
    }

    public void setStartingThread(ThreadInfo threadInfo) {
        if (!logIfFinished()) {
            this.startingThread = threadInfo;
        }
    }
}
