package com.newrelic.agent.android.agentdata.builder;

import com.newrelic.agent.android.agentdata.HexAttributes;
import com.newrelic.com.google.flatbuffers.FlatBufferBuilder;
import com.newrelic.com.google.gson.GsonBuilder;
import com.newrelic.mobile.fbs.AgentData;
import com.newrelic.mobile.fbs.AgentDataBundle;
import com.newrelic.mobile.fbs.ApplicationInfo;
import com.newrelic.mobile.fbs.BoolSessionAttribute;
import com.newrelic.mobile.fbs.DoubleSessionAttribute;
import com.newrelic.mobile.fbs.LongSessionAttribute;
import com.newrelic.mobile.fbs.StringSessionAttribute;
import com.newrelic.mobile.fbs.hex.Frame;
import com.newrelic.mobile.fbs.hex.HandledException;
import com.newrelic.mobile.fbs.hex.Thread;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class AgentDataBuilder {
    public static Map<String, Object> attributesMapFromAgentData(AgentData agentData) {
        HashMap hashMap = new HashMap();
        for (int i = 0; i < agentData.stringAttributesLength(); i++) {
            StringSessionAttribute stringAttributes = agentData.stringAttributes(i);
            hashMap.put(stringAttributes.name(), stringAttributes.value());
        }
        for (int i2 = 0; i2 < agentData.longAttributesLength(); i2++) {
            LongSessionAttribute longAttributes = agentData.longAttributes(i2);
            hashMap.put(longAttributes.name(), Long.valueOf(longAttributes.value()));
        }
        for (int i3 = 0; i3 < agentData.doubleAttributesLength(); i3++) {
            DoubleSessionAttribute doubleAttributes = agentData.doubleAttributes(i3);
            hashMap.put(doubleAttributes.name(), Double.valueOf(doubleAttributes.value()));
        }
        for (int i4 = 0; i4 < agentData.boolAttributesLength(); i4++) {
            BoolSessionAttribute boolAttributes = agentData.boolAttributes(i4);
            hashMap.put(boolAttributes.name(), Boolean.valueOf(boolAttributes.value()));
        }
        for (int i5 = 0; i5 < agentData.handledExceptionsLength(); i5++) {
            HandledException handledExceptions = agentData.handledExceptions(i5);
            hashMap.put(HexAttributes.HEX_ATTR_TIMESTAMP_MS, Long.valueOf(handledExceptions.timestampMs()));
            hashMap.put(HexAttributes.HEX_ATTR_APP_UUID_HI, Long.valueOf(handledExceptions.appUuidHigh()));
            hashMap.put(HexAttributes.HEX_ATTR_APP_UUID_LO, Long.valueOf(handledExceptions.appUuidLow()));
            hashMap.put("name", handledExceptions.name());
            hashMap.put(HexAttributes.HEX_ATTR_CAUSE, handledExceptions.cause());
            hashMap.put(HexAttributes.HEX_ATTR_MESSAGE, handledExceptions.message());
            for (int i6 = 0; i6 < handledExceptions.threadsLength(); i6++) {
                Thread currentThread = Thread.currentThread();
                LinkedHashMap linkedHashMap = new LinkedHashMap();
                for (int i7 = 0; i7 < handledExceptions.threads(i6).framesLength(); i7++) {
                    LinkedHashMap linkedHashMap2 = new LinkedHashMap();
                    linkedHashMap2.put(HexAttributes.HEX_ATTR_FILENAME, handledExceptions.threads(i6).frames(i7).fileName());
                    linkedHashMap2.put(HexAttributes.HEX_ATTR_LINE_NUMBER, Long.valueOf(handledExceptions.threads(i6).frames(i7).lineNumber()));
                    linkedHashMap2.put(HexAttributes.HEX_ATTR_CLASS_NAME, handledExceptions.threads(i6).frames(i7).className());
                    linkedHashMap2.put(HexAttributes.HEX_ATTR_METHOD_NAME, handledExceptions.threads(i6).frames(i7).methodName());
                    linkedHashMap.put("frame " + i7, linkedHashMap2);
                }
                linkedHashMap.put(HexAttributes.HEX_ATTR_THREAD_CRASHED, false);
                linkedHashMap.put(HexAttributes.HEX_ATTR_THREAD_STATE, currentThread.getState().toString());
                linkedHashMap.put(HexAttributes.HEX_ATTR_THREAD_NUMBER, Long.valueOf(currentThread.getId()));
                linkedHashMap.put(HexAttributes.HEX_ATTR_THREAD_ID, currentThread.getName());
                linkedHashMap.put(HexAttributes.HEX_ATTR_THREAD_PRI, Integer.valueOf(currentThread.getPriority()));
                hashMap.put("thread " + i6, linkedHashMap);
            }
        }
        return hashMap;
    }

    public static void computeIfAbsent(String str, Map<String, Integer> map, FlatBufferBuilder flatBufferBuilder) {
        if (str != null && !map.containsValue(str)) {
            map.put(str, Integer.valueOf(flatBufferBuilder.createString((CharSequence) str)));
        }
    }

    public static FlatBufferBuilder startAndFinishAgentData(Map<String, Object> map, Set<Map<String, Object>> set) {
        String str;
        String str2;
        String str3;
        Iterator<Map<String, Object>> it;
        int i;
        long j;
        long j2;
        String str4;
        HashMap hashMap = new HashMap();
        FlatBufferBuilder flatBufferBuilder = new FlatBufferBuilder();
        for (Map.Entry next : map.entrySet()) {
            Object value = next.getValue();
            computeIfAbsent((String) next.getKey(), hashMap, flatBufferBuilder);
            if (value instanceof String) {
                computeIfAbsent((String) value, hashMap, flatBufferBuilder);
            }
        }
        List<Map> list = null;
        Iterator<Map<String, Object>> it2 = set.iterator();
        while (true) {
            boolean hasNext = it2.hasNext();
            str = HexAttributes.HEX_ATTR_CAUSE;
            str2 = HexAttributes.HEX_ATTR_MESSAGE;
            str3 = "name";
            if (!hasNext) {
                break;
            }
            Map next2 = it2.next();
            computeIfAbsent((String) next2.get(str3), hashMap, flatBufferBuilder);
            computeIfAbsent((String) next2.get(str2), hashMap, flatBufferBuilder);
            computeIfAbsent((String) next2.get(str), hashMap, flatBufferBuilder);
            list = (List) next2.get(HexAttributes.HEX_ATTR_THREAD);
        }
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        if (list != null) {
            for (Map map2 : list) {
                HashMap hashMap2 = new HashMap();
                hashMap2.put(HexAttributes.HEX_ATTR_FILENAME, Integer.valueOf(flatBufferBuilder.createString((CharSequence) "")));
                for (Map.Entry entry : map2.entrySet()) {
                    String str5 = (String) entry.getKey();
                    Object value2 = entry.getValue();
                    if (value2 instanceof String) {
                        hashMap2.put(str5, Integer.valueOf(flatBufferBuilder.createString((CharSequence) (String) value2)));
                    }
                }
                Frame.startFrame(flatBufferBuilder);
                if (hashMap2.get(HexAttributes.HEX_ATTR_CLASS_NAME) != null) {
                    Frame.addClassName(flatBufferBuilder, ((Integer) hashMap2.get(HexAttributes.HEX_ATTR_CLASS_NAME)).intValue());
                }
                if (hashMap2.get(HexAttributes.HEX_ATTR_METHOD_NAME) != null) {
                    Frame.addMethodName(flatBufferBuilder, ((Integer) hashMap2.get(HexAttributes.HEX_ATTR_METHOD_NAME)).intValue());
                }
                if (hashMap2.get(HexAttributes.HEX_ATTR_FILENAME) != null) {
                    Frame.addFileName(flatBufferBuilder, ((Integer) hashMap2.get(HexAttributes.HEX_ATTR_FILENAME)).intValue());
                }
                if (map2.get(HexAttributes.HEX_ATTR_LINE_NUMBER) != null) {
                    Frame.addLineNumber(flatBufferBuilder, (long) ((Integer) map2.get(HexAttributes.HEX_ATTR_LINE_NUMBER)).intValue());
                }
                arrayList.add(Integer.valueOf(Frame.endFrame(flatBufferBuilder)));
            }
        }
        arrayList2.add(Integer.valueOf(Thread.createThread(flatBufferBuilder, Thread.createFramesVector(flatBufferBuilder, toArray(arrayList)))));
        int createThreadsVector = HandledException.createThreadsVector(flatBufferBuilder, toArray(arrayList2));
        HashSet hashSet = new HashSet();
        HashSet hashSet2 = new HashSet();
        HashSet hashSet3 = new HashSet();
        HashSet hashSet4 = new HashSet();
        for (Map.Entry next3 : map.entrySet()) {
            int intValue = ((Integer) hashMap.get((String) next3.getKey())).intValue();
            Object value3 = next3.getValue();
            if (value3 instanceof String) {
                hashSet.add(Integer.valueOf(StringSessionAttribute.createStringSessionAttribute(flatBufferBuilder, intValue, ((Integer) hashMap.get(value3)).intValue())));
            } else if ((value3 instanceof Double) || (value3 instanceof Float)) {
                hashSet2.add(Integer.valueOf(DoubleSessionAttribute.createDoubleSessionAttribute(flatBufferBuilder, intValue, ((Number) value3).doubleValue())));
            } else if (value3 instanceof Number) {
                hashSet3.add(Integer.valueOf(LongSessionAttribute.createLongSessionAttribute(flatBufferBuilder, intValue, ((Number) value3).longValue())));
            } else if (value3 instanceof Boolean) {
                hashSet4.add(Integer.valueOf(BoolSessionAttribute.createBoolSessionAttribute(flatBufferBuilder, intValue, ((Boolean) value3).booleanValue())));
            }
        }
        int createStringAttributesVector = !hashSet.isEmpty() ? AgentData.createStringAttributesVector(flatBufferBuilder, toArray(hashSet)) : -1;
        int createDoubleAttributesVector = !hashSet2.isEmpty() ? AgentData.createDoubleAttributesVector(flatBufferBuilder, toArray(hashSet2)) : -1;
        int createLongAttributesVector = !hashSet3.isEmpty() ? AgentData.createLongAttributesVector(flatBufferBuilder, toArray(hashSet3)) : -1;
        int createBoolAttributesVector = !hashSet4.isEmpty() ? AgentData.createBoolAttributesVector(flatBufferBuilder, toArray(hashSet4)) : -1;
        HashSet hashSet5 = new HashSet();
        if (!set.isEmpty()) {
            Iterator<Map<String, Object>> it3 = set.iterator();
            while (it3.hasNext()) {
                Map next4 = it3.next();
                int stringIndexMapOffset = stringIndexMapOffset(hashMap, next4.get(str3));
                int stringIndexMapOffset2 = stringIndexMapOffset(hashMap, next4.get(str2));
                int stringIndexMapOffset3 = stringIndexMapOffset(hashMap, next4.get(str));
                HashMap hashMap3 = hashMap;
                String str6 = str;
                String str7 = str2;
                long longValue = ((Long) (next4.containsKey(HexAttributes.HEX_ATTR_TIMESTAMP_MS) ? next4.get(HexAttributes.HEX_ATTR_TIMESTAMP_MS) : Long.valueOf(System.currentTimeMillis()))).longValue();
                try {
                    str4 = str3;
                    it = it3;
                    j = ((Long) next4.get(HexAttributes.HEX_ATTR_APP_UUID_HI)).longValue();
                    i = createLongAttributesVector;
                    j2 = ((Long) next4.get(HexAttributes.HEX_ATTR_APP_UUID_LO)).longValue();
                } catch (ClassCastException unused) {
                    str4 = str3;
                    it = it3;
                    j = 0;
                    i = createLongAttributesVector;
                    j2 = 0;
                }
                HandledException.startHandledException(flatBufferBuilder);
                HandledException.addAppUuidHigh(flatBufferBuilder, j);
                HandledException.addAppUuidLow(flatBufferBuilder, j2);
                if (-1 != longValue) {
                    HandledException.addTimestampMs(flatBufferBuilder, longValue);
                }
                if (-1 != stringIndexMapOffset) {
                    HandledException.addName(flatBufferBuilder, stringIndexMapOffset);
                }
                if (-1 != stringIndexMapOffset2) {
                    HandledException.addMessage(flatBufferBuilder, stringIndexMapOffset2);
                }
                if (-1 != stringIndexMapOffset3) {
                    HandledException.addCause(flatBufferBuilder, stringIndexMapOffset3);
                }
                HandledException.addThreads(flatBufferBuilder, createThreadsVector);
                hashSet5.add(Integer.valueOf(HandledException.endHandledException(flatBufferBuilder)));
                it3 = it;
                str3 = str4;
                hashMap = hashMap3;
                str2 = str7;
                str = str6;
                createLongAttributesVector = i;
            }
        }
        int i2 = createLongAttributesVector;
        int createHandledExceptionsVector = !hashSet5.isEmpty() ? AgentData.createHandledExceptionsVector(flatBufferBuilder, toArray(hashSet5)) : -1;
        ApplicationInfo.startApplicationInfo(flatBufferBuilder);
        ApplicationInfo.addPlatform(flatBufferBuilder, 0);
        int endApplicationInfo = ApplicationInfo.endApplicationInfo(flatBufferBuilder);
        AgentData.startAgentData(flatBufferBuilder);
        if (createStringAttributesVector != -1) {
            AgentData.addStringAttributes(flatBufferBuilder, createStringAttributesVector);
        }
        if (createDoubleAttributesVector != -1) {
            AgentData.addDoubleAttributes(flatBufferBuilder, createDoubleAttributesVector);
        }
        int i3 = i2;
        if (i3 != -1) {
            AgentData.addLongAttributes(flatBufferBuilder, i3);
        }
        if (createBoolAttributesVector != -1) {
            AgentData.addBoolAttributes(flatBufferBuilder, createBoolAttributesVector);
        }
        if (createHandledExceptionsVector != -1) {
            AgentData.addHandledExceptions(flatBufferBuilder, createHandledExceptionsVector);
        }
        AgentData.addApplicationInfo(flatBufferBuilder, endApplicationInfo);
        HashSet hashSet6 = new HashSet();
        hashSet6.add(Integer.valueOf(AgentData.endAgentData(flatBufferBuilder)));
        int createAgentDataVector = AgentDataBundle.createAgentDataVector(flatBufferBuilder, toArray(hashSet6));
        AgentDataBundle.startAgentDataBundle(flatBufferBuilder);
        AgentDataBundle.addAgentData(flatBufferBuilder, createAgentDataVector);
        flatBufferBuilder.finish(AgentDataBundle.endAgentDataBundle(flatBufferBuilder));
        return flatBufferBuilder;
    }

    public static int stringIndexMapOffset(Map<String, Integer> map, Object obj) {
        Integer num;
        Integer num2 = -1;
        if (!(obj == null || (num = map.get(obj)) == null)) {
            num2 = num;
        }
        return num2.intValue();
    }

    public static int[] toArray(Collection<Integer> collection) {
        int[] iArr = new int[collection.size()];
        int i = 0;
        for (Integer intValue : collection) {
            iArr[i] = intValue.intValue();
            i++;
        }
        return iArr;
    }

    public static String toJsonString(AgentDataBundle agentDataBundle, int i) {
        return new GsonBuilder().enableComplexMapKeySerialization().serializeNulls().setPrettyPrinting().create().toJson((Object) attributesMapFromAgentData(agentDataBundle.agentData(i)));
    }
}
