package com.newrelic.agent.android.analytics;

import com.newrelic.agent.android.harvest.type.HarvestableObject;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.com.google.gson.JsonArray;
import com.newrelic.com.google.gson.JsonElement;
import com.newrelic.com.google.gson.JsonObject;
import com.newrelic.com.google.gson.JsonPrimitive;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import p085c.p086a.p087a.p088a.outline;

public class AnalyticsEvent extends HarvestableObject {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public Set<AnalyticAttribute> attributeSet;
    public AnalyticsEventCategory category;
    public String eventType;
    public String name;
    public long timestamp;

    public AnalyticsEvent(String str) {
        this(str, AnalyticsEventCategory.Custom, (String) null, (Set<AnalyticAttribute>) null);
    }

    public static AnalyticsEvent newFromJson(JsonObject jsonObject) {
        HashSet hashSet = new HashSet();
        String str = null;
        long j = 0;
        String str2 = null;
        AnalyticsEventCategory analyticsEventCategory = null;
        for (Map.Entry next : jsonObject.entrySet()) {
            String str3 = (String) next.getKey();
            if (str3.equalsIgnoreCase("name")) {
                str2 = ((JsonElement) next.getValue()).getAsString();
            } else if (str3.equalsIgnoreCase("category")) {
                analyticsEventCategory = AnalyticsEventCategory.fromString(((JsonElement) next.getValue()).getAsString());
            } else if (str3.equalsIgnoreCase(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE)) {
                str = ((JsonElement) next.getValue()).getAsString();
            } else if (str3.equalsIgnoreCase(AnalyticAttribute.EVENT_TIMESTAMP_ATTRIBUTE)) {
                j = ((JsonElement) next.getValue()).getAsLong();
            } else {
                JsonPrimitive asJsonPrimitive = ((JsonElement) next.getValue()).getAsJsonPrimitive();
                if (asJsonPrimitive.isString()) {
                    hashSet.add(new AnalyticAttribute(str3, asJsonPrimitive.getAsString(), false));
                } else if (asJsonPrimitive.isBoolean()) {
                    hashSet.add(new AnalyticAttribute(str3, asJsonPrimitive.getAsBoolean(), false));
                } else if (asJsonPrimitive.isNumber()) {
                    hashSet.add(new AnalyticAttribute(str3, (double) asJsonPrimitive.getAsFloat(), false));
                }
            }
        }
        return new AnalyticsEvent(str2, analyticsEventCategory, str, j, hashSet);
    }

    public void addAttributes(Set<AnalyticAttribute> set) {
        if (set != null) {
            for (AnalyticAttribute next : set) {
                if (!this.attributeSet.add(next)) {
                    AgentLog agentLog = log;
                    StringBuilder a = outline.m2937a("Failed to add attribute ");
                    a.append(next.getName());
                    a.append(" to event ");
                    a.append(getName());
                    a.append(": the event already contains that attribute.");
                    agentLog.error(a.toString());
                }
            }
        }
    }

    public JsonObject asJsonObject() {
        JsonObject jsonObject = new JsonObject();
        synchronized (this) {
            for (AnalyticAttribute next : this.attributeSet) {
                jsonObject.add(next.getName(), next.asJsonElement());
            }
        }
        return jsonObject;
    }

    public Collection<AnalyticAttribute> getAttributeSet() {
        return Collections.unmodifiableCollection(this.attributeSet);
    }

    public AnalyticsEventCategory getCategory() {
        return this.category;
    }

    public String getEventType() {
        return this.eventType;
    }

    public String getName() {
        return this.name;
    }

    public long getTimestamp() {
        return this.timestamp;
    }

    public AnalyticsEvent(String str, AnalyticsEventCategory analyticsEventCategory) {
        this(str, analyticsEventCategory, (String) null, (Set<AnalyticAttribute>) null);
    }

    public AnalyticsEvent(String str, AnalyticsEventCategory analyticsEventCategory, String str2, Set<AnalyticAttribute> set) {
        this(str, analyticsEventCategory, str2, System.currentTimeMillis(), set);
    }

    public AnalyticsEvent(String str, AnalyticsEventCategory analyticsEventCategory, String str2, long j, Set<AnalyticAttribute> set) {
        this.attributeSet = Collections.synchronizedSet(new HashSet());
        this.name = str;
        if (analyticsEventCategory == null) {
            this.category = AnalyticsEventCategory.Custom;
        } else {
            this.category = analyticsEventCategory;
        }
        if (str2 == null) {
            this.eventType = AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE;
        } else {
            this.eventType = str2;
        }
        this.timestamp = j;
        if (set != null) {
            for (AnalyticAttribute analyticAttribute : set) {
                this.attributeSet.add(new AnalyticAttribute(analyticAttribute));
            }
        }
        if (str != null) {
            this.attributeSet.add(new AnalyticAttribute("name", this.name));
        }
        this.attributeSet.add(new AnalyticAttribute(AnalyticAttribute.EVENT_TIMESTAMP_ATTRIBUTE, String.valueOf(this.timestamp)));
        this.attributeSet.add(new AnalyticAttribute("category", this.category.name()));
        this.attributeSet.add(new AnalyticAttribute(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE, this.eventType));
    }

    public static Collection<AnalyticsEvent> newFromJson(JsonArray jsonArray) {
        ArrayList arrayList = new ArrayList();
        Iterator<JsonElement> it = jsonArray.iterator();
        while (it.hasNext()) {
            arrayList.add(newFromJson(it.next().getAsJsonObject()));
        }
        return arrayList;
    }
}
