package com.google.android.material.textfield;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Point;
import android.graphics.Rect;
import android.os.Build;
import android.text.Editable;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import java.util.Locale;
import p008b.p010b.p019p.AppCompatEditText;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p156b.C1161b;
import p085c.p132d.p133a.p156b.C1163d;
import p085c.p132d.p133a.p156b.C1221j;
import p085c.p132d.p133a.p156b.C1224k;
import p085c.p132d.p133a.p156b.p165i0.p166a.MaterialThemeOverlay;
import p085c.p132d.p133a.p156b.p183z.ThemeEnforcement;

public class TextInputEditText extends AppCompatEditText {

    /* renamed from: e */
    public final Rect f7015e;

    /* renamed from: f */
    public boolean f7016f;

    public TextInputEditText(Context context) {
        this(context, (AttributeSet) null);
    }

    private CharSequence getHintFromLayout() {
        TextInputLayout textInputLayout = getTextInputLayout();
        if (textInputLayout != null) {
            return textInputLayout.getHint();
        }
        return null;
    }

    private TextInputLayout getTextInputLayout() {
        for (ViewParent parent = getParent(); parent instanceof View; parent = parent.getParent()) {
            if (parent instanceof TextInputLayout) {
                return (TextInputLayout) parent;
            }
        }
        return null;
    }

    public void getFocusedRect(Rect rect) {
        super.getFocusedRect(rect);
        TextInputLayout textInputLayout = getTextInputLayout();
        if (textInputLayout != null && this.f7016f && rect != null) {
            textInputLayout.getFocusedRect(this.f7015e);
            rect.bottom = this.f7015e.bottom;
        }
    }

    public boolean getGlobalVisibleRect(Rect rect, Point point) {
        boolean globalVisibleRect = super.getGlobalVisibleRect(rect, point);
        TextInputLayout textInputLayout = getTextInputLayout();
        if (!(textInputLayout == null || !this.f7016f || rect == null)) {
            textInputLayout.getGlobalVisibleRect(this.f7015e, point);
            rect.bottom = this.f7015e.bottom;
        }
        return globalVisibleRect;
    }

    public CharSequence getHint() {
        TextInputLayout textInputLayout = getTextInputLayout();
        if (textInputLayout == null || !textInputLayout.f7020B) {
            return super.getHint();
        }
        return textInputLayout.getHint();
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        TextInputLayout textInputLayout = getTextInputLayout();
        if (textInputLayout != null && textInputLayout.f7020B && super.getHint() == null && Build.MANUFACTURER.toLowerCase(Locale.ENGLISH).equals("meizu")) {
            setHint("");
        }
    }

    public InputConnection onCreateInputConnection(EditorInfo editorInfo) {
        InputConnection onCreateInputConnection = super.onCreateInputConnection(editorInfo);
        if (onCreateInputConnection != null && editorInfo.hintText == null) {
            editorInfo.hintText = getHintFromLayout();
        }
        return onCreateInputConnection;
    }

    public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo accessibilityNodeInfo) {
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        TextInputLayout textInputLayout = getTextInputLayout();
        if (Build.VERSION.SDK_INT < 23 && textInputLayout != null) {
            Editable text = getText();
            CharSequence hint = textInputLayout.getHint();
            CharSequence helperText = textInputLayout.getHelperText();
            CharSequence error = textInputLayout.getError();
            boolean z = !TextUtils.isEmpty(text);
            boolean z2 = !TextUtils.isEmpty(hint);
            boolean z3 = !TextUtils.isEmpty(helperText);
            boolean z4 = !TextUtils.isEmpty(error);
            String str = "";
            String charSequence = z2 ? hint.toString() : str;
            StringBuilder a = outline.m2937a(charSequence);
            a.append(((z4 || z3) && !TextUtils.isEmpty(charSequence)) ? ", " : str);
            StringBuilder a2 = outline.m2937a(a.toString());
            if (z4) {
                helperText = error;
            } else if (!z3) {
                helperText = str;
            }
            a2.append(helperText);
            String sb = a2.toString();
            if (z) {
                StringBuilder sb2 = new StringBuilder();
                sb2.append(text);
                if (!TextUtils.isEmpty(sb)) {
                    str = outline.m2941b(", ", sb);
                }
                sb2.append(str);
                str = sb2.toString();
            } else if (!TextUtils.isEmpty(sb)) {
                str = sb;
            }
            accessibilityNodeInfo.setText(str);
        }
    }

    public boolean requestRectangleOnScreen(Rect rect) {
        boolean requestRectangleOnScreen = super.requestRectangleOnScreen(rect);
        TextInputLayout textInputLayout = getTextInputLayout();
        if (textInputLayout != null && this.f7016f) {
            this.f7015e.set(0, textInputLayout.getHeight() - getResources().getDimensionPixelOffset(C1163d.mtrl_edittext_rectangle_top_offset), textInputLayout.getWidth(), textInputLayout.getHeight());
            textInputLayout.requestRectangleOnScreen(this.f7015e, true);
        }
        return requestRectangleOnScreen;
    }

    public void setTextInputLayoutFocusedRectEnabled(boolean z) {
        this.f7016f = z;
    }

    public TextInputEditText(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, C1161b.editTextStyle);
    }

    public TextInputEditText(Context context, AttributeSet attributeSet, int i) {
        super(MaterialThemeOverlay.m4458a(context, attributeSet, i, 0), attributeSet, i);
        this.f7015e = new Rect();
        TypedArray b = ThemeEnforcement.m4671b(context, attributeSet, C1224k.TextInputEditText, i, C1221j.Widget_Design_TextInputEditText, new int[0]);
        setTextInputLayoutFocusedRectEnabled(b.getBoolean(C1224k.TextInputEditText_textInputLayoutFocusedRectEnabled, false));
        b.recycle();
    }
}
