package com.newrelic.agent.android.analytics;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.FeatureFlag;
import com.newrelic.agent.android.harvest.HttpTransaction;
import com.newrelic.agent.android.util.Constants;
import java.util.Set;

public class NetworkRequestErrorEvent extends AnalyticsEvent {
    public static final String DISABLE_FF_RESPONSE = "NEWRELIC_RESPONSE_BODY_CAPTURE_DISABLED";

    public NetworkRequestErrorEvent(Set<AnalyticAttribute> set) {
        super((String) null, AnalyticsEventCategory.RequestError, AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_REQUEST_ERROR, set);
    }

    public static Set<AnalyticAttribute> createErrorAttributeSet(HttpTransaction httpTransaction) {
        String str;
        Set<AnalyticAttribute> createDefaultAttributeSet = NetworkRequestEvent.createDefaultAttributeSet(httpTransaction);
        if (FeatureFlag.featureEnabled(FeatureFlag.HttpResponseBodyCapture)) {
            String responseBody = httpTransaction.getResponseBody();
            if (responseBody != null && !responseBody.isEmpty()) {
                if (responseBody.length() > 4096) {
                    AnalyticsEvent.log.warning("NetworkRequestErrorEvent: truncating response body to 4096 bytes");
                    responseBody = responseBody.substring(0, 4096);
                }
                String encodeNoWrap = Agent.getEncoder().encodeNoWrap(responseBody.getBytes());
                if (encodeNoWrap != null && !encodeNoWrap.isEmpty()) {
                    createDefaultAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.RESPONSE_BODY_ATTRIBUTE, encodeNoWrap));
                }
            }
        } else {
            createDefaultAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.RESPONSE_BODY_ATTRIBUTE, DISABLE_FF_RESPONSE));
        }
        String appData = httpTransaction.getAppData();
        if (appData != null && !appData.isEmpty()) {
            createDefaultAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.APP_DATA_ATTRIBUTE, appData));
        }
        if (!(httpTransaction.getParams() == null || (str = httpTransaction.getParams().get(Constants.Transactions.CONTENT_TYPE)) == null || str.isEmpty())) {
            createDefaultAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.CONTENT_TYPE_ATTRIBUTE, str));
        }
        return createDefaultAttributeSet;
    }

    public static NetworkRequestErrorEvent createHttpErrorEvent(HttpTransaction httpTransaction) {
        Set<AnalyticAttribute> createErrorAttributeSet = createErrorAttributeSet(httpTransaction);
        createErrorAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.STATUS_CODE_ATTRIBUTE, (double) httpTransaction.getStatusCode()));
        return new NetworkRequestErrorEvent(createErrorAttributeSet);
    }

    public static NetworkRequestErrorEvent createNetworkFailureEvent(HttpTransaction httpTransaction) {
        Set<AnalyticAttribute> createErrorAttributeSet = createErrorAttributeSet(httpTransaction);
        createErrorAttributeSet.add(new AnalyticAttribute(AnalyticAttribute.NETWORK_ERROR_CODE_ATTRIBUTE, (double) httpTransaction.getErrorCode()));
        return new NetworkRequestErrorEvent(createErrorAttributeSet);
    }
}
