package com.newrelic.agent.android.api.common;

import java.util.concurrent.TimeUnit;

public final class ConnectionState {
    public static final ConnectionState NULL = new ConnectionState();
    public final boolean collectingNetworkErrors;
    public final String crossProcessId;
    public final Object dataToken;
    public final int errorLimit;
    public final long harvestInterval;
    public final TimeUnit harvestIntervalTimeUnit;
    public final long maxTransactionAge;
    public final TimeUnit maxTransactionAgeTimeUnit;
    public final long maxTransactionCount;
    public final int responseBodyLimit;
    public final long serverTimestamp;
    public final int stackTraceLimit;

    public ConnectionState() {
        this.dataToken = null;
        this.crossProcessId = null;
        this.serverTimestamp = 0;
        this.harvestInterval = 60;
        TimeUnit timeUnit = TimeUnit.SECONDS;
        this.harvestIntervalTimeUnit = timeUnit;
        this.maxTransactionAge = 600;
        this.maxTransactionAgeTimeUnit = timeUnit;
        this.maxTransactionCount = 1000;
        this.stackTraceLimit = 50;
        this.responseBodyLimit = 1024;
        this.collectingNetworkErrors = true;
        this.errorLimit = 10;
    }

    public String getCrossProcessId() {
        return this.crossProcessId;
    }

    public Object getDataToken() {
        return this.dataToken;
    }

    public int getErrorLimit() {
        return this.errorLimit;
    }

    public long getHarvestIntervalInMilliseconds() {
        return TimeUnit.MILLISECONDS.convert(this.harvestInterval, this.harvestIntervalTimeUnit);
    }

    public long getHarvestIntervalInSeconds() {
        return TimeUnit.SECONDS.convert(this.harvestInterval, this.harvestIntervalTimeUnit);
    }

    public long getMaxTransactionAgeInMilliseconds() {
        return TimeUnit.MILLISECONDS.convert(this.maxTransactionAge, this.maxTransactionAgeTimeUnit);
    }

    public long getMaxTransactionAgeInSeconds() {
        return TimeUnit.SECONDS.convert(this.maxTransactionAge, this.maxTransactionAgeTimeUnit);
    }

    public long getMaxTransactionCount() {
        return this.maxTransactionCount;
    }

    public int getResponseBodyLimit() {
        return this.responseBodyLimit;
    }

    public long getServerTimestamp() {
        return this.serverTimestamp;
    }

    public int getStackTraceLimit() {
        return this.stackTraceLimit;
    }

    public boolean isCollectingNetworkErrors() {
        return this.collectingNetworkErrors;
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(this.dataToken);
        return sb.toString();
    }

    public ConnectionState(Object obj, String str, long j, long j2, TimeUnit timeUnit, long j3, TimeUnit timeUnit2, long j4, int i, int i2, boolean z, int i3) {
        this.dataToken = obj;
        this.crossProcessId = str;
        this.serverTimestamp = j;
        this.harvestInterval = j2;
        this.harvestIntervalTimeUnit = timeUnit;
        this.maxTransactionAge = j3;
        this.maxTransactionAgeTimeUnit = timeUnit2;
        this.maxTransactionCount = j4;
        this.stackTraceLimit = i;
        this.responseBodyLimit = i2;
        this.collectingNetworkErrors = z;
        this.errorLimit = i3;
    }
}
