package com.newrelic.agent.android.crash;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.payload.PayloadSender;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import p085c.p086a.p087a.p088a.outline;

public class CrashSender extends PayloadSender {
    public static final String CRASH_COLLECTOR_PATH = "/mobile_crash";
    public static final int CRASH_COLLECTOR_TIMEOUT = 5000;
    public final Crash crash;

    public CrashSender(Crash crash2, AgentConfiguration agentConfiguration) {
        super(crash2.toJsonString().getBytes(), agentConfiguration);
        this.crash = crash2;
    }

    public HttpURLConnection getConnection() throws IOException {
        HttpURLConnection httpURLConnection = (HttpURLConnection) new URL(getProtocol() + this.agentConfiguration.getCrashCollectorHost() + CRASH_COLLECTOR_PATH).openConnection();
        httpURLConnection.setDoOutput(true);
        httpURLConnection.setRequestProperty(Constants.Network.CONTENT_TYPE_HEADER, Constants.Network.ContentType.JSON);
        httpURLConnection.setRequestProperty(this.agentConfiguration.getAppTokenHeader(), this.agentConfiguration.getApplicationToken());
        httpURLConnection.setRequestProperty(this.agentConfiguration.getDeviceOsNameHeader(), Agent.getDeviceInformation().getOsName());
        httpURLConnection.setRequestProperty(this.agentConfiguration.getAppVersionHeader(), Agent.getApplicationInformation().getAppVersion());
        httpURLConnection.setConnectTimeout(5000);
        httpURLConnection.setReadTimeout(5000);
        return httpURLConnection;
    }

    public void onFailedUpload(String str) {
        PayloadSender.log.error(str);
        StatsEngine.get().inc(MetricNames.SUPPORTABILITY_CRASH_FAILED_UPLOAD);
    }

    public void onRequestException(Exception exc) {
        AgentLog agentLog = PayloadSender.log;
        agentLog.error("Crash upload failed: " + exc);
    }

    public void onRequestResponse(HttpURLConnection httpURLConnection) throws IOException {
        int responseCode = httpURLConnection.getResponseCode();
        if (responseCode == 200) {
            StatsEngine.get().sampleTimeMs(MetricNames.SUPPORTABILITY_CRASH_UPLOAD_TIME, this.timer.peek());
            AgentLog agentLog = PayloadSender.log;
            StringBuilder a = outline.m2937a("Crash ");
            a.append(this.crash.getUuid().toString());
            a.append(" successfully submitted.");
            agentLog.info(a.toString());
        } else if (responseCode != 500) {
            StringBuilder a2 = outline.m2937a("Something went wrong while submitting a crash (will try again later) - Response code ");
            a2.append(httpURLConnection.getResponseCode());
            onFailedUpload(a2.toString());
        } else {
            StatsEngine.get().inc(MetricNames.SUPPORTABILITY_CRASH_REMOVED_REJECTED);
            onFailedUpload("The crash was rejected and will be deleted - Response code " + httpURLConnection.getResponseCode());
        }
        AgentLog agentLog2 = PayloadSender.log;
        StringBuilder a3 = outline.m2937a("Crash collection took ");
        a3.append(this.timer.toc());
        a3.append("ms");
        agentLog2.debug(a3.toString());
    }

    public boolean shouldUploadOpportunistically() {
        return Agent.hasReachableNetworkConnection((String) null);
    }

    public PayloadSender call() {
        setPayload(this.crash.toJsonString().getBytes());
        this.crash.incrementUploadCount();
        this.agentConfiguration.getCrashStore().store(this.crash);
        try {
            return super.call();
        } catch (Exception e) {
            onFailedUpload("Unable to report crash to New Relic, will try again later. " + e);
            return this;
        }
    }
}
