package com.newrelic.agent.android.harvest;

import com.newrelic.agent.android.activity.config.ActivityTraceConfiguration;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;
import p085c.p086a.p087a.p088a.outline;

public class HarvestConfiguration {
    public static final String DEFAULT_ACCOUNT_ID = "";
    public static final int DEFAULT_ACTIVITY_TRACE_LENGTH = 65534;
    public static final int DEFAULT_ACTIVITY_TRACE_MAX_REPORT_ATTEMPTS = 1;
    public static final float DEFAULT_ACTIVITY_TRACE_MIN_UTILIZATION = 0.3f;
    public static final String DEFAULT_APP_ID = "";
    public static final int DEFAULT_ERROR_LIMIT = 50;
    public static final int DEFAULT_MAX_TRANSACTION_AGE = 600;
    public static final int DEFAULT_MAX_TRANSACTION_COUNT = 1000;
    public static final String DEFAULT_PRIORITY_ENCODING_KEY = "d67afc830dab717fd163bfcb0b8b88423e9a1a3b";
    public static final int DEFAULT_REPORT_PERIOD = 60;
    public static final int DEFAULT_RESPONSE_BODY_LIMIT = 2048;
    public static final int DEFAULT_STACK_TRACE_LIMIT = 100;
    public static HarvestConfiguration defaultHarvestConfiguration;
    public String account_id;
    public int activity_trace_max_report_attempts;
    public int activity_trace_max_size;
    public double activity_trace_min_utilization;
    public String application_id;
    public ActivityTraceConfiguration at_capture;
    public boolean collect_network_errors;
    public String cross_process_id;
    public int data_report_period;
    public int[] data_token;
    public int error_limit;
    public String priority_encoding_key;
    public int report_max_transaction_age;
    public int report_max_transaction_count;
    public int response_body_limit;
    public long server_timestamp;
    public int stack_trace_limit;

    public HarvestConfiguration() {
        setDefaultValues();
    }

    public static HarvestConfiguration getDefaultHarvestConfiguration() {
        HarvestConfiguration harvestConfiguration = defaultHarvestConfiguration;
        if (harvestConfiguration != null) {
            return harvestConfiguration;
        }
        HarvestConfiguration harvestConfiguration2 = new HarvestConfiguration();
        defaultHarvestConfiguration = harvestConfiguration2;
        return harvestConfiguration2;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || HarvestConfiguration.class != obj.getClass()) {
            return false;
        }
        HarvestConfiguration harvestConfiguration = (HarvestConfiguration) obj;
        if (this.collect_network_errors != harvestConfiguration.collect_network_errors || this.data_report_period != harvestConfiguration.data_report_period || this.error_limit != harvestConfiguration.error_limit || this.report_max_transaction_age != harvestConfiguration.report_max_transaction_age || this.report_max_transaction_count != harvestConfiguration.report_max_transaction_count || this.response_body_limit != harvestConfiguration.response_body_limit || this.stack_trace_limit != harvestConfiguration.stack_trace_limit || this.activity_trace_max_size != harvestConfiguration.activity_trace_max_size || this.activity_trace_max_report_attempts != harvestConfiguration.activity_trace_max_report_attempts) {
            return false;
        }
        if (this.cross_process_id == null && harvestConfiguration.cross_process_id != null) {
            return false;
        }
        if (this.cross_process_id != null && harvestConfiguration.cross_process_id == null) {
            return false;
        }
        String str = this.cross_process_id;
        if ((str != null && !str.equals(harvestConfiguration.cross_process_id)) || !this.priority_encoding_key.equals(harvestConfiguration.priority_encoding_key)) {
            return false;
        }
        if (this.account_id == null && harvestConfiguration.account_id != null) {
            return false;
        }
        if (this.account_id != null && harvestConfiguration.account_id == null) {
            return false;
        }
        String str2 = this.account_id;
        if (str2 != null && !str2.equals(harvestConfiguration.account_id)) {
            return false;
        }
        if (this.application_id == null && harvestConfiguration.application_id != null) {
            return false;
        }
        if (this.application_id != null && harvestConfiguration.application_id == null) {
            return false;
        }
        String str3 = this.application_id;
        if ((str3 == null || str3.equals(harvestConfiguration.application_id)) && ((int) this.activity_trace_min_utilization) * 100 == ((int) harvestConfiguration.activity_trace_min_utilization) * 100) {
            return Arrays.equals(this.data_token, harvestConfiguration.data_token);
        }
        return false;
    }

    public String getAccount_id() {
        String str = this.account_id;
        return str == null ? "" : str;
    }

    public int getActivity_trace_max_report_attempts() {
        return this.activity_trace_max_report_attempts;
    }

    public int getActivity_trace_max_size() {
        return this.activity_trace_max_size;
    }

    public double getActivity_trace_min_utilization() {
        return this.activity_trace_min_utilization;
    }

    public String getApplication_id() {
        String str = this.application_id;
        return str == null ? "" : str;
    }

    public ActivityTraceConfiguration getAt_capture() {
        return this.at_capture;
    }

    public String getCross_process_id() {
        return this.cross_process_id;
    }

    public DataToken getDataToken() {
        if (this.data_token == null) {
            return null;
        }
        int[] iArr = this.data_token;
        return new DataToken(iArr[0], iArr[1]);
    }

    public int getData_report_period() {
        return this.data_report_period;
    }

    public int[] getData_token() {
        return this.data_token;
    }

    public int getError_limit() {
        return this.error_limit;
    }

    public String getPriority_encoding_key() {
        return this.priority_encoding_key;
    }

    public long getReportMaxTransactionAgeMilliseconds() {
        return TimeUnit.MILLISECONDS.convert((long) this.report_max_transaction_age, TimeUnit.SECONDS);
    }

    public int getReport_max_transaction_age() {
        return this.report_max_transaction_age;
    }

    public int getReport_max_transaction_count() {
        return this.report_max_transaction_count;
    }

    public int getResponse_body_limit() {
        return this.response_body_limit;
    }

    public long getServer_timestamp() {
        return this.server_timestamp;
    }

    public int getStack_trace_limit() {
        return this.stack_trace_limit;
    }

    public int hashCode() {
        int i = (this.collect_network_errors ? 1 : 0) * true;
        String str = this.cross_process_id;
        int i2 = 0;
        int hashCode = (((i + (str != null ? str.hashCode() : 0)) * 31) + this.data_report_period) * 31;
        int[] iArr = this.data_token;
        int hashCode2 = iArr != null ? Arrays.hashCode(iArr) : 0;
        long doubleToLongBits = Double.doubleToLongBits(this.activity_trace_min_utilization);
        int i3 = (((((((((((((((((hashCode + hashCode2) * 31) + this.error_limit) * 31) + this.report_max_transaction_age) * 31) + this.report_max_transaction_count) * 31) + this.response_body_limit) * 31) + this.stack_trace_limit) * 31) + this.activity_trace_max_size) * 31) + this.activity_trace_max_report_attempts) * 31) + ((int) (doubleToLongBits ^ (doubleToLongBits >>> 32)))) * 31;
        ActivityTraceConfiguration activityTraceConfiguration = this.at_capture;
        int hashCode3 = (i3 + (activityTraceConfiguration != null ? activityTraceConfiguration.hashCode() : 0)) * 31;
        String str2 = this.account_id;
        int hashCode4 = (hashCode3 + (str2 != null ? str2.hashCode() : 0)) * 31;
        String str3 = this.application_id;
        int hashCode5 = (hashCode4 + (str3 != null ? str3.hashCode() : 0)) * 31;
        String str4 = this.priority_encoding_key;
        if (str4 != null) {
            i2 = str4.hashCode();
        }
        return hashCode5 + i2;
    }

    public boolean isCollect_network_errors() {
        return this.collect_network_errors;
    }

    public void reconfigure(HarvestConfiguration harvestConfiguration) {
        setCollect_network_errors(harvestConfiguration.isCollect_network_errors());
        if (harvestConfiguration.getCross_process_id() != null) {
            setCross_process_id(harvestConfiguration.getCross_process_id());
        }
        setData_report_period(harvestConfiguration.getData_report_period());
        if (harvestConfiguration.getDataToken().isValid()) {
            setData_token(harvestConfiguration.getData_token());
        }
        setError_limit(harvestConfiguration.getError_limit());
        setReport_max_transaction_age(harvestConfiguration.getReport_max_transaction_age());
        setReport_max_transaction_count(harvestConfiguration.getReport_max_transaction_count());
        setResponse_body_limit(harvestConfiguration.getResponse_body_limit());
        setServer_timestamp(harvestConfiguration.getServer_timestamp());
        setStack_trace_limit(harvestConfiguration.getStack_trace_limit());
        setActivity_trace_min_utilization(harvestConfiguration.getActivity_trace_min_utilization());
        setActivity_trace_max_report_attempts(harvestConfiguration.getActivity_trace_max_report_attempts());
        if (harvestConfiguration.getAt_capture() != null) {
            setAt_capture(harvestConfiguration.getAt_capture());
        }
        setPriority_encoding_key(harvestConfiguration.getPriority_encoding_key());
        setAccount_id(harvestConfiguration.getAccount_id());
        setApplication_id(harvestConfiguration.getApplication_id());
    }

    public void setAccount_id(String str) {
        this.account_id = str;
    }

    public void setActivity_trace_max_report_attempts(int i) {
        this.activity_trace_max_report_attempts = i;
    }

    public void setActivity_trace_max_size(int i) {
        this.activity_trace_max_size = i;
    }

    public void setActivity_trace_min_utilization(double d) {
        this.activity_trace_min_utilization = d;
    }

    public void setApplication_id(String str) {
        this.application_id = str;
    }

    public void setAt_capture(ActivityTraceConfiguration activityTraceConfiguration) {
        this.at_capture = activityTraceConfiguration;
    }

    public void setCollect_network_errors(boolean z) {
        this.collect_network_errors = z;
    }

    public void setCross_process_id(String str) {
        this.cross_process_id = str;
    }

    public void setData_report_period(int i) {
        this.data_report_period = i;
    }

    public void setData_token(int[] iArr) {
        this.data_token = iArr;
    }

    public void setDefaultValues() {
        setData_token(new int[2]);
        setCollect_network_errors(true);
        setCross_process_id((String) null);
        setData_report_period(60);
        setError_limit(50);
        setResponse_body_limit(DEFAULT_RESPONSE_BODY_LIMIT);
        setStack_trace_limit(100);
        setReport_max_transaction_age(DEFAULT_MAX_TRANSACTION_AGE);
        setReport_max_transaction_count(DEFAULT_MAX_TRANSACTION_COUNT);
        setActivity_trace_max_size(65534);
        setActivity_trace_max_report_attempts(1);
        setActivity_trace_min_utilization(0.30000001192092896d);
        setAt_capture(ActivityTraceConfiguration.defaultActivityTraceConfiguration());
        setPriority_encoding_key(DEFAULT_PRIORITY_ENCODING_KEY);
        setAccount_id("");
        setApplication_id("");
    }

    public void setError_limit(int i) {
        this.error_limit = i;
    }

    public void setPriority_encoding_key(String str) {
        this.priority_encoding_key = str;
    }

    public void setReport_max_transaction_age(int i) {
        this.report_max_transaction_age = i;
    }

    public void setReport_max_transaction_count(int i) {
        this.report_max_transaction_count = i;
    }

    public void setResponse_body_limit(int i) {
        this.response_body_limit = i;
    }

    public void setServer_timestamp(long j) {
        this.server_timestamp = j;
    }

    public void setStack_trace_limit(int i) {
        this.stack_trace_limit = i;
    }

    public String toString() {
        StringBuilder a = outline.m2937a("HarvestConfiguration{collect_network_errors=");
        a.append(this.collect_network_errors);
        a.append(", cross_process_id='");
        outline.m2940a(a, this.cross_process_id, '\'', ", data_report_period=");
        a.append(this.data_report_period);
        a.append(", data_token=");
        a.append(Arrays.toString(this.data_token));
        a.append(", error_limit=");
        a.append(this.error_limit);
        a.append(", report_max_transaction_age=");
        a.append(this.report_max_transaction_age);
        a.append(", report_max_transaction_count=");
        a.append(this.report_max_transaction_count);
        a.append(", response_body_limit=");
        a.append(this.response_body_limit);
        a.append(", server_timestamp=");
        a.append(this.server_timestamp);
        a.append(", stack_trace_limit=");
        a.append(this.stack_trace_limit);
        a.append(", activity_trace_max_size=");
        a.append(this.activity_trace_max_size);
        a.append(", activity_trace_max_report_attempts=");
        a.append(this.activity_trace_max_report_attempts);
        a.append(", activity_trace_min_utilization=");
        a.append(this.activity_trace_min_utilization);
        a.append(", at_capture=");
        a.append(this.at_capture);
        a.append(", priority_encoding_key=");
        a.append(this.priority_encoding_key);
        a.append(", account_id=");
        a.append(this.account_id);
        a.append(", application_id=");
        a.append(this.application_id);
        a.append('}');
        return a.toString();
    }
}
