package okhttp3;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.IOException;
import java.security.Principal;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSession;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.Lazy;
import p250f.LazyJVM;
import p250f.p251i.C1892h;
import p250f.p251i._Arrays;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: Handshake.kt */
public final class Handshake {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final CipherSuite cipherSuite;
    public final List<Certificate> localCertificates;
    public final Lazy peerCertificates$delegate;
    public final TlsVersion tlsVersion;

    /* compiled from: Handshake.kt */
    public static final class Companion {
        public Companion() {
        }

        private final List<Certificate> toImmutableList(Certificate[] certificateArr) {
            if (certificateArr != null) {
                return Util.immutableListOf((Certificate[]) Arrays.copyOf(certificateArr, certificateArr.length));
            }
            return C1892h.f7579b;
        }

        /* renamed from: -deprecated_get  reason: not valid java name */
        public final Handshake m6085deprecated_get(SSLSession sSLSession) throws IOException {
            if (sSLSession != null) {
                return get(sSLSession);
            }
            Intrinsics.m5822a("sslSession");
            throw null;
        }

        public final Handshake get(SSLSession sSLSession) throws IOException {
            List list;
            if (sSLSession != null) {
                String cipherSuite = sSLSession.getCipherSuite();
                if (cipherSuite != null) {
                    int hashCode = cipherSuite.hashCode();
                    if (hashCode == 1019404634 ? cipherSuite.equals("TLS_NULL_WITH_NULL_NULL") : hashCode == 1208658923 && cipherSuite.equals("SSL_NULL_WITH_NULL_NULL")) {
                        throw new IOException(outline.m2941b("cipherSuite == ", cipherSuite));
                    }
                    CipherSuite forJavaName = CipherSuite.Companion.forJavaName(cipherSuite);
                    String protocol = sSLSession.getProtocol();
                    if (protocol == null) {
                        throw new IllegalStateException("tlsVersion == null".toString());
                    } else if (!Intrinsics.m5823a((Object) "NONE", (Object) protocol)) {
                        TlsVersion forJavaName2 = TlsVersion.Companion.forJavaName(protocol);
                        try {
                            list = toImmutableList(sSLSession.getPeerCertificates());
                        } catch (SSLPeerUnverifiedException unused) {
                            list = C1892h.f7579b;
                        }
                        return new Handshake(forJavaName2, forJavaName, toImmutableList(sSLSession.getLocalCertificates()), new Handshake$Companion$handshake$1(list));
                    } else {
                        throw new IOException("tlsVersion == NONE");
                    }
                } else {
                    throw new IllegalStateException("cipherSuite == null".toString());
                }
            } else {
                Intrinsics.m5822a("$this$handshake");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }

        public final Handshake get(TlsVersion tlsVersion, CipherSuite cipherSuite, List<? extends Certificate> list, List<? extends Certificate> list2) {
            if (tlsVersion == null) {
                Intrinsics.m5822a("tlsVersion");
                throw null;
            } else if (cipherSuite == null) {
                Intrinsics.m5822a("cipherSuite");
                throw null;
            } else if (list == null) {
                Intrinsics.m5822a("peerCertificates");
                throw null;
            } else if (list2 != null) {
                return new Handshake(tlsVersion, cipherSuite, Util.toImmutableList(list2), new Handshake$Companion$get$1(Util.toImmutableList(list)));
            } else {
                Intrinsics.m5822a("localCertificates");
                throw null;
            }
        }
    }

    public Handshake(TlsVersion tlsVersion2, CipherSuite cipherSuite2, List<? extends Certificate> list, C1896a<? extends List<? extends Certificate>> aVar) {
        if (tlsVersion2 == null) {
            Intrinsics.m5822a("tlsVersion");
            throw null;
        } else if (cipherSuite2 == null) {
            Intrinsics.m5822a("cipherSuite");
            throw null;
        } else if (list == null) {
            Intrinsics.m5822a("localCertificates");
            throw null;
        } else if (aVar != null) {
            this.tlsVersion = tlsVersion2;
            this.cipherSuite = cipherSuite2;
            this.localCertificates = list;
            this.peerCertificates$delegate = new LazyJVM(new Handshake$peerCertificates$2(aVar), (Object) null, 2);
        } else {
            Intrinsics.m5822a("peerCertificatesFn");
            throw null;
        }
    }

    public static final Handshake get(SSLSession sSLSession) throws IOException {
        return Companion.get(sSLSession);
    }

    public static final Handshake get(TlsVersion tlsVersion2, CipherSuite cipherSuite2, List<? extends Certificate> list, List<? extends Certificate> list2) {
        return Companion.get(tlsVersion2, cipherSuite2, list, list2);
    }

    private final String getName(Certificate certificate) {
        if (certificate instanceof X509Certificate) {
            return ((X509Certificate) certificate).getSubjectDN().toString();
        }
        String type = certificate.getType();
        Intrinsics.m5821a((Object) type, AnalyticAttribute.TYPE_ATTRIBUTE);
        return type;
    }

    /* renamed from: -deprecated_cipherSuite  reason: not valid java name */
    public final CipherSuite m6079deprecated_cipherSuite() {
        return this.cipherSuite;
    }

    /* renamed from: -deprecated_localCertificates  reason: not valid java name */
    public final List<Certificate> m6080deprecated_localCertificates() {
        return this.localCertificates;
    }

    /* renamed from: -deprecated_localPrincipal  reason: not valid java name */
    public final Principal m6081deprecated_localPrincipal() {
        return localPrincipal();
    }

    /* renamed from: -deprecated_peerCertificates  reason: not valid java name */
    public final List<Certificate> m6082deprecated_peerCertificates() {
        return peerCertificates();
    }

    /* renamed from: -deprecated_peerPrincipal  reason: not valid java name */
    public final Principal m6083deprecated_peerPrincipal() {
        return peerPrincipal();
    }

    /* renamed from: -deprecated_tlsVersion  reason: not valid java name */
    public final TlsVersion m6084deprecated_tlsVersion() {
        return this.tlsVersion;
    }

    public final CipherSuite cipherSuite() {
        return this.cipherSuite;
    }

    public boolean equals(Object obj) {
        if (obj instanceof Handshake) {
            Handshake handshake = (Handshake) obj;
            return handshake.tlsVersion == this.tlsVersion && Intrinsics.m5823a((Object) handshake.cipherSuite, (Object) this.cipherSuite) && Intrinsics.m5823a((Object) handshake.peerCertificates(), (Object) peerCertificates()) && Intrinsics.m5823a((Object) handshake.localCertificates, (Object) this.localCertificates);
        }
    }

    public int hashCode() {
        int hashCode = this.cipherSuite.hashCode();
        int hashCode2 = peerCertificates().hashCode();
        return this.localCertificates.hashCode() + ((hashCode2 + ((hashCode + ((this.tlsVersion.hashCode() + 527) * 31)) * 31)) * 31);
    }

    public final List<Certificate> localCertificates() {
        return this.localCertificates;
    }

    public final Principal localPrincipal() {
        Object a = _Arrays.m5801a(this.localCertificates);
        if (!(a instanceof X509Certificate)) {
            a = null;
        }
        X509Certificate x509Certificate = (X509Certificate) a;
        if (x509Certificate != null) {
            return x509Certificate.getSubjectX500Principal();
        }
        return null;
    }

    public final List<Certificate> peerCertificates() {
        return (List) this.peerCertificates$delegate.getValue();
    }

    public final Principal peerPrincipal() {
        Object a = _Arrays.m5801a(peerCertificates());
        if (!(a instanceof X509Certificate)) {
            a = null;
        }
        X509Certificate x509Certificate = (X509Certificate) a;
        if (x509Certificate != null) {
            return x509Certificate.getSubjectX500Principal();
        }
        return null;
    }

    public final TlsVersion tlsVersion() {
        return this.tlsVersion;
    }

    public String toString() {
        List<Certificate> peerCertificates = peerCertificates();
        ArrayList arrayList = new ArrayList(C1050v.m4134a(peerCertificates, 10));
        for (Certificate name : peerCertificates) {
            arrayList.add(getName(name));
        }
        String obj = arrayList.toString();
        StringBuilder a = outline.m2938a("Handshake{", "tlsVersion=");
        a.append(this.tlsVersion);
        a.append(SafeJsonPrimitive.NULL_CHAR);
        a.append("cipherSuite=");
        a.append(this.cipherSuite);
        a.append(SafeJsonPrimitive.NULL_CHAR);
        a.append("peerCertificates=");
        a.append(obj);
        a.append(SafeJsonPrimitive.NULL_CHAR);
        a.append("localCertificates=");
        List<Certificate> list = this.localCertificates;
        ArrayList arrayList2 = new ArrayList(C1050v.m4134a(list, 10));
        for (Certificate name2 : list) {
            arrayList2.add(getName(name2));
        }
        a.append(arrayList2);
        a.append('}');
        return a.toString();
    }
}
