package okhttp3;

import com.newrelic.agent.android.agentdata.HexAttributes;
import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.util.List;
import okhttp3.Headers;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.http.HttpHeaders;
import p085c.p086a.p087a.p088a.outline;
import p250f.p251i.C1892h;
import p250f.p254l.p256c.Intrinsics;
import p262g.BufferedSource;
import p262g.C1948d;

/* compiled from: Response.kt */
public final class Response implements Closeable {
    public final ResponseBody body;
    public final Response cacheResponse;
    public final int code;
    public final Exchange exchange;
    public final Handshake handshake;
    public final Headers headers;
    public CacheControl lazyCacheControl;
    public final String message;
    public final Response networkResponse;
    public final Response priorResponse;
    public final Protocol protocol;
    public final long receivedResponseAtMillis;
    public final Request request;
    public final long sentRequestAtMillis;

    public Response(Request request2, Protocol protocol2, String str, int i, Handshake handshake2, Headers headers2, ResponseBody responseBody, Response response, Response response2, Response response3, long j, long j2, Exchange exchange2) {
        Request request3 = request2;
        Protocol protocol3 = protocol2;
        String str2 = str;
        Headers headers3 = headers2;
        if (request3 == null) {
            Intrinsics.m5822a("request");
            throw null;
        } else if (protocol3 == null) {
            Intrinsics.m5822a("protocol");
            throw null;
        } else if (str2 == null) {
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        } else if (headers3 != null) {
            this.request = request3;
            this.protocol = protocol3;
            this.message = str2;
            this.code = i;
            this.handshake = handshake2;
            this.headers = headers3;
            this.body = responseBody;
            this.networkResponse = response;
            this.cacheResponse = response2;
            this.priorResponse = response3;
            this.sentRequestAtMillis = j;
            this.receivedResponseAtMillis = j2;
            this.exchange = exchange2;
        } else {
            Intrinsics.m5822a("headers");
            throw null;
        }
    }

    public static /* synthetic */ String header$default(Response response, String str, String str2, int i, Object obj) {
        if ((i & 2) != 0) {
            str2 = null;
        }
        return response.header(str, str2);
    }

    /* renamed from: -deprecated_body  reason: not valid java name */
    public final ResponseBody m6155deprecated_body() {
        return this.body;
    }

    /* renamed from: -deprecated_cacheControl  reason: not valid java name */
    public final CacheControl m6156deprecated_cacheControl() {
        return cacheControl();
    }

    /* renamed from: -deprecated_cacheResponse  reason: not valid java name */
    public final Response m6157deprecated_cacheResponse() {
        return this.cacheResponse;
    }

    /* renamed from: -deprecated_code  reason: not valid java name */
    public final int m6158deprecated_code() {
        return this.code;
    }

    /* renamed from: -deprecated_handshake  reason: not valid java name */
    public final Handshake m6159deprecated_handshake() {
        return this.handshake;
    }

    /* renamed from: -deprecated_headers  reason: not valid java name */
    public final Headers m6160deprecated_headers() {
        return this.headers;
    }

    /* renamed from: -deprecated_message  reason: not valid java name */
    public final String m6161deprecated_message() {
        return this.message;
    }

    /* renamed from: -deprecated_networkResponse  reason: not valid java name */
    public final Response m6162deprecated_networkResponse() {
        return this.networkResponse;
    }

    /* renamed from: -deprecated_priorResponse  reason: not valid java name */
    public final Response m6163deprecated_priorResponse() {
        return this.priorResponse;
    }

    /* renamed from: -deprecated_protocol  reason: not valid java name */
    public final Protocol m6164deprecated_protocol() {
        return this.protocol;
    }

    /* renamed from: -deprecated_receivedResponseAtMillis  reason: not valid java name */
    public final long m6165deprecated_receivedResponseAtMillis() {
        return this.receivedResponseAtMillis;
    }

    /* renamed from: -deprecated_request  reason: not valid java name */
    public final Request m6166deprecated_request() {
        return this.request;
    }

    /* renamed from: -deprecated_sentRequestAtMillis  reason: not valid java name */
    public final long m6167deprecated_sentRequestAtMillis() {
        return this.sentRequestAtMillis;
    }

    public final ResponseBody body() {
        return this.body;
    }

    public final CacheControl cacheControl() {
        CacheControl cacheControl = this.lazyCacheControl;
        if (cacheControl != null) {
            return cacheControl;
        }
        CacheControl parse = CacheControl.Companion.parse(this.headers);
        this.lazyCacheControl = parse;
        return parse;
    }

    public final Response cacheResponse() {
        return this.cacheResponse;
    }

    public final List<Challenge> challenges() {
        String str;
        Headers headers2 = this.headers;
        int i = this.code;
        if (i == 401) {
            str = "WWW-Authenticate";
        } else if (i != 407) {
            return C1892h.f7579b;
        } else {
            str = "Proxy-Authenticate";
        }
        return HttpHeaders.parseChallenges(headers2, str);
    }

    public void close() {
        ResponseBody responseBody = this.body;
        if (responseBody != null) {
            responseBody.close();
            return;
        }
        throw new IllegalStateException("response is not eligible for a body and must not be closed".toString());
    }

    public final int code() {
        return this.code;
    }

    public final Exchange exchange() {
        return this.exchange;
    }

    public final Handshake handshake() {
        return this.handshake;
    }

    public final String header(String str) {
        return header$default(this, str, (String) null, 2, (Object) null);
    }

    public final String header(String str, String str2) {
        if (str != null) {
            String str3 = this.headers.get(str);
            return str3 != null ? str3 : str2;
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final Headers headers() {
        return this.headers;
    }

    public final boolean isRedirect() {
        int i = this.code;
        if (!(i == 307 || i == 308)) {
            switch (i) {
                case 300:
                case 301:
                case 302:
                case 303:
                    break;
                default:
                    return false;
            }
        }
        return true;
    }

    public final boolean isSuccessful() {
        int i = this.code;
        return 200 <= i && 299 >= i;
    }

    public final String message() {
        return this.message;
    }

    public final Response networkResponse() {
        return this.networkResponse;
    }

    public final Builder newBuilder() {
        return new Builder(this);
    }

    public final ResponseBody peekBody(long j) throws IOException {
        ResponseBody responseBody = this.body;
        if (responseBody != null) {
            BufferedSource peek = responseBody.source().peek();
            C1948d dVar = new C1948d();
            peek.mo9484d(j);
            long min = Math.min(j, peek.getBuffer().f7648c);
            while (min > 0) {
                long read = peek.read(dVar, min);
                if (read != -1) {
                    min -= read;
                } else {
                    throw new EOFException();
                }
            }
            return ResponseBody.Companion.create((BufferedSource) dVar, this.body.contentType(), dVar.f7648c);
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final Response priorResponse() {
        return this.priorResponse;
    }

    public final Protocol protocol() {
        return this.protocol;
    }

    public final long receivedResponseAtMillis() {
        return this.receivedResponseAtMillis;
    }

    public final Request request() {
        return this.request;
    }

    public final long sentRequestAtMillis() {
        return this.sentRequestAtMillis;
    }

    public String toString() {
        StringBuilder a = outline.m2937a("Response{protocol=");
        a.append(this.protocol);
        a.append(", code=");
        a.append(this.code);
        a.append(", message=");
        a.append(this.message);
        a.append(", url=");
        a.append(this.request.url());
        a.append('}');
        return a.toString();
    }

    public final Headers trailers() throws IOException {
        Exchange exchange2 = this.exchange;
        if (exchange2 != null) {
            return exchange2.trailers();
        }
        throw new IllegalStateException("trailers not available".toString());
    }

    public final List<String> headers(String str) {
        if (str != null) {
            return this.headers.values(str);
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    /* compiled from: Response.kt */
    public static class Builder {
        public ResponseBody body;
        public Response cacheResponse;
        public int code;
        public Exchange exchange;
        public Handshake handshake;
        public Headers.Builder headers;
        public String message;
        public Response networkResponse;
        public Response priorResponse;
        public Protocol protocol;
        public long receivedResponseAtMillis;
        public Request request;
        public long sentRequestAtMillis;

        public Builder() {
            this.code = -1;
            this.headers = new Headers.Builder();
        }

        private final void checkPriorResponse(Response response) {
            if (response != null) {
                if (!(response.body() == null)) {
                    throw new IllegalArgumentException("priorResponse.body != null".toString());
                }
            }
        }

        private final void checkSupportResponse(String str, Response response) {
            if (response != null) {
                boolean z = true;
                if (response.body() == null) {
                    if (response.networkResponse() == null) {
                        if (response.cacheResponse() == null) {
                            if (response.priorResponse() != null) {
                                z = false;
                            }
                            if (!z) {
                                throw new IllegalArgumentException(outline.m2941b(str, ".priorResponse != null").toString());
                            }
                            return;
                        }
                        throw new IllegalArgumentException(outline.m2941b(str, ".cacheResponse != null").toString());
                    }
                    throw new IllegalArgumentException(outline.m2941b(str, ".networkResponse != null").toString());
                }
                throw new IllegalArgumentException(outline.m2941b(str, ".body != null").toString());
            }
        }

        public Builder addHeader(String str, String str2) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (str2 != null) {
                this.headers.add(str, str2);
                return this;
            } else {
                Intrinsics.m5822a("value");
                throw null;
            }
        }

        public Builder body(ResponseBody responseBody) {
            this.body = responseBody;
            return this;
        }

        public Response build() {
            if (this.code >= 0) {
                Request request2 = this.request;
                if (request2 != null) {
                    Protocol protocol2 = this.protocol;
                    if (protocol2 != null) {
                        String str = this.message;
                        if (str != null) {
                            return new Response(request2, protocol2, str, this.code, this.handshake, this.headers.build(), this.body, this.networkResponse, this.cacheResponse, this.priorResponse, this.sentRequestAtMillis, this.receivedResponseAtMillis, this.exchange);
                        }
                        throw new IllegalStateException("message == null".toString());
                    }
                    throw new IllegalStateException("protocol == null".toString());
                }
                throw new IllegalStateException("request == null".toString());
            }
            StringBuilder a = outline.m2937a("code < 0: ");
            a.append(this.code);
            throw new IllegalStateException(a.toString().toString());
        }

        public Builder cacheResponse(Response response) {
            checkSupportResponse("cacheResponse", response);
            this.cacheResponse = response;
            return this;
        }

        public Builder code(int i) {
            this.code = i;
            return this;
        }

        public final ResponseBody getBody$okhttp() {
            return this.body;
        }

        public final Response getCacheResponse$okhttp() {
            return this.cacheResponse;
        }

        public final int getCode$okhttp() {
            return this.code;
        }

        public final Exchange getExchange$okhttp() {
            return this.exchange;
        }

        public final Handshake getHandshake$okhttp() {
            return this.handshake;
        }

        public final Headers.Builder getHeaders$okhttp() {
            return this.headers;
        }

        public final String getMessage$okhttp() {
            return this.message;
        }

        public final Response getNetworkResponse$okhttp() {
            return this.networkResponse;
        }

        public final Response getPriorResponse$okhttp() {
            return this.priorResponse;
        }

        public final Protocol getProtocol$okhttp() {
            return this.protocol;
        }

        public final long getReceivedResponseAtMillis$okhttp() {
            return this.receivedResponseAtMillis;
        }

        public final Request getRequest$okhttp() {
            return this.request;
        }

        public final long getSentRequestAtMillis$okhttp() {
            return this.sentRequestAtMillis;
        }

        public Builder handshake(Handshake handshake2) {
            this.handshake = handshake2;
            return this;
        }

        public Builder header(String str, String str2) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (str2 != null) {
                this.headers.set(str, str2);
                return this;
            } else {
                Intrinsics.m5822a("value");
                throw null;
            }
        }

        public Builder headers(Headers headers2) {
            if (headers2 != null) {
                this.headers = headers2.newBuilder();
                return this;
            }
            Intrinsics.m5822a("headers");
            throw null;
        }

        public final void initExchange$okhttp(Exchange exchange2) {
            if (exchange2 != null) {
                this.exchange = exchange2;
            } else {
                Intrinsics.m5822a("deferredTrailers");
                throw null;
            }
        }

        public Builder message(String str) {
            if (str != null) {
                this.message = str;
                return this;
            }
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        }

        public Builder networkResponse(Response response) {
            checkSupportResponse("networkResponse", response);
            this.networkResponse = response;
            return this;
        }

        public Builder priorResponse(Response response) {
            checkPriorResponse(response);
            this.priorResponse = response;
            return this;
        }

        public Builder protocol(Protocol protocol2) {
            if (protocol2 != null) {
                this.protocol = protocol2;
                return this;
            }
            Intrinsics.m5822a("protocol");
            throw null;
        }

        public Builder receivedResponseAtMillis(long j) {
            this.receivedResponseAtMillis = j;
            return this;
        }

        public Builder removeHeader(String str) {
            if (str != null) {
                this.headers.removeAll(str);
                return this;
            }
            Intrinsics.m5822a("name");
            throw null;
        }

        public Builder request(Request request2) {
            if (request2 != null) {
                this.request = request2;
                return this;
            }
            Intrinsics.m5822a("request");
            throw null;
        }

        public Builder sentRequestAtMillis(long j) {
            this.sentRequestAtMillis = j;
            return this;
        }

        public final void setBody$okhttp(ResponseBody responseBody) {
            this.body = responseBody;
        }

        public final void setCacheResponse$okhttp(Response response) {
            this.cacheResponse = response;
        }

        public final void setCode$okhttp(int i) {
            this.code = i;
        }

        public final void setExchange$okhttp(Exchange exchange2) {
            this.exchange = exchange2;
        }

        public final void setHandshake$okhttp(Handshake handshake2) {
            this.handshake = handshake2;
        }

        public final void setHeaders$okhttp(Headers.Builder builder) {
            if (builder != null) {
                this.headers = builder;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setMessage$okhttp(String str) {
            this.message = str;
        }

        public final void setNetworkResponse$okhttp(Response response) {
            this.networkResponse = response;
        }

        public final void setPriorResponse$okhttp(Response response) {
            this.priorResponse = response;
        }

        public final void setProtocol$okhttp(Protocol protocol2) {
            this.protocol = protocol2;
        }

        public final void setReceivedResponseAtMillis$okhttp(long j) {
            this.receivedResponseAtMillis = j;
        }

        public final void setRequest$okhttp(Request request2) {
            this.request = request2;
        }

        public final void setSentRequestAtMillis$okhttp(long j) {
            this.sentRequestAtMillis = j;
        }

        public Builder(Response response) {
            if (response != null) {
                this.code = -1;
                this.request = response.request();
                this.protocol = response.protocol();
                this.code = response.code();
                this.message = response.message();
                this.handshake = response.handshake();
                this.headers = response.headers().newBuilder();
                this.body = response.body();
                this.networkResponse = response.networkResponse();
                this.cacheResponse = response.cacheResponse();
                this.priorResponse = response.priorResponse();
                this.sentRequestAtMillis = response.sentRequestAtMillis();
                this.receivedResponseAtMillis = response.receivedResponseAtMillis();
                this.exchange = response.exchange();
                return;
            }
            Intrinsics.m5822a("response");
            throw null;
        }
    }
}
