package okhttp3.internal.connection;

import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.net.ProtocolException;
import java.net.SocketException;
import okhttp3.EventListener;
import okhttp3.Headers;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.RealResponseBody;
import okhttp3.internal.p270ws.RealWebSocket;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.Intrinsics;
import p262g.C1948d;
import p262g.ForwardingSink;
import p262g.ForwardingSource;
import p262g.Sink;
import p262g.Source;

/* compiled from: Exchange.kt */
public final class Exchange {
    public final RealCall call;
    public final ExchangeCodec codec;
    public final RealConnection connection;
    public final EventListener eventListener;
    public final ExchangeFinder finder;
    public boolean isDuplex;

    /* compiled from: Exchange.kt */
    public final class RequestBodySink extends ForwardingSink {
        public long bytesReceived;
        public boolean closed;
        public boolean completed;
        public final long contentLength;
        public final /* synthetic */ Exchange this$0;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public RequestBodySink(Exchange exchange, Sink xVar, long j) {
            super(xVar);
            if (xVar != null) {
                this.this$0 = exchange;
                this.contentLength = j;
                return;
            }
            Intrinsics.m5822a("delegate");
            throw null;
        }

        private final <E extends IOException> E complete(E e) {
            if (this.completed) {
                return e;
            }
            this.completed = true;
            return this.this$0.bodyComplete(this.bytesReceived, false, true, e);
        }

        public void close() throws IOException {
            if (!this.closed) {
                this.closed = true;
                long j = this.contentLength;
                if (j == -1 || this.bytesReceived == j) {
                    try {
                        super.close();
                        complete((IOException) null);
                    } catch (IOException e) {
                        throw complete(e);
                    }
                } else {
                    throw new ProtocolException("unexpected end of stream");
                }
            }
        }

        public void flush() throws IOException {
            try {
                super.flush();
            } catch (IOException e) {
                throw complete(e);
            }
        }

        public void write(C1948d dVar, long j) throws IOException {
            if (dVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (!this.closed) {
                long j2 = this.contentLength;
                if (j2 == -1 || this.bytesReceived + j <= j2) {
                    try {
                        super.write(dVar, j);
                        this.bytesReceived += j;
                    } catch (IOException e) {
                        throw complete(e);
                    }
                } else {
                    StringBuilder a = outline.m2937a("expected ");
                    a.append(this.contentLength);
                    a.append(" bytes but received ");
                    a.append(this.bytesReceived + j);
                    throw new ProtocolException(a.toString());
                }
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    /* compiled from: Exchange.kt */
    public final class ResponseBodySource extends ForwardingSource {
        public long bytesReceived;
        public boolean closed;
        public boolean completed;
        public final long contentLength;
        public boolean invokeStartEvent;
        public final /* synthetic */ Exchange this$0;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public ResponseBodySource(Exchange exchange, Source zVar, long j) {
            super(zVar);
            if (zVar != null) {
                this.this$0 = exchange;
                this.contentLength = j;
                this.invokeStartEvent = true;
                if (j == 0) {
                    complete((IOException) null);
                    return;
                }
                return;
            }
            Intrinsics.m5822a("delegate");
            throw null;
        }

        public void close() throws IOException {
            if (!this.closed) {
                this.closed = true;
                try {
                    super.close();
                    complete((IOException) null);
                } catch (IOException e) {
                    throw complete(e);
                }
            }
        }

        public final <E extends IOException> E complete(E e) {
            if (this.completed) {
                return e;
            }
            this.completed = true;
            if (e == null && this.invokeStartEvent) {
                this.invokeStartEvent = false;
                this.this$0.getEventListener$okhttp().responseBodyStart(this.this$0.getCall$okhttp());
            }
            return this.this$0.bodyComplete(this.bytesReceived, true, false, e);
        }

        public long read(C1948d dVar, long j) throws IOException {
            if (dVar == null) {
                Intrinsics.m5822a("sink");
                throw null;
            } else if (!this.closed) {
                try {
                    long read = delegate().read(dVar, j);
                    if (this.invokeStartEvent) {
                        this.invokeStartEvent = false;
                        this.this$0.getEventListener$okhttp().responseBodyStart(this.this$0.getCall$okhttp());
                    }
                    if (read == -1) {
                        complete((IOException) null);
                        return -1;
                    }
                    long j2 = this.bytesReceived + read;
                    if (this.contentLength != -1) {
                        if (j2 > this.contentLength) {
                            throw new ProtocolException("expected " + this.contentLength + " bytes but received " + j2);
                        }
                    }
                    this.bytesReceived = j2;
                    if (j2 == this.contentLength) {
                        complete((IOException) null);
                    }
                    return read;
                } catch (IOException e) {
                    throw complete(e);
                }
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    public Exchange(RealCall realCall, EventListener eventListener2, ExchangeFinder exchangeFinder, ExchangeCodec exchangeCodec) {
        if (realCall == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (eventListener2 == null) {
            Intrinsics.m5822a("eventListener");
            throw null;
        } else if (exchangeFinder == null) {
            Intrinsics.m5822a("finder");
            throw null;
        } else if (exchangeCodec != null) {
            this.call = realCall;
            this.eventListener = eventListener2;
            this.finder = exchangeFinder;
            this.codec = exchangeCodec;
            this.connection = exchangeCodec.getConnection();
        } else {
            Intrinsics.m5822a("codec");
            throw null;
        }
    }

    private final void trackFailure(IOException iOException) {
        this.finder.trackFailure(iOException);
        this.codec.getConnection().trackFailure$okhttp(this.call, iOException);
    }

    public final <E extends IOException> E bodyComplete(long j, boolean z, boolean z2, E e) {
        if (e != null) {
            trackFailure(e);
        }
        if (z2) {
            if (e != null) {
                this.eventListener.requestFailed(this.call, e);
            } else {
                this.eventListener.requestBodyEnd(this.call, j);
            }
        }
        if (z) {
            if (e != null) {
                this.eventListener.responseFailed(this.call, e);
            } else {
                this.eventListener.responseBodyEnd(this.call, j);
            }
        }
        return this.call.messageDone$okhttp(this, z2, z, e);
    }

    public final void cancel() {
        this.codec.cancel();
    }

    public final Sink createRequestBody(Request request, boolean z) throws IOException {
        if (request != null) {
            this.isDuplex = z;
            RequestBody body = request.body();
            if (body != null) {
                long contentLength = body.contentLength();
                this.eventListener.requestBodyStart(this.call);
                return new RequestBodySink(this, this.codec.createRequestBody(request, contentLength), contentLength);
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("request");
        throw null;
    }

    public final void detachWithViolence() {
        this.codec.cancel();
        this.call.messageDone$okhttp(this, true, true, null);
    }

    public final void finishRequest() throws IOException {
        try {
            this.codec.finishRequest();
        } catch (IOException e) {
            this.eventListener.requestFailed(this.call, e);
            trackFailure(e);
            throw e;
        }
    }

    public final void flushRequest() throws IOException {
        try {
            this.codec.flushRequest();
        } catch (IOException e) {
            this.eventListener.requestFailed(this.call, e);
            trackFailure(e);
            throw e;
        }
    }

    public final RealCall getCall$okhttp() {
        return this.call;
    }

    public final RealConnection getConnection$okhttp() {
        return this.connection;
    }

    public final EventListener getEventListener$okhttp() {
        return this.eventListener;
    }

    public final ExchangeFinder getFinder$okhttp() {
        return this.finder;
    }

    public final boolean isCoalescedConnection$okhttp() {
        return !Intrinsics.m5823a((Object) this.finder.getAddress$okhttp().url().host(), (Object) this.connection.route().address().url().host());
    }

    public final boolean isDuplex$okhttp() {
        return this.isDuplex;
    }

    public final RealWebSocket.Streams newWebSocketStreams() throws SocketException {
        this.call.timeoutEarlyExit();
        return this.codec.getConnection().newWebSocketStreams$okhttp(this);
    }

    public final void noNewExchangesOnConnection() {
        this.codec.getConnection().noNewExchanges();
    }

    public final void noRequestBody() {
        this.call.messageDone$okhttp(this, true, false, null);
    }

    public final ResponseBody openResponseBody(Response response) throws IOException {
        if (response != null) {
            try {
                String header$default = Response.header$default(response, Constants.Network.CONTENT_TYPE_HEADER, (String) null, 2, (Object) null);
                long reportedContentLength = this.codec.reportedContentLength(response);
                return new RealResponseBody(header$default, reportedContentLength, C1050v.m4148a((Source) new ResponseBodySource(this, this.codec.openResponseBodySource(response), reportedContentLength)));
            } catch (IOException e) {
                this.eventListener.responseFailed(this.call, e);
                trackFailure(e);
                throw e;
            }
        } else {
            Intrinsics.m5822a("response");
            throw null;
        }
    }

    public final Response.Builder readResponseHeaders(boolean z) throws IOException {
        try {
            Response.Builder readResponseHeaders = this.codec.readResponseHeaders(z);
            if (readResponseHeaders != null) {
                readResponseHeaders.initExchange$okhttp(this);
            }
            return readResponseHeaders;
        } catch (IOException e) {
            this.eventListener.responseFailed(this.call, e);
            trackFailure(e);
            throw e;
        }
    }

    public final void responseHeadersEnd(Response response) {
        if (response != null) {
            this.eventListener.responseHeadersEnd(this.call, response);
        } else {
            Intrinsics.m5822a("response");
            throw null;
        }
    }

    public final void responseHeadersStart() {
        this.eventListener.responseHeadersStart(this.call);
    }

    public final Headers trailers() throws IOException {
        return this.codec.trailers();
    }

    public final void webSocketUpgradeFailed() {
        bodyComplete(-1, true, true, (IOException) null);
    }

    public final void writeRequestHeaders(Request request) throws IOException {
        if (request != null) {
            try {
                this.eventListener.requestHeadersStart(this.call);
                this.codec.writeRequestHeaders(request);
                this.eventListener.requestHeadersEnd(this.call, request);
            } catch (IOException e) {
                this.eventListener.requestFailed(this.call, e);
                trackFailure(e);
                throw e;
            }
        } else {
            Intrinsics.m5822a("request");
            throw null;
        }
    }
}
