package com.newrelic.agent.android.harvest;

import com.newrelic.agent.android.FeatureFlag;
import com.newrelic.agent.android.connectivity.CatPayload;
import com.newrelic.agent.android.harvest.type.HarvestableArray;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonArray;
import java.util.Map;
import p085c.p086a.p087a.p088a.outline;

public class HttpTransaction extends HarvestableArray {
    public String appData;
    public long bytesReceived;
    public long bytesSent;
    public String carrier;
    public int errorCode;
    public String httpMethod;
    public Map<String, String> params;
    public CatPayload payload;
    public String responseBody;
    public int statusCode;
    public Long timestamp;
    public double totalTime;
    public String url;
    public String wanType;

    public JsonArray asJsonArray() {
        JsonArray jsonArray = new JsonArray();
        jsonArray.add(SafeJsonPrimitive.factory(this.url));
        jsonArray.add(SafeJsonPrimitive.factory(this.carrier));
        jsonArray.add(SafeJsonPrimitive.factory(Double.valueOf(this.totalTime)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Integer.valueOf(this.statusCode)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Integer.valueOf(this.errorCode)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(this.bytesSent)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(this.bytesReceived)));
        String str = this.appData;
        jsonArray.add(str == null ? null : SafeJsonPrimitive.factory(str));
        jsonArray.add(SafeJsonPrimitive.factory(this.wanType));
        jsonArray.add(SafeJsonPrimitive.factory(this.httpMethod));
        return jsonArray;
    }

    public String getAppData() {
        return this.appData;
    }

    public long getBytesReceived() {
        return this.bytesReceived;
    }

    public long getBytesSent() {
        return this.bytesSent;
    }

    public String getCarrier() {
        return this.carrier;
    }

    public CatPayload getCatPayload() {
        return this.payload;
    }

    public int getErrorCode() {
        return this.errorCode;
    }

    public String getHttpMethod() {
        return this.httpMethod;
    }

    public Map<String, String> getParams() {
        return this.params;
    }

    public String getResponseBody() {
        return this.responseBody;
    }

    public int getStatusCode() {
        return this.statusCode;
    }

    public Long getTimestamp() {
        return this.timestamp;
    }

    public double getTotalTime() {
        return this.totalTime;
    }

    public String getUrl() {
        return this.url;
    }

    public String getWanType() {
        return this.wanType;
    }

    public void setAppData(String str) {
        this.appData = str;
    }

    public void setBytesReceived(long j) {
        this.bytesReceived = j;
    }

    public void setBytesSent(long j) {
        this.bytesSent = j;
    }

    public void setCarrier(String str) {
        this.carrier = str;
    }

    public void setCatPayload(CatPayload catPayload) {
        this.payload = catPayload;
    }

    public void setErrorCode(int i) {
        this.errorCode = i;
    }

    public void setHttpMethod(String str) {
        this.httpMethod = str;
    }

    public void setParams(Map<String, String> map) {
        this.params = map;
    }

    public void setResponseBody(String str) {
        if (!FeatureFlag.featureEnabled(FeatureFlag.HttpResponseBodyCapture)) {
            return;
        }
        if (str == null || str.isEmpty()) {
            this.responseBody = null;
        } else {
            this.responseBody = str;
        }
    }

    public void setStatusCode(int i) {
        this.statusCode = i;
    }

    public void setTimestamp(Long l) {
        this.timestamp = l;
    }

    public void setTotalTime(double d) {
        this.totalTime = d;
    }

    public void setUrl(String str) {
        this.url = str;
    }

    public void setWanType(String str) {
        this.wanType = str;
    }

    public String toString() {
        StringBuilder a = outline.m2937a("HttpTransaction{url='");
        outline.m2940a(a, this.url, '\'', ", carrier='");
        outline.m2940a(a, this.carrier, '\'', ", wanType='");
        outline.m2940a(a, this.wanType, '\'', ", httpMethod='");
        outline.m2940a(a, this.httpMethod, '\'', ", totalTime=");
        a.append(this.totalTime);
        a.append(", statusCode=");
        a.append(this.statusCode);
        a.append(", errorCode=");
        a.append(this.errorCode);
        a.append(", bytesSent=");
        a.append(this.bytesSent);
        a.append(", bytesReceived=");
        a.append(this.bytesReceived);
        a.append(", appData='");
        outline.m2940a(a, this.appData, '\'', ", responseBody='");
        outline.m2940a(a, this.responseBody, '\'', ", params='");
        a.append(this.params);
        a.append('\'');
        a.append(", timestamp=");
        a.append(this.timestamp);
        a.append('}');
        return a.toString();
    }
}
