package okhttp3.internal.http;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.httpclient.HttpResponseEntityImpl;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.Constants;
import java.io.Closeable;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.ProtocolException;
import java.net.SocketTimeoutException;
import java.security.cert.CertificateException;
import java.util.List;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLPeerUnverifiedException;
import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.connection.RouteException;
import okhttp3.internal.http2.ConnectionShutdownException;
import p250f.p251i.C1892h;
import p250f.p251i._Arrays;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.Regex;

@Instrumented
/* compiled from: RetryAndFollowUpInterceptor.kt */
public final class RetryAndFollowUpInterceptor implements Interceptor {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final int MAX_FOLLOW_UPS = 20;
    public final OkHttpClient client;

    /* compiled from: RetryAndFollowUpInterceptor.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public RetryAndFollowUpInterceptor(OkHttpClient okHttpClient) {
        if (okHttpClient != null) {
            this.client = okHttpClient;
        } else {
            Intrinsics.m5822a("client");
            throw null;
        }
    }

    private final Request buildRedirectRequest(Response response, String str) {
        String header$default;
        HttpUrl resolve;
        RequestBody requestBody = null;
        if (!this.client.followRedirects() || (header$default = Response.header$default(response, "Location", (String) null, 2, (Object) null)) == null || (resolve = response.request().url().resolve(header$default)) == null) {
            return null;
        }
        if (!Intrinsics.m5823a((Object) resolve.scheme(), (Object) response.request().url().scheme()) && !this.client.followSslRedirects()) {
            return null;
        }
        Request.Builder newBuilder = response.request().newBuilder();
        if (HttpMethod.permitsRequestBody(str)) {
            boolean redirectsWithBody = HttpMethod.INSTANCE.redirectsWithBody(str);
            if (HttpMethod.INSTANCE.redirectsToGet(str)) {
                newBuilder.method("GET", (RequestBody) null);
            } else {
                if (redirectsWithBody) {
                    requestBody = response.request().body();
                }
                newBuilder.method(str, requestBody);
            }
            if (!redirectsWithBody) {
                newBuilder.removeHeader(HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER);
                newBuilder.removeHeader("Content-Length");
                newBuilder.removeHeader(Constants.Network.CONTENT_TYPE_HEADER);
            }
        }
        if (!Util.canReuseConnectionFor(response.request().url(), resolve)) {
            newBuilder.removeHeader("Authorization");
        }
        Request.Builder url = newBuilder.url(resolve);
        return !(url instanceof Request.Builder) ? url.build() : OkHttp3Instrumentation.build(url);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:2:0x0003, code lost:
        r1 = r7.getConnection$okhttp();
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final okhttp3.Request followUpRequest(okhttp3.Response r6, okhttp3.internal.connection.Exchange r7) throws java.io.IOException {
        /*
            r5 = this;
            r0 = 0
            if (r7 == 0) goto L_0x000e
            okhttp3.internal.connection.RealConnection r1 = r7.getConnection$okhttp()
            if (r1 == 0) goto L_0x000e
            okhttp3.Route r1 = r1.route()
            goto L_0x000f
        L_0x000e:
            r1 = r0
        L_0x000f:
            int r2 = r6.code()
            okhttp3.Request r3 = r6.request()
            java.lang.String r3 = r3.method()
            r4 = 307(0x133, float:4.3E-43)
            if (r2 == r4) goto L_0x00e7
            r4 = 308(0x134, float:4.32E-43)
            if (r2 == r4) goto L_0x00e7
            r4 = 401(0x191, float:5.62E-43)
            if (r2 == r4) goto L_0x00dc
            r4 = 421(0x1a5, float:5.9E-43)
            if (r2 == r4) goto L_0x00b5
            r7 = 503(0x1f7, float:7.05E-43)
            if (r2 == r7) goto L_0x0099
            r7 = 407(0x197, float:5.7E-43)
            if (r2 == r7) goto L_0x0074
            r7 = 408(0x198, float:5.72E-43)
            if (r2 == r7) goto L_0x0040
            switch(r2) {
                case 300: goto L_0x003b;
                case 301: goto L_0x003b;
                case 302: goto L_0x003b;
                case 303: goto L_0x003b;
                default: goto L_0x003a;
            }
        L_0x003a:
            return r0
        L_0x003b:
            okhttp3.Request r6 = r5.buildRedirectRequest(r6, r3)
            return r6
        L_0x0040:
            okhttp3.OkHttpClient r1 = r5.client
            boolean r1 = r1.retryOnConnectionFailure()
            if (r1 != 0) goto L_0x0049
            return r0
        L_0x0049:
            okhttp3.Request r1 = r6.request()
            okhttp3.RequestBody r1 = r1.body()
            if (r1 == 0) goto L_0x005a
            boolean r1 = r1.isOneShot()
            if (r1 == 0) goto L_0x005a
            return r0
        L_0x005a:
            okhttp3.Response r1 = r6.priorResponse()
            if (r1 == 0) goto L_0x0067
            int r1 = r1.code()
            if (r1 != r7) goto L_0x0067
            return r0
        L_0x0067:
            r7 = 0
            int r7 = r5.retryAfter(r6, r7)
            if (r7 <= 0) goto L_0x006f
            return r0
        L_0x006f:
            okhttp3.Request r6 = r6.request()
            return r6
        L_0x0074:
            if (r1 == 0) goto L_0x0095
            java.net.Proxy r7 = r1.proxy()
            java.net.Proxy$Type r7 = r7.type()
            java.net.Proxy$Type r0 = java.net.Proxy.Type.HTTP
            if (r7 != r0) goto L_0x008d
            okhttp3.OkHttpClient r7 = r5.client
            okhttp3.Authenticator r7 = r7.proxyAuthenticator()
            okhttp3.Request r6 = r7.authenticate(r1, r6)
            return r6
        L_0x008d:
            java.net.ProtocolException r6 = new java.net.ProtocolException
            java.lang.String r7 = "Received HTTP_PROXY_AUTH (407) code while not using proxy"
            r6.<init>(r7)
            throw r6
        L_0x0095:
            p250f.p254l.p256c.Intrinsics.m5820a()
            throw r0
        L_0x0099:
            okhttp3.Response r1 = r6.priorResponse()
            if (r1 == 0) goto L_0x00a6
            int r1 = r1.code()
            if (r1 != r7) goto L_0x00a6
            return r0
        L_0x00a6:
            r7 = 2147483647(0x7fffffff, float:NaN)
            int r7 = r5.retryAfter(r6, r7)
            if (r7 != 0) goto L_0x00b4
            okhttp3.Request r6 = r6.request()
            return r6
        L_0x00b4:
            return r0
        L_0x00b5:
            okhttp3.Request r1 = r6.request()
            okhttp3.RequestBody r1 = r1.body()
            if (r1 == 0) goto L_0x00c6
            boolean r1 = r1.isOneShot()
            if (r1 == 0) goto L_0x00c6
            return r0
        L_0x00c6:
            if (r7 == 0) goto L_0x00db
            boolean r1 = r7.isCoalescedConnection$okhttp()
            if (r1 != 0) goto L_0x00cf
            goto L_0x00db
        L_0x00cf:
            okhttp3.internal.connection.RealConnection r7 = r7.getConnection$okhttp()
            r7.noCoalescedConnections()
            okhttp3.Request r6 = r6.request()
            return r6
        L_0x00db:
            return r0
        L_0x00dc:
            okhttp3.OkHttpClient r7 = r5.client
            okhttp3.Authenticator r7 = r7.authenticator()
            okhttp3.Request r6 = r7.authenticate(r1, r6)
            return r6
        L_0x00e7:
            java.lang.String r7 = "GET"
            boolean r7 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r3, (java.lang.Object) r7)
            r7 = r7 ^ 1
            if (r7 == 0) goto L_0x00fc
            java.lang.String r7 = "HEAD"
            boolean r7 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r3, (java.lang.Object) r7)
            r7 = r7 ^ 1
            if (r7 == 0) goto L_0x00fc
            return r0
        L_0x00fc:
            okhttp3.Request r6 = r5.buildRedirectRequest(r6, r3)
            return r6
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http.RetryAndFollowUpInterceptor.followUpRequest(okhttp3.Response, okhttp3.internal.connection.Exchange):okhttp3.Request");
    }

    private final boolean isRecoverable(IOException iOException, boolean z) {
        if (iOException instanceof ProtocolException) {
            return false;
        }
        if (iOException instanceof InterruptedIOException) {
            if (!(iOException instanceof SocketTimeoutException) || z) {
                return false;
            }
            return true;
        } else if ((!(iOException instanceof SSLHandshakeException) || !(iOException.getCause() instanceof CertificateException)) && !(iOException instanceof SSLPeerUnverifiedException)) {
            return true;
        } else {
            return false;
        }
    }

    private final boolean recover(IOException iOException, RealCall realCall, Request request, boolean z) {
        if (!this.client.retryOnConnectionFailure()) {
            return false;
        }
        if ((!z || !requestIsOneShot(iOException, request)) && isRecoverable(iOException, z) && realCall.retryAfterFailure()) {
            return true;
        }
        return false;
    }

    private final boolean requestIsOneShot(IOException iOException, Request request) {
        RequestBody body = request.body();
        return (body != null && body.isOneShot()) || (iOException instanceof FileNotFoundException);
    }

    private final int retryAfter(Response response, int i) {
        String header$default = Response.header$default(response, "Retry-After", (String) null, 2, (Object) null);
        if (header$default == null) {
            return i;
        }
        if (!new Regex("\\d+").mo9424a(header$default)) {
            return Integer.MAX_VALUE;
        }
        Integer valueOf = Integer.valueOf(header$default);
        Intrinsics.m5821a((Object) valueOf, "Integer.valueOf(header)");
        return valueOf.intValue();
    }

    public Response intercept(Interceptor.Chain chain) throws IOException {
        if (chain != null) {
            RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
            Request request$okhttp = realInterceptorChain.getRequest$okhttp();
            RealCall call$okhttp = realInterceptorChain.getCall$okhttp();
            List list = C1892h.f7579b;
            Response response = null;
            boolean z = true;
            int i = 0;
            while (true) {
                call$okhttp.enterNetworkInterceptorExchange(request$okhttp, z);
                try {
                    if (!call$okhttp.isCanceled()) {
                        Response proceed = realInterceptorChain.proceed(request$okhttp);
                        if (response != null) {
                            Response.Builder newBuilder = !(proceed instanceof Response.Builder) ? proceed.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) proceed);
                            Response.Builder newBuilder2 = !(response instanceof Response.Builder) ? response.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) response);
                            proceed = newBuilder.priorResponse((!(newBuilder2 instanceof Response.Builder) ? newBuilder2.body((ResponseBody) null) : OkHttp3Instrumentation.body(newBuilder2, (ResponseBody) null)).build()).build();
                        }
                        response = proceed;
                        Exchange interceptorScopedExchange$okhttp = call$okhttp.getInterceptorScopedExchange$okhttp();
                        Request followUpRequest = followUpRequest(response, interceptorScopedExchange$okhttp);
                        if (followUpRequest == null) {
                            if (interceptorScopedExchange$okhttp != null && interceptorScopedExchange$okhttp.isDuplex$okhttp()) {
                                call$okhttp.timeoutEarlyExit();
                            }
                            call$okhttp.exitNetworkInterceptorExchange$okhttp(false);
                            return response;
                        }
                        RequestBody body = followUpRequest.body();
                        if (body == null || !body.isOneShot()) {
                            ResponseBody body2 = response.body();
                            if (body2 != null) {
                                Util.closeQuietly((Closeable) body2);
                            }
                            i++;
                            if (i <= 20) {
                                call$okhttp.exitNetworkInterceptorExchange$okhttp(true);
                                request$okhttp = followUpRequest;
                                z = true;
                            } else {
                                throw new ProtocolException("Too many follow-up requests: " + i);
                            }
                        } else {
                            call$okhttp.exitNetworkInterceptorExchange$okhttp(false);
                            return response;
                        }
                    } else {
                        throw new IOException("Canceled");
                    }
                } catch (RouteException e) {
                    if (recover(e.getLastConnectException(), call$okhttp, request$okhttp, false)) {
                        list = _Arrays.m5806a(list, e.getFirstConnectException());
                        call$okhttp.exitNetworkInterceptorExchange$okhttp(true);
                        z = false;
                    } else {
                        throw Util.withSuppressed(e.getFirstConnectException(), list);
                    }
                } catch (IOException e2) {
                    if (recover(e2, call$okhttp, request$okhttp, !(e2 instanceof ConnectionShutdownException))) {
                        list = _Arrays.m5806a(list, e2);
                        call$okhttp.exitNetworkInterceptorExchange$okhttp(true);
                        z = false;
                    } else {
                        throw Util.withSuppressed(e2, list);
                    }
                } catch (Throwable th) {
                    call$okhttp.exitNetworkInterceptorExchange$okhttp(true);
                    throw th;
                }
            }
        } else {
            Intrinsics.m5822a("chain");
            throw null;
        }
    }
}
