package okhttp3.internal.http2;

import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.concurrent.TimeUnit;
import okhttp3.Headers;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http.RequestLine;
import okhttp3.internal.http.StatusLine;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.Sink;
import p262g.Source;

/* compiled from: Http2ExchangeCodec.kt */
public final class Http2ExchangeCodec implements ExchangeCodec {
    public static final String CONNECTION = "connection";
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final String ENCODING = "encoding";
    public static final String HOST = "host";
    public static final List<String> HTTP_2_SKIPPED_REQUEST_HEADERS = Util.immutableListOf(CONNECTION, HOST, KEEP_ALIVE, PROXY_CONNECTION, f7726TE, TRANSFER_ENCODING, ENCODING, UPGRADE, Header.TARGET_METHOD_UTF8, Header.TARGET_PATH_UTF8, Header.TARGET_SCHEME_UTF8, Header.TARGET_AUTHORITY_UTF8);
    public static final List<String> HTTP_2_SKIPPED_RESPONSE_HEADERS = Util.immutableListOf(CONNECTION, HOST, KEEP_ALIVE, PROXY_CONNECTION, f7726TE, TRANSFER_ENCODING, ENCODING, UPGRADE);
    public static final String KEEP_ALIVE = "keep-alive";
    public static final String PROXY_CONNECTION = "proxy-connection";

    /* renamed from: TE */
    public static final String f7726TE = "te";
    public static final String TRANSFER_ENCODING = "transfer-encoding";
    public static final String UPGRADE = "upgrade";
    public volatile boolean canceled;
    public final RealInterceptorChain chain;
    public final RealConnection connection;
    public final Http2Connection http2Connection;
    public final Protocol protocol;
    public volatile Http2Stream stream;

    /* compiled from: Http2ExchangeCodec.kt */
    public static final class Companion {
        public Companion() {
        }

        public final List<Header> http2HeadersList(Request request) {
            if (request != null) {
                Headers headers = request.headers();
                ArrayList arrayList = new ArrayList(headers.size() + 4);
                arrayList.add(new Header(Header.TARGET_METHOD, request.method()));
                arrayList.add(new Header(Header.TARGET_PATH, RequestLine.INSTANCE.requestPath(request.url())));
                String header = request.header(Constants.Network.HOST_HEADER);
                if (header != null) {
                    arrayList.add(new Header(Header.TARGET_AUTHORITY, header));
                }
                arrayList.add(new Header(Header.TARGET_SCHEME, request.url().scheme()));
                int i = 0;
                int size = headers.size();
                while (i < size) {
                    String name = headers.name(i);
                    Locale locale = Locale.US;
                    Intrinsics.m5821a((Object) locale, "Locale.US");
                    if (name != null) {
                        String lowerCase = name.toLowerCase(locale);
                        Intrinsics.m5821a((Object) lowerCase, "(this as java.lang.String).toLowerCase(locale)");
                        if (!Http2ExchangeCodec.HTTP_2_SKIPPED_REQUEST_HEADERS.contains(lowerCase) || (Intrinsics.m5823a((Object) lowerCase, (Object) Http2ExchangeCodec.f7726TE) && Intrinsics.m5823a((Object) headers.value(i), (Object) "trailers"))) {
                            arrayList.add(new Header(lowerCase, headers.value(i)));
                        }
                        i++;
                    } else {
                        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
                    }
                }
                return arrayList;
            }
            Intrinsics.m5822a("request");
            throw null;
        }

        public final Response.Builder readHttp2HeadersList(Headers headers, Protocol protocol) {
            StatusLine statusLine = null;
            if (headers == null) {
                Intrinsics.m5822a("headerBlock");
                throw null;
            } else if (protocol != null) {
                Headers.Builder builder = new Headers.Builder();
                int size = headers.size();
                for (int i = 0; i < size; i++) {
                    String name = headers.name(i);
                    String value = headers.value(i);
                    if (Intrinsics.m5823a((Object) name, (Object) Header.RESPONSE_STATUS_UTF8)) {
                        StatusLine.Companion companion = StatusLine.Companion;
                        statusLine = companion.parse("HTTP/1.1 " + value);
                    } else if (!Http2ExchangeCodec.HTTP_2_SKIPPED_RESPONSE_HEADERS.contains(name)) {
                        builder.addLenient$okhttp(name, value);
                    }
                }
                if (statusLine != null) {
                    return new Response.Builder().protocol(protocol).code(statusLine.code).message(statusLine.message).headers(builder.build());
                }
                throw new ProtocolException("Expected ':status' header not present");
            } else {
                Intrinsics.m5822a("protocol");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Http2ExchangeCodec(OkHttpClient okHttpClient, RealConnection realConnection, RealInterceptorChain realInterceptorChain, Http2Connection http2Connection2) {
        Protocol protocol2;
        if (okHttpClient == null) {
            Intrinsics.m5822a("client");
            throw null;
        } else if (realConnection == null) {
            Intrinsics.m5822a(CONNECTION);
            throw null;
        } else if (realInterceptorChain == null) {
            Intrinsics.m5822a("chain");
            throw null;
        } else if (http2Connection2 != null) {
            this.connection = realConnection;
            this.chain = realInterceptorChain;
            this.http2Connection = http2Connection2;
            if (okHttpClient.protocols().contains(Protocol.H2_PRIOR_KNOWLEDGE)) {
                protocol2 = Protocol.H2_PRIOR_KNOWLEDGE;
            } else {
                protocol2 = Protocol.HTTP_2;
            }
            this.protocol = protocol2;
        } else {
            Intrinsics.m5822a("http2Connection");
            throw null;
        }
    }

    public void cancel() {
        this.canceled = true;
        Http2Stream http2Stream = this.stream;
        if (http2Stream != null) {
            http2Stream.closeLater(ErrorCode.CANCEL);
        }
    }

    public Sink createRequestBody(Request request, long j) {
        if (request != null) {
            Http2Stream http2Stream = this.stream;
            if (http2Stream != null) {
                return http2Stream.getSink();
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("request");
        throw null;
    }

    public void finishRequest() {
        Http2Stream http2Stream = this.stream;
        if (http2Stream != null) {
            http2Stream.getSink().close();
        } else {
            Intrinsics.m5820a();
            throw null;
        }
    }

    public void flushRequest() {
        this.http2Connection.flush();
    }

    public RealConnection getConnection() {
        return this.connection;
    }

    public Source openResponseBodySource(Response response) {
        if (response != null) {
            Http2Stream http2Stream = this.stream;
            if (http2Stream != null) {
                return http2Stream.getSource$okhttp();
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("response");
        throw null;
    }

    public Response.Builder readResponseHeaders(boolean z) {
        Http2Stream http2Stream = this.stream;
        if (http2Stream != null) {
            Response.Builder readHttp2HeadersList = Companion.readHttp2HeadersList(http2Stream.takeHeaders(), this.protocol);
            if (!z || readHttp2HeadersList.getCode$okhttp() != 100) {
                return readHttp2HeadersList;
            }
            return null;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public long reportedContentLength(Response response) {
        if (response == null) {
            Intrinsics.m5822a("response");
            throw null;
        } else if (!HttpHeaders.promisesBody(response)) {
            return 0;
        } else {
            return Util.headersContentLength(response);
        }
    }

    public Headers trailers() {
        Http2Stream http2Stream = this.stream;
        if (http2Stream != null) {
            return http2Stream.trailers();
        }
        Intrinsics.m5820a();
        throw null;
    }

    public void writeRequestHeaders(Request request) {
        if (request == null) {
            Intrinsics.m5822a("request");
            throw null;
        } else if (this.stream == null) {
            this.stream = this.http2Connection.newStream(Companion.http2HeadersList(request), request.body() != null);
            if (this.canceled) {
                Http2Stream http2Stream = this.stream;
                if (http2Stream == null) {
                    Intrinsics.m5820a();
                    throw null;
                } else {
                    http2Stream.closeLater(ErrorCode.CANCEL);
                    throw new IOException("Canceled");
                }
            } else {
                Http2Stream http2Stream2 = this.stream;
                if (http2Stream2 != null) {
                    http2Stream2.readTimeout().timeout((long) this.chain.getReadTimeoutMillis$okhttp(), TimeUnit.MILLISECONDS);
                    Http2Stream http2Stream3 = this.stream;
                    if (http2Stream3 != null) {
                        http2Stream3.writeTimeout().timeout((long) this.chain.getWriteTimeoutMillis$okhttp(), TimeUnit.MILLISECONDS);
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                } else {
                    Intrinsics.m5820a();
                    throw null;
                }
            }
        }
    }
}
