package com.newrelic.agent.android.harvest.crash;

import com.newrelic.agent.android.agentdata.HexAttributes;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.harvest.ApplicationInformation;
import com.newrelic.agent.android.harvest.type.HarvestableObject;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonObject;

public class ApplicationInfo extends HarvestableObject {
    public String applicationBuild = "";
    public String applicationName = "";
    public String applicationVersion = "";
    public String bundleId = "";
    public int processId = 0;

    public ApplicationInfo() {
    }

    public static ApplicationInfo newFromJson(JsonObject jsonObject) {
        ApplicationInfo applicationInfo = new ApplicationInfo();
        applicationInfo.applicationName = jsonObject.get(AnalyticAttribute.APP_NAME_ATTRIBUTE).getAsString();
        applicationInfo.applicationVersion = jsonObject.get(HexAttributes.HEX_ATTR_APP_VERSION).getAsString();
        applicationInfo.applicationBuild = jsonObject.get("appBuild").getAsString();
        applicationInfo.bundleId = jsonObject.get("bundleId").getAsString();
        applicationInfo.processId = jsonObject.get("processId").getAsInt();
        return applicationInfo;
    }

    public JsonObject asJsonObject() {
        JsonObject jsonObject = new JsonObject();
        jsonObject.add(AnalyticAttribute.APP_NAME_ATTRIBUTE, SafeJsonPrimitive.factory(this.applicationName));
        jsonObject.add(HexAttributes.HEX_ATTR_APP_VERSION, SafeJsonPrimitive.factory(this.applicationVersion));
        jsonObject.add("appBuild", SafeJsonPrimitive.factory(this.applicationBuild));
        jsonObject.add("bundleId", SafeJsonPrimitive.factory(this.bundleId));
        jsonObject.add("processId", SafeJsonPrimitive.factory((Number) Integer.valueOf(this.processId)));
        return jsonObject;
    }

    public String getApplicationBuild() {
        return this.applicationBuild;
    }

    public String getApplicationName() {
        return this.applicationName;
    }

    public String getApplicationVersion() {
        return this.applicationVersion;
    }

    public ApplicationInfo(ApplicationInformation applicationInformation) {
        this.applicationName = applicationInformation.getAppName();
        this.applicationVersion = applicationInformation.getAppVersion();
        this.applicationBuild = applicationInformation.getAppBuild();
        this.bundleId = applicationInformation.getPackageId();
    }
}
