package com.newrelic.agent.android.harvest.crash;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.harvest.DeviceInformation;
import com.newrelic.agent.android.harvest.EnvironmentInformation;
import com.newrelic.agent.android.harvest.type.HarvestableObject;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonArray;
import com.newrelic.com.google.gson.JsonElement;
import com.newrelic.com.google.gson.JsonObject;
import java.util.Iterator;

public class DeviceInfo extends HarvestableObject {
    public String OSBuild;
    public String OSVersion;
    public String architecture;
    public String deviceName;
    public String deviceUuid;
    public long[] diskAvailable;
    public long memoryUsage;
    public String modelNumber;
    public String networkStatus;
    public int orientation;
    public String runTime;
    public String screenResolution;

    public DeviceInfo() {
    }

    private JsonArray getDiskAvailableAsJson() {
        JsonArray jsonArray = new JsonArray();
        for (long valueOf : this.diskAvailable) {
            jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(valueOf)));
        }
        return jsonArray;
    }

    public static long[] longArrayFromJsonArray(JsonArray jsonArray) {
        long[] jArr = new long[jsonArray.size()];
        Iterator<JsonElement> it = jsonArray.iterator();
        int i = 0;
        while (it.hasNext()) {
            jArr[i] = it.next().getAsLong();
            i++;
        }
        return jArr;
    }

    public static DeviceInfo newFromJson(JsonObject jsonObject) {
        DeviceInfo deviceInfo = new DeviceInfo();
        deviceInfo.memoryUsage = jsonObject.get("memoryUsage").getAsLong();
        deviceInfo.orientation = jsonObject.get(AnalyticAttribute.GESTURE_ORIENTATION_ATTRIBUTE).getAsInt();
        deviceInfo.networkStatus = jsonObject.get("networkStatus").getAsString();
        deviceInfo.diskAvailable = longArrayFromJsonArray(jsonObject.get("diskAvailable").getAsJsonArray());
        deviceInfo.OSVersion = jsonObject.get(AnalyticAttribute.OS_VERSION_ATTRIBUTE).getAsString();
        deviceInfo.deviceName = jsonObject.get("deviceName").getAsString();
        deviceInfo.OSBuild = jsonObject.get(AnalyticAttribute.OS_BUILD_ATTRIBUTE).getAsString();
        deviceInfo.architecture = jsonObject.get(AnalyticAttribute.ARCHITECTURE_ATTRIBUTE).getAsString();
        deviceInfo.runTime = jsonObject.get(AnalyticAttribute.RUNTIME_ATTRIBUTE).getAsString();
        deviceInfo.modelNumber = jsonObject.get("modelNumber").getAsString();
        deviceInfo.screenResolution = jsonObject.get("screenResolution").getAsString();
        deviceInfo.deviceUuid = jsonObject.get("deviceUuid").getAsString();
        return deviceInfo;
    }

    public JsonObject asJsonObject() {
        JsonObject jsonObject = new JsonObject();
        jsonObject.add("memoryUsage", SafeJsonPrimitive.factory((Number) Long.valueOf(this.memoryUsage)));
        jsonObject.add(AnalyticAttribute.GESTURE_ORIENTATION_ATTRIBUTE, SafeJsonPrimitive.factory((Number) Integer.valueOf(this.orientation)));
        jsonObject.add("networkStatus", SafeJsonPrimitive.factory(this.networkStatus));
        jsonObject.add("diskAvailable", getDiskAvailableAsJson());
        jsonObject.add(AnalyticAttribute.OS_VERSION_ATTRIBUTE, SafeJsonPrimitive.factory(this.OSVersion));
        jsonObject.add("deviceName", SafeJsonPrimitive.factory(this.deviceName));
        jsonObject.add(AnalyticAttribute.OS_BUILD_ATTRIBUTE, SafeJsonPrimitive.factory(this.OSBuild));
        jsonObject.add(AnalyticAttribute.ARCHITECTURE_ATTRIBUTE, SafeJsonPrimitive.factory(this.architecture));
        jsonObject.add(AnalyticAttribute.RUNTIME_ATTRIBUTE, SafeJsonPrimitive.factory(this.runTime));
        jsonObject.add("modelNumber", SafeJsonPrimitive.factory(this.modelNumber));
        jsonObject.add("screenResolution", SafeJsonPrimitive.factory(this.screenResolution));
        jsonObject.add("deviceUuid", SafeJsonPrimitive.factory(this.deviceUuid));
        return jsonObject;
    }

    public DeviceInfo(DeviceInformation deviceInformation, EnvironmentInformation environmentInformation) {
        this.memoryUsage = environmentInformation.getMemoryUsage();
        this.orientation = environmentInformation.getOrientation();
        this.networkStatus = environmentInformation.getNetworkStatus();
        this.diskAvailable = environmentInformation.getDiskAvailable();
        this.OSVersion = deviceInformation.getOsVersion();
        this.deviceName = deviceInformation.getManufacturer();
        this.OSBuild = deviceInformation.getOsBuild();
        this.architecture = deviceInformation.getArchitecture();
        this.modelNumber = deviceInformation.getModel();
        this.screenResolution = deviceInformation.getSize();
        this.deviceUuid = deviceInformation.getDeviceId();
        this.runTime = deviceInformation.getRunTime();
    }
}
