package okhttp3.internal.http2;

import java.io.EOFException;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.SocketTimeoutException;
import java.util.ArrayDeque;
import java.util.List;
import okhttp3.Headers;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.AsyncTimeout;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.Sink;
import p262g.Source;
import p262g.Timeout;

/* compiled from: Http2Stream.kt */
public final class Http2Stream {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final long EMIT_BUFFER_SIZE = 16384;
    public final Http2Connection connection;
    public ErrorCode errorCode;
    public IOException errorException;
    public boolean hasResponseHeaders;
    public final ArrayDeque<Headers> headersQueue;

    /* renamed from: id */
    public final int f7727id;
    public long readBytesAcknowledged;
    public long readBytesTotal;
    public final StreamTimeout readTimeout;
    public final FramingSink sink;
    public final FramingSource source;
    public long writeBytesMaximum;
    public long writeBytesTotal;
    public final StreamTimeout writeTimeout;

    /* compiled from: Http2Stream.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: Http2Stream.kt */
    public final class FramingSource implements Source {
        public boolean closed;
        public boolean finished;
        public final long maxByteCount;
        public final C1948d readBuffer = new C1948d();
        public final C1948d receiveBuffer = new C1948d();
        public Headers trailers;

        public FramingSource(long j, boolean z) {
            this.maxByteCount = j;
            this.finished = z;
        }

        private final void updateConnectionFlowControl(long j) {
            Http2Stream http2Stream = Http2Stream.this;
            if (!Util.assertionsEnabled || !Thread.holdsLock(http2Stream)) {
                Http2Stream.this.getConnection().updateConnectionFlowControl$okhttp(j);
                return;
            }
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(http2Stream);
            throw new AssertionError(a.toString());
        }

        public void close() throws IOException {
            long j;
            synchronized (Http2Stream.this) {
                this.closed = true;
                j = this.readBuffer.f7648c;
                C1948d dVar = this.readBuffer;
                dVar.skip(dVar.f7648c);
                Http2Stream http2Stream = Http2Stream.this;
                if (http2Stream != null) {
                    http2Stream.notifyAll();
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type java.lang.Object");
                }
            }
            if (j > 0) {
                updateConnectionFlowControl(j);
            }
            Http2Stream.this.cancelStreamIfNecessary$okhttp();
        }

        public final boolean getClosed$okhttp() {
            return this.closed;
        }

        public final boolean getFinished$okhttp() {
            return this.finished;
        }

        public final C1948d getReadBuffer() {
            return this.readBuffer;
        }

        public final C1948d getReceiveBuffer() {
            return this.receiveBuffer;
        }

        public final Headers getTrailers() {
            return this.trailers;
        }

        public long read(C1948d dVar, long j) throws IOException {
            Throwable th;
            long j2;
            boolean z;
            long j3;
            if (dVar != null) {
                long j4 = 0;
                if (j >= 0) {
                    while (true) {
                        synchronized (Http2Stream.this) {
                            Http2Stream.this.getReadTimeout$okhttp().enter();
                            try {
                                if (Http2Stream.this.getErrorCode$okhttp() != null) {
                                    th = Http2Stream.this.getErrorException$okhttp();
                                    if (th == null) {
                                        ErrorCode errorCode$okhttp = Http2Stream.this.getErrorCode$okhttp();
                                        if (errorCode$okhttp != null) {
                                            th = new StreamResetException(errorCode$okhttp);
                                        } else {
                                            Intrinsics.m5820a();
                                            throw null;
                                        }
                                    }
                                } else {
                                    th = null;
                                }
                                if (!this.closed) {
                                    if (this.readBuffer.f7648c > j4) {
                                        j3 = this.readBuffer.read(dVar, Math.min(j, this.readBuffer.f7648c));
                                        Http2Stream http2Stream = Http2Stream.this;
                                        http2Stream.setReadBytesTotal$okhttp(http2Stream.getReadBytesTotal() + j3);
                                        long readBytesTotal = Http2Stream.this.getReadBytesTotal() - Http2Stream.this.getReadBytesAcknowledged();
                                        if (th == null && readBytesTotal >= ((long) (Http2Stream.this.getConnection().getOkHttpSettings().getInitialWindowSize() / 2))) {
                                            Http2Stream.this.getConnection().writeWindowUpdateLater$okhttp(Http2Stream.this.getId(), readBytesTotal);
                                            Http2Stream.this.setReadBytesAcknowledged$okhttp(Http2Stream.this.getReadBytesTotal());
                                        }
                                    } else if (this.finished || th != null) {
                                        j3 = -1;
                                    } else {
                                        Http2Stream.this.waitForIo$okhttp();
                                        z = true;
                                        j2 = -1;
                                    }
                                    j2 = j3;
                                    z = false;
                                } else {
                                    throw new IOException("stream closed");
                                }
                            } finally {
                                Http2Stream.this.getReadTimeout$okhttp().exitAndThrowIfTimedOut();
                            }
                        }
                        if (z) {
                            j4 = 0;
                        } else if (j2 != -1) {
                            updateConnectionFlowControl(j2);
                            return j2;
                        } else if (th == null) {
                            return -1;
                        } else {
                            throw th;
                        }
                    }
                } else {
                    throw new IllegalArgumentException(outline.m2931a("byteCount < 0: ", j).toString());
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }

        public final void receive$okhttp(BufferedSource gVar, long j) throws IOException {
            boolean z;
            boolean z2;
            boolean z3;
            long j2;
            if (gVar != null) {
                Http2Stream http2Stream = Http2Stream.this;
                if (!Util.assertionsEnabled || !Thread.holdsLock(http2Stream)) {
                    while (j > 0) {
                        synchronized (Http2Stream.this) {
                            z = this.finished;
                            z2 = true;
                            z3 = this.readBuffer.f7648c + j > this.maxByteCount;
                        }
                        if (z3) {
                            gVar.skip(j);
                            Http2Stream.this.closeLater(ErrorCode.FLOW_CONTROL_ERROR);
                            return;
                        } else if (z) {
                            gVar.skip(j);
                            return;
                        } else {
                            long read = gVar.read(this.receiveBuffer, j);
                            if (read != -1) {
                                j -= read;
                                synchronized (Http2Stream.this) {
                                    if (this.closed) {
                                        j2 = this.receiveBuffer.f7648c;
                                        C1948d dVar = this.receiveBuffer;
                                        dVar.skip(dVar.f7648c);
                                    } else {
                                        if (this.readBuffer.f7648c != 0) {
                                            z2 = false;
                                        }
                                        this.readBuffer.mo9463a((Source) this.receiveBuffer);
                                        if (z2) {
                                            Http2Stream http2Stream2 = Http2Stream.this;
                                            if (http2Stream2 != null) {
                                                http2Stream2.notifyAll();
                                            } else {
                                                throw new TypeCastException("null cannot be cast to non-null type java.lang.Object");
                                            }
                                        }
                                        j2 = 0;
                                    }
                                }
                                if (j2 > 0) {
                                    updateConnectionFlowControl(j2);
                                }
                            } else {
                                throw new EOFException();
                            }
                        }
                    }
                    return;
                }
                StringBuilder a = outline.m2937a("Thread ");
                Thread currentThread = Thread.currentThread();
                Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
                a.append(currentThread.getName());
                a.append(" MUST NOT hold lock on ");
                a.append(http2Stream);
                throw new AssertionError(a.toString());
            }
            Intrinsics.m5822a("source");
            throw null;
        }

        public final void setClosed$okhttp(boolean z) {
            this.closed = z;
        }

        public final void setFinished$okhttp(boolean z) {
            this.finished = z;
        }

        public final void setTrailers(Headers headers) {
            this.trailers = headers;
        }

        public Timeout timeout() {
            return Http2Stream.this.getReadTimeout$okhttp();
        }
    }

    /* compiled from: Http2Stream.kt */
    public final class StreamTimeout extends AsyncTimeout {
        public StreamTimeout() {
        }

        public final void exitAndThrowIfTimedOut() throws IOException {
            if (exit()) {
                throw newTimeoutException((IOException) null);
            }
        }

        public IOException newTimeoutException(IOException iOException) {
            SocketTimeoutException socketTimeoutException = new SocketTimeoutException("timeout");
            if (iOException != null) {
                socketTimeoutException.initCause(iOException);
            }
            return socketTimeoutException;
        }

        public void timedOut() {
            Http2Stream.this.closeLater(ErrorCode.CANCEL);
            Http2Stream.this.getConnection().sendDegradedPingLater$okhttp();
        }
    }

    public Http2Stream(int i, Http2Connection http2Connection, boolean z, boolean z2, Headers headers) {
        if (http2Connection != null) {
            this.f7727id = i;
            this.connection = http2Connection;
            this.writeBytesMaximum = (long) http2Connection.getPeerSettings().getInitialWindowSize();
            this.headersQueue = new ArrayDeque<>();
            this.source = new FramingSource((long) this.connection.getOkHttpSettings().getInitialWindowSize(), z2);
            this.sink = new FramingSink(z);
            this.readTimeout = new StreamTimeout();
            this.writeTimeout = new StreamTimeout();
            if (headers != null) {
                if (!isLocallyInitiated()) {
                    this.headersQueue.add(headers);
                    return;
                }
                throw new IllegalStateException("locally-initiated streams shouldn't have headers yet".toString());
            } else if (!isLocallyInitiated()) {
                throw new IllegalStateException("remotely-initiated streams should have headers".toString());
            }
        } else {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        }
    }

    private final boolean closeInternal(ErrorCode errorCode2, IOException iOException) {
        if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            synchronized (this) {
                if (this.errorCode != null) {
                    return false;
                }
                if (this.source.getFinished$okhttp() && this.sink.getFinished()) {
                    return false;
                }
                this.errorCode = errorCode2;
                this.errorException = iOException;
                notifyAll();
                this.connection.removeStream$okhttp(this.f7727id);
                return true;
            }
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST NOT hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    public final void addBytesToWriteWindow(long j) {
        this.writeBytesMaximum += j;
        if (j > 0) {
            notifyAll();
        }
    }

    public final void cancelStreamIfNecessary$okhttp() throws IOException {
        boolean z;
        boolean isOpen;
        if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            synchronized (this) {
                z = !this.source.getFinished$okhttp() && this.source.getClosed$okhttp() && (this.sink.getFinished() || this.sink.getClosed());
                isOpen = isOpen();
            }
            if (z) {
                close(ErrorCode.CANCEL, (IOException) null);
            } else if (!isOpen) {
                this.connection.removeStream$okhttp(this.f7727id);
            }
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    public final void checkOutNotClosed$okhttp() throws IOException {
        if (this.sink.getClosed()) {
            throw new IOException("stream closed");
        } else if (this.sink.getFinished()) {
            throw new IOException("stream finished");
        } else if (this.errorCode != null) {
            Throwable th = this.errorException;
            if (th == null) {
                ErrorCode errorCode2 = this.errorCode;
                if (errorCode2 == null) {
                    Intrinsics.m5820a();
                    throw null;
                }
                th = new StreamResetException(errorCode2);
            }
            throw th;
        }
    }

    public final void close(ErrorCode errorCode2, IOException iOException) throws IOException {
        if (errorCode2 == null) {
            Intrinsics.m5822a("rstStatusCode");
            throw null;
        } else if (closeInternal(errorCode2, iOException)) {
            this.connection.writeSynReset$okhttp(this.f7727id, errorCode2);
        }
    }

    public final void closeLater(ErrorCode errorCode2) {
        if (errorCode2 == null) {
            Intrinsics.m5822a("errorCode");
            throw null;
        } else if (closeInternal(errorCode2, (IOException) null)) {
            this.connection.writeSynResetLater$okhttp(this.f7727id, errorCode2);
        }
    }

    public final void enqueueTrailers(Headers headers) {
        if (headers != null) {
            synchronized (this) {
                boolean z = true;
                if (!this.sink.getFinished()) {
                    if (headers.size() == 0) {
                        z = false;
                    }
                    if (z) {
                        this.sink.setTrailers(headers);
                    } else {
                        throw new IllegalArgumentException("trailers.size() == 0".toString());
                    }
                } else {
                    throw new IllegalStateException("already finished".toString());
                }
            }
            return;
        }
        Intrinsics.m5822a("trailers");
        throw null;
    }

    public final Http2Connection getConnection() {
        return this.connection;
    }

    public final synchronized ErrorCode getErrorCode$okhttp() {
        return this.errorCode;
    }

    public final IOException getErrorException$okhttp() {
        return this.errorException;
    }

    public final int getId() {
        return this.f7727id;
    }

    public final long getReadBytesAcknowledged() {
        return this.readBytesAcknowledged;
    }

    public final long getReadBytesTotal() {
        return this.readBytesTotal;
    }

    public final StreamTimeout getReadTimeout$okhttp() {
        return this.readTimeout;
    }

    public final Sink getSink() {
        synchronized (this) {
            if (!(this.hasResponseHeaders || isLocallyInitiated())) {
                throw new IllegalStateException("reply before requesting the sink".toString());
            }
        }
        return this.sink;
    }

    public final FramingSink getSink$okhttp() {
        return this.sink;
    }

    public final Source getSource() {
        return this.source;
    }

    public final FramingSource getSource$okhttp() {
        return this.source;
    }

    public final long getWriteBytesMaximum() {
        return this.writeBytesMaximum;
    }

    public final long getWriteBytesTotal() {
        return this.writeBytesTotal;
    }

    public final StreamTimeout getWriteTimeout$okhttp() {
        return this.writeTimeout;
    }

    public final boolean isLocallyInitiated() {
        if (this.connection.getClient$okhttp() == ((this.f7727id & 1) == 1)) {
            return true;
        }
        return false;
    }

    public final synchronized boolean isOpen() {
        if (this.errorCode != null) {
            return false;
        }
        if ((this.source.getFinished$okhttp() || this.source.getClosed$okhttp()) && ((this.sink.getFinished() || this.sink.getClosed()) && this.hasResponseHeaders)) {
            return false;
        }
        return true;
    }

    public final Timeout readTimeout() {
        return this.readTimeout;
    }

    public final void receiveData(BufferedSource gVar, int i) throws IOException {
        if (gVar == null) {
            Intrinsics.m5822a("source");
            throw null;
        } else if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            this.source.receive$okhttp(gVar, (long) i);
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x004d  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void receiveHeaders(okhttp3.Headers r3, boolean r4) {
        /*
            r2 = this;
            if (r3 == 0) goto L_0x0067
            boolean r0 = okhttp3.internal.Util.assertionsEnabled
            if (r0 == 0) goto L_0x0035
            boolean r0 = java.lang.Thread.holdsLock(r2)
            if (r0 != 0) goto L_0x000d
            goto L_0x0035
        L_0x000d:
            java.lang.AssertionError r3 = new java.lang.AssertionError
            java.lang.String r4 = "Thread "
            java.lang.StringBuilder r4 = p085c.p086a.p087a.p088a.outline.m2937a(r4)
            java.lang.Thread r0 = java.lang.Thread.currentThread()
            java.lang.String r1 = "Thread.currentThread()"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r0, (java.lang.String) r1)
            java.lang.String r0 = r0.getName()
            r4.append(r0)
            java.lang.String r0 = " MUST NOT hold lock on "
            r4.append(r0)
            r4.append(r2)
            java.lang.String r4 = r4.toString()
            r3.<init>(r4)
            throw r3
        L_0x0035:
            monitor-enter(r2)
            boolean r0 = r2.hasResponseHeaders     // Catch:{ all -> 0x0064 }
            r1 = 1
            if (r0 == 0) goto L_0x0044
            if (r4 != 0) goto L_0x003e
            goto L_0x0044
        L_0x003e:
            okhttp3.internal.http2.Http2Stream$FramingSource r0 = r2.source     // Catch:{ all -> 0x0064 }
            r0.setTrailers(r3)     // Catch:{ all -> 0x0064 }
            goto L_0x004b
        L_0x0044:
            r2.hasResponseHeaders = r1     // Catch:{ all -> 0x0064 }
            java.util.ArrayDeque<okhttp3.Headers> r0 = r2.headersQueue     // Catch:{ all -> 0x0064 }
            r0.add(r3)     // Catch:{ all -> 0x0064 }
        L_0x004b:
            if (r4 == 0) goto L_0x0052
            okhttp3.internal.http2.Http2Stream$FramingSource r3 = r2.source     // Catch:{ all -> 0x0064 }
            r3.setFinished$okhttp(r1)     // Catch:{ all -> 0x0064 }
        L_0x0052:
            boolean r3 = r2.isOpen()     // Catch:{ all -> 0x0064 }
            r2.notifyAll()     // Catch:{ all -> 0x0064 }
            monitor-exit(r2)
            if (r3 != 0) goto L_0x0063
            okhttp3.internal.http2.Http2Connection r3 = r2.connection
            int r4 = r2.f7727id
            r3.removeStream$okhttp(r4)
        L_0x0063:
            return
        L_0x0064:
            r3 = move-exception
            monitor-exit(r2)
            throw r3
        L_0x0067:
            java.lang.String r3 = "headers"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r3)
            r3 = 0
            throw r3
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Stream.receiveHeaders(okhttp3.Headers, boolean):void");
    }

    public final synchronized void receiveRstStream(ErrorCode errorCode2) {
        if (errorCode2 == null) {
            Intrinsics.m5822a("errorCode");
            throw null;
        } else if (this.errorCode == null) {
            this.errorCode = errorCode2;
            notifyAll();
        }
    }

    public final void setErrorCode$okhttp(ErrorCode errorCode2) {
        this.errorCode = errorCode2;
    }

    public final void setErrorException$okhttp(IOException iOException) {
        this.errorException = iOException;
    }

    public final void setReadBytesAcknowledged$okhttp(long j) {
        this.readBytesAcknowledged = j;
    }

    public final void setReadBytesTotal$okhttp(long j) {
        this.readBytesTotal = j;
    }

    public final void setWriteBytesMaximum$okhttp(long j) {
        this.writeBytesMaximum = j;
    }

    public final void setWriteBytesTotal$okhttp(long j) {
        this.writeBytesTotal = j;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:26:0x0047, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0048, code lost:
        r2.readTimeout.exitAndThrowIfTimedOut();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x004d, code lost:
        throw r0;
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized okhttp3.Headers takeHeaders() throws java.io.IOException {
        /*
            r2 = this;
            monitor-enter(r2)
            okhttp3.internal.http2.Http2Stream$StreamTimeout r0 = r2.readTimeout     // Catch:{ all -> 0x004e }
            r0.enter()     // Catch:{ all -> 0x004e }
        L_0x0006:
            java.util.ArrayDeque<okhttp3.Headers> r0 = r2.headersQueue     // Catch:{ all -> 0x0047 }
            boolean r0 = r0.isEmpty()     // Catch:{ all -> 0x0047 }
            if (r0 == 0) goto L_0x0016
            okhttp3.internal.http2.ErrorCode r0 = r2.errorCode     // Catch:{ all -> 0x0047 }
            if (r0 != 0) goto L_0x0016
            r2.waitForIo$okhttp()     // Catch:{ all -> 0x0047 }
            goto L_0x0006
        L_0x0016:
            okhttp3.internal.http2.Http2Stream$StreamTimeout r0 = r2.readTimeout     // Catch:{ all -> 0x004e }
            r0.exitAndThrowIfTimedOut()     // Catch:{ all -> 0x004e }
            java.util.ArrayDeque<okhttp3.Headers> r0 = r2.headersQueue     // Catch:{ all -> 0x004e }
            boolean r0 = r0.isEmpty()     // Catch:{ all -> 0x004e }
            r0 = r0 ^ 1
            if (r0 == 0) goto L_0x0034
            java.util.ArrayDeque<okhttp3.Headers> r0 = r2.headersQueue     // Catch:{ all -> 0x004e }
            java.lang.Object r0 = r0.removeFirst()     // Catch:{ all -> 0x004e }
            java.lang.String r1 = "headersQueue.removeFirst()"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r0, (java.lang.String) r1)     // Catch:{ all -> 0x004e }
            okhttp3.Headers r0 = (okhttp3.Headers) r0     // Catch:{ all -> 0x004e }
            monitor-exit(r2)
            return r0
        L_0x0034:
            java.io.IOException r0 = r2.errorException     // Catch:{ all -> 0x004e }
            if (r0 != 0) goto L_0x0046
            okhttp3.internal.http2.StreamResetException r0 = new okhttp3.internal.http2.StreamResetException     // Catch:{ all -> 0x004e }
            okhttp3.internal.http2.ErrorCode r1 = r2.errorCode     // Catch:{ all -> 0x004e }
            if (r1 != 0) goto L_0x0043
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x004e }
            r0 = 0
            throw r0
        L_0x0043:
            r0.<init>(r1)     // Catch:{ all -> 0x004e }
        L_0x0046:
            throw r0     // Catch:{ all -> 0x004e }
        L_0x0047:
            r0 = move-exception
            okhttp3.internal.http2.Http2Stream$StreamTimeout r1 = r2.readTimeout     // Catch:{ all -> 0x004e }
            r1.exitAndThrowIfTimedOut()     // Catch:{ all -> 0x004e }
            throw r0     // Catch:{ all -> 0x004e }
        L_0x004e:
            r0 = move-exception
            monitor-exit(r2)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Stream.takeHeaders():okhttp3.Headers");
    }

    public final synchronized Headers trailers() throws IOException {
        Headers trailers;
        if (this.errorCode != null) {
            Throwable th = this.errorException;
            if (th == null) {
                ErrorCode errorCode2 = this.errorCode;
                if (errorCode2 == null) {
                    Intrinsics.m5820a();
                    throw null;
                }
                th = new StreamResetException(errorCode2);
            }
            throw th;
        }
        if (this.source.getFinished$okhttp() && this.source.getReceiveBuffer().mo9501k() && this.source.getReadBuffer().mo9501k()) {
            trailers = this.source.getTrailers();
            if (trailers == null) {
                trailers = Util.EMPTY_HEADERS;
            }
        } else {
            throw new IllegalStateException("too early; can't read the trailers yet".toString());
        }
        return trailers;
    }

    public final void waitForIo$okhttp() throws InterruptedIOException {
        try {
            wait();
        } catch (InterruptedException unused) {
            Thread.currentThread().interrupt();
            throw new InterruptedIOException();
        }
    }

    public final void writeHeaders(List<Header> list, boolean z, boolean z2) throws IOException {
        boolean z3;
        if (list == null) {
            Intrinsics.m5822a("responseHeaders");
            throw null;
        } else if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            synchronized (this) {
                z3 = true;
                this.hasResponseHeaders = true;
                if (z) {
                    this.sink.setFinished(true);
                }
            }
            if (!z2) {
                synchronized (this.connection) {
                    if (this.connection.getWriteBytesTotal() < this.connection.getWriteBytesMaximum()) {
                        z3 = false;
                    }
                }
                z2 = z3;
            }
            this.connection.writeHeaders$okhttp(this.f7727id, z, list);
            if (z2) {
                this.connection.flush();
            }
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    public final Timeout writeTimeout() {
        return this.writeTimeout;
    }

    /* compiled from: Http2Stream.kt */
    public final class FramingSink implements Sink {
        public boolean closed;
        public boolean finished;
        public final C1948d sendBuffer;
        public Headers trailers;

        public FramingSink(boolean z) {
            this.finished = z;
            this.sendBuffer = new C1948d();
        }

        /* JADX INFO: finally extract failed */
        private final void emitFrame(boolean z) throws IOException {
            long min;
            boolean z2;
            synchronized (Http2Stream.this) {
                Http2Stream.this.getWriteTimeout$okhttp().enter();
                while (Http2Stream.this.getWriteBytesTotal() >= Http2Stream.this.getWriteBytesMaximum() && !this.finished && !this.closed && Http2Stream.this.getErrorCode$okhttp() == null) {
                    try {
                        Http2Stream.this.waitForIo$okhttp();
                    } catch (Throwable th) {
                        Http2Stream.this.getWriteTimeout$okhttp().exitAndThrowIfTimedOut();
                        throw th;
                    }
                }
                Http2Stream.this.getWriteTimeout$okhttp().exitAndThrowIfTimedOut();
                Http2Stream.this.checkOutNotClosed$okhttp();
                min = Math.min(Http2Stream.this.getWriteBytesMaximum() - Http2Stream.this.getWriteBytesTotal(), this.sendBuffer.f7648c);
                Http2Stream http2Stream = Http2Stream.this;
                http2Stream.setWriteBytesTotal$okhttp(http2Stream.getWriteBytesTotal() + min);
                z2 = z && min == this.sendBuffer.f7648c && Http2Stream.this.getErrorCode$okhttp() == null;
            }
            Http2Stream.this.getWriteTimeout$okhttp().enter();
            try {
                Http2Stream.this.getConnection().writeData(Http2Stream.this.getId(), z2, this.sendBuffer, min);
            } finally {
                Http2Stream.this.getWriteTimeout$okhttp().exitAndThrowIfTimedOut();
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:21:0x0054, code lost:
            if (r10.this$0.getSink$okhttp().finished != false) goto L_0x00b8;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:23:0x005e, code lost:
            if (r10.sendBuffer.f7648c <= 0) goto L_0x0062;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:24:0x0060, code lost:
            r0 = true;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:25:0x0062, code lost:
            r0 = false;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:0x0065, code lost:
            if (r10.trailers == null) goto L_0x0069;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:28:0x0067, code lost:
            r4 = true;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:29:0x0069, code lost:
            r4 = false;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:30:0x006a, code lost:
            if (r4 == false) goto L_0x0095;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:32:0x0072, code lost:
            if (r10.sendBuffer.f7648c <= 0) goto L_0x0078;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:33:0x0074, code lost:
            emitFrame(false);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:34:0x0078, code lost:
            r0 = r10.this$0.getConnection();
            r2 = r10.this$0.getId();
            r4 = r10.trailers;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:35:0x0086, code lost:
            if (r4 == null) goto L_0x0090;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:36:0x0088, code lost:
            r0.writeHeaders$okhttp(r2, r1, okhttp3.internal.Util.toHeaderList(r4));
         */
        /* JADX WARNING: Code restructure failed: missing block: B:37:0x0090, code lost:
            p250f.p254l.p256c.Intrinsics.m5820a();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:38:0x0094, code lost:
            throw null;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:39:0x0095, code lost:
            if (r0 == false) goto L_0x00a3;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:41:0x009d, code lost:
            if (r10.sendBuffer.f7648c <= 0) goto L_0x00b8;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:42:0x009f, code lost:
            emitFrame(true);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:43:0x00a3, code lost:
            if (r1 == false) goto L_0x00b8;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:44:0x00a5, code lost:
            r10.this$0.getConnection().writeData(r10.this$0.getId(), true, (p262g.C1948d) null, 0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:45:0x00b8, code lost:
            r0 = r10.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:46:0x00ba, code lost:
            monitor-enter(r0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:48:?, code lost:
            r10.closed = true;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:49:0x00bd, code lost:
            monitor-exit(r0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:50:0x00be, code lost:
            r10.this$0.getConnection().flush();
            r10.this$0.cancelStreamIfNecessary$okhttp();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:51:0x00cc, code lost:
            return;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public void close() throws java.io.IOException {
            /*
                r10 = this;
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                boolean r1 = okhttp3.internal.Util.assertionsEnabled
                if (r1 == 0) goto L_0x0035
                boolean r1 = java.lang.Thread.holdsLock(r0)
                if (r1 != 0) goto L_0x000d
                goto L_0x0035
            L_0x000d:
                java.lang.AssertionError r1 = new java.lang.AssertionError
                java.lang.String r2 = "Thread "
                java.lang.StringBuilder r2 = p085c.p086a.p087a.p088a.outline.m2937a(r2)
                java.lang.Thread r3 = java.lang.Thread.currentThread()
                java.lang.String r4 = "Thread.currentThread()"
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r3, (java.lang.String) r4)
                java.lang.String r3 = r3.getName()
                r2.append(r3)
                java.lang.String r3 = " MUST NOT hold lock on "
                r2.append(r3)
                r2.append(r0)
                java.lang.String r0 = r2.toString()
                r1.<init>(r0)
                throw r1
            L_0x0035:
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                monitor-enter(r0)
                boolean r1 = r10.closed     // Catch:{ all -> 0x00d0 }
                if (r1 == 0) goto L_0x003e
                monitor-exit(r0)
                return
            L_0x003e:
                okhttp3.internal.http2.Http2Stream r1 = okhttp3.internal.http2.Http2Stream.this     // Catch:{ all -> 0x00d0 }
                okhttp3.internal.http2.ErrorCode r1 = r1.getErrorCode$okhttp()     // Catch:{ all -> 0x00d0 }
                r2 = 0
                r3 = 1
                if (r1 != 0) goto L_0x004a
                r1 = 1
                goto L_0x004b
            L_0x004a:
                r1 = 0
            L_0x004b:
                monitor-exit(r0)
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                okhttp3.internal.http2.Http2Stream$FramingSink r0 = r0.getSink$okhttp()
                boolean r0 = r0.finished
                if (r0 != 0) goto L_0x00b8
                g.d r0 = r10.sendBuffer
                long r4 = r0.f7648c
                r6 = 0
                int r0 = (r4 > r6 ? 1 : (r4 == r6 ? 0 : -1))
                if (r0 <= 0) goto L_0x0062
                r0 = 1
                goto L_0x0063
            L_0x0062:
                r0 = 0
            L_0x0063:
                okhttp3.Headers r4 = r10.trailers
                if (r4 == 0) goto L_0x0069
                r4 = 1
                goto L_0x006a
            L_0x0069:
                r4 = 0
            L_0x006a:
                if (r4 == 0) goto L_0x0095
            L_0x006c:
                g.d r0 = r10.sendBuffer
                long r4 = r0.f7648c
                int r0 = (r4 > r6 ? 1 : (r4 == r6 ? 0 : -1))
                if (r0 <= 0) goto L_0x0078
                r10.emitFrame(r2)
                goto L_0x006c
            L_0x0078:
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                okhttp3.internal.http2.Http2Connection r0 = r0.getConnection()
                okhttp3.internal.http2.Http2Stream r2 = okhttp3.internal.http2.Http2Stream.this
                int r2 = r2.getId()
                okhttp3.Headers r4 = r10.trailers
                if (r4 == 0) goto L_0x0090
                java.util.List r4 = okhttp3.internal.Util.toHeaderList(r4)
                r0.writeHeaders$okhttp(r2, r1, r4)
                goto L_0x00b8
            L_0x0090:
                p250f.p254l.p256c.Intrinsics.m5820a()
                r0 = 0
                throw r0
            L_0x0095:
                if (r0 == 0) goto L_0x00a3
            L_0x0097:
                g.d r0 = r10.sendBuffer
                long r0 = r0.f7648c
                int r2 = (r0 > r6 ? 1 : (r0 == r6 ? 0 : -1))
                if (r2 <= 0) goto L_0x00b8
                r10.emitFrame(r3)
                goto L_0x0097
            L_0x00a3:
                if (r1 == 0) goto L_0x00b8
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                okhttp3.internal.http2.Http2Connection r4 = r0.getConnection()
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                int r5 = r0.getId()
                r6 = 1
                r7 = 0
                r8 = 0
                r4.writeData(r5, r6, r7, r8)
            L_0x00b8:
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                monitor-enter(r0)
                r10.closed = r3     // Catch:{ all -> 0x00cd }
                monitor-exit(r0)
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                okhttp3.internal.http2.Http2Connection r0 = r0.getConnection()
                r0.flush()
                okhttp3.internal.http2.Http2Stream r0 = okhttp3.internal.http2.Http2Stream.this
                r0.cancelStreamIfNecessary$okhttp()
                return
            L_0x00cd:
                r1 = move-exception
                monitor-exit(r0)
                throw r1
            L_0x00d0:
                r1 = move-exception
                monitor-exit(r0)
                throw r1
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Stream.FramingSink.close():void");
        }

        public void flush() throws IOException {
            Http2Stream http2Stream = Http2Stream.this;
            if (!Util.assertionsEnabled || !Thread.holdsLock(http2Stream)) {
                synchronized (Http2Stream.this) {
                    Http2Stream.this.checkOutNotClosed$okhttp();
                }
                while (this.sendBuffer.f7648c > 0) {
                    emitFrame(false);
                    Http2Stream.this.getConnection().flush();
                }
                return;
            }
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(http2Stream);
            throw new AssertionError(a.toString());
        }

        public final boolean getClosed() {
            return this.closed;
        }

        public final boolean getFinished() {
            return this.finished;
        }

        public final Headers getTrailers() {
            return this.trailers;
        }

        public final void setClosed(boolean z) {
            this.closed = z;
        }

        public final void setFinished(boolean z) {
            this.finished = z;
        }

        public final void setTrailers(Headers headers) {
            this.trailers = headers;
        }

        public Timeout timeout() {
            return Http2Stream.this.getWriteTimeout$okhttp();
        }

        public void write(C1948d dVar, long j) throws IOException {
            if (dVar != null) {
                Http2Stream http2Stream = Http2Stream.this;
                if (!Util.assertionsEnabled || !Thread.holdsLock(http2Stream)) {
                    this.sendBuffer.write(dVar, j);
                    while (this.sendBuffer.f7648c >= Http2Stream.EMIT_BUFFER_SIZE) {
                        emitFrame(false);
                    }
                    return;
                }
                StringBuilder a = outline.m2937a("Thread ");
                Thread currentThread = Thread.currentThread();
                Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
                a.append(currentThread.getName());
                a.append(" MUST NOT hold lock on ");
                a.append(http2Stream);
                throw new AssertionError(a.toString());
            }
            Intrinsics.m5822a("source");
            throw null;
        }

        /* JADX INFO: this call moved to the top of the method (can break code semantics) */
        public /* synthetic */ FramingSink(Http2Stream http2Stream, boolean z, int i, DefaultConstructorMarker fVar) {
            this((i & 1) != 0 ? false : z);
        }
    }
}
