package com.newrelic.agent.android.harvest.crash;

import com.newrelic.agent.android.agentdata.HexAttributes;
import com.newrelic.agent.android.harvest.type.HarvestableObject;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonArray;
import com.newrelic.com.google.gson.JsonElement;
import com.newrelic.com.google.gson.JsonObject;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class ThreadInfo extends HarvestableObject {
    public boolean crashed;
    public StackTraceElement[] stackTrace;
    public String state;
    public long threadId;
    public String threadName;
    public int threadPriority;

    public ThreadInfo() {
    }

    public static List<ThreadInfo> extractThreads(Throwable th) {
        ArrayList arrayList = new ArrayList();
        ThreadInfo threadInfo = new ThreadInfo(th);
        long threadId2 = threadInfo.getThreadId();
        arrayList.add(threadInfo);
        for (Map.Entry next : Thread.getAllStackTraces().entrySet()) {
            Thread thread = (Thread) next.getKey();
            StackTraceElement[] stackTraceElementArr = (StackTraceElement[]) next.getValue();
            if (thread.getId() != threadId2) {
                arrayList.add(new ThreadInfo(thread, stackTraceElementArr));
            }
        }
        return arrayList;
    }

    private JsonArray getStackAsJson() {
        JsonArray jsonArray = new JsonArray();
        for (StackTraceElement stackTraceElement : this.stackTrace) {
            JsonObject jsonObject = new JsonObject();
            if (stackTraceElement.getFileName() != null) {
                jsonObject.add(HexAttributes.HEX_ATTR_FILENAME, SafeJsonPrimitive.factory(stackTraceElement.getFileName()));
            }
            jsonObject.add(HexAttributes.HEX_ATTR_CLASS_NAME, SafeJsonPrimitive.factory(stackTraceElement.getClassName()));
            jsonObject.add(HexAttributes.HEX_ATTR_METHOD_NAME, SafeJsonPrimitive.factory(stackTraceElement.getMethodName()));
            jsonObject.add(HexAttributes.HEX_ATTR_LINE_NUMBER, SafeJsonPrimitive.factory((Number) Integer.valueOf(stackTraceElement.getLineNumber())));
            jsonArray.add(jsonObject);
        }
        return jsonArray;
    }

    public static ThreadInfo newFromJson(JsonObject jsonObject) {
        ThreadInfo threadInfo = new ThreadInfo();
        threadInfo.crashed = jsonObject.get(HexAttributes.HEX_ATTR_THREAD_CRASHED).getAsBoolean();
        threadInfo.state = jsonObject.get(HexAttributes.HEX_ATTR_THREAD_STATE).getAsString();
        threadInfo.threadId = jsonObject.get(HexAttributes.HEX_ATTR_THREAD_NUMBER).getAsLong();
        threadInfo.threadName = jsonObject.get(HexAttributes.HEX_ATTR_THREAD_ID).getAsString();
        threadInfo.threadPriority = jsonObject.get(HexAttributes.HEX_ATTR_THREAD_PRI).getAsInt();
        threadInfo.stackTrace = stackTraceFromJson(jsonObject.get("stack").getAsJsonArray());
        return threadInfo;
    }

    public static List<ThreadInfo> newListFromJson(JsonArray jsonArray) {
        ArrayList arrayList = new ArrayList();
        Iterator<JsonElement> it = jsonArray.iterator();
        while (it.hasNext()) {
            arrayList.add(newFromJson(it.next().getAsJsonObject()));
        }
        return arrayList;
    }

    public static StackTraceElement[] stackTraceFromJson(JsonArray jsonArray) {
        StackTraceElement[] stackTraceElementArr = new StackTraceElement[jsonArray.size()];
        Iterator<JsonElement> it = jsonArray.iterator();
        int i = 0;
        while (it.hasNext()) {
            JsonElement next = it.next();
            stackTraceElementArr[i] = new StackTraceElement(next.getAsJsonObject().get(HexAttributes.HEX_ATTR_CLASS_NAME).getAsString(), next.getAsJsonObject().get(HexAttributes.HEX_ATTR_METHOD_NAME).getAsString(), next.getAsJsonObject().get(HexAttributes.HEX_ATTR_FILENAME) != null ? next.getAsJsonObject().get(HexAttributes.HEX_ATTR_FILENAME).getAsString() : "unknown", next.getAsJsonObject().get(HexAttributes.HEX_ATTR_LINE_NUMBER).getAsInt());
            i++;
        }
        return stackTraceElementArr;
    }

    public JsonObject asJsonObject() {
        JsonObject jsonObject = new JsonObject();
        jsonObject.add(HexAttributes.HEX_ATTR_THREAD_CRASHED, SafeJsonPrimitive.factory(Boolean.valueOf(this.crashed)));
        jsonObject.add(HexAttributes.HEX_ATTR_THREAD_STATE, SafeJsonPrimitive.factory(this.state));
        jsonObject.add(HexAttributes.HEX_ATTR_THREAD_NUMBER, SafeJsonPrimitive.factory((Number) Long.valueOf(this.threadId)));
        jsonObject.add(HexAttributes.HEX_ATTR_THREAD_ID, SafeJsonPrimitive.factory(this.threadName));
        jsonObject.add(HexAttributes.HEX_ATTR_THREAD_PRI, SafeJsonPrimitive.factory((Number) Integer.valueOf(this.threadPriority)));
        jsonObject.add("stack", getStackAsJson());
        return jsonObject;
    }

    public long getThreadId() {
        return this.threadId;
    }

    public ThreadInfo(Throwable th) {
        this.crashed = true;
        this.threadId = Thread.currentThread().getId();
        this.threadName = Thread.currentThread().getName();
        this.threadPriority = Thread.currentThread().getPriority();
        this.stackTrace = th.getStackTrace();
        this.state = Thread.currentThread().getState().toString();
    }

    public ThreadInfo(Thread thread, StackTraceElement[] stackTraceElementArr) {
        this.crashed = false;
        this.threadId = thread.getId();
        this.threadName = thread.getName();
        this.threadPriority = thread.getPriority();
        this.stackTrace = stackTraceElementArr;
        this.state = thread.getState().toString();
    }
}
