package okhttp3.internal.p270ws;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.Closeable;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.ArrayDeque;
import java.util.List;
import java.util.Random;
import java.util.concurrent.TimeUnit;
import okhttp3.Call;
import okhttp3.EventListener;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.WebSocket;
import okhttp3.WebSocketListener;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.Task;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.p270ws.WebSocketReader;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSink;
import p262g.BufferedSource;
import p262g.C1952h;

@Instrumented
/* renamed from: okhttp3.internal.ws.RealWebSocket */
/* compiled from: RealWebSocket.kt */
public final class RealWebSocket implements WebSocket, WebSocketReader.FrameCallback {
    public static final long CANCEL_AFTER_CLOSE_MILLIS = 60000;
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final long DEFAULT_MINIMUM_DEFLATE_SIZE = 1024;
    public static final long MAX_QUEUE_SIZE = 16777216;
    public static final List<Protocol> ONLY_HTTP1 = C1050v.m4212c(Protocol.HTTP_1_1);
    public boolean awaitingPong;
    public Call call;
    public boolean enqueuedClose;
    public WebSocketExtensions extensions;
    public boolean failed;
    public final String key;
    public final WebSocketListener listener;
    public final ArrayDeque<Object> messageAndCloseQueue;
    public long minimumDeflateSize;
    public String name;
    public final Request originalRequest;
    public final long pingIntervalMillis;
    public final ArrayDeque<C1952h> pongQueue;
    public long queueSize;
    public final Random random;
    public WebSocketReader reader;
    public int receivedCloseCode;
    public String receivedCloseReason;
    public int receivedPingCount;
    public int receivedPongCount;
    public int sentPingCount;
    public Streams streams;
    public TaskQueue taskQueue;
    public WebSocketWriter writer;
    public Task writerTask;

    /* renamed from: okhttp3.internal.ws.RealWebSocket$Close */
    /* compiled from: RealWebSocket.kt */
    public static final class Close {
        public final long cancelAfterCloseMillis;
        public final int code;
        public final C1952h reason;

        public Close(int i, C1952h hVar, long j) {
            this.code = i;
            this.reason = hVar;
            this.cancelAfterCloseMillis = j;
        }

        public final long getCancelAfterCloseMillis() {
            return this.cancelAfterCloseMillis;
        }

        public final int getCode() {
            return this.code;
        }

        public final C1952h getReason() {
            return this.reason;
        }
    }

    /* renamed from: okhttp3.internal.ws.RealWebSocket$Companion */
    /* compiled from: RealWebSocket.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* renamed from: okhttp3.internal.ws.RealWebSocket$Message */
    /* compiled from: RealWebSocket.kt */
    public static final class Message {
        public final C1952h data;
        public final int formatOpcode;

        public Message(int i, C1952h hVar) {
            if (hVar != null) {
                this.formatOpcode = i;
                this.data = hVar;
                return;
            }
            Intrinsics.m5822a("data");
            throw null;
        }

        public final C1952h getData() {
            return this.data;
        }

        public final int getFormatOpcode() {
            return this.formatOpcode;
        }
    }

    /* renamed from: okhttp3.internal.ws.RealWebSocket$Streams */
    /* compiled from: RealWebSocket.kt */
    public static abstract class Streams implements Closeable {
        public final boolean client;
        public final BufferedSink sink;
        public final BufferedSource source;

        public Streams(boolean z, BufferedSource gVar, BufferedSink fVar) {
            if (gVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (fVar != null) {
                this.client = z;
                this.source = gVar;
                this.sink = fVar;
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }

        public final boolean getClient() {
            return this.client;
        }

        public final BufferedSink getSink() {
            return this.sink;
        }

        public final BufferedSource getSource() {
            return this.source;
        }
    }

    /* renamed from: okhttp3.internal.ws.RealWebSocket$WriterTask */
    /* compiled from: RealWebSocket.kt */
    public final class WriterTask extends Task {
        public WriterTask() {
            super(RealWebSocket.this.name + " writer", false, 2, (DefaultConstructorMarker) null);
        }

        public long runOnce() {
            try {
                if (RealWebSocket.this.writeOneFrame$okhttp()) {
                    return 0;
                }
                return -1;
            } catch (IOException e) {
                RealWebSocket.this.failWebSocket(e, (Response) null);
                return -1;
            }
        }
    }

    public RealWebSocket(TaskRunner taskRunner, Request request, WebSocketListener webSocketListener, Random random2, long j, WebSocketExtensions webSocketExtensions, long j2) {
        if (taskRunner == null) {
            Intrinsics.m5822a("taskRunner");
            throw null;
        } else if (request == null) {
            Intrinsics.m5822a("originalRequest");
            throw null;
        } else if (webSocketListener == null) {
            Intrinsics.m5822a("listener");
            throw null;
        } else if (random2 != null) {
            this.originalRequest = request;
            this.listener = webSocketListener;
            this.random = random2;
            this.pingIntervalMillis = j;
            this.extensions = webSocketExtensions;
            this.minimumDeflateSize = j2;
            this.taskQueue = taskRunner.newQueue();
            this.pongQueue = new ArrayDeque<>();
            this.messageAndCloseQueue = new ArrayDeque<>();
            this.receivedCloseCode = -1;
            if (Intrinsics.m5823a((Object) "GET", (Object) this.originalRequest.method())) {
                C1952h.C1953a aVar = C1952h.f7659f;
                byte[] bArr = new byte[16];
                this.random.nextBytes(bArr);
                this.key = C1952h.C1953a.m5962a(aVar, bArr, 0, 0, 3).mo9535a();
                return;
            }
            StringBuilder a = outline.m2937a("Request must be GET: ");
            a.append(this.originalRequest.method());
            throw new IllegalArgumentException(a.toString().toString());
        } else {
            Intrinsics.m5822a("random");
            throw null;
        }
    }

    /* access modifiers changed from: private */
    public final boolean isValid(WebSocketExtensions webSocketExtensions) {
        if (webSocketExtensions.unknownValues || webSocketExtensions.clientMaxWindowBits != null) {
            return false;
        }
        Integer num = webSocketExtensions.serverMaxWindowBits;
        if (num == null) {
            return true;
        }
        int intValue = num.intValue();
        if (8 > intValue || 15 < intValue) {
            return false;
        }
        return true;
    }

    private final void runWriter() {
        if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            Task task = this.writerTask;
            if (task != null) {
                TaskQueue.schedule$default(this.taskQueue, task, 0, 2, (Object) null);
                return;
            }
            return;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    public final void awaitTermination(long j, TimeUnit timeUnit) throws InterruptedException {
        if (timeUnit != null) {
            this.taskQueue.idleLatch().await(j, timeUnit);
        } else {
            Intrinsics.m5822a("timeUnit");
            throw null;
        }
    }

    public void cancel() {
        Call call2 = this.call;
        if (call2 != null) {
            call2.cancel();
        } else {
            Intrinsics.m5820a();
            throw null;
        }
    }

    public final void checkUpgradeSuccess$okhttp(Response response, Exchange exchange) throws IOException {
        if (response == null) {
            Intrinsics.m5822a("response");
            throw null;
        } else if (response.code() == 101) {
            String header$default = Response.header$default(response, "Connection", (String) null, 2, (Object) null);
            if (C1937g.m5858a("Upgrade", header$default, true)) {
                String header$default2 = Response.header$default(response, "Upgrade", (String) null, 2, (Object) null);
                if (C1937g.m5858a("websocket", header$default2, true)) {
                    String header$default3 = Response.header$default(response, "Sec-WebSocket-Accept", (String) null, 2, (Object) null);
                    C1952h.C1953a aVar = C1952h.f7659f;
                    String a = aVar.mo9552c(this.key + WebSocketProtocol.ACCEPT_MAGIC).mo9544e().mo9535a();
                    if (!Intrinsics.m5823a((Object) a, (Object) header$default3)) {
                        throw new ProtocolException("Expected 'Sec-WebSocket-Accept' header value '" + a + "' but was '" + header$default3 + '\'');
                    } else if (exchange == null) {
                        throw new ProtocolException("Web Socket exchange missing: bad interceptor?");
                    }
                } else {
                    throw new ProtocolException("Expected 'Upgrade' header value 'websocket' but was '" + header$default2 + '\'');
                }
            } else {
                throw new ProtocolException("Expected 'Connection' header value 'Upgrade' but was '" + header$default + '\'');
            }
        } else {
            StringBuilder a2 = outline.m2937a("Expected HTTP 101 response but was '");
            a2.append(response.code());
            a2.append(SafeJsonPrimitive.NULL_CHAR);
            a2.append(response.message());
            a2.append('\'');
            throw new ProtocolException(a2.toString());
        }
    }

    public boolean close(int i, String str) {
        return close(i, str, 60000);
    }

    public final void connect(OkHttpClient okHttpClient) {
        if (okHttpClient == null) {
            Intrinsics.m5822a("client");
            throw null;
        } else if (this.originalRequest.header(WebSocketExtensions.HEADER_WEB_SOCKET_EXTENSION) != null) {
            failWebSocket(new ProtocolException("Request header not permitted: 'Sec-WebSocket-Extensions'"), (Response) null);
        } else {
            OkHttpClient build = okHttpClient.newBuilder().eventListener(EventListener.NONE).protocols(ONLY_HTTP1).build();
            Request.Builder header = this.originalRequest.newBuilder().header("Upgrade", "websocket").header("Connection", "Upgrade").header("Sec-WebSocket-Key", this.key).header("Sec-WebSocket-Version", "13").header(WebSocketExtensions.HEADER_WEB_SOCKET_EXTENSION, "permessage-deflate");
            Request build2 = !(header instanceof Request.Builder) ? header.build() : OkHttp3Instrumentation.build(header);
            RealCall realCall = new RealCall(build, build2, true);
            this.call = realCall;
            if (realCall != null) {
                realCall.enqueue(new RealWebSocket$connect$1(this, build2));
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
        r4.listener.onFailure(r4, r5, r6);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0034, code lost:
        r5 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0035, code lost:
        if (r1 != null) goto L_0x0037;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0037, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x003a, code lost:
        if (r2 != null) goto L_0x003c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x003c, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x003f, code lost:
        if (r3 != null) goto L_0x0041;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:0x0041, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0044, code lost:
        throw r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:?, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void failWebSocket(java.lang.Exception r5, okhttp3.Response r6) {
        /*
            r4 = this;
            r0 = 0
            if (r5 == 0) goto L_0x0048
            monitor-enter(r4)
            boolean r1 = r4.failed     // Catch:{ all -> 0x0045 }
            if (r1 == 0) goto L_0x000a
            monitor-exit(r4)
            return
        L_0x000a:
            r1 = 1
            r4.failed = r1     // Catch:{ all -> 0x0045 }
            okhttp3.internal.ws.RealWebSocket$Streams r1 = r4.streams     // Catch:{ all -> 0x0045 }
            r4.streams = r0     // Catch:{ all -> 0x0045 }
            okhttp3.internal.ws.WebSocketReader r2 = r4.reader     // Catch:{ all -> 0x0045 }
            r4.reader = r0     // Catch:{ all -> 0x0045 }
            okhttp3.internal.ws.WebSocketWriter r3 = r4.writer     // Catch:{ all -> 0x0045 }
            r4.writer = r0     // Catch:{ all -> 0x0045 }
            okhttp3.internal.concurrent.TaskQueue r0 = r4.taskQueue     // Catch:{ all -> 0x0045 }
            r0.shutdown()     // Catch:{ all -> 0x0045 }
            monitor-exit(r4)
            okhttp3.WebSocketListener r0 = r4.listener     // Catch:{ all -> 0x0034 }
            r0.onFailure(r4, r5, r6)     // Catch:{ all -> 0x0034 }
            if (r1 == 0) goto L_0x0029
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x0029:
            if (r2 == 0) goto L_0x002e
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2)
        L_0x002e:
            if (r3 == 0) goto L_0x0033
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r3)
        L_0x0033:
            return
        L_0x0034:
            r5 = move-exception
            if (r1 == 0) goto L_0x003a
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x003a:
            if (r2 == 0) goto L_0x003f
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2)
        L_0x003f:
            if (r3 == 0) goto L_0x0044
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r3)
        L_0x0044:
            throw r5
        L_0x0045:
            r5 = move-exception
            monitor-exit(r4)
            throw r5
        L_0x0048:
            java.lang.String r5 = "e"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r5)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.failWebSocket(java.lang.Exception, okhttp3.Response):void");
    }

    public final WebSocketListener getListener$okhttp() {
        return this.listener;
    }

    public final void initReaderAndWriter(String str, Streams streams2) throws IOException {
        String str2 = str;
        Streams streams3 = streams2;
        if (str2 == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (streams3 != null) {
            WebSocketExtensions webSocketExtensions = this.extensions;
            if (webSocketExtensions != null) {
                synchronized (this) {
                    this.name = str2;
                    this.streams = streams3;
                    this.writer = new WebSocketWriter(streams2.getClient(), streams2.getSink(), this.random, webSocketExtensions.perMessageDeflate, webSocketExtensions.noContextTakeover(streams2.getClient()), this.minimumDeflateSize);
                    this.writerTask = new WriterTask();
                    if (this.pingIntervalMillis != 0) {
                        long nanos = TimeUnit.MILLISECONDS.toNanos(this.pingIntervalMillis);
                        TaskQueue taskQueue2 = this.taskQueue;
                        String str3 = str2 + " ping";
                        RealWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$1 realWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$1 = r1;
                        RealWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$1 realWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$12 = new RealWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$1(str3, str3, nanos, this, str, streams2, webSocketExtensions);
                        taskQueue2.schedule(realWebSocket$initReaderAndWriter$$inlined$synchronized$lambda$1, nanos);
                    }
                    if (!this.messageAndCloseQueue.isEmpty()) {
                        runWriter();
                    }
                }
                this.reader = new WebSocketReader(streams2.getClient(), streams2.getSource(), this, webSocketExtensions.perMessageDeflate, webSocketExtensions.noContextTakeover(!streams2.getClient()));
                return;
            }
            Intrinsics.m5820a();
            throw null;
        } else {
            Intrinsics.m5822a("streams");
            throw null;
        }
    }

    public final void loopReader() throws IOException {
        while (this.receivedCloseCode == -1) {
            WebSocketReader webSocketReader = this.reader;
            if (webSocketReader != null) {
                webSocketReader.processNextFrame();
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        }
    }

    /* JADX WARNING: type inference failed for: r0v0, types: [java.lang.Throwable, okhttp3.internal.ws.WebSocketWriter, okhttp3.internal.ws.WebSocketReader, okhttp3.internal.ws.RealWebSocket$Streams] */
    /* JADX WARNING: type inference failed for: r0v1, types: [java.io.Closeable] */
    /* JADX WARNING: type inference failed for: r0v3 */
    /* JADX WARNING: Multi-variable type inference failed */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void onReadClose(int r6, java.lang.String r7) {
        /*
            r5 = this;
            r0 = 0
            if (r7 == 0) goto L_0x0084
            r1 = 1
            r2 = 0
            r3 = -1
            if (r6 == r3) goto L_0x000a
            r4 = 1
            goto L_0x000b
        L_0x000a:
            r4 = 0
        L_0x000b:
            if (r4 == 0) goto L_0x0078
            monitor-enter(r5)
            int r4 = r5.receivedCloseCode     // Catch:{ all -> 0x0075 }
            if (r4 != r3) goto L_0x0013
            goto L_0x0014
        L_0x0013:
            r1 = 0
        L_0x0014:
            if (r1 == 0) goto L_0x0069
            r5.receivedCloseCode = r6     // Catch:{ all -> 0x0075 }
            r5.receivedCloseReason = r7     // Catch:{ all -> 0x0075 }
            boolean r1 = r5.enqueuedClose     // Catch:{ all -> 0x0075 }
            if (r1 == 0) goto L_0x0039
            java.util.ArrayDeque<java.lang.Object> r1 = r5.messageAndCloseQueue     // Catch:{ all -> 0x0075 }
            boolean r1 = r1.isEmpty()     // Catch:{ all -> 0x0075 }
            if (r1 == 0) goto L_0x0039
            okhttp3.internal.ws.RealWebSocket$Streams r1 = r5.streams     // Catch:{ all -> 0x0075 }
            r5.streams = r0     // Catch:{ all -> 0x0075 }
            okhttp3.internal.ws.WebSocketReader r2 = r5.reader     // Catch:{ all -> 0x0075 }
            r5.reader = r0     // Catch:{ all -> 0x0075 }
            okhttp3.internal.ws.WebSocketWriter r3 = r5.writer     // Catch:{ all -> 0x0075 }
            r5.writer = r0     // Catch:{ all -> 0x0075 }
            okhttp3.internal.concurrent.TaskQueue r0 = r5.taskQueue     // Catch:{ all -> 0x0075 }
            r0.shutdown()     // Catch:{ all -> 0x0075 }
            r0 = r1
            goto L_0x003b
        L_0x0039:
            r2 = r0
            r3 = r2
        L_0x003b:
            monitor-exit(r5)
            okhttp3.WebSocketListener r1 = r5.listener     // Catch:{ all -> 0x0058 }
            r1.onClosing(r5, r6, r7)     // Catch:{ all -> 0x0058 }
            if (r0 == 0) goto L_0x0048
            okhttp3.WebSocketListener r1 = r5.listener     // Catch:{ all -> 0x0058 }
            r1.onClosed(r5, r6, r7)     // Catch:{ all -> 0x0058 }
        L_0x0048:
            if (r0 == 0) goto L_0x004d
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r0)
        L_0x004d:
            if (r2 == 0) goto L_0x0052
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2)
        L_0x0052:
            if (r3 == 0) goto L_0x0057
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r3)
        L_0x0057:
            return
        L_0x0058:
            r6 = move-exception
            if (r0 == 0) goto L_0x005e
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r0)
        L_0x005e:
            if (r2 == 0) goto L_0x0063
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2)
        L_0x0063:
            if (r3 == 0) goto L_0x0068
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r3)
        L_0x0068:
            throw r6
        L_0x0069:
            java.lang.String r6 = "already closed"
            java.lang.IllegalStateException r7 = new java.lang.IllegalStateException     // Catch:{ all -> 0x0075 }
            java.lang.String r6 = r6.toString()     // Catch:{ all -> 0x0075 }
            r7.<init>(r6)     // Catch:{ all -> 0x0075 }
            throw r7     // Catch:{ all -> 0x0075 }
        L_0x0075:
            r6 = move-exception
            monitor-exit(r5)
            throw r6
        L_0x0078:
            java.lang.IllegalArgumentException r6 = new java.lang.IllegalArgumentException
            java.lang.String r7 = "Failed requirement."
            java.lang.String r7 = r7.toString()
            r6.<init>(r7)
            throw r6
        L_0x0084:
            java.lang.String r6 = "reason"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r6)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.onReadClose(int, java.lang.String):void");
    }

    public void onReadMessage(String str) throws IOException {
        if (str != null) {
            this.listener.onMessage((WebSocket) this, str);
        } else {
            Intrinsics.m5822a("text");
            throw null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0027, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public synchronized void onReadPing(p262g.C1952h r2) {
        /*
            r1 = this;
            monitor-enter(r1)
            java.lang.String r0 = "payload"
            if (r2 == 0) goto L_0x0028
            boolean r0 = r1.failed     // Catch:{ all -> 0x002d }
            if (r0 != 0) goto L_0x0026
            boolean r0 = r1.enqueuedClose     // Catch:{ all -> 0x002d }
            if (r0 == 0) goto L_0x0016
            java.util.ArrayDeque<java.lang.Object> r0 = r1.messageAndCloseQueue     // Catch:{ all -> 0x002d }
            boolean r0 = r0.isEmpty()     // Catch:{ all -> 0x002d }
            if (r0 == 0) goto L_0x0016
            goto L_0x0026
        L_0x0016:
            java.util.ArrayDeque<g.h> r0 = r1.pongQueue     // Catch:{ all -> 0x002d }
            r0.add(r2)     // Catch:{ all -> 0x002d }
            r1.runWriter()     // Catch:{ all -> 0x002d }
            int r2 = r1.receivedPingCount     // Catch:{ all -> 0x002d }
            int r2 = r2 + 1
            r1.receivedPingCount = r2     // Catch:{ all -> 0x002d }
            monitor-exit(r1)
            return
        L_0x0026:
            monitor-exit(r1)
            return
        L_0x0028:
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)     // Catch:{ all -> 0x002d }
            r2 = 0
            throw r2
        L_0x002d:
            r2 = move-exception
            monitor-exit(r1)
            throw r2
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.onReadPing(g.h):void");
    }

    public synchronized void onReadPong(C1952h hVar) {
        if (hVar != null) {
            this.receivedPongCount++;
            this.awaitingPong = false;
        } else {
            Intrinsics.m5822a("payload");
            throw null;
        }
    }

    public final synchronized boolean pong(C1952h hVar) {
        if (hVar != null) {
            if (!this.failed) {
                if (!this.enqueuedClose || !this.messageAndCloseQueue.isEmpty()) {
                    this.pongQueue.add(hVar);
                    runWriter();
                    return true;
                }
            }
            return false;
        }
        Intrinsics.m5822a("payload");
        throw null;
    }

    public final boolean processNextFrame() throws IOException {
        try {
            WebSocketReader webSocketReader = this.reader;
            if (webSocketReader != null) {
                webSocketReader.processNextFrame();
                if (this.receivedCloseCode == -1) {
                    return true;
                }
                return false;
            }
            Intrinsics.m5820a();
            throw null;
        } catch (Exception e) {
            failWebSocket(e, (Response) null);
            return false;
        }
    }

    public synchronized long queueSize() {
        return this.queueSize;
    }

    public final synchronized int receivedPingCount() {
        return this.receivedPingCount;
    }

    public final synchronized int receivedPongCount() {
        return this.receivedPongCount;
    }

    public Request request() {
        return this.originalRequest;
    }

    public boolean send(String str) {
        if (str != null) {
            return send(C1952h.f7659f.mo9552c(str), 1);
        }
        Intrinsics.m5822a("text");
        throw null;
    }

    public final synchronized int sentPingCount() {
        return this.sentPingCount;
    }

    public final void tearDown() throws InterruptedException {
        this.taskQueue.shutdown();
        this.taskQueue.idleLatch().await(10, TimeUnit.SECONDS);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01d8, code lost:
        if (r1 != null) goto L_0x01da;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:101:0x01da, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:102:0x01dd, code lost:
        r1 = (okhttp3.internal.p270ws.WebSocketReader) r2.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:103:0x01e1, code lost:
        if (r1 != null) goto L_0x01e3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:104:0x01e3, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:105:0x01e6, code lost:
        r1 = (okhttp3.internal.p270ws.WebSocketWriter) r3.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:106:0x01ea, code lost:
        if (r1 != null) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:107:0x01ec, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:108:0x01ef, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x00fc, code lost:
        r2 = r20;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x00fe, code lost:
        if (r2 == null) goto L_0x010c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0100, code lost:
        r1 = r21;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0102, code lost:
        if (r1 == null) goto L_0x0108;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:?, code lost:
        r1.writePong(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x0108, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x010b, code lost:
        throw r27;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x010c, code lost:
        r1 = r21;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:38:0x0112, code lost:
        if ((r0.f7597b instanceof okhttp3.internal.p270ws.RealWebSocket.Message) == false) goto L_0x0149;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x0114, code lost:
        r0 = r0.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x0116, code lost:
        if (r0 == null) goto L_0x0141;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x0118, code lost:
        r0 = (okhttp3.internal.p270ws.RealWebSocket.Message) r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x011a, code lost:
        if (r1 == null) goto L_0x013d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x011c, code lost:
        r1.writeMessageFrame(r0.getFormatOpcode(), r0.getData());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:44:0x0127, code lost:
        monitor-enter(r28);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:46:?, code lost:
        r15.queueSize -= (long) r0.getData().mo9540b();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:?, code lost:
        monitor-exit(r28);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x0137, code lost:
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:53:0x013d, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:0x0140, code lost:
        throw r27;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x0148, code lost:
        throw new p250f.TypeCastException("null cannot be cast to non-null type okhttp3.internal.ws.RealWebSocket.Message");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x014d, code lost:
        if ((r0.f7597b instanceof okhttp3.internal.p270ws.RealWebSocket.Close) == false) goto L_0x01bf;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x014f, code lost:
        r0 = r0.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x0151, code lost:
        if (r0 == null) goto L_0x01b1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x0153, code lost:
        r0 = (okhttp3.internal.p270ws.RealWebSocket.Close) r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x0155, code lost:
        if (r1 == null) goto L_0x01a7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x0157, code lost:
        r1.writeClose(r0.getCode(), r0.getReason());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x0162, code lost:
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:68:0x0168, code lost:
        if (((okhttp3.internal.p270ws.RealWebSocket.Streams) r1.f7597b) == null) goto L_0x0180;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:69:0x016a, code lost:
        r0 = r15.listener;
        r2 = r26.f7595b;
        r3 = (java.lang.String) r25.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:70:0x0176, code lost:
        if (r3 == null) goto L_0x017c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x0178, code lost:
        r0.onClosed(r15, r2, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:72:0x017c, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x017f, code lost:
        throw r27;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x0180, code lost:
        r1 = (okhttp3.internal.p270ws.RealWebSocket.Streams) r1.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x0185, code lost:
        if (r1 == null) goto L_0x018a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x0187, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:77:0x018a, code lost:
        r1 = (okhttp3.internal.p270ws.WebSocketReader) r23.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:0x0190, code lost:
        if (r1 == null) goto L_0x0195;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x0192, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x0195, code lost:
        r1 = (okhttp3.internal.p270ws.WebSocketWriter) r22.f7597b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x019b, code lost:
        if (r1 == null) goto L_0x01a0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x019d, code lost:
        okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:0x01a0, code lost:
        return true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:84:0x01a1, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:85:0x01a2, code lost:
        r3 = r22;
        r2 = r23;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:86:0x01a7, code lost:
        r3 = r22;
        r2 = r23;
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:88:?, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:89:0x01b0, code lost:
        throw r27;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:90:0x01b1, code lost:
        r3 = r22;
        r2 = r23;
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:93:0x01be, code lost:
        throw new p250f.TypeCastException("null cannot be cast to non-null type okhttp3.internal.ws.RealWebSocket.Close");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:94:0x01bf, code lost:
        r3 = r22;
        r2 = r23;
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:95:0x01ca, code lost:
        throw new java.lang.AssertionError();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:96:0x01cb, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:0x01cd, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x01ce, code lost:
        r3 = r22;
        r2 = r23;
        r1 = r24;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:99:0x01d4, code lost:
        r1 = (okhttp3.internal.p270ws.RealWebSocket.Streams) r1.f7597b;
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* JADX WARNING: Removed duplicated region for block: B:101:0x01da  */
    /* JADX WARNING: Removed duplicated region for block: B:104:0x01e3  */
    /* JADX WARNING: Removed duplicated region for block: B:107:0x01ec  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final boolean writeOneFrame$okhttp() throws java.io.IOException {
        /*
            r28 = this;
            r15 = r28
            f.l.c.n r0 = new f.l.c.n
            r0.<init>()
            r14 = 0
            r0.f7597b = r14
            f.l.c.l r13 = new f.l.c.l
            r13.<init>()
            r1 = -1
            r13.f7595b = r1
            f.l.c.n r12 = new f.l.c.n
            r12.<init>()
            r12.f7597b = r14
            f.l.c.n r11 = new f.l.c.n
            r11.<init>()
            r11.f7597b = r14
            f.l.c.n r10 = new f.l.c.n
            r10.<init>()
            r10.f7597b = r14
            f.l.c.n r9 = new f.l.c.n
            r9.<init>()
            r9.f7597b = r14
            monitor-enter(r28)
            boolean r2 = r15.failed     // Catch:{ all -> 0x01f0 }
            r3 = 0
            if (r2 == 0) goto L_0x0036
            monitor-exit(r28)
            return r3
        L_0x0036:
            okhttp3.internal.ws.WebSocketWriter r8 = r15.writer     // Catch:{ all -> 0x01f0 }
            java.util.ArrayDeque<g.h> r2 = r15.pongQueue     // Catch:{ all -> 0x01f0 }
            java.lang.Object r2 = r2.poll()     // Catch:{ all -> 0x01f0 }
            r7 = r2
            g.h r7 = (p262g.C1952h) r7     // Catch:{ all -> 0x01f0 }
            if (r7 != 0) goto L_0x00eb
            java.util.ArrayDeque<java.lang.Object> r2 = r15.messageAndCloseQueue     // Catch:{ all -> 0x01f0 }
            java.lang.Object r2 = r2.poll()     // Catch:{ all -> 0x01f0 }
            r0.f7597b = r2     // Catch:{ all -> 0x01f0 }
            boolean r4 = r2 instanceof okhttp3.internal.p270ws.RealWebSocket.Close     // Catch:{ all -> 0x01f0 }
            if (r4 == 0) goto L_0x00d7
            int r2 = r15.receivedCloseCode     // Catch:{ all -> 0x01f0 }
            r13.f7595b = r2     // Catch:{ all -> 0x01f0 }
            java.lang.String r3 = r15.receivedCloseReason     // Catch:{ all -> 0x01f0 }
            r12.f7597b = r3     // Catch:{ all -> 0x01f0 }
            if (r2 == r1) goto L_0x0072
            okhttp3.internal.ws.RealWebSocket$Streams r1 = r15.streams     // Catch:{ all -> 0x01f0 }
            r11.f7597b = r1     // Catch:{ all -> 0x01f0 }
            r15.streams = r14     // Catch:{ all -> 0x01f0 }
            okhttp3.internal.ws.WebSocketReader r1 = r15.reader     // Catch:{ all -> 0x01f0 }
            r10.f7597b = r1     // Catch:{ all -> 0x01f0 }
            r15.reader = r14     // Catch:{ all -> 0x01f0 }
            okhttp3.internal.ws.WebSocketWriter r1 = r15.writer     // Catch:{ all -> 0x01f0 }
            r9.f7597b = r1     // Catch:{ all -> 0x01f0 }
            r15.writer = r14     // Catch:{ all -> 0x01f0 }
            okhttp3.internal.concurrent.TaskQueue r1 = r15.taskQueue     // Catch:{ all -> 0x01f0 }
            r1.shutdown()     // Catch:{ all -> 0x01f0 }
            goto L_0x00eb
        L_0x0072:
            T r1 = r0.f7597b     // Catch:{ all -> 0x01f0 }
            if (r1 == 0) goto L_0x00cf
            okhttp3.internal.ws.RealWebSocket$Close r1 = (okhttp3.internal.p270ws.RealWebSocket.Close) r1     // Catch:{ all -> 0x01f0 }
            long r1 = r1.getCancelAfterCloseMillis()     // Catch:{ all -> 0x01f0 }
            okhttp3.internal.concurrent.TaskQueue r6 = r15.taskQueue     // Catch:{ all -> 0x01f0 }
            java.lang.StringBuilder r3 = new java.lang.StringBuilder     // Catch:{ all -> 0x01f0 }
            r3.<init>()     // Catch:{ all -> 0x01f0 }
            java.lang.String r4 = r15.name     // Catch:{ all -> 0x01f0 }
            r3.append(r4)     // Catch:{ all -> 0x01f0 }
            java.lang.String r4 = " cancel"
            r3.append(r4)     // Catch:{ all -> 0x01f0 }
            java.lang.String r4 = r3.toString()     // Catch:{ all -> 0x01f0 }
            java.util.concurrent.TimeUnit r3 = java.util.concurrent.TimeUnit.MILLISECONDS     // Catch:{ all -> 0x01f0 }
            long r2 = r3.toNanos(r1)     // Catch:{ all -> 0x01f0 }
            r5 = 1
            okhttp3.internal.ws.RealWebSocket$writeOneFrame$$inlined$synchronized$lambda$1 r1 = new okhttp3.internal.ws.RealWebSocket$writeOneFrame$$inlined$synchronized$lambda$1     // Catch:{ all -> 0x01f0 }
            r16 = r1
            r1 = r16
            r17 = r2
            r2 = r4
            r3 = r5
            r19 = r6
            r6 = r28
            r20 = r7
            r7 = r8
            r21 = r8
            r8 = r20
            r22 = r9
            r9 = r0
            r23 = r10
            r10 = r13
            r24 = r11
            r11 = r12
            r25 = r12
            r12 = r24
            r26 = r13
            r13 = r23
            r27 = r14
            r14 = r22
            r1.<init>(r2, r3, r4, r5, r6, r7, r8, r9, r10, r11, r12, r13, r14)     // Catch:{ all -> 0x01f0 }
            r4 = r16
            r2 = r17
            r1 = r19
            r1.schedule(r4, r2)     // Catch:{ all -> 0x01f0 }
            goto L_0x00fb
        L_0x00cf:
            f.e r0 = new f.e     // Catch:{ all -> 0x01f0 }
            java.lang.String r1 = "null cannot be cast to non-null type okhttp3.internal.ws.RealWebSocket.Close"
            r0.<init>(r1)     // Catch:{ all -> 0x01f0 }
            throw r0     // Catch:{ all -> 0x01f0 }
        L_0x00d7:
            r20 = r7
            r21 = r8
            r22 = r9
            r23 = r10
            r24 = r11
            r25 = r12
            r26 = r13
            r27 = r14
            if (r2 != 0) goto L_0x00fb
            monitor-exit(r28)
            return r3
        L_0x00eb:
            r20 = r7
            r21 = r8
            r22 = r9
            r23 = r10
            r24 = r11
            r25 = r12
            r26 = r13
            r27 = r14
        L_0x00fb:
            monitor-exit(r28)
            r2 = r20
            if (r2 == 0) goto L_0x010c
            r1 = r21
            if (r1 == 0) goto L_0x0108
            r1.writePong(r2)     // Catch:{ all -> 0x01cd }
            goto L_0x0137
        L_0x0108:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x01cd }
            throw r27
        L_0x010c:
            r1 = r21
            T r2 = r0.f7597b     // Catch:{ all -> 0x01cd }
            boolean r2 = r2 instanceof okhttp3.internal.p270ws.RealWebSocket.Message     // Catch:{ all -> 0x01cd }
            if (r2 == 0) goto L_0x0149
            T r0 = r0.f7597b     // Catch:{ all -> 0x01cd }
            if (r0 == 0) goto L_0x0141
            okhttp3.internal.ws.RealWebSocket$Message r0 = (okhttp3.internal.p270ws.RealWebSocket.Message) r0     // Catch:{ all -> 0x01cd }
            if (r1 == 0) goto L_0x013d
            int r2 = r0.getFormatOpcode()     // Catch:{ all -> 0x01cd }
            g.h r3 = r0.getData()     // Catch:{ all -> 0x01cd }
            r1.writeMessageFrame(r2, r3)     // Catch:{ all -> 0x01cd }
            monitor-enter(r28)     // Catch:{ all -> 0x01cd }
            long r1 = r15.queueSize     // Catch:{ all -> 0x013a }
            g.h r0 = r0.getData()     // Catch:{ all -> 0x013a }
            int r0 = r0.mo9540b()     // Catch:{ all -> 0x013a }
            long r3 = (long) r0     // Catch:{ all -> 0x013a }
            long r1 = r1 - r3
            r15.queueSize = r1     // Catch:{ all -> 0x013a }
            monitor-exit(r28)     // Catch:{ all -> 0x01cd }
        L_0x0137:
            r1 = r24
            goto L_0x0180
        L_0x013a:
            r0 = move-exception
            monitor-exit(r28)     // Catch:{ all -> 0x01cd }
            throw r0     // Catch:{ all -> 0x01cd }
        L_0x013d:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x01cd }
            throw r27
        L_0x0141:
            f.e r0 = new f.e     // Catch:{ all -> 0x01cd }
            java.lang.String r1 = "null cannot be cast to non-null type okhttp3.internal.ws.RealWebSocket.Message"
            r0.<init>(r1)     // Catch:{ all -> 0x01cd }
            throw r0     // Catch:{ all -> 0x01cd }
        L_0x0149:
            T r2 = r0.f7597b     // Catch:{ all -> 0x01cd }
            boolean r2 = r2 instanceof okhttp3.internal.p270ws.RealWebSocket.Close     // Catch:{ all -> 0x01cd }
            if (r2 == 0) goto L_0x01bf
            T r0 = r0.f7597b     // Catch:{ all -> 0x01cd }
            if (r0 == 0) goto L_0x01b1
            okhttp3.internal.ws.RealWebSocket$Close r0 = (okhttp3.internal.p270ws.RealWebSocket.Close) r0     // Catch:{ all -> 0x01cd }
            if (r1 == 0) goto L_0x01a7
            int r2 = r0.getCode()     // Catch:{ all -> 0x01cd }
            g.h r0 = r0.getReason()     // Catch:{ all -> 0x01cd }
            r1.writeClose(r2, r0)     // Catch:{ all -> 0x01cd }
            r1 = r24
            T r0 = r1.f7597b     // Catch:{ all -> 0x01a1 }
            okhttp3.internal.ws.RealWebSocket$Streams r0 = (okhttp3.internal.p270ws.RealWebSocket.Streams) r0     // Catch:{ all -> 0x01a1 }
            if (r0 == 0) goto L_0x0180
            okhttp3.WebSocketListener r0 = r15.listener     // Catch:{ all -> 0x01a1 }
            r2 = r26
            int r2 = r2.f7595b     // Catch:{ all -> 0x01a1 }
            r3 = r25
            T r3 = r3.f7597b     // Catch:{ all -> 0x01a1 }
            java.lang.String r3 = (java.lang.String) r3     // Catch:{ all -> 0x01a1 }
            if (r3 == 0) goto L_0x017c
            r0.onClosed(r15, r2, r3)     // Catch:{ all -> 0x01a1 }
            goto L_0x0180
        L_0x017c:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x01a1 }
            throw r27
        L_0x0180:
            r0 = 1
            T r1 = r1.f7597b
            okhttp3.internal.ws.RealWebSocket$Streams r1 = (okhttp3.internal.p270ws.RealWebSocket.Streams) r1
            if (r1 == 0) goto L_0x018a
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x018a:
            r2 = r23
            T r1 = r2.f7597b
            okhttp3.internal.ws.WebSocketReader r1 = (okhttp3.internal.p270ws.WebSocketReader) r1
            if (r1 == 0) goto L_0x0195
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x0195:
            r3 = r22
            T r1 = r3.f7597b
            okhttp3.internal.ws.WebSocketWriter r1 = (okhttp3.internal.p270ws.WebSocketWriter) r1
            if (r1 == 0) goto L_0x01a0
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x01a0:
            return r0
        L_0x01a1:
            r0 = move-exception
            r3 = r22
            r2 = r23
            goto L_0x01d4
        L_0x01a7:
            r3 = r22
            r2 = r23
            r1 = r24
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x01cb }
            throw r27
        L_0x01b1:
            r3 = r22
            r2 = r23
            r1 = r24
            f.e r0 = new f.e     // Catch:{ all -> 0x01cb }
            java.lang.String r4 = "null cannot be cast to non-null type okhttp3.internal.ws.RealWebSocket.Close"
            r0.<init>(r4)     // Catch:{ all -> 0x01cb }
            throw r0     // Catch:{ all -> 0x01cb }
        L_0x01bf:
            r3 = r22
            r2 = r23
            r1 = r24
            java.lang.AssertionError r0 = new java.lang.AssertionError     // Catch:{ all -> 0x01cb }
            r0.<init>()     // Catch:{ all -> 0x01cb }
            throw r0     // Catch:{ all -> 0x01cb }
        L_0x01cb:
            r0 = move-exception
            goto L_0x01d4
        L_0x01cd:
            r0 = move-exception
            r3 = r22
            r2 = r23
            r1 = r24
        L_0x01d4:
            T r1 = r1.f7597b
            okhttp3.internal.ws.RealWebSocket$Streams r1 = (okhttp3.internal.p270ws.RealWebSocket.Streams) r1
            if (r1 == 0) goto L_0x01dd
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x01dd:
            T r1 = r2.f7597b
            okhttp3.internal.ws.WebSocketReader r1 = (okhttp3.internal.p270ws.WebSocketReader) r1
            if (r1 == 0) goto L_0x01e6
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x01e6:
            T r1 = r3.f7597b
            okhttp3.internal.ws.WebSocketWriter r1 = (okhttp3.internal.p270ws.WebSocketWriter) r1
            if (r1 == 0) goto L_0x01ef
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r1)
        L_0x01ef:
            throw r0
        L_0x01f0:
            r0 = move-exception
            monitor-exit(r28)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.writeOneFrame$okhttp():boolean");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:14:0x001c, code lost:
        if (r1 == -1) goto L_0x0044;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x001e, code lost:
        r2 = p085c.p086a.p087a.p088a.outline.m2937a("sent ping but didn't receive pong within ");
        r2.append(r7.pingIntervalMillis);
        r2.append("ms (after ");
        r2.append(r1 - 1);
        r2.append(" successful ping/pongs)");
        failWebSocket(new java.net.SocketTimeoutException(r2.toString()), (okhttp3.Response) null);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0043, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0044, code lost:
        if (r0 == null) goto L_0x004c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
        r0.writePing(p262g.C1952h.f7658e);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x004c, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x004f, code lost:
        throw null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0050, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0051, code lost:
        failWebSocket(r0, (okhttp3.Response) null);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:?, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void writePingFrame$okhttp() {
        /*
            r7 = this;
            monitor-enter(r7)
            boolean r0 = r7.failed     // Catch:{ all -> 0x0055 }
            if (r0 == 0) goto L_0x0007
            monitor-exit(r7)
            return
        L_0x0007:
            okhttp3.internal.ws.WebSocketWriter r0 = r7.writer     // Catch:{ all -> 0x0055 }
            boolean r1 = r7.awaitingPong     // Catch:{ all -> 0x0055 }
            r2 = -1
            if (r1 == 0) goto L_0x0011
            int r1 = r7.sentPingCount     // Catch:{ all -> 0x0055 }
            goto L_0x0012
        L_0x0011:
            r1 = -1
        L_0x0012:
            int r3 = r7.sentPingCount     // Catch:{ all -> 0x0055 }
            r4 = 1
            int r3 = r3 + r4
            r7.sentPingCount = r3     // Catch:{ all -> 0x0055 }
            r7.awaitingPong = r4     // Catch:{ all -> 0x0055 }
            monitor-exit(r7)
            r3 = 0
            if (r1 == r2) goto L_0x0044
            java.net.SocketTimeoutException r0 = new java.net.SocketTimeoutException
            java.lang.String r2 = "sent ping but didn't receive pong within "
            java.lang.StringBuilder r2 = p085c.p086a.p087a.p088a.outline.m2937a(r2)
            long r5 = r7.pingIntervalMillis
            r2.append(r5)
            java.lang.String r5 = "ms (after "
            r2.append(r5)
            int r1 = r1 - r4
            r2.append(r1)
            java.lang.String r1 = " successful ping/pongs)"
            r2.append(r1)
            java.lang.String r1 = r2.toString()
            r0.<init>(r1)
            r7.failWebSocket(r0, r3)
            return
        L_0x0044:
            if (r0 == 0) goto L_0x004c
            g.h r1 = p262g.C1952h.f7658e     // Catch:{ IOException -> 0x0050 }
            r0.writePing(r1)     // Catch:{ IOException -> 0x0050 }
            goto L_0x0054
        L_0x004c:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ IOException -> 0x0050 }
            throw r3
        L_0x0050:
            r0 = move-exception
            r7.failWebSocket(r0, r3)
        L_0x0054:
            return
        L_0x0055:
            r0 = move-exception
            monitor-exit(r7)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.writePingFrame$okhttp():void");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0058, code lost:
        return false;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized boolean close(int r9, java.lang.String r10, long r11) {
        /*
            r8 = this;
            monitor-enter(r8)
            okhttp3.internal.ws.WebSocketProtocol r0 = okhttp3.internal.p270ws.WebSocketProtocol.INSTANCE     // Catch:{ all -> 0x0059 }
            r0.validateCloseCode(r9)     // Catch:{ all -> 0x0059 }
            r0 = 0
            r1 = 0
            r2 = 1
            if (r10 == 0) goto L_0x003d
            g.h$a r0 = p262g.C1952h.f7659f     // Catch:{ all -> 0x0059 }
            g.h r0 = r0.mo9552c(r10)     // Catch:{ all -> 0x0059 }
            int r3 = r0.mo9540b()     // Catch:{ all -> 0x0059 }
            long r3 = (long) r3     // Catch:{ all -> 0x0059 }
            r5 = 123(0x7b, double:6.1E-322)
            int r7 = (r3 > r5 ? 1 : (r3 == r5 ? 0 : -1))
            if (r7 > 0) goto L_0x001e
            r3 = 1
            goto L_0x001f
        L_0x001e:
            r3 = 0
        L_0x001f:
            if (r3 == 0) goto L_0x0022
            goto L_0x003d
        L_0x0022:
            java.lang.StringBuilder r9 = new java.lang.StringBuilder     // Catch:{ all -> 0x0059 }
            r9.<init>()     // Catch:{ all -> 0x0059 }
            java.lang.String r11 = "reason.size() > 123: "
            r9.append(r11)     // Catch:{ all -> 0x0059 }
            r9.append(r10)     // Catch:{ all -> 0x0059 }
            java.lang.String r9 = r9.toString()     // Catch:{ all -> 0x0059 }
            java.lang.IllegalArgumentException r10 = new java.lang.IllegalArgumentException     // Catch:{ all -> 0x0059 }
            java.lang.String r9 = r9.toString()     // Catch:{ all -> 0x0059 }
            r10.<init>(r9)     // Catch:{ all -> 0x0059 }
            throw r10     // Catch:{ all -> 0x0059 }
        L_0x003d:
            boolean r10 = r8.failed     // Catch:{ all -> 0x0059 }
            if (r10 != 0) goto L_0x0057
            boolean r10 = r8.enqueuedClose     // Catch:{ all -> 0x0059 }
            if (r10 == 0) goto L_0x0046
            goto L_0x0057
        L_0x0046:
            r8.enqueuedClose = r2     // Catch:{ all -> 0x0059 }
            java.util.ArrayDeque<java.lang.Object> r10 = r8.messageAndCloseQueue     // Catch:{ all -> 0x0059 }
            okhttp3.internal.ws.RealWebSocket$Close r1 = new okhttp3.internal.ws.RealWebSocket$Close     // Catch:{ all -> 0x0059 }
            r1.<init>(r9, r0, r11)     // Catch:{ all -> 0x0059 }
            r10.add(r1)     // Catch:{ all -> 0x0059 }
            r8.runWriter()     // Catch:{ all -> 0x0059 }
            monitor-exit(r8)
            return r2
        L_0x0057:
            monitor-exit(r8)
            return r1
        L_0x0059:
            r9 = move-exception
            monitor-exit(r8)
            throw r9
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.close(int, java.lang.String, long):boolean");
    }

    public void onReadMessage(C1952h hVar) throws IOException {
        if (hVar != null) {
            this.listener.onMessage((WebSocket) this, hVar);
        } else {
            Intrinsics.m5822a("bytes");
            throw null;
        }
    }

    public boolean send(C1952h hVar) {
        if (hVar != null) {
            return send(hVar, 2);
        }
        Intrinsics.m5822a("bytes");
        throw null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:18:0x003d, code lost:
        return false;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final synchronized boolean send(p262g.C1952h r7, int r8) {
        /*
            r6 = this;
            monitor-enter(r6)
            boolean r0 = r6.failed     // Catch:{ all -> 0x003e }
            r1 = 0
            if (r0 != 0) goto L_0x003c
            boolean r0 = r6.enqueuedClose     // Catch:{ all -> 0x003e }
            if (r0 == 0) goto L_0x000b
            goto L_0x003c
        L_0x000b:
            long r2 = r6.queueSize     // Catch:{ all -> 0x003e }
            int r0 = r7.mo9540b()     // Catch:{ all -> 0x003e }
            long r4 = (long) r0     // Catch:{ all -> 0x003e }
            long r2 = r2 + r4
            r4 = 16777216(0x1000000, double:8.289046E-317)
            int r0 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1))
            if (r0 <= 0) goto L_0x0022
            r7 = 1001(0x3e9, float:1.403E-42)
            r8 = 0
            r6.close(r7, r8)     // Catch:{ all -> 0x003e }
            monitor-exit(r6)
            return r1
        L_0x0022:
            long r0 = r6.queueSize     // Catch:{ all -> 0x003e }
            int r2 = r7.mo9540b()     // Catch:{ all -> 0x003e }
            long r2 = (long) r2     // Catch:{ all -> 0x003e }
            long r0 = r0 + r2
            r6.queueSize = r0     // Catch:{ all -> 0x003e }
            java.util.ArrayDeque<java.lang.Object> r0 = r6.messageAndCloseQueue     // Catch:{ all -> 0x003e }
            okhttp3.internal.ws.RealWebSocket$Message r1 = new okhttp3.internal.ws.RealWebSocket$Message     // Catch:{ all -> 0x003e }
            r1.<init>(r8, r7)     // Catch:{ all -> 0x003e }
            r0.add(r1)     // Catch:{ all -> 0x003e }
            r6.runWriter()     // Catch:{ all -> 0x003e }
            r7 = 1
            monitor-exit(r6)
            return r7
        L_0x003c:
            monitor-exit(r6)
            return r1
        L_0x003e:
            r7 = move-exception
            monitor-exit(r6)
            throw r7
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.p270ws.RealWebSocket.send(g.h, int):boolean");
    }
}
