package okhttp3.internal.p270ws;

import java.io.Closeable;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.concurrent.TimeUnit;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.Intrinsics;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;

/* renamed from: okhttp3.internal.ws.WebSocketReader */
/* compiled from: WebSocketReader.kt */
public final class WebSocketReader implements Closeable {
    public boolean closed;
    public final C1948d controlFrameBuffer;
    public final FrameCallback frameCallback;
    public long frameLength;
    public final boolean isClient;
    public boolean isControlFrame;
    public boolean isFinalFrame;
    public final C1948d.C1949a maskCursor;
    public final byte[] maskKey;
    public final C1948d messageFrameBuffer;
    public MessageInflater messageInflater;
    public final boolean noContextTakeover;
    public int opcode;
    public final boolean perMessageDeflate;
    public boolean readingCompressedMessage;
    public final BufferedSource source;

    /* renamed from: okhttp3.internal.ws.WebSocketReader$FrameCallback */
    /* compiled from: WebSocketReader.kt */
    public interface FrameCallback {
        void onReadClose(int i, String str);

        void onReadMessage(C1952h hVar) throws IOException;

        void onReadMessage(String str) throws IOException;

        void onReadPing(C1952h hVar);

        void onReadPong(C1952h hVar);
    }

    public WebSocketReader(boolean z, BufferedSource gVar, FrameCallback frameCallback2, boolean z2, boolean z3) {
        C1948d.C1949a aVar = null;
        if (gVar == null) {
            Intrinsics.m5822a("source");
            throw null;
        } else if (frameCallback2 != null) {
            this.isClient = z;
            this.source = gVar;
            this.frameCallback = frameCallback2;
            this.perMessageDeflate = z2;
            this.noContextTakeover = z3;
            this.controlFrameBuffer = new C1948d();
            this.messageFrameBuffer = new C1948d();
            this.maskKey = this.isClient ? null : new byte[4];
            this.maskCursor = !this.isClient ? new C1948d.C1949a() : aVar;
        } else {
            Intrinsics.m5822a("frameCallback");
            throw null;
        }
    }

    private final void readControlFrame() throws IOException {
        String str;
        long j = this.frameLength;
        if (j > 0) {
            this.source.mo9474a(this.controlFrameBuffer, j);
            if (!this.isClient) {
                C1948d dVar = this.controlFrameBuffer;
                C1948d.C1949a aVar = this.maskCursor;
                if (aVar != null) {
                    dVar.mo9464a(aVar);
                    this.maskCursor.mo9522f(0);
                    WebSocketProtocol webSocketProtocol = WebSocketProtocol.INSTANCE;
                    C1948d.C1949a aVar2 = this.maskCursor;
                    byte[] bArr = this.maskKey;
                    if (bArr != null) {
                        webSocketProtocol.toggleMask(aVar2, bArr);
                        this.maskCursor.close();
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                } else {
                    Intrinsics.m5820a();
                    throw null;
                }
            }
        }
        switch (this.opcode) {
            case 8:
                short s = 1005;
                C1948d dVar2 = this.controlFrameBuffer;
                long j2 = dVar2.f7648c;
                if (j2 != 1) {
                    if (j2 != 0) {
                        s = dVar2.readShort();
                        str = this.controlFrameBuffer.mo9494h();
                        String closeCodeExceptionMessage = WebSocketProtocol.INSTANCE.closeCodeExceptionMessage(s);
                        if (closeCodeExceptionMessage != null) {
                            throw new ProtocolException(closeCodeExceptionMessage);
                        }
                    } else {
                        str = "";
                    }
                    this.frameCallback.onReadClose(s, str);
                    this.closed = true;
                    return;
                }
                throw new ProtocolException("Malformed close payload length of 1.");
            case 9:
                this.frameCallback.onReadPing(this.controlFrameBuffer.mo9486e());
                return;
            case 10:
                this.frameCallback.onReadPong(this.controlFrameBuffer.mo9486e());
                return;
            default:
                StringBuilder a = outline.m2937a("Unknown control opcode: ");
                a.append(Util.toHexString(this.opcode));
                throw new ProtocolException(a.toString());
        }
    }

    /* JADX INFO: finally extract failed */
    private final void readHeader() throws IOException, ProtocolException {
        if (!this.closed) {
            long timeoutNanos = this.source.timeout().timeoutNanos();
            this.source.timeout().clearTimeout();
            try {
                int and = Util.and(this.source.readByte(), 255);
                this.source.timeout().timeout(timeoutNanos, TimeUnit.NANOSECONDS);
                this.opcode = and & 15;
                boolean z = false;
                this.isFinalFrame = (and & 128) != 0;
                boolean z2 = (and & 8) != 0;
                this.isControlFrame = z2;
                if (!z2 || this.isFinalFrame) {
                    boolean z3 = (and & 64) != 0;
                    int i = this.opcode;
                    if (i == 1 || i == 2) {
                        if (!z3) {
                            this.readingCompressedMessage = false;
                        } else if (this.perMessageDeflate) {
                            this.readingCompressedMessage = true;
                        } else {
                            throw new ProtocolException("Unexpected rsv1 flag");
                        }
                    } else if (z3) {
                        throw new ProtocolException("Unexpected rsv1 flag");
                    }
                    if (!((and & 32) != 0)) {
                        if (!((and & 16) != 0)) {
                            int and2 = Util.and(this.source.readByte(), 255);
                            if ((and2 & 128) != 0) {
                                z = true;
                            }
                            if (z == this.isClient) {
                                throw new ProtocolException(this.isClient ? "Server-sent frames must not be masked." : "Client-sent frames must be masked.");
                            }
                            long j = (long) (and2 & 127);
                            this.frameLength = j;
                            if (j == ((long) WebSocketProtocol.PAYLOAD_SHORT)) {
                                this.frameLength = (long) Util.and(this.source.readShort(), 65535);
                            } else if (j == ((long) 127)) {
                                long readLong = this.source.readLong();
                                this.frameLength = readLong;
                                if (readLong < 0) {
                                    StringBuilder a = outline.m2937a("Frame length 0x");
                                    a.append(Util.toHexString(this.frameLength));
                                    a.append(" > 0x7FFFFFFFFFFFFFFF");
                                    throw new ProtocolException(a.toString());
                                }
                            }
                            if (this.isControlFrame && this.frameLength > 125) {
                                throw new ProtocolException("Control frame must be less than 125B.");
                            } else if (z) {
                                BufferedSource gVar = this.source;
                                byte[] bArr = this.maskKey;
                                if (bArr != null) {
                                    gVar.readFully(bArr);
                                } else {
                                    Intrinsics.m5820a();
                                    throw null;
                                }
                            }
                        } else {
                            throw new ProtocolException("Unexpected rsv3 flag");
                        }
                    } else {
                        throw new ProtocolException("Unexpected rsv2 flag");
                    }
                } else {
                    throw new ProtocolException("Control frames must be final.");
                }
            } catch (Throwable th) {
                this.source.timeout().timeout(timeoutNanos, TimeUnit.NANOSECONDS);
                throw th;
            }
        } else {
            throw new IOException("closed");
        }
    }

    private final void readMessage() throws IOException {
        while (!this.closed) {
            long j = this.frameLength;
            if (j > 0) {
                this.source.mo9474a(this.messageFrameBuffer, j);
                if (!this.isClient) {
                    C1948d dVar = this.messageFrameBuffer;
                    C1948d.C1949a aVar = this.maskCursor;
                    if (aVar != null) {
                        dVar.mo9464a(aVar);
                        this.maskCursor.mo9522f(this.messageFrameBuffer.f7648c - this.frameLength);
                        WebSocketProtocol webSocketProtocol = WebSocketProtocol.INSTANCE;
                        C1948d.C1949a aVar2 = this.maskCursor;
                        byte[] bArr = this.maskKey;
                        if (bArr != null) {
                            webSocketProtocol.toggleMask(aVar2, bArr);
                            this.maskCursor.close();
                        } else {
                            Intrinsics.m5820a();
                            throw null;
                        }
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
            }
            if (!this.isFinalFrame) {
                readUntilNonControlFrame();
                if (this.opcode != 0) {
                    StringBuilder a = outline.m2937a("Expected continuation opcode. Got: ");
                    a.append(Util.toHexString(this.opcode));
                    throw new ProtocolException(a.toString());
                }
            } else {
                return;
            }
        }
        throw new IOException("closed");
    }

    private final void readMessageFrame() throws IOException {
        int i = this.opcode;
        if (i == 1 || i == 2) {
            readMessage();
            if (this.readingCompressedMessage) {
                MessageInflater messageInflater2 = this.messageInflater;
                if (messageInflater2 == null) {
                    messageInflater2 = new MessageInflater(this.noContextTakeover);
                    this.messageInflater = messageInflater2;
                }
                messageInflater2.inflate(this.messageFrameBuffer);
            }
            if (i == 1) {
                this.frameCallback.onReadMessage(this.messageFrameBuffer.mo9494h());
            } else {
                this.frameCallback.onReadMessage(this.messageFrameBuffer.mo9486e());
            }
        } else {
            StringBuilder a = outline.m2937a("Unknown opcode: ");
            a.append(Util.toHexString(i));
            throw new ProtocolException(a.toString());
        }
    }

    private final void readUntilNonControlFrame() throws IOException {
        while (!this.closed) {
            readHeader();
            if (this.isControlFrame) {
                readControlFrame();
            } else {
                return;
            }
        }
    }

    public void close() throws IOException {
        MessageInflater messageInflater2 = this.messageInflater;
        if (messageInflater2 != null) {
            messageInflater2.close();
        }
    }

    public final BufferedSource getSource() {
        return this.source;
    }

    public final void processNextFrame() throws IOException {
        readHeader();
        if (this.isControlFrame) {
            readControlFrame();
        } else {
            readMessageFrame();
        }
    }
}
