package okhttp3.logging;

import androidx.recyclerview.widget.RecyclerView;
import com.newrelic.agent.android.util.Constants;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.Closeable;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.Comparator;
import java.util.Set;
import java.util.TreeSet;
import java.util.concurrent.TimeUnit;
import okhttp3.Connection;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.http.HttpHeaders;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p251i.Sets;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.GzipSource;
import p262g.Source;

/* compiled from: HttpLoggingInterceptor.kt */
public final class HttpLoggingInterceptor implements Interceptor {
    public volatile Set<String> headersToRedact;
    public volatile Level level;
    public final Logger logger;

    /* compiled from: HttpLoggingInterceptor.kt */
    public enum Level {
        NONE,
        BASIC,
        HEADERS,
        BODY
    }

    /* compiled from: HttpLoggingInterceptor.kt */
    public interface Logger {
        public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
        public static final Logger DEFAULT = new HttpLoggingInterceptor$Logger$Companion$DEFAULT$1();

        /* compiled from: HttpLoggingInterceptor.kt */
        public static final class Companion {
            public static final /* synthetic */ Companion $$INSTANCE = null;

            public Companion() {
            }

            public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
                this();
            }
        }

        void log(String str);
    }

    public HttpLoggingInterceptor() {
        this((Logger) null, 1, (DefaultConstructorMarker) null);
    }

    public HttpLoggingInterceptor(Logger logger2) {
        if (logger2 != null) {
            this.logger = logger2;
            this.headersToRedact = Sets.f7581b;
            this.level = Level.NONE;
            return;
        }
        Intrinsics.m5822a("logger");
        throw null;
    }

    private final boolean bodyHasUnknownEncoding(Headers headers) {
        String str = headers.get(Constants.Network.CONTENT_ENCODING_HEADER);
        if (str == null || C1937g.m5858a(str, "identity", true) || C1937g.m5858a(str, "gzip", true)) {
            return false;
        }
        return true;
    }

    private final void logHeader(Headers headers, int i) {
        String value = this.headersToRedact.contains(headers.name(i)) ? "██" : headers.value(i);
        Logger logger2 = this.logger;
        logger2.log(headers.name(i) + ": " + value);
    }

    /* renamed from: -deprecated_level  reason: not valid java name */
    public final Level m6172deprecated_level() {
        return this.level;
    }

    public final Level getLevel() {
        return this.level;
    }

    public Response intercept(Interceptor.Chain chain) throws IOException {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        Long l;
        Charset charset;
        Throwable th;
        Charset charset2;
        Interceptor.Chain chain2 = chain;
        if (chain2 != null) {
            Level level2 = this.level;
            Request request = chain.request();
            if (level2 == Level.NONE) {
                return chain2.proceed(request);
            }
            boolean z = level2 == Level.BODY;
            boolean z2 = z || level2 == Level.HEADERS;
            RequestBody body = request.body();
            Connection connection = chain.connection();
            StringBuilder a = outline.m2937a("--> ");
            a.append(request.method());
            a.append(SafeJsonPrimitive.NULL_CHAR);
            a.append(request.url());
            if (connection != null) {
                StringBuilder a2 = outline.m2937a(" ");
                a2.append(connection.protocol());
                str = a2.toString();
            } else {
                str = "";
            }
            a.append(str);
            String sb = a.toString();
            if (!z2 && body != null) {
                StringBuilder a3 = outline.m2938a(sb, " (");
                a3.append(body.contentLength());
                a3.append("-byte body)");
                sb = a3.toString();
            }
            this.logger.log(sb);
            if (z2) {
                Headers headers = request.headers();
                if (body != null) {
                    MediaType contentType = body.contentType();
                    if (contentType != null && headers.get(Constants.Network.CONTENT_TYPE_HEADER) == null) {
                        this.logger.log("Content-Type: " + contentType);
                    }
                    if (body.contentLength() != -1 && headers.get("Content-Length") == null) {
                        Logger logger2 = this.logger;
                        StringBuilder a4 = outline.m2937a("Content-Length: ");
                        a4.append(body.contentLength());
                        logger2.log(a4.toString());
                    }
                }
                int size = headers.size();
                for (int i = 0; i < size; i++) {
                    logHeader(headers, i);
                }
                if (!z || body == null) {
                    Logger logger3 = this.logger;
                    StringBuilder a5 = outline.m2937a("--> END ");
                    a5.append(request.method());
                    logger3.log(a5.toString());
                } else if (bodyHasUnknownEncoding(request.headers())) {
                    Logger logger4 = this.logger;
                    StringBuilder a6 = outline.m2937a("--> END ");
                    a6.append(request.method());
                    a6.append(" (encoded body omitted)");
                    logger4.log(a6.toString());
                } else if (body.isDuplex()) {
                    Logger logger5 = this.logger;
                    StringBuilder a7 = outline.m2937a("--> END ");
                    a7.append(request.method());
                    a7.append(" (duplex request body omitted)");
                    logger5.log(a7.toString());
                } else if (body.isOneShot()) {
                    Logger logger6 = this.logger;
                    StringBuilder a8 = outline.m2937a("--> END ");
                    a8.append(request.method());
                    a8.append(" (one-shot body omitted)");
                    logger6.log(a8.toString());
                } else {
                    C1948d dVar = new C1948d();
                    body.writeTo(dVar);
                    MediaType contentType2 = body.contentType();
                    if (contentType2 == null || (charset2 = contentType2.charset(StandardCharsets.UTF_8)) == null) {
                        charset2 = StandardCharsets.UTF_8;
                        Intrinsics.m5821a((Object) charset2, "UTF_8");
                    }
                    this.logger.log("");
                    if (Utf8Kt.isProbablyUtf8(dVar)) {
                        this.logger.log(dVar.mo9473a(charset2));
                        Logger logger7 = this.logger;
                        StringBuilder a9 = outline.m2937a("--> END ");
                        a9.append(request.method());
                        a9.append(" (");
                        a9.append(body.contentLength());
                        a9.append("-byte body)");
                        logger7.log(a9.toString());
                    } else {
                        Logger logger8 = this.logger;
                        StringBuilder a10 = outline.m2937a("--> END ");
                        a10.append(request.method());
                        a10.append(" (binary ");
                        a10.append(body.contentLength());
                        a10.append("-byte body omitted)");
                        logger8.log(a10.toString());
                    }
                }
            }
            long nanoTime = System.nanoTime();
            try {
                Response proceed = chain2.proceed(request);
                long millis = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - nanoTime);
                ResponseBody body2 = proceed.body();
                if (body2 != null) {
                    long contentLength = body2.contentLength();
                    if (contentLength != -1) {
                        str2 = contentLength + "-byte";
                    } else {
                        str2 = "unknown-length";
                    }
                    Logger logger9 = this.logger;
                    String str6 = "-byte body)";
                    StringBuilder a11 = outline.m2937a("<-- ");
                    long j = contentLength;
                    a11.append(proceed.code());
                    if (proceed.message().length() == 0) {
                        str3 = "-byte body omitted)";
                        str4 = "";
                    } else {
                        String message = proceed.message();
                        StringBuilder sb2 = new StringBuilder();
                        str3 = "-byte body omitted)";
                        sb2.append(String.valueOf(SafeJsonPrimitive.NULL_CHAR));
                        sb2.append(message);
                        str4 = sb2.toString();
                    }
                    a11.append(str4);
                    a11.append(SafeJsonPrimitive.NULL_CHAR);
                    a11.append(proceed.request().url());
                    a11.append(" (");
                    a11.append(millis);
                    a11.append("ms");
                    if (!z2) {
                        str5 = outline.m2934a(", ", str2, " body");
                    } else {
                        str5 = "";
                    }
                    a11.append(str5);
                    a11.append(')');
                    logger9.log(a11.toString());
                    if (z2) {
                        Headers headers2 = proceed.headers();
                        int size2 = headers2.size();
                        for (int i2 = 0; i2 < size2; i2++) {
                            logHeader(headers2, i2);
                        }
                        if (!z || !HttpHeaders.promisesBody(proceed)) {
                            this.logger.log("<-- END HTTP");
                        } else if (bodyHasUnknownEncoding(proceed.headers())) {
                            this.logger.log("<-- END HTTP (encoded body omitted)");
                        } else {
                            BufferedSource source = body2.source();
                            source.mo9484d(RecyclerView.FOREVER_NS);
                            C1948d buffer = source.getBuffer();
                            if (C1937g.m5858a("gzip", headers2.get(Constants.Network.CONTENT_ENCODING_HEADER), true)) {
                                l = Long.valueOf(buffer.f7648c);
                                GzipSource mVar = new GzipSource(buffer.clone());
                                try {
                                    buffer = new C1948d();
                                    buffer.mo9463a((Source) mVar);
                                    C1050v.m4176a((Closeable) mVar, (Throwable) null);
                                } catch (Throwable th2) {
                                    Throwable th3 = th2;
                                    C1050v.m4176a((Closeable) mVar, th);
                                    throw th3;
                                }
                            } else {
                                l = null;
                            }
                            MediaType contentType3 = body2.contentType();
                            if (contentType3 == null || (charset = contentType3.charset(StandardCharsets.UTF_8)) == null) {
                                charset = StandardCharsets.UTF_8;
                                Intrinsics.m5821a((Object) charset, "UTF_8");
                            }
                            if (!Utf8Kt.isProbablyUtf8(buffer)) {
                                this.logger.log("");
                                Logger logger10 = this.logger;
                                StringBuilder a12 = outline.m2937a("<-- END HTTP (binary ");
                                a12.append(buffer.f7648c);
                                a12.append(str3);
                                logger10.log(a12.toString());
                                return proceed;
                            }
                            if (j != 0) {
                                this.logger.log("");
                                this.logger.log(buffer.clone().mo9473a(charset));
                            }
                            if (l != null) {
                                Logger logger11 = this.logger;
                                StringBuilder a13 = outline.m2937a("<-- END HTTP (");
                                a13.append(buffer.f7648c);
                                a13.append("-byte, ");
                                a13.append(l);
                                a13.append("-gzipped-byte body)");
                                logger11.log(a13.toString());
                            } else {
                                Logger logger12 = this.logger;
                                StringBuilder a14 = outline.m2937a("<-- END HTTP (");
                                a14.append(buffer.f7648c);
                                a14.append(str6);
                                logger12.log(a14.toString());
                            }
                        }
                    }
                    return proceed;
                }
                Intrinsics.m5820a();
                throw null;
            } catch (Exception e) {
                Exception exc = e;
                this.logger.log("<-- HTTP FAILED: " + exc);
                throw exc;
            }
        } else {
            Intrinsics.m5822a("chain");
            throw null;
        }
    }

    public final void level(Level level2) {
        if (level2 != null) {
            this.level = level2;
        } else {
            Intrinsics.m5822a("<set-?>");
            throw null;
        }
    }

    public final void redactHeader(String str) {
        if (str != null) {
            Comparator comparator = String.CASE_INSENSITIVE_ORDER;
            Intrinsics.m5821a((Object) comparator, "java.lang.String.CASE_INSENSITIVE_ORDER");
            TreeSet treeSet = new TreeSet(comparator);
            C1050v.m4187a(treeSet, this.headersToRedact);
            treeSet.add(str);
            this.headersToRedact = treeSet;
            return;
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final HttpLoggingInterceptor setLevel(Level level2) {
        if (level2 != null) {
            this.level = level2;
            return this;
        }
        Intrinsics.m5822a("level");
        throw null;
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ HttpLoggingInterceptor(Logger logger2, int i, DefaultConstructorMarker fVar) {
        this((i & 1) != 0 ? Logger.DEFAULT : logger2);
    }
}
