package com.newrelic.agent.android.instrumentation;

import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import com.newrelic.agent.android.tracing.TraceMachine;
import java.io.Reader;
import java.io.StringReader;
import java.io.StringWriter;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Arrays;
import p085c.p132d.p184b.C1319k;
import p085c.p132d.p184b.JsonElement;
import p085c.p132d.p184b.JsonIOException;
import p085c.p132d.p184b.JsonNull;
import p085c.p132d.p184b.JsonSyntaxException;
import p085c.p132d.p184b.p186e0.Primitives;
import p085c.p132d.p184b.p186e0.p187z.JsonTreeReader;

public class GsonInstrumentation {
    public static final ArrayList<String> categoryParams = new ArrayList<>(Arrays.asList(new String[]{"category", MetricCategory.class.getName(), "JSON"}));

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, String str, Class<T> cls) throws JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        T a = kVar.mo5712a(str, cls);
        TraceMachine.exitMethod();
        return a;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static String toJson(C1319k kVar, Object obj) {
        String str;
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        if (kVar != null) {
            if (obj == null) {
                str = toJson(kVar, (JsonElement) JsonNull.f5948a);
            } else {
                str = toJson(kVar, obj, (Type) obj.getClass());
            }
            TraceMachine.exitMethod();
            return str;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, String str, Type type) throws JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        T t = null;
        if (kVar != null) {
            if (str != null) {
                t = fromJson(kVar, (Reader) new StringReader(str), type);
            }
            TraceMachine.exitMethod();
            return t;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static String toJson(C1319k kVar, Object obj, Type type) {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        if (kVar != null) {
            StringWriter stringWriter = new StringWriter();
            toJson(kVar, obj, type, (Appendable) stringWriter);
            String stringWriter2 = stringWriter.toString();
            TraceMachine.exitMethod();
            return stringWriter2;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, Reader reader, Class<T> cls) throws JsonSyntaxException, JsonIOException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        JsonReader a = kVar.mo5709a(reader);
        T fromJson = fromJson(kVar, a, (Type) cls);
        C1319k.m4731a((Object) fromJson, a);
        T cast = Primitives.m4703a(cls).cast(fromJson);
        TraceMachine.exitMethod();
        return cast;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static void toJson(C1319k kVar, Object obj, Appendable appendable) throws JsonIOException {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        if (kVar != null) {
            if (obj != null) {
                toJson(kVar, obj, (Type) obj.getClass(), appendable);
            } else {
                toJson(kVar, (JsonElement) JsonNull.f5948a, appendable);
            }
            TraceMachine.exitMethod();
            return;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, Reader reader, Type type) throws JsonIOException, JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        JsonReader a = kVar.mo5709a(reader);
        T fromJson = fromJson(kVar, a, type);
        C1319k.m4731a((Object) fromJson, a);
        TraceMachine.exitMethod();
        return fromJson;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static void toJson(C1319k kVar, Object obj, Type type, Appendable appendable) throws JsonIOException {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        kVar.mo5716a(obj, type, appendable);
        TraceMachine.exitMethod();
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, JsonReader jsonReader, Type type) throws JsonIOException, JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        T a = kVar.mo5711a(jsonReader, type);
        TraceMachine.exitMethod();
        return a;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static void toJson(C1319k kVar, Object obj, Type type, JsonWriter jsonWriter) throws JsonIOException {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        kVar.mo5715a(obj, type, jsonWriter);
        TraceMachine.exitMethod();
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, JsonElement qVar, Class<T> cls) throws JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        if (kVar != null) {
            T cast = Primitives.m4703a(cls).cast(fromJson(kVar, qVar, (Type) cls));
            TraceMachine.exitMethod();
            return cast;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static String toJson(C1319k kVar, JsonElement qVar) {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        if (kVar != null) {
            StringWriter stringWriter = new StringWriter();
            toJson(kVar, qVar, (Appendable) stringWriter);
            String stringWriter2 = stringWriter.toString();
            TraceMachine.exitMethod();
            return stringWriter2;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static <T> T fromJson(C1319k kVar, JsonElement qVar, Type type) throws JsonSyntaxException {
        TraceMachine.enterMethod("Gson#fromJson", categoryParams);
        T t = null;
        if (kVar != null) {
            if (qVar != null) {
                t = fromJson(kVar, (JsonReader) new JsonTreeReader(qVar), type);
            }
            TraceMachine.exitMethod();
            return t;
        }
        throw null;
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static void toJson(C1319k kVar, JsonElement qVar, Appendable appendable) throws JsonIOException {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        kVar.mo5714a(qVar, appendable);
        TraceMachine.exitMethod();
    }

    @ReplaceCallSite(scope = "com.google.gson.Gson")
    public static void toJson(C1319k kVar, JsonElement qVar, JsonWriter jsonWriter) throws JsonIOException {
        TraceMachine.enterMethod("Gson#toJson", categoryParams);
        kVar.mo5713a(qVar, jsonWriter);
        TraceMachine.exitMethod();
    }
}
