package com.newrelic.agent.android.instrumentation.okhttp2;

import com.newrelic.agent.android.Measurements;
import com.newrelic.agent.android.TaskQueue;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.instrumentation.TransactionState;
import com.newrelic.agent.android.instrumentation.TransactionStateUtil;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.measurement.http.HttpTransactionMeasurement;
import com.newrelic.agent.android.util.Constants;
import com.newrelic.agent.android.util.Reachability;
import com.squareup.okhttp.Request;
import com.squareup.okhttp.Response;
import com.squareup.okhttp.ResponseBody;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.TreeMap;
import p085c.p086a.p087a.p088a.outline;
import p262g.C1948d;

public class OkHttp2TransactionStateUtil extends TransactionStateUtil {
    public static Response addTransactionAndErrorData(TransactionState transactionState, Response response) {
        TransactionData end = transactionState.end();
        if (end != null) {
            if (response != null && transactionState.isErrorOrFailure()) {
                String header = response.header(Constants.Network.CONTENT_TYPE_HEADER);
                TreeMap treeMap = new TreeMap();
                if (header != null && !header.isEmpty()) {
                    treeMap.put(Constants.Transactions.CONTENT_TYPE, header);
                }
                StringBuilder sb = new StringBuilder();
                sb.append(transactionState.getBytesReceived());
                String str = "";
                sb.append(str);
                treeMap.put(Constants.Transactions.CONTENT_LENGTH, sb.toString());
                try {
                    if (response.body() != null) {
                        ResponseBody body = response.body();
                        ByteBuffer wrap = ByteBuffer.wrap(body.bytes());
                        C1948d dVar = new C1948d();
                        dVar.write(wrap.array());
                        response = response.newBuilder().body(new PrebufferedResponseBody(body, dVar)).build();
                        str = new String(wrap.array());
                    } else if (response.message() != null) {
                        TransactionStateUtil.log.debug("Missing response body, using response message");
                        str = response.message();
                    }
                } catch (Exception unused) {
                    if (response.message() != null) {
                        TransactionStateUtil.log.debug("Missing response body, using response message");
                        str = response.message();
                    }
                }
                end.setResponseBody(str);
                end.setParams(treeMap);
                Measurements.addHttpError(end);
            }
            TaskQueue.queue(new HttpTransactionMeasurement(end));
        }
        return response;
    }

    public static long exhaustiveContentLength(Response response) {
        long j = -1;
        if (response == null) {
            return -1;
        }
        if (response.body() != null) {
            try {
                j = response.body().contentLength();
            } catch (IOException e) {
                AgentLog agentLog = TransactionStateUtil.log;
                StringBuilder a = outline.m2937a("Failed to parse content length: ");
                a.append(e.toString());
                agentLog.debug(a.toString());
            }
        }
        if (j >= 0) {
            return j;
        }
        String header = response.header(Constants.Network.CONTENT_LENGTH_HEADER);
        if (header == null || header.length() <= 0) {
            Response networkResponse = response.networkResponse();
            if (networkResponse == null) {
                return j;
            }
            String header2 = networkResponse.header(Constants.Network.CONTENT_LENGTH_HEADER);
            if (header2 != null && header2.length() > 0) {
                try {
                    return Long.parseLong(header2);
                } catch (NumberFormatException e2) {
                    AgentLog agentLog2 = TransactionStateUtil.log;
                    StringBuilder a2 = outline.m2937a("Failed to parse content length: ");
                    a2.append(e2.toString());
                    agentLog2.debug(a2.toString());
                    return j;
                }
            } else if (networkResponse.body() == null) {
                return j;
            } else {
                try {
                    return networkResponse.body().contentLength();
                } catch (IOException e3) {
                    AgentLog agentLog3 = TransactionStateUtil.log;
                    StringBuilder a3 = outline.m2937a("Failed to parse network response content length: ");
                    a3.append(e3.toString());
                    agentLog3.debug(a3.toString());
                    e3.printStackTrace();
                    return j;
                }
            }
        } else {
            try {
                return Long.parseLong(header);
            } catch (NumberFormatException e4) {
                AgentLog agentLog4 = TransactionStateUtil.log;
                StringBuilder a4 = outline.m2937a("Failed to parse content length: ");
                a4.append(e4.toString());
                agentLog4.debug(a4.toString());
                return j;
            }
        }
    }

    public static void inspectAndInstrument(TransactionState transactionState, Request request) {
        if (request == null) {
            TransactionStateUtil.log.debug("Missing request");
        } else {
            TransactionStateUtil.inspectAndInstrument(transactionState, request.urlString(), request.method());
        }
    }

    public static Response inspectAndInstrumentResponse(TransactionState transactionState, Response response) {
        int i;
        String str = "";
        long j = 0;
        if (response == null) {
            i = Reachability.REACHABILITY_TIMEOUT;
            TransactionStateUtil.log.debug("Missing response");
        } else {
            Request request = response.request();
            if (!(request == null || request.url() == null)) {
                String url = request.url().toString();
                if (!url.isEmpty()) {
                    TransactionStateUtil.inspectAndInstrument(transactionState, url, request.method());
                }
            }
            i = -1;
            try {
                str = response.header(Constants.Network.APP_DATA_HEADER);
                i = response.code();
                j = exhaustiveContentLength(response);
            } catch (Exception unused) {
                TransactionStateUtil.log.debug("Missing body or content length");
            }
        }
        TransactionStateUtil.inspectAndInstrumentResponse(transactionState, str, (int) j, i);
        return addTransactionAndErrorData(transactionState, response);
    }
}
