package com.newrelic.agent.android.instrumentation.okhttp3;

import com.newrelic.agent.android.Measurements;
import com.newrelic.agent.android.TaskQueue;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.instrumentation.TransactionState;
import com.newrelic.agent.android.instrumentation.TransactionStateUtil;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.measurement.http.HttpTransactionMeasurement;
import com.newrelic.agent.android.util.Constants;
import com.newrelic.agent.android.util.Reachability;
import java.util.TreeMap;
import okhttp3.Request;
import okhttp3.Response;
import p085c.p086a.p087a.p088a.outline;

public class OkHttp3TransactionStateUtil extends TransactionStateUtil {
    public static Response addTransactionAndErrorData(TransactionState transactionState, Response response) {
        TransactionData end = transactionState.end();
        if (end != null) {
            if (response != null && transactionState.isErrorOrFailure()) {
                String header = response.header(Constants.Network.CONTENT_TYPE_HEADER);
                TreeMap treeMap = new TreeMap();
                if (header != null && !header.isEmpty()) {
                    treeMap.put(Constants.Transactions.CONTENT_TYPE, header);
                }
                StringBuilder sb = new StringBuilder();
                sb.append(transactionState.getBytesReceived());
                String str = "";
                sb.append(str);
                treeMap.put(Constants.Transactions.CONTENT_LENGTH, sb.toString());
                try {
                    long exhaustiveContentLength = exhaustiveContentLength(response);
                    if (exhaustiveContentLength > 0) {
                        str = response.peekBody(exhaustiveContentLength).string();
                    }
                } catch (Exception unused) {
                    if (response.message() != null) {
                        TransactionStateUtil.log.debug("Missing response body, using response message");
                        str = response.message();
                    }
                }
                end.setResponseBody(str);
                end.setParams(treeMap);
                Measurements.addHttpError(end);
            }
            TaskQueue.queue(new HttpTransactionMeasurement(end));
        }
        return response;
    }

    public static long exhaustiveContentLength(Response response) {
        long j = -1;
        if (response == null) {
            return -1;
        }
        if (response.body() != null) {
            j = response.body().contentLength();
        }
        if (j >= 0) {
            return j;
        }
        String header = response.header(Constants.Network.CONTENT_LENGTH_HEADER);
        if (header == null || header.length() <= 0) {
            Response networkResponse = response.networkResponse();
            if (networkResponse == null) {
                return j;
            }
            String header2 = networkResponse.header(Constants.Network.CONTENT_LENGTH_HEADER);
            if (header2 == null || header2.length() <= 0) {
                return networkResponse.body() != null ? networkResponse.body().contentLength() : j;
            }
            try {
                return Long.parseLong(header2);
            } catch (NumberFormatException e) {
                AgentLog agentLog = TransactionStateUtil.log;
                StringBuilder a = outline.m2937a("Failed to parse network response content length: ");
                a.append(e.toString());
                agentLog.debug(a.toString());
                return j;
            }
        } else {
            try {
                return Long.parseLong(header);
            } catch (NumberFormatException e2) {
                AgentLog agentLog2 = TransactionStateUtil.log;
                StringBuilder a2 = outline.m2937a("Failed to parse content length: ");
                a2.append(e2.toString());
                agentLog2.debug(a2.toString());
                return j;
            }
        }
    }

    public static void inspectAndInstrument(TransactionState transactionState, Request request) {
        if (request == null) {
            TransactionStateUtil.log.debug("Missing request");
        } else {
            TransactionStateUtil.inspectAndInstrument(transactionState, request.url().toString(), request.method());
        }
    }

    public static Response inspectAndInstrumentResponse(TransactionState transactionState, Response response) {
        String str;
        int i;
        long j;
        long j2 = 0;
        if (response == null) {
            i = Reachability.REACHABILITY_TIMEOUT;
            TransactionStateUtil.log.debug("Missing response");
            str = "";
        } else {
            Request request = response.request();
            if (!(request == null || request.url() == null)) {
                String httpUrl = request.url().toString();
                if (!httpUrl.isEmpty()) {
                    TransactionStateUtil.inspectAndInstrument(transactionState, httpUrl, request.method());
                }
            }
            str = response.header(Constants.Network.APP_DATA_HEADER);
            i = response.code();
            try {
                j = exhaustiveContentLength(response);
            } catch (Exception unused) {
                j = 0;
            }
            if (j < 0) {
                TransactionStateUtil.log.debug("OkHttp3TransactionStateUtil: Missing body or content length");
            }
            j2 = j;
        }
        TransactionStateUtil.inspectAndInstrumentResponse(transactionState, str, (int) j2, i);
        return addTransactionAndErrorData(transactionState, response);
    }
}
