package com.newrelic.agent.android.measurement;

import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import p085c.p086a.p087a.p088a.outline;

public class BaseMeasurement implements Measurement {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public long endTime;
    public long exclusiveTime;
    public boolean finished;
    public String name;
    public String scope;
    public long startTime;
    public ThreadInfo threadInfo;
    public MeasurementType type;

    public BaseMeasurement(MeasurementType measurementType) {
        setType(measurementType);
    }

    private boolean logIfFinished() {
        if (this.finished) {
            log.warning("BaseMeasuredActivity: cannot modify finished Activity");
        }
        return this.finished;
    }

    private void throwIfFinished() {
        if (this.finished) {
            throw new MeasurementException("Attempted to modify finished Measurement");
        }
    }

    public double asDouble() {
        throw new UnsupportedOperationException();
    }

    public void finish() {
        if (!this.finished) {
            this.finished = true;
            return;
        }
        throw new MeasurementException("Finish called on already finished Measurement");
    }

    public long getEndTime() {
        return this.endTime;
    }

    public double getEndTimeInSeconds() {
        return ((double) this.endTime) / 1000.0d;
    }

    public long getExclusiveTime() {
        return this.exclusiveTime;
    }

    public double getExclusiveTimeInSeconds() {
        return ((double) this.exclusiveTime) / 1000.0d;
    }

    public String getName() {
        return this.name;
    }

    public String getScope() {
        return this.scope;
    }

    public long getStartTime() {
        return this.startTime;
    }

    public double getStartTimeInSeconds() {
        return ((double) this.startTime) / 1000.0d;
    }

    public ThreadInfo getThreadInfo() {
        return this.threadInfo;
    }

    public MeasurementType getType() {
        return this.type;
    }

    public boolean isFinished() {
        return this.finished;
    }

    public boolean isInstantaneous() {
        return this.endTime == 0;
    }

    public void setEndTime(long j) {
        if (logIfFinished()) {
            return;
        }
        if (j < this.startTime) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Measurement end time must not precede start time - startTime: ");
            a.append(this.startTime);
            a.append(" endTime: ");
            a.append(j);
            agentLog.error(a.toString());
            return;
        }
        this.endTime = j;
    }

    public void setExclusiveTime(long j) {
        if (!logIfFinished()) {
            this.exclusiveTime = j;
        }
    }

    public void setName(String str) {
        if (!logIfFinished()) {
            this.name = str;
        }
    }

    public void setScope(String str) {
        if (!logIfFinished()) {
            this.scope = str;
        }
    }

    public void setStartTime(long j) {
        if (!logIfFinished()) {
            this.startTime = j;
        }
    }

    public void setThreadInfo(ThreadInfo threadInfo2) {
        this.threadInfo = threadInfo2;
    }

    public void setType(MeasurementType measurementType) {
        if (!logIfFinished()) {
            this.type = measurementType;
        }
    }

    public String toString() {
        StringBuilder a = outline.m2937a("BaseMeasurement{type=");
        a.append(this.type);
        a.append(", name='");
        outline.m2940a(a, this.name, '\'', ", scope='");
        outline.m2940a(a, this.scope, '\'', ", startTime=");
        a.append(this.startTime);
        a.append(", endTime=");
        a.append(this.endTime);
        a.append(", exclusiveTime=");
        a.append(this.exclusiveTime);
        a.append(", threadInfo=");
        a.append(this.threadInfo);
        a.append(", finished=");
        a.append(this.finished);
        a.append('}');
        return a.toString();
    }

    public BaseMeasurement(Measurement measurement) {
        setType(measurement.getType());
        setName(measurement.getName());
        setScope(measurement.getScope());
        setStartTime(measurement.getStartTime());
        setEndTime(measurement.getEndTime());
        setExclusiveTime(measurement.getExclusiveTime());
        setThreadInfo(measurement.getThreadInfo());
        this.finished = measurement.isFinished();
    }
}
