package com.newrelic.agent.android.measurement.http;

import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.connectivity.CatPayload;
import com.newrelic.agent.android.measurement.BaseMeasurement;
import com.newrelic.agent.android.measurement.MeasurementType;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.Util;
import java.util.Map;
import p085c.p086a.p087a.p088a.outline;

public class HttpTransactionMeasurement extends BaseMeasurement {
    public String appData;
    public long bytesReceived;
    public long bytesSent;
    public int errorCode;
    public String httpMethod;
    public Map<String, String> params;
    public CatPayload payload;
    public String responseBody;
    public int statusCode;
    public double totalTime;
    public String url;

    public HttpTransactionMeasurement(String str, String str2, int i, int i2, long j, double d, long j2, long j3, String str3) {
        super(MeasurementType.Network);
        String sanitizeUrl = Util.sanitizeUrl(str);
        setName(sanitizeUrl);
        setScope(TraceMachine.getCurrentScope());
        setStartTime(j);
        setEndTime(j + ((long) ((int) d)));
        setExclusiveTime((long) ((int) (1000.0d * d)));
        this.url = sanitizeUrl;
        this.httpMethod = str2;
        this.statusCode = i;
        this.bytesSent = j2;
        this.bytesReceived = j3;
        this.totalTime = d;
        this.appData = str3;
        this.errorCode = i2;
        this.responseBody = null;
        this.params = null;
        this.payload = null;
    }

    public double asDouble() {
        return this.totalTime;
    }

    public String getAppData() {
        return this.appData;
    }

    public long getBytesReceived() {
        return this.bytesReceived;
    }

    public long getBytesSent() {
        return this.bytesSent;
    }

    public CatPayload getCatPayload() {
        return this.payload;
    }

    public int getErrorCode() {
        return this.errorCode;
    }

    public String getHttpMethod() {
        return this.httpMethod;
    }

    public Map<String, String> getParams() {
        return this.params;
    }

    public String getResponseBody() {
        return this.responseBody;
    }

    public int getStatusCode() {
        return this.statusCode;
    }

    public double getTotalTime() {
        return this.totalTime;
    }

    public String getUrl() {
        return this.url;
    }

    public void setUrl(String str) {
        this.url = str;
    }

    public String toString() {
        StringBuilder a = outline.m2937a("HttpTransactionMeasurement{url='");
        outline.m2940a(a, this.url, '\'', ", httpMethod='");
        outline.m2940a(a, this.httpMethod, '\'', ", totalTime=");
        a.append(this.totalTime);
        a.append(", statusCode=");
        a.append(this.statusCode);
        a.append(", errorCode=");
        a.append(this.errorCode);
        a.append(", bytesSent=");
        a.append(this.bytesSent);
        a.append(", bytesReceived=");
        a.append(this.bytesReceived);
        a.append(", appData='");
        outline.m2940a(a, this.appData, '\'', ", responseBody='");
        outline.m2940a(a, this.responseBody, '\'', ", params='");
        a.append(this.params);
        a.append('\'');
        a.append('}');
        return a.toString();
    }

    public HttpTransactionMeasurement(TransactionData transactionData) {
        this(transactionData.getUrl(), transactionData.getHttpMethod(), transactionData.getStatusCode(), transactionData.getErrorCode(), transactionData.getTimestamp(), (double) transactionData.getTime(), transactionData.getBytesSent(), transactionData.getBytesReceived(), transactionData.getAppData());
        this.responseBody = transactionData.getResponseBody();
        this.params = transactionData.getParams();
        this.payload = transactionData.getCatPayload();
    }
}
