package com.newrelic.agent.android.measurement.producer;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.measurement.MeasurementType;
import com.newrelic.agent.android.measurement.ThreadInfo;
import com.newrelic.agent.android.measurement.http.HttpErrorMeasurement;
import com.newrelic.agent.android.util.Util;
import java.util.HashMap;
import java.util.Map;

public class HttpErrorMeasurementProducer extends BaseMeasurementProducer {
    public static final String HTTP_METHOD_PARAMS_KEY = "http_method";
    public static final String WAN_TYPE_PARAMS_KEY = "wan_type";
    public static final AgentLog log = AgentLogManager.getAgentLog();

    public HttpErrorMeasurementProducer() {
        super(MeasurementType.HttpError);
    }

    private String getSanitizedStackTrace() {
        StringBuilder sb = new StringBuilder();
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        int i = 0;
        for (int i2 = 0; i2 < stackTrace.length; i2++) {
            StackTraceElement stackTraceElement = stackTrace[i2];
            if (!shouldFilterStackTraceElement(stackTraceElement)) {
                sb.append(stackTraceElement.toString());
                if (i2 <= stackTrace.length - 1) {
                    sb.append("\n");
                }
                i++;
                if (i >= Agent.getStackTraceLimit()) {
                    break;
                }
            }
        }
        return sb.toString();
    }

    private boolean shouldFilterStackTraceElement(StackTraceElement stackTraceElement) {
        String className = stackTraceElement.getClassName();
        String methodName = stackTraceElement.getMethodName();
        if (className.startsWith("com.newrelic")) {
            return true;
        }
        if (className.startsWith("dalvik.system.VMStack") && methodName.startsWith("getThreadStackTrace")) {
            return true;
        }
        if (!className.startsWith("java.lang.Thread") || !methodName.startsWith("getStackTrace")) {
            return false;
        }
        return true;
    }

    public void produceMeasurement(String str, String str2, int i, int i2, String str3, Map<String, String> map, ThreadInfo threadInfo) {
        HttpErrorMeasurement httpErrorMeasurement = new HttpErrorMeasurement(str, i);
        httpErrorMeasurement.setHttpMethod(str2);
        httpErrorMeasurement.setErrorCode(i2);
        httpErrorMeasurement.setResponseBody(str3);
        httpErrorMeasurement.setParams(map);
        httpErrorMeasurement.setThreadInfo(threadInfo);
        httpErrorMeasurement.setTotalTime(0.0d);
        produceMeasurement(httpErrorMeasurement);
    }

    public void produceMeasurement(HttpErrorMeasurement httpErrorMeasurement) {
        String sanitizeUrl = Util.sanitizeUrl(httpErrorMeasurement.getUrl());
        if (sanitizeUrl == null) {
            log.error("HttpErrorMeasurementProducer.produceMeasurement: URL is null");
            return;
        }
        Map params = httpErrorMeasurement.getParams();
        if (params == null) {
            params = new HashMap();
        }
        params.put(HTTP_METHOD_PARAMS_KEY, httpErrorMeasurement.getHttpMethod());
        params.put(WAN_TYPE_PARAMS_KEY, Agent.getActiveNetworkWanType());
        httpErrorMeasurement.setUrl(sanitizeUrl);
        httpErrorMeasurement.setParams(params);
        httpErrorMeasurement.setStackTrace(getSanitizedStackTrace());
        httpErrorMeasurement.setWanType(Agent.getActiveNetworkWanType());
        super.produceMeasurement(httpErrorMeasurement);
    }
}
