package com.newrelic.agent.android.payload;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.stats.TicToc;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.util.concurrent.Callable;
import p085c.p086a.p087a.p088a.outline;

public abstract class PayloadSender implements Callable<PayloadSender> {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public final AgentConfiguration agentConfiguration;
    public Payload payload;
    public int responseCode;
    public final TicToc timer;

    public interface CompletionHandler {
        void onException(PayloadSender payloadSender, Exception exc);

        void onResponse(PayloadSender payloadSender);
    }

    public PayloadSender(AgentConfiguration agentConfiguration2) {
        this.agentConfiguration = agentConfiguration2;
        this.timer = new TicToc();
        this.responseCode = 0;
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof PayloadSender) || getPayload() != ((PayloadSender) obj).getPayload()) {
            return false;
        }
        return true;
    }

    public abstract HttpURLConnection getConnection() throws IOException;

    public Payload getPayload() {
        return this.payload;
    }

    public String getProtocol() {
        return this.agentConfiguration.useSsl() ? "https://" : "http://";
    }

    public int getResponseCode() {
        return this.responseCode;
    }

    public boolean isSuccessfulResponse() {
        int i = this.responseCode;
        return i == 200 || i == 500;
    }

    public void onFailedUpload(String str) {
        log.error(str);
    }

    public void onRequestContent(String str) {
    }

    public void onRequestException(Exception exc) {
        StringBuilder a = outline.m2937a("Payload [");
        a.append(this.payload.getUuid());
        a.append("] upload failed: ");
        a.append(exc);
        onFailedUpload(a.toString());
    }

    public void onRequestResponse(HttpURLConnection httpURLConnection) throws IOException {
        int responseCode2 = httpURLConnection.getResponseCode();
        if (responseCode2 == 200) {
            InputStream inputStream = httpURLConnection.getInputStream();
            if (inputStream != null) {
                onRequestContent(readStream(inputStream, inputStream.available()));
            }
        } else if (responseCode2 == 403 || responseCode2 == 500) {
            StringBuilder a = outline.m2937a("Payload [");
            a.append(this.payload.getUuid());
            a.append("] was rejected and will be deleted - Response code [");
            a.append(responseCode2);
            a.append("]");
            onFailedUpload(a.toString());
        } else {
            StringBuilder a2 = outline.m2937a("Something went wrong while submitting the payload [");
            a2.append(this.payload.getUuid());
            a2.append("] (will try again later) - Response code [");
            a2.append(responseCode2);
            a2.append("]");
            onFailedUpload(a2.toString());
        }
        AgentLog agentLog = log;
        StringBuilder a3 = outline.m2937a("Payload [");
        a3.append(this.payload.getUuid());
        a3.append("] delivery took ");
        a3.append(this.timer.toc());
        a3.append("ms");
        agentLog.debug(a3.toString());
    }

    public String readStream(InputStream inputStream, int i) throws IOException {
        InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "UTF-8");
        char[] cArr = new char[i];
        int i2 = 0;
        int i3 = 0;
        while (i2 < i && i3 != -1) {
            i2 += i3;
            i3 = inputStreamReader.read(cArr, i2, i - i2);
        }
        if (i2 != -1) {
            return new String(cArr, 0, Math.min(i2, i));
        }
        return null;
    }

    public void setPayload(byte[] bArr) {
        this.payload.putBytes(bArr);
    }

    public boolean shouldRetry() {
        return false;
    }

    public boolean shouldUploadOpportunistically() {
        return Agent.hasReachableNetworkConnection((String) null);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x004a, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
        r1.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0053, code lost:
        throw r3;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public com.newrelic.agent.android.payload.PayloadSender call() throws java.lang.Exception {
        /*
            r4 = this;
            com.newrelic.agent.android.stats.TicToc r0 = r4.timer     // Catch:{ Exception -> 0x0062 }
            r0.tic()     // Catch:{ Exception -> 0x0062 }
            java.net.HttpURLConnection r0 = r4.getConnection()     // Catch:{ Exception -> 0x0062 }
            com.newrelic.agent.android.payload.Payload r1 = r4.payload     // Catch:{ Exception -> 0x0062 }
            byte[] r1 = r1.getBytes()     // Catch:{ Exception -> 0x0062 }
            int r1 = r1.length     // Catch:{ Exception -> 0x0062 }
            r0.setFixedLengthStreamingMode(r1)     // Catch:{ Exception -> 0x0062 }
            java.lang.String r1 = "Content-length"
            com.newrelic.agent.android.payload.Payload r2 = r4.payload     // Catch:{ Exception -> 0x0062 }
            byte[] r2 = r2.getBytes()     // Catch:{ Exception -> 0x0062 }
            int r2 = r2.length     // Catch:{ Exception -> 0x0062 }
            java.lang.String r2 = java.lang.Integer.toString(r2)     // Catch:{ Exception -> 0x0062 }
            r0.setRequestProperty(r1, r2)     // Catch:{ Exception -> 0x0062 }
            r0.connect()     // Catch:{ Exception -> 0x0056 }
            java.io.BufferedOutputStream r1 = new java.io.BufferedOutputStream     // Catch:{ Exception -> 0x0056 }
            java.io.OutputStream r2 = r0.getOutputStream()     // Catch:{ Exception -> 0x0056 }
            r1.<init>(r2)     // Catch:{ Exception -> 0x0056 }
            com.newrelic.agent.android.payload.Payload r2 = r4.payload     // Catch:{ all -> 0x0048 }
            byte[] r2 = r2.getBytes()     // Catch:{ all -> 0x0048 }
            r1.write(r2)     // Catch:{ all -> 0x0048 }
            r1.flush()     // Catch:{ all -> 0x0048 }
            r1.close()     // Catch:{ Exception -> 0x0056 }
            int r1 = r0.getResponseCode()     // Catch:{ Exception -> 0x0056 }
            r4.responseCode = r1     // Catch:{ Exception -> 0x0056 }
            r4.onRequestResponse(r0)     // Catch:{ Exception -> 0x0056 }
            goto L_0x005a
        L_0x0048:
            r2 = move-exception
            throw r2     // Catch:{ all -> 0x004a }
        L_0x004a:
            r3 = move-exception
            r1.close()     // Catch:{ all -> 0x004f }
            goto L_0x0053
        L_0x004f:
            r1 = move-exception
            r2.addSuppressed(r1)     // Catch:{ Exception -> 0x0056 }
        L_0x0053:
            throw r3     // Catch:{ Exception -> 0x0056 }
        L_0x0054:
            r1 = move-exception
            goto L_0x005e
        L_0x0056:
            r1 = move-exception
            r4.onRequestException(r1)     // Catch:{ all -> 0x0054 }
        L_0x005a:
            r0.disconnect()     // Catch:{ Exception -> 0x0062 }
            return r4
        L_0x005e:
            r0.disconnect()     // Catch:{ Exception -> 0x0062 }
            throw r1     // Catch:{ Exception -> 0x0062 }
        L_0x0062:
            r0 = move-exception
            java.lang.String r1 = "Unable to upload payload ["
            java.lang.StringBuilder r1 = p085c.p086a.p087a.p088a.outline.m2937a(r1)
            com.newrelic.agent.android.payload.Payload r2 = r4.payload
            java.lang.String r2 = r2.getUuid()
            r1.append(r2)
            java.lang.String r2 = "]  to New Relic, will try again later. "
            r1.append(r2)
            r1.append(r0)
            java.lang.String r0 = r1.toString()
            r4.onFailedUpload(r0)
            return r4
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.payload.PayloadSender.call():com.newrelic.agent.android.payload.PayloadSender");
    }

    public PayloadSender(Payload payload2, AgentConfiguration agentConfiguration2) {
        this(agentConfiguration2);
        this.payload = payload2;
    }

    public PayloadSender(byte[] bArr, AgentConfiguration agentConfiguration2) {
        this(agentConfiguration2);
        this.payload = new Payload(bArr);
    }
}
