package com.newrelic.agent.android.stores;

import android.content.Context;
import com.newrelic.agent.android.crash.Crash;
import com.newrelic.agent.android.crash.CrashStore;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonObject;
import java.util.ArrayList;
import java.util.List;

public class SharedPrefsCrashStore extends SharedPrefsStore implements CrashStore {
    public static final String STORE_FILE = "NRCrashStore";

    public SharedPrefsCrashStore(Context context) {
        this(context, STORE_FILE);
    }

    public List<Crash> fetchAll() {
        ArrayList arrayList = new ArrayList();
        for (Object next : super.fetchAll()) {
            if (next instanceof String) {
                try {
                    arrayList.add(Crash.crashFromJsonString((String) next));
                } catch (Exception e) {
                    SharedPrefsStore.log.error("Exception encountered while deserializing crash", e);
                }
            }
        }
        return arrayList;
    }

    public SharedPrefsCrashStore(Context context, String str) {
        super(context, str);
    }

    public void delete(Crash crash) {
        super.delete(crash.getUuid().toString());
    }

    public boolean store(Crash crash) {
        boolean store;
        synchronized (this) {
            JsonObject asJsonObject = crash.asJsonObject();
            asJsonObject.add("uploadCount", SafeJsonPrimitive.factory((Number) Integer.valueOf(crash.getUploadCount())));
            store = store(crash.getUuid().toString(), asJsonObject.toString());
        }
        return store;
    }
}
