package com.newrelic.agent.android.util;

import com.newrelic.agent.android.harvest.type.HarvestErrorCodes;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import java.net.ConnectException;
import java.net.MalformedURLException;
import java.net.SocketTimeoutException;
import java.net.UnknownHostException;
import javax.net.ssl.SSLException;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpResponseException;
import org.apache.http.conn.ConnectTimeoutException;
import p085c.p086a.p087a.p088a.outline;

public enum NetworkFailure {
    Unknown(-1),
    BadURL(HarvestErrorCodes.NSURLErrorBadURL),
    TimedOut(HarvestErrorCodes.NSURLErrorTimedOut),
    CannotConnectToHost(HarvestErrorCodes.NSURLErrorCannotConnectToHost),
    DNSLookupFailed(HarvestErrorCodes.NSURLErrorDNSLookupFailed),
    BadServerResponse(HarvestErrorCodes.NSURLErrorBadServerResponse),
    SecureConnectionFailed(HarvestErrorCodes.NSURLErrorSecureConnectionFailed);
    
    public static final AgentLog log = null;
    public int errorCode;

    /* access modifiers changed from: public */
    static {
        log = AgentLogManager.getAgentLog();
    }

    /* access modifiers changed from: public */
    NetworkFailure(int i) {
        this.errorCode = i;
    }

    public static int exceptionToErrorCode(Exception exc) {
        return exceptionToNetworkFailure(exc).getErrorCode();
    }

    public static NetworkFailure exceptionToNetworkFailure(Exception exc) {
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("NetworkFailure.exceptionToNetworkFailure: Attempting to convert network exception ");
        a.append(exc.getClass().getName());
        a.append(" to error code.");
        agentLog.error(a.toString());
        NetworkFailure networkFailure = Unknown;
        try {
            if (exc instanceof ConnectTimeoutException) {
                networkFailure = TimedOut;
            } else if ((exc instanceof HttpResponseException) || (exc instanceof ClientProtocolException)) {
                networkFailure = BadServerResponse;
            }
            if (!(exc instanceof SocketTimeoutException)) {
                if (!(exc instanceof UnknownHostException)) {
                    if (!(exc instanceof ConnectException)) {
                        if (!(exc instanceof MalformedURLException)) {
                            if (!(exc instanceof SSLException)) {
                                return networkFailure;
                            }
                            return SecureConnectionFailed;
                        }
                        return BadURL;
                    }
                    return CannotConnectToHost;
                }
                return DNSLookupFailed;
            }
        } catch (NoClassDefFoundError unused) {
            if (!(exc instanceof SocketTimeoutException)) {
                if (!(exc instanceof UnknownHostException)) {
                    if (!(exc instanceof ConnectException)) {
                        if (!(exc instanceof MalformedURLException)) {
                            if (!(exc instanceof SSLException)) {
                                return networkFailure;
                            }
                        }
                    }
                }
            }
        } catch (Throwable th) {
            if (!(exc instanceof SocketTimeoutException) && !(exc instanceof UnknownHostException) && !(exc instanceof ConnectException) && !(exc instanceof MalformedURLException)) {
                boolean z = exc instanceof SSLException;
            }
            throw th;
        }
        return TimedOut;
    }

    public static NetworkFailure fromErrorCode(int i) {
        log.debug("fromErrorCode invoked with errorCode: " + i);
        for (NetworkFailure networkFailure : values()) {
            if (networkFailure.getErrorCode() == i) {
                log.debug("fromErrorCode found matching failure: " + networkFailure);
                return networkFailure;
            }
        }
        return Unknown;
    }

    public int getErrorCode() {
        return this.errorCode;
    }
}
