package com.newrelic.agent.android.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Build;
import android.os.Environment;
import android.provider.Settings;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.analytics.AnalyticsControllerImpl;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.stats.StatsEngine;
import java.io.File;
import java.util.Arrays;
import java.util.UUID;
import p085c.p086a.p087a.p088a.outline;

public class PersistentUUID {
    public static final String METRIC_UUID_RECOVERED = "UUIDRecovered";
    public static File UUID_FILE = new File(Environment.getDataDirectory(), UUID_FILENAME);
    public static final String UUID_FILENAME = "nr_installation";
    public static final String UUID_KEY = "nr_uuid";
    public static AgentLog log = AgentLogManager.getAgentLog();

    public PersistentUUID(Context context) {
        UUID_FILE = new File(context.getFilesDir(), UUID_FILENAME);
    }

    @SuppressLint({"MissingPermission"})
    private String generateUniqueID(Context context) {
        String str = Build.SERIAL;
        String str2 = Build.ID;
        try {
            String string = Settings.Secure.getString(context.getContentResolver(), "android_id");
            if (TextUtils.isEmpty(string)) {
                return UUID.randomUUID().toString();
            }
            try {
                TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
                if (telephonyManager != null) {
                    str = telephonyManager.getDeviceId();
                }
            } catch (Exception unused) {
                str = "badf00d";
            }
            if (TextUtils.isEmpty(str)) {
                str = Build.HARDWARE + Build.DEVICE + Build.BOARD + Build.BRAND;
            }
            intToHexString(string.hashCode(), 8);
            intToHexString(str.hashCode(), 4);
            intToHexString(Build.VERSION.SDK_INT, 4);
            intToHexString(Build.VERSION.RELEASE.hashCode(), 12);
            throw new RuntimeException("Not supported (TODO)");
        } catch (Exception unused2) {
            return UUID.randomUUID().toString();
        }
    }

    private String intToHexString(int i, int i2) {
        String hexString = Integer.toHexString(i);
        char[] cArr = new char[(i2 - hexString.length())];
        Arrays.fill(cArr, '0');
        String str = new String(cArr) + hexString;
        String str2 = "";
        int i3 = 0;
        for (int length = str.length() - 1; length >= 0; length--) {
            i3++;
            str2 = str.substring(length, length + 1) + str2;
            if (i3 % i2 == 0) {
                str2 = outline.m2941b("-", str2);
            }
        }
        return str2.startsWith("-") ? str2.substring(1, str2.length()) : str2;
    }

    public String getDeviceId(Context context) {
        String generateUniqueID = generateUniqueID(context);
        return TextUtils.isEmpty(generateUniqueID) ? UUID.randomUUID().toString() : generateUniqueID;
    }

    public String getPersistentUUID() {
        String uUIDFromFileStore = getUUIDFromFileStore();
        if (!TextUtils.isEmpty(uUIDFromFileStore)) {
            noticeUUIDMetric(METRIC_UUID_RECOVERED);
            return uUIDFromFileStore;
        }
        String uuid = UUID.randomUUID().toString();
        AgentLog agentLog = log;
        agentLog.info("Created random UUID: " + uuid);
        StatsEngine.get().inc(MetricNames.MOBILE_APP_INSTALL);
        AnalyticsControllerImpl.getInstance().addAttributeUnchecked(new AnalyticAttribute(AnalyticAttribute.APP_INSTALL_ATTRIBUTE, true), false);
        setPersistedUUID(uuid);
        return uuid;
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0052 A[SYNTHETIC, Splitter:B:22:0x0052] */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0065 A[SYNTHETIC, Splitter:B:29:0x0065] */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0078 A[SYNTHETIC, Splitter:B:36:0x0078] */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x008b A[SYNTHETIC, Splitter:B:43:0x008b] */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x009d A[SYNTHETIC, Splitter:B:49:0x009d] */
    /* JADX WARNING: Unknown top exception splitter block from list: {B:40:0x0080=Splitter:B:40:0x0080, B:19:0x0047=Splitter:B:19:0x0047, B:26:0x005a=Splitter:B:26:0x005a, B:33:0x006d=Splitter:B:33:0x006d} */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public java.lang.String getUUIDFromFileStore() {
        /*
            r5 = this;
            java.io.File r0 = UUID_FILE
            boolean r0 = r0.exists()
            if (r0 == 0) goto L_0x00ac
            r0 = 0
            java.io.BufferedReader r1 = new java.io.BufferedReader     // Catch:{ FileNotFoundException -> 0x007c, IOException -> 0x0069, JSONException -> 0x0056, NullPointerException -> 0x0043, all -> 0x003d }
            java.io.FileReader r2 = new java.io.FileReader     // Catch:{ FileNotFoundException -> 0x007c, IOException -> 0x0069, JSONException -> 0x0056, NullPointerException -> 0x0043, all -> 0x003d }
            java.io.File r3 = UUID_FILE     // Catch:{ FileNotFoundException -> 0x007c, IOException -> 0x0069, JSONException -> 0x0056, NullPointerException -> 0x0043, all -> 0x003d }
            r2.<init>(r3)     // Catch:{ FileNotFoundException -> 0x007c, IOException -> 0x0069, JSONException -> 0x0056, NullPointerException -> 0x0043, all -> 0x003d }
            r1.<init>(r2)     // Catch:{ FileNotFoundException -> 0x007c, IOException -> 0x0069, JSONException -> 0x0056, NullPointerException -> 0x0043, all -> 0x003d }
            java.lang.String r0 = r1.readLine()     // Catch:{ FileNotFoundException -> 0x003b, IOException -> 0x0039, JSONException -> 0x0037, NullPointerException -> 0x0035 }
            org.json.JSONObject r2 = new org.json.JSONObject     // Catch:{ FileNotFoundException -> 0x003b, IOException -> 0x0039, JSONException -> 0x0037, NullPointerException -> 0x0035 }
            r2.<init>(r0)     // Catch:{ FileNotFoundException -> 0x003b, IOException -> 0x0039, JSONException -> 0x0037, NullPointerException -> 0x0035 }
            java.lang.String r0 = "nr_uuid"
            java.lang.String r0 = r2.getString(r0)     // Catch:{ FileNotFoundException -> 0x003b, IOException -> 0x0039, JSONException -> 0x0037, NullPointerException -> 0x0035 }
            r1.close()     // Catch:{ IOException -> 0x0029 }
            goto L_0x00ae
        L_0x0029:
            r1 = move-exception
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.String r1 = r1.getMessage()
            r2.error(r1)
            goto L_0x00ae
        L_0x0035:
            r0 = move-exception
            goto L_0x0047
        L_0x0037:
            r0 = move-exception
            goto L_0x005a
        L_0x0039:
            r0 = move-exception
            goto L_0x006d
        L_0x003b:
            r0 = move-exception
            goto L_0x0080
        L_0x003d:
            r1 = move-exception
            r4 = r1
            r1 = r0
            r0 = r4
            goto L_0x009b
        L_0x0043:
            r1 = move-exception
            r4 = r1
            r1 = r0
            r0 = r4
        L_0x0047:
            com.newrelic.agent.android.logging.AgentLog r2 = log     // Catch:{ all -> 0x009a }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x009a }
            r2.error(r0)     // Catch:{ all -> 0x009a }
            if (r1 == 0) goto L_0x00ac
            r1.close()     // Catch:{ IOException -> 0x008f }
            goto L_0x00ac
        L_0x0056:
            r1 = move-exception
            r4 = r1
            r1 = r0
            r0 = r4
        L_0x005a:
            com.newrelic.agent.android.logging.AgentLog r2 = log     // Catch:{ all -> 0x009a }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x009a }
            r2.error(r0)     // Catch:{ all -> 0x009a }
            if (r1 == 0) goto L_0x00ac
            r1.close()     // Catch:{ IOException -> 0x008f }
            goto L_0x00ac
        L_0x0069:
            r1 = move-exception
            r4 = r1
            r1 = r0
            r0 = r4
        L_0x006d:
            com.newrelic.agent.android.logging.AgentLog r2 = log     // Catch:{ all -> 0x009a }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x009a }
            r2.error(r0)     // Catch:{ all -> 0x009a }
            if (r1 == 0) goto L_0x00ac
            r1.close()     // Catch:{ IOException -> 0x008f }
            goto L_0x00ac
        L_0x007c:
            r1 = move-exception
            r4 = r1
            r1 = r0
            r0 = r4
        L_0x0080:
            com.newrelic.agent.android.logging.AgentLog r2 = log     // Catch:{ all -> 0x009a }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x009a }
            r2.error(r0)     // Catch:{ all -> 0x009a }
            if (r1 == 0) goto L_0x00ac
            r1.close()     // Catch:{ IOException -> 0x008f }
            goto L_0x00ac
        L_0x008f:
            r0 = move-exception
            com.newrelic.agent.android.logging.AgentLog r1 = log
            java.lang.String r0 = r0.getMessage()
            r1.error(r0)
            goto L_0x00ac
        L_0x009a:
            r0 = move-exception
        L_0x009b:
            if (r1 == 0) goto L_0x00ab
            r1.close()     // Catch:{ IOException -> 0x00a1 }
            goto L_0x00ab
        L_0x00a1:
            r1 = move-exception
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.String r1 = r1.getMessage()
            r2.error(r1)
        L_0x00ab:
            throw r0
        L_0x00ac:
            java.lang.String r0 = ""
        L_0x00ae:
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.util.PersistentUUID.getUUIDFromFileStore():java.lang.String");
    }

    public void noticeUUIDMetric(String str) {
        StatsEngine statsEngine = StatsEngine.get();
        if (statsEngine != null) {
            statsEngine.inc("Supportability/AgentHealth/" + str);
            return;
        }
        AgentLog agentLog = log;
        agentLog.error("StatsEngine is null. " + str + "  not recorded.");
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x003d A[SYNTHETIC, Splitter:B:16:0x003d] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0050 A[SYNTHETIC, Splitter:B:23:0x0050] */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0062 A[SYNTHETIC, Splitter:B:29:0x0062] */
    /* JADX WARNING: Removed duplicated region for block: B:35:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:36:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Unknown top exception splitter block from list: {B:13:0x0032=Splitter:B:13:0x0032, B:20:0x0045=Splitter:B:20:0x0045} */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void putUUIDToFileStore(java.lang.String r6) {
        /*
            r5 = this;
            r0 = 0
            org.json.JSONObject r1 = new org.json.JSONObject     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            r1.<init>()     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            java.lang.String r2 = "nr_uuid"
            r1.put(r2, r6)     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            java.io.BufferedWriter r6 = new java.io.BufferedWriter     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            java.io.FileWriter r2 = new java.io.FileWriter     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            java.io.File r3 = UUID_FILE     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            r2.<init>(r3)     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            r6.<init>(r2)     // Catch:{ IOException -> 0x0041, JSONException -> 0x002e, all -> 0x0029 }
            java.lang.String r0 = r1.toString()     // Catch:{ IOException -> 0x0027, JSONException -> 0x0025 }
            r6.write(r0)     // Catch:{ IOException -> 0x0027, JSONException -> 0x0025 }
            r6.flush()     // Catch:{ IOException -> 0x0027, JSONException -> 0x0025 }
            r6.close()     // Catch:{ IOException -> 0x0054 }
            goto L_0x005e
        L_0x0025:
            r0 = move-exception
            goto L_0x0032
        L_0x0027:
            r0 = move-exception
            goto L_0x0045
        L_0x0029:
            r6 = move-exception
            r4 = r0
            r0 = r6
            r6 = r4
            goto L_0x0060
        L_0x002e:
            r6 = move-exception
            r4 = r0
            r0 = r6
            r6 = r4
        L_0x0032:
            com.newrelic.agent.android.logging.AgentLog r1 = log     // Catch:{ all -> 0x005f }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x005f }
            r1.error(r0)     // Catch:{ all -> 0x005f }
            if (r6 == 0) goto L_0x005e
            r6.close()     // Catch:{ IOException -> 0x0054 }
            goto L_0x005e
        L_0x0041:
            r6 = move-exception
            r4 = r0
            r0 = r6
            r6 = r4
        L_0x0045:
            com.newrelic.agent.android.logging.AgentLog r1 = log     // Catch:{ all -> 0x005f }
            java.lang.String r0 = r0.getMessage()     // Catch:{ all -> 0x005f }
            r1.error(r0)     // Catch:{ all -> 0x005f }
            if (r6 == 0) goto L_0x005e
            r6.close()     // Catch:{ IOException -> 0x0054 }
            goto L_0x005e
        L_0x0054:
            r6 = move-exception
            com.newrelic.agent.android.logging.AgentLog r0 = log
            java.lang.String r6 = r6.getMessage()
            r0.error(r6)
        L_0x005e:
            return
        L_0x005f:
            r0 = move-exception
        L_0x0060:
            if (r6 == 0) goto L_0x0070
            r6.close()     // Catch:{ IOException -> 0x0066 }
            goto L_0x0070
        L_0x0066:
            r6 = move-exception
            com.newrelic.agent.android.logging.AgentLog r1 = log
            java.lang.String r6 = r6.getMessage()
            r1.error(r6)
        L_0x0070:
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.util.PersistentUUID.putUUIDToFileStore(java.lang.String):void");
    }

    public void setPersistedUUID(String str) {
        putUUIDToFileStore(str);
    }
}
