package okhttp3;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.Constants;
import java.io.Closeable;
import java.io.File;
import java.io.Flushable;
import java.io.IOException;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;
import okhttp3.Headers;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.cache.CacheRequest;
import okhttp3.internal.cache.CacheStrategy;
import okhttp3.internal.cache.DiskLruCache;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.http.HttpMethod;
import okhttp3.internal.http.StatusLine;
import okhttp3.internal.p269io.FileSystem;
import okhttp3.internal.platform.Platform;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.p251i.C1892h;
import p250f.p251i.Sets;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSink;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;
import p262g.ForwardingSink;
import p262g.ForwardingSource;
import p262g.Sink;
import p262g.Source;

/* compiled from: Cache.kt */
public final class Cache implements Closeable, Flushable {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final int ENTRY_BODY = 1;
    public static final int ENTRY_COUNT = 2;
    public static final int ENTRY_METADATA = 0;
    public static final int VERSION = 201105;
    public final DiskLruCache cache;
    public int hitCount;
    public int networkCount;
    public int requestCount;
    public int writeAbortCount;
    public int writeSuccessCount;

    /* compiled from: Cache.kt */
    public static final class CacheResponseBody extends ResponseBody {
        public final BufferedSource bodySource;
        public final String contentLength;
        public final String contentType;
        public final DiskLruCache.Snapshot snapshot;

        public CacheResponseBody(DiskLruCache.Snapshot snapshot2, String str, String str2) {
            if (snapshot2 != null) {
                this.snapshot = snapshot2;
                this.contentType = str;
                this.contentLength = str2;
                Source source = snapshot2.getSource(1);
                this.bodySource = C1050v.m4148a((Source) new ForwardingSource(this, source, source) {
                    public final /* synthetic */ Source $source;
                    public final /* synthetic */ CacheResponseBody this$0;

                    {
                        this.this$0 = r1;
                        this.$source = r2;
                    }

                    public void close() throws IOException {
                        this.this$0.getSnapshot$okhttp().close();
                        super.close();
                    }
                });
                return;
            }
            Intrinsics.m5822a("snapshot");
            throw null;
        }

        public long contentLength() {
            String str = this.contentLength;
            if (str != null) {
                return Util.toLongOrDefault(str, -1);
            }
            return -1;
        }

        public MediaType contentType() {
            String str = this.contentType;
            if (str != null) {
                return MediaType.Companion.parse(str);
            }
            return null;
        }

        public final DiskLruCache.Snapshot getSnapshot$okhttp() {
            return this.snapshot;
        }

        public BufferedSource source() {
            return this.bodySource;
        }
    }

    /* compiled from: Cache.kt */
    public static final class Companion {
        public Companion() {
        }

        private final Set<String> varyFields(Headers headers) {
            int size = headers.size();
            TreeSet treeSet = null;
            for (int i = 0; i < size; i++) {
                if (C1937g.m5858a("Vary", headers.name(i), true)) {
                    String value = headers.value(i);
                    if (treeSet == null) {
                        Comparator comparator = String.CASE_INSENSITIVE_ORDER;
                        Intrinsics.m5821a((Object) comparator, "java.lang.String.CASE_INSENSITIVE_ORDER");
                        treeSet = new TreeSet(comparator);
                    }
                    for (String str : C1937g.m5850a((CharSequence) value, new char[]{','}, false, 0, 6)) {
                        if (str != null) {
                            treeSet.add(C1937g.m5865c(str).toString());
                        } else {
                            throw new TypeCastException("null cannot be cast to non-null type kotlin.CharSequence");
                        }
                    }
                    continue;
                }
            }
            return treeSet != null ? treeSet : Sets.f7581b;
        }

        public final boolean hasVaryAll(Response response) {
            if (response != null) {
                return varyFields(response.headers()).contains("*");
            }
            Intrinsics.m5822a("$this$hasVaryAll");
            throw null;
        }

        public final String key(HttpUrl httpUrl) {
            if (httpUrl != null) {
                return C1952h.f7659f.mo9552c(httpUrl.toString()).mo9534a("MD5").mo9541c();
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        public final int readInt$okhttp(BufferedSource gVar) throws IOException {
            if (gVar != null) {
                try {
                    long c = gVar.mo9479c();
                    String i = gVar.mo9496i();
                    if (c >= 0 && c <= ((long) Integer.MAX_VALUE)) {
                        if (!(i.length() > 0)) {
                            return (int) c;
                        }
                    }
                    throw new IOException("expected an int but was \"" + c + i + '\"');
                } catch (NumberFormatException e) {
                    throw new IOException(e.getMessage());
                }
            } else {
                Intrinsics.m5822a("source");
                throw null;
            }
        }

        public final Headers varyHeaders(Response response) {
            if (response != null) {
                Response networkResponse = response.networkResponse();
                if (networkResponse != null) {
                    return varyHeaders(networkResponse.request().headers(), response.headers());
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5822a("$this$varyHeaders");
            throw null;
        }

        public final boolean varyMatches(Response response, Headers headers, Request request) {
            if (response == null) {
                Intrinsics.m5822a("cachedResponse");
                throw null;
            } else if (headers == null) {
                Intrinsics.m5822a("cachedRequest");
                throw null;
            } else if (request != null) {
                Set<String> varyFields = varyFields(response.headers());
                if ((varyFields instanceof Collection) && varyFields.isEmpty()) {
                    return true;
                }
                for (String str : varyFields) {
                    if (!Intrinsics.m5823a((Object) headers.values(str), (Object) request.headers(str))) {
                        return false;
                    }
                }
                return true;
            } else {
                Intrinsics.m5822a("newRequest");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }

        private final Headers varyHeaders(Headers headers, Headers headers2) {
            Set<String> varyFields = varyFields(headers2);
            if (varyFields.isEmpty()) {
                return Util.EMPTY_HEADERS;
            }
            Headers.Builder builder = new Headers.Builder();
            int size = headers.size();
            for (int i = 0; i < size; i++) {
                String name = headers.name(i);
                if (varyFields.contains(name)) {
                    builder.add(name, headers.value(i));
                }
            }
            return builder.build();
        }
    }

    /* compiled from: Cache.kt */
    public final class RealCacheRequest implements CacheRequest {
        public final Sink body;
        public final Sink cacheOut;
        public boolean done;
        public final DiskLruCache.Editor editor;
        public final /* synthetic */ Cache this$0;

        public RealCacheRequest(Cache cache, DiskLruCache.Editor editor2) {
            if (editor2 != null) {
                this.this$0 = cache;
                this.editor = editor2;
                Sink newSink = editor2.newSink(1);
                this.cacheOut = newSink;
                this.body = new ForwardingSink(this, newSink) {
                    public final /* synthetic */ RealCacheRequest this$0;

                    {
                        this.this$0 = r1;
                    }

                    public void close() throws IOException {
                        synchronized (this.this$0.this$0) {
                            if (!this.this$0.getDone$okhttp()) {
                                this.this$0.setDone$okhttp(true);
                                Cache cache = this.this$0.this$0;
                                cache.setWriteSuccessCount$okhttp(cache.getWriteSuccessCount$okhttp() + 1);
                                super.close();
                                this.this$0.editor.commit();
                            }
                        }
                    }
                };
                return;
            }
            Intrinsics.m5822a("editor");
            throw null;
        }

        public void abort() {
            synchronized (this.this$0) {
                if (!this.done) {
                    this.done = true;
                    Cache cache = this.this$0;
                    cache.setWriteAbortCount$okhttp(cache.getWriteAbortCount$okhttp() + 1);
                    Util.closeQuietly((Closeable) this.cacheOut);
                    try {
                        this.editor.abort();
                    } catch (IOException unused) {
                    }
                }
            }
        }

        public Sink body() {
            return this.body;
        }

        public final boolean getDone$okhttp() {
            return this.done;
        }

        public final void setDone$okhttp(boolean z) {
            this.done = z;
        }
    }

    public Cache(File file, long j, FileSystem fileSystem) {
        if (file == null) {
            Intrinsics.m5822a("directory");
            throw null;
        } else if (fileSystem != null) {
            this.cache = new DiskLruCache(fileSystem, file, VERSION, 2, j, TaskRunner.INSTANCE);
        } else {
            Intrinsics.m5822a("fileSystem");
            throw null;
        }
    }

    private final void abortQuietly(DiskLruCache.Editor editor) {
        if (editor != null) {
            try {
                editor.abort();
            } catch (IOException unused) {
            }
        }
    }

    public static final String key(HttpUrl httpUrl) {
        return Companion.key(httpUrl);
    }

    /* renamed from: -deprecated_directory  reason: not valid java name */
    public final File m6049deprecated_directory() {
        return this.cache.getDirectory();
    }

    public void close() throws IOException {
        this.cache.close();
    }

    public final void delete() throws IOException {
        this.cache.delete();
    }

    public final File directory() {
        return this.cache.getDirectory();
    }

    public final void evictAll() throws IOException {
        this.cache.evictAll();
    }

    public void flush() throws IOException {
        this.cache.flush();
    }

    public final Response get$okhttp(Request request) {
        if (request != null) {
            try {
                DiskLruCache.Snapshot snapshot = this.cache.get(Companion.key(request.url()));
                if (snapshot != null) {
                    try {
                        Entry entry = new Entry(snapshot.getSource(0));
                        Response response = entry.response(snapshot);
                        if (entry.matches(request, response)) {
                            return response;
                        }
                        ResponseBody body = response.body();
                        if (body != null) {
                            Util.closeQuietly((Closeable) body);
                        }
                        return null;
                    } catch (IOException unused) {
                        Util.closeQuietly((Closeable) snapshot);
                    }
                }
            } catch (IOException unused2) {
            }
            return null;
        }
        Intrinsics.m5822a("request");
        throw null;
    }

    public final DiskLruCache getCache$okhttp() {
        return this.cache;
    }

    public final int getWriteAbortCount$okhttp() {
        return this.writeAbortCount;
    }

    public final int getWriteSuccessCount$okhttp() {
        return this.writeSuccessCount;
    }

    public final synchronized int hitCount() {
        return this.hitCount;
    }

    public final void initialize() throws IOException {
        this.cache.initialize();
    }

    public final boolean isClosed() {
        return this.cache.isClosed();
    }

    public final long maxSize() {
        return this.cache.getMaxSize();
    }

    public final synchronized int networkCount() {
        return this.networkCount;
    }

    public final CacheRequest put$okhttp(Response response) {
        DiskLruCache.Editor editor;
        if (response != null) {
            String method = response.request().method();
            if (HttpMethod.INSTANCE.invalidatesCache(response.request().method())) {
                try {
                    remove$okhttp(response.request());
                } catch (IOException unused) {
                }
                return null;
            } else if ((!Intrinsics.m5823a((Object) method, (Object) "GET")) || Companion.hasVaryAll(response)) {
                return null;
            } else {
                Entry entry = new Entry(response);
                try {
                    editor = DiskLruCache.edit$default(this.cache, Companion.key(response.request().url()), 0, 2, (Object) null);
                    if (editor == null) {
                        return null;
                    }
                    try {
                        entry.writeTo(editor);
                        return new RealCacheRequest(this, editor);
                    } catch (IOException unused2) {
                        abortQuietly(editor);
                        return null;
                    }
                } catch (IOException unused3) {
                    editor = null;
                    abortQuietly(editor);
                    return null;
                }
            }
        } else {
            Intrinsics.m5822a("response");
            throw null;
        }
    }

    public final void remove$okhttp(Request request) throws IOException {
        if (request != null) {
            this.cache.remove(Companion.key(request.url()));
        } else {
            Intrinsics.m5822a("request");
            throw null;
        }
    }

    public final synchronized int requestCount() {
        return this.requestCount;
    }

    public final void setWriteAbortCount$okhttp(int i) {
        this.writeAbortCount = i;
    }

    public final void setWriteSuccessCount$okhttp(int i) {
        this.writeSuccessCount = i;
    }

    public final long size() throws IOException {
        return this.cache.size();
    }

    public final synchronized void trackConditionalCacheHit$okhttp() {
        this.hitCount++;
    }

    public final synchronized void trackResponse$okhttp(CacheStrategy cacheStrategy) {
        if (cacheStrategy != null) {
            this.requestCount++;
            if (cacheStrategy.getNetworkRequest() != null) {
                this.networkCount++;
            } else if (cacheStrategy.getCacheResponse() != null) {
                this.hitCount++;
            }
        } else {
            Intrinsics.m5822a("cacheStrategy");
            throw null;
        }
    }

    public final void update$okhttp(Response response, Response response2) {
        if (response == null) {
            Intrinsics.m5822a("cached");
            throw null;
        } else if (response2 != null) {
            Entry entry = new Entry(response2);
            ResponseBody body = response.body();
            if (body != null) {
                try {
                    DiskLruCache.Editor edit = ((CacheResponseBody) body).getSnapshot$okhttp().edit();
                    if (edit != null) {
                        entry.writeTo(edit);
                        edit.commit();
                    }
                } catch (IOException unused) {
                    abortQuietly((DiskLruCache.Editor) null);
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type okhttp3.Cache.CacheResponseBody");
            }
        } else {
            Intrinsics.m5822a("network");
            throw null;
        }
    }

    public final Iterator<String> urls() throws IOException {
        return new Cache$urls$1(this);
    }

    public final synchronized int writeAbortCount() {
        return this.writeAbortCount;
    }

    public final synchronized int writeSuccessCount() {
        return this.writeSuccessCount;
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public Cache(File file, long j) {
        this(file, j, FileSystem.SYSTEM);
        if (file != null) {
        } else {
            Intrinsics.m5822a("directory");
            throw null;
        }
    }

    @Instrumented
    /* compiled from: Cache.kt */
    public static final class Entry {
        public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
        public static final String RECEIVED_MILLIS = (Platform.Companion.get().getPrefix() + "-Received-Millis");
        public static final String SENT_MILLIS = (Platform.Companion.get().getPrefix() + "-Sent-Millis");
        public final int code;
        public final Handshake handshake;
        public final String message;
        public final Protocol protocol;
        public final long receivedResponseMillis;
        public final String requestMethod;
        public final Headers responseHeaders;
        public final long sentRequestMillis;
        public final String url;
        public final Headers varyHeaders;

        /* compiled from: Cache.kt */
        public static final class Companion {
            public Companion() {
            }

            public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
                this();
            }
        }

        public Entry(Source zVar) throws IOException {
            TlsVersion tlsVersion;
            if (zVar != null) {
                try {
                    BufferedSource a = C1050v.m4148a(zVar);
                    this.url = a.mo9496i();
                    this.requestMethod = a.mo9496i();
                    Headers.Builder builder = new Headers.Builder();
                    int readInt$okhttp = Cache.Companion.readInt$okhttp(a);
                    boolean z = false;
                    for (int i = 0; i < readInt$okhttp; i++) {
                        builder.addLenient$okhttp(a.mo9496i());
                    }
                    this.varyHeaders = builder.build();
                    StatusLine parse = StatusLine.Companion.parse(a.mo9496i());
                    this.protocol = parse.protocol;
                    this.code = parse.code;
                    this.message = parse.message;
                    Headers.Builder builder2 = new Headers.Builder();
                    int readInt$okhttp2 = Cache.Companion.readInt$okhttp(a);
                    for (int i2 = 0; i2 < readInt$okhttp2; i2++) {
                        builder2.addLenient$okhttp(a.mo9496i());
                    }
                    String str = builder2.get(SENT_MILLIS);
                    String str2 = builder2.get(RECEIVED_MILLIS);
                    builder2.removeAll(SENT_MILLIS);
                    builder2.removeAll(RECEIVED_MILLIS);
                    long j = 0;
                    this.sentRequestMillis = str != null ? Long.parseLong(str) : 0;
                    this.receivedResponseMillis = str2 != null ? Long.parseLong(str2) : j;
                    this.responseHeaders = builder2.build();
                    if (isHttps()) {
                        String i3 = a.mo9496i();
                        if (!(i3.length() > 0 ? true : z)) {
                            CipherSuite forJavaName = CipherSuite.Companion.forJavaName(a.mo9496i());
                            List<Certificate> readCertificateList = readCertificateList(a);
                            List<Certificate> readCertificateList2 = readCertificateList(a);
                            if (!a.mo9501k()) {
                                tlsVersion = TlsVersion.Companion.forJavaName(a.mo9496i());
                            } else {
                                tlsVersion = TlsVersion.SSL_3_0;
                            }
                            this.handshake = Handshake.Companion.get(tlsVersion, forJavaName, readCertificateList, readCertificateList2);
                        } else {
                            throw new IOException("expected \"\" but was \"" + i3 + '\"');
                        }
                    } else {
                        this.handshake = null;
                    }
                } finally {
                    zVar.close();
                }
            } else {
                Intrinsics.m5822a("rawSource");
                throw null;
            }
        }

        private final boolean isHttps() {
            return C1937g.m5864b(this.url, "https://", false, 2);
        }

        private final List<Certificate> readCertificateList(BufferedSource gVar) throws IOException {
            int readInt$okhttp = Cache.Companion.readInt$okhttp(gVar);
            if (readInt$okhttp == -1) {
                return C1892h.f7579b;
            }
            try {
                CertificateFactory instance = CertificateFactory.getInstance("X.509");
                ArrayList arrayList = new ArrayList(readInt$okhttp);
                int i = 0;
                while (i < readInt$okhttp) {
                    String i2 = gVar.mo9496i();
                    C1948d dVar = new C1948d();
                    C1952h a = C1952h.f7659f.mo9550a(i2);
                    if (a != null) {
                        dVar.mo9467a(a);
                        arrayList.add(instance.generateCertificate(new C1948d.C1950b(dVar)));
                        i++;
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
                return arrayList;
            } catch (CertificateException e) {
                throw new IOException(e.getMessage());
            }
        }

        private final void writeCertList(BufferedSink fVar, List<? extends Certificate> list) throws IOException {
            try {
                fVar.mo9493h((long) list.size()).writeByte(10);
                int size = list.size();
                for (int i = 0; i < size; i++) {
                    byte[] encoded = ((Certificate) list.get(i)).getEncoded();
                    C1952h.C1953a aVar = C1952h.f7659f;
                    Intrinsics.m5821a((Object) encoded, "bytes");
                    fVar.mo9468a(C1952h.C1953a.m5962a(aVar, encoded, 0, 0, 3).mo9535a()).writeByte(10);
                }
            } catch (CertificateEncodingException e) {
                throw new IOException(e.getMessage());
            }
        }

        public final boolean matches(Request request, Response response) {
            if (request == null) {
                Intrinsics.m5822a("request");
                throw null;
            } else if (response != null) {
                return Intrinsics.m5823a((Object) this.url, (Object) request.url().toString()) && Intrinsics.m5823a((Object) this.requestMethod, (Object) request.method()) && Cache.Companion.varyMatches(response, this.varyHeaders, request);
            } else {
                Intrinsics.m5822a("response");
                throw null;
            }
        }

        public final Response response(DiskLruCache.Snapshot snapshot) {
            if (snapshot != null) {
                String str = this.responseHeaders.get(Constants.Network.CONTENT_TYPE_HEADER);
                String str2 = this.responseHeaders.get("Content-Length");
                Request.Builder headers = new Request.Builder().url(this.url).method(this.requestMethod, (RequestBody) null).headers(this.varyHeaders);
                Response.Builder headers2 = new Response.Builder().request(!(headers instanceof Request.Builder) ? headers.build() : OkHttp3Instrumentation.build(headers)).protocol(this.protocol).code(this.code).message(this.message).headers(this.responseHeaders);
                CacheResponseBody cacheResponseBody = new CacheResponseBody(snapshot, str, str2);
                return (!(headers2 instanceof Response.Builder) ? headers2.body(cacheResponseBody) : OkHttp3Instrumentation.body(headers2, cacheResponseBody)).handshake(this.handshake).sentRequestAtMillis(this.sentRequestMillis).receivedResponseAtMillis(this.receivedResponseMillis).build();
            }
            Intrinsics.m5822a("snapshot");
            throw null;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:25:0x0113, code lost:
            r1 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:26:0x0114, code lost:
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r9, r0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:0x0117, code lost:
            throw r1;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final void writeTo(okhttp3.internal.cache.DiskLruCache.Editor r9) throws java.io.IOException {
            /*
                r8 = this;
                r0 = 0
                if (r9 == 0) goto L_0x0118
                r1 = 0
                g.x r9 = r9.newSink(r1)
                g.f r9 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4147a((p262g.Sink) r9)
                java.lang.String r2 = r8.url     // Catch:{ all -> 0x0111 }
                g.f r2 = r9.mo9468a((java.lang.String) r2)     // Catch:{ all -> 0x0111 }
                r3 = 10
                r2.writeByte(r3)     // Catch:{ all -> 0x0111 }
                java.lang.String r2 = r8.requestMethod     // Catch:{ all -> 0x0111 }
                g.f r2 = r9.mo9468a((java.lang.String) r2)     // Catch:{ all -> 0x0111 }
                r2.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r2 = r8.varyHeaders     // Catch:{ all -> 0x0111 }
                int r2 = r2.size()     // Catch:{ all -> 0x0111 }
                long r4 = (long) r2     // Catch:{ all -> 0x0111 }
                g.f r2 = r9.mo9493h(r4)     // Catch:{ all -> 0x0111 }
                r2.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r2 = r8.varyHeaders     // Catch:{ all -> 0x0111 }
                int r2 = r2.size()     // Catch:{ all -> 0x0111 }
                r4 = 0
            L_0x0035:
                java.lang.String r5 = ": "
                if (r4 >= r2) goto L_0x0057
                okhttp3.Headers r6 = r8.varyHeaders     // Catch:{ all -> 0x0111 }
                java.lang.String r6 = r6.name(r4)     // Catch:{ all -> 0x0111 }
                g.f r6 = r9.mo9468a((java.lang.String) r6)     // Catch:{ all -> 0x0111 }
                g.f r5 = r6.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r6 = r8.varyHeaders     // Catch:{ all -> 0x0111 }
                java.lang.String r6 = r6.value(r4)     // Catch:{ all -> 0x0111 }
                g.f r5 = r5.mo9468a((java.lang.String) r6)     // Catch:{ all -> 0x0111 }
                r5.writeByte(r3)     // Catch:{ all -> 0x0111 }
                int r4 = r4 + 1
                goto L_0x0035
            L_0x0057:
                okhttp3.internal.http.StatusLine r2 = new okhttp3.internal.http.StatusLine     // Catch:{ all -> 0x0111 }
                okhttp3.Protocol r4 = r8.protocol     // Catch:{ all -> 0x0111 }
                int r6 = r8.code     // Catch:{ all -> 0x0111 }
                java.lang.String r7 = r8.message     // Catch:{ all -> 0x0111 }
                r2.<init>(r4, r6, r7)     // Catch:{ all -> 0x0111 }
                java.lang.String r2 = r2.toString()     // Catch:{ all -> 0x0111 }
                g.f r2 = r9.mo9468a((java.lang.String) r2)     // Catch:{ all -> 0x0111 }
                r2.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r2 = r8.responseHeaders     // Catch:{ all -> 0x0111 }
                int r2 = r2.size()     // Catch:{ all -> 0x0111 }
                int r2 = r2 + 2
                long r6 = (long) r2     // Catch:{ all -> 0x0111 }
                g.f r2 = r9.mo9493h(r6)     // Catch:{ all -> 0x0111 }
                r2.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r2 = r8.responseHeaders     // Catch:{ all -> 0x0111 }
                int r2 = r2.size()     // Catch:{ all -> 0x0111 }
            L_0x0083:
                if (r1 >= r2) goto L_0x00a3
                okhttp3.Headers r4 = r8.responseHeaders     // Catch:{ all -> 0x0111 }
                java.lang.String r4 = r4.name(r1)     // Catch:{ all -> 0x0111 }
                g.f r4 = r9.mo9468a((java.lang.String) r4)     // Catch:{ all -> 0x0111 }
                g.f r4 = r4.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x0111 }
                okhttp3.Headers r6 = r8.responseHeaders     // Catch:{ all -> 0x0111 }
                java.lang.String r6 = r6.value(r1)     // Catch:{ all -> 0x0111 }
                g.f r4 = r4.mo9468a((java.lang.String) r6)     // Catch:{ all -> 0x0111 }
                r4.writeByte(r3)     // Catch:{ all -> 0x0111 }
                int r1 = r1 + 1
                goto L_0x0083
            L_0x00a3:
                java.lang.String r1 = SENT_MILLIS     // Catch:{ all -> 0x0111 }
                g.f r1 = r9.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x0111 }
                g.f r1 = r1.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x0111 }
                long r6 = r8.sentRequestMillis     // Catch:{ all -> 0x0111 }
                g.f r1 = r1.mo9493h(r6)     // Catch:{ all -> 0x0111 }
                r1.writeByte(r3)     // Catch:{ all -> 0x0111 }
                java.lang.String r1 = RECEIVED_MILLIS     // Catch:{ all -> 0x0111 }
                g.f r1 = r9.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x0111 }
                g.f r1 = r1.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x0111 }
                long r4 = r8.receivedResponseMillis     // Catch:{ all -> 0x0111 }
                g.f r1 = r1.mo9493h(r4)     // Catch:{ all -> 0x0111 }
                r1.writeByte(r3)     // Catch:{ all -> 0x0111 }
                boolean r1 = r8.isHttps()     // Catch:{ all -> 0x0111 }
                if (r1 == 0) goto L_0x010d
                r9.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Handshake r1 = r8.handshake     // Catch:{ all -> 0x0111 }
                if (r1 == 0) goto L_0x0109
                okhttp3.CipherSuite r1 = r1.cipherSuite()     // Catch:{ all -> 0x0111 }
                java.lang.String r1 = r1.javaName()     // Catch:{ all -> 0x0111 }
                g.f r1 = r9.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x0111 }
                r1.writeByte(r3)     // Catch:{ all -> 0x0111 }
                okhttp3.Handshake r1 = r8.handshake     // Catch:{ all -> 0x0111 }
                java.util.List r1 = r1.peerCertificates()     // Catch:{ all -> 0x0111 }
                r8.writeCertList(r9, r1)     // Catch:{ all -> 0x0111 }
                okhttp3.Handshake r1 = r8.handshake     // Catch:{ all -> 0x0111 }
                java.util.List r1 = r1.localCertificates()     // Catch:{ all -> 0x0111 }
                r8.writeCertList(r9, r1)     // Catch:{ all -> 0x0111 }
                okhttp3.Handshake r1 = r8.handshake     // Catch:{ all -> 0x0111 }
                okhttp3.TlsVersion r1 = r1.tlsVersion()     // Catch:{ all -> 0x0111 }
                java.lang.String r1 = r1.javaName()     // Catch:{ all -> 0x0111 }
                g.f r1 = r9.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x0111 }
                r1.writeByte(r3)     // Catch:{ all -> 0x0111 }
                goto L_0x010d
            L_0x0109:
                p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0111 }
                throw r0
            L_0x010d:
                p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r9, (java.lang.Throwable) r0)
                return
            L_0x0111:
                r0 = move-exception
                throw r0     // Catch:{ all -> 0x0113 }
            L_0x0113:
                r1 = move-exception
                p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r9, (java.lang.Throwable) r0)
                throw r1
            L_0x0118:
                java.lang.String r9 = "editor"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r9)
                throw r0
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.Cache.Entry.writeTo(okhttp3.internal.cache.DiskLruCache$Editor):void");
        }

        public Entry(Response response) {
            if (response != null) {
                this.url = response.request().url().toString();
                this.varyHeaders = Cache.Companion.varyHeaders(response);
                this.requestMethod = response.request().method();
                this.protocol = response.protocol();
                this.code = response.code();
                this.message = response.message();
                this.responseHeaders = response.headers();
                this.handshake = response.handshake();
                this.sentRequestMillis = response.sentRequestAtMillis();
                this.receivedResponseMillis = response.receivedResponseAtMillis();
                return;
            }
            Intrinsics.m5822a("response");
            throw null;
        }
    }
}
