package okhttp3;

import java.util.concurrent.TimeUnit;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;

/* compiled from: CacheControl.kt */
public final class CacheControl {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final CacheControl FORCE_CACHE = new Builder().onlyIfCached().maxStale(Integer.MAX_VALUE, TimeUnit.SECONDS).build();
    public static final CacheControl FORCE_NETWORK = new Builder().noCache().build();
    public String headerValue;
    public final boolean immutable;
    public final boolean isPrivate;
    public final boolean isPublic;
    public final int maxAgeSeconds;
    public final int maxStaleSeconds;
    public final int minFreshSeconds;
    public final boolean mustRevalidate;
    public final boolean noCache;
    public final boolean noStore;
    public final boolean noTransform;
    public final boolean onlyIfCached;
    public final int sMaxAgeSeconds;

    /* compiled from: CacheControl.kt */
    public static final class Builder {
        public boolean immutable;
        public int maxAgeSeconds = -1;
        public int maxStaleSeconds = -1;
        public int minFreshSeconds = -1;
        public boolean noCache;
        public boolean noStore;
        public boolean noTransform;
        public boolean onlyIfCached;

        private final int clampToInt(long j) {
            if (j > ((long) Integer.MAX_VALUE)) {
                return Integer.MAX_VALUE;
            }
            return (int) j;
        }

        public final CacheControl build() {
            return new CacheControl(this.noCache, this.noStore, this.maxAgeSeconds, -1, false, false, false, this.maxStaleSeconds, this.minFreshSeconds, this.onlyIfCached, this.noTransform, this.immutable, (String) null, (DefaultConstructorMarker) null);
        }

        public final Builder immutable() {
            this.immutable = true;
            return this;
        }

        public final Builder maxAge(int i, TimeUnit timeUnit) {
            if (timeUnit != null) {
                if (i >= 0) {
                    this.maxAgeSeconds = clampToInt(timeUnit.toSeconds((long) i));
                    return this;
                }
                throw new IllegalArgumentException(outline.m2930a("maxAge < 0: ", i).toString());
            }
            Intrinsics.m5822a("timeUnit");
            throw null;
        }

        public final Builder maxStale(int i, TimeUnit timeUnit) {
            if (timeUnit != null) {
                if (i >= 0) {
                    this.maxStaleSeconds = clampToInt(timeUnit.toSeconds((long) i));
                    return this;
                }
                throw new IllegalArgumentException(outline.m2930a("maxStale < 0: ", i).toString());
            }
            Intrinsics.m5822a("timeUnit");
            throw null;
        }

        public final Builder minFresh(int i, TimeUnit timeUnit) {
            if (timeUnit != null) {
                if (i >= 0) {
                    this.minFreshSeconds = clampToInt(timeUnit.toSeconds((long) i));
                    return this;
                }
                throw new IllegalArgumentException(outline.m2930a("minFresh < 0: ", i).toString());
            }
            Intrinsics.m5822a("timeUnit");
            throw null;
        }

        public final Builder noCache() {
            this.noCache = true;
            return this;
        }

        public final Builder noStore() {
            this.noStore = true;
            return this;
        }

        public final Builder noTransform() {
            this.noTransform = true;
            return this;
        }

        public final Builder onlyIfCached() {
            this.onlyIfCached = true;
            return this;
        }
    }

    /* compiled from: CacheControl.kt */
    public static final class Companion {
        public Companion() {
        }

        private final int indexOfElement(String str, String str2, int i) {
            int length = str.length();
            while (i < length) {
                if (C1937g.m5851a((CharSequence) str2, str.charAt(i), false, 2)) {
                    return i;
                }
                i++;
            }
            return str.length();
        }

        public static /* synthetic */ int indexOfElement$default(Companion companion, String str, String str2, int i, int i2, Object obj) {
            if ((i2 & 2) != 0) {
                i = 0;
            }
            return companion.indexOfElement(str, str2, i);
        }

        /* JADX WARNING: Removed duplicated region for block: B:14:0x0047  */
        /* JADX WARNING: Removed duplicated region for block: B:30:0x00ca  */
        /* JADX WARNING: Removed duplicated region for block: B:31:0x00ce  */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final okhttp3.CacheControl parse(okhttp3.Headers r27) {
            /*
                r26 = this;
                r0 = r26
                r1 = r27
                if (r1 == 0) goto L_0x0184
                int r3 = r27.size()
                r6 = 1
                r7 = 0
                r8 = 1
                r9 = 0
                r10 = 0
                r11 = 0
                r12 = -1
                r13 = -1
                r14 = 0
                r15 = 0
                r16 = 0
                r17 = -1
                r18 = -1
                r19 = 0
                r20 = 0
                r21 = 0
            L_0x0020:
                if (r7 >= r3) goto L_0x0173
                java.lang.String r2 = r1.name(r7)
                java.lang.String r4 = r1.value(r7)
                java.lang.String r5 = "Cache-Control"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r2, (java.lang.String) r5, (boolean) r6)
                if (r5 == 0) goto L_0x0037
                if (r9 == 0) goto L_0x0035
                goto L_0x003f
            L_0x0035:
                r9 = r4
                goto L_0x0040
            L_0x0037:
                java.lang.String r5 = "Pragma"
                boolean r2 = p250f.p261p.C1937g.m5858a((java.lang.String) r2, (java.lang.String) r5, (boolean) r6)
                if (r2 == 0) goto L_0x0167
            L_0x003f:
                r8 = 0
            L_0x0040:
                r2 = 0
            L_0x0041:
                int r5 = r4.length()
                if (r2 >= r5) goto L_0x0162
                java.lang.String r5 = "=,;"
                int r5 = r0.indexOfElement(r4, r5, r2)
                java.lang.String r2 = r4.substring(r2, r5)
                java.lang.String r6 = "(this as java.lang.Strin…ing(startIndex, endIndex)"
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r2, (java.lang.String) r6)
                java.lang.CharSequence r2 = p250f.p261p.C1937g.m5865c(r2)
                java.lang.String r2 = r2.toString()
                int r1 = r4.length()
                if (r5 == r1) goto L_0x00b8
                char r1 = r4.charAt(r5)
                r24 = r3
                r3 = 44
                if (r1 == r3) goto L_0x00ba
                char r1 = r4.charAt(r5)
                r3 = 59
                if (r1 != r3) goto L_0x0077
                goto L_0x00ba
            L_0x0077:
                int r5 = r5 + 1
                int r1 = okhttp3.internal.Util.indexOfNonWhitespace(r4, r5)
                int r3 = r4.length()
                if (r1 >= r3) goto L_0x009f
                char r3 = r4.charAt(r1)
                r5 = 34
                if (r3 != r5) goto L_0x009f
                int r1 = r1 + 1
                r3 = 4
                r25 = r9
                r9 = 0
                int r3 = p250f.p261p.C1937g.m5836a((java.lang.CharSequence) r4, (char) r5, (int) r1, (boolean) r9, (int) r3)
                java.lang.String r1 = r4.substring(r1, r3)
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r1, (java.lang.String) r6)
                r5 = 1
                int r3 = r3 + r5
                goto L_0x00c1
            L_0x009f:
                r25 = r9
                r9 = 0
                java.lang.String r3 = ",;"
                int r3 = r0.indexOfElement(r4, r3, r1)
                java.lang.String r1 = r4.substring(r1, r3)
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r1, (java.lang.String) r6)
                java.lang.CharSequence r1 = p250f.p261p.C1937g.m5865c(r1)
                java.lang.String r1 = r1.toString()
                goto L_0x00c1
            L_0x00b8:
                r24 = r3
            L_0x00ba:
                r25 = r9
                r9 = 0
                int r5 = r5 + 1
                r3 = r5
                r1 = 0
            L_0x00c1:
                java.lang.String r5 = "no-cache"
                r6 = 1
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x00ce
                r5 = -1
                r10 = 1
                goto L_0x0159
            L_0x00ce:
                java.lang.String r5 = "no-store"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x00da
                r5 = -1
                r11 = 1
                goto L_0x0159
            L_0x00da:
                java.lang.String r5 = "max-age"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x00e9
                r5 = -1
                int r12 = okhttp3.internal.Util.toNonNegativeInt(r1, r5)
                goto L_0x0159
            L_0x00e9:
                r5 = -1
                java.lang.String r9 = "s-maxage"
                boolean r9 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r2, (boolean) r6)
                if (r9 == 0) goto L_0x00f7
                int r13 = okhttp3.internal.Util.toNonNegativeInt(r1, r5)
                goto L_0x0159
            L_0x00f7:
                java.lang.String r5 = "private"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x0102
                r5 = -1
                r14 = 1
                goto L_0x0159
            L_0x0102:
                java.lang.String r5 = "public"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x010d
                r5 = -1
                r15 = 1
                goto L_0x0159
            L_0x010d:
                java.lang.String r5 = "must-revalidate"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x0119
                r5 = -1
                r16 = 1
                goto L_0x0159
            L_0x0119:
                java.lang.String r5 = "max-stale"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x012a
                r2 = 2147483647(0x7fffffff, float:NaN)
                int r17 = okhttp3.internal.Util.toNonNegativeInt(r1, r2)
                r5 = -1
                goto L_0x0159
            L_0x012a:
                java.lang.String r5 = "min-fresh"
                boolean r5 = p250f.p261p.C1937g.m5858a((java.lang.String) r5, (java.lang.String) r2, (boolean) r6)
                if (r5 == 0) goto L_0x0138
                r5 = -1
                int r18 = okhttp3.internal.Util.toNonNegativeInt(r1, r5)
                goto L_0x0159
            L_0x0138:
                r5 = -1
                java.lang.String r1 = "only-if-cached"
                boolean r1 = p250f.p261p.C1937g.m5858a((java.lang.String) r1, (java.lang.String) r2, (boolean) r6)
                if (r1 == 0) goto L_0x0144
                r19 = 1
                goto L_0x0159
            L_0x0144:
                java.lang.String r1 = "no-transform"
                boolean r1 = p250f.p261p.C1937g.m5858a((java.lang.String) r1, (java.lang.String) r2, (boolean) r6)
                if (r1 == 0) goto L_0x014f
                r20 = 1
                goto L_0x0159
            L_0x014f:
                java.lang.String r1 = "immutable"
                boolean r1 = p250f.p261p.C1937g.m5858a((java.lang.String) r1, (java.lang.String) r2, (boolean) r6)
                if (r1 == 0) goto L_0x0159
                r21 = 1
            L_0x0159:
                r1 = r27
                r2 = r3
                r3 = r24
                r9 = r25
                goto L_0x0041
            L_0x0162:
                r24 = r3
                r25 = r9
                goto L_0x016a
            L_0x0167:
                r24 = r3
                r2 = r9
            L_0x016a:
                r5 = -1
                int r7 = r7 + 1
                r1 = r27
                r3 = r24
                goto L_0x0020
            L_0x0173:
                r2 = r9
                if (r8 != 0) goto L_0x0179
                r22 = 0
                goto L_0x017b
            L_0x0179:
                r22 = r2
            L_0x017b:
                okhttp3.CacheControl r1 = new okhttp3.CacheControl
                r23 = 0
                r9 = r1
                r9.<init>(r10, r11, r12, r13, r14, r15, r16, r17, r18, r19, r20, r21, r22, r23)
                return r1
            L_0x0184:
                java.lang.String r1 = "headers"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r1)
                r1 = 0
                throw r1
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.CacheControl.Companion.parse(okhttp3.Headers):okhttp3.CacheControl");
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public CacheControl(boolean z, boolean z2, int i, int i2, boolean z3, boolean z4, boolean z5, int i3, int i4, boolean z6, boolean z7, boolean z8, String str) {
        this.noCache = z;
        this.noStore = z2;
        this.maxAgeSeconds = i;
        this.sMaxAgeSeconds = i2;
        this.isPrivate = z3;
        this.isPublic = z4;
        this.mustRevalidate = z5;
        this.maxStaleSeconds = i3;
        this.minFreshSeconds = i4;
        this.onlyIfCached = z6;
        this.noTransform = z7;
        this.immutable = z8;
        this.headerValue = str;
    }

    public static final CacheControl parse(Headers headers) {
        return Companion.parse(headers);
    }

    /* renamed from: -deprecated_immutable  reason: not valid java name */
    public final boolean m6050deprecated_immutable() {
        return this.immutable;
    }

    /* renamed from: -deprecated_maxAgeSeconds  reason: not valid java name */
    public final int m6051deprecated_maxAgeSeconds() {
        return this.maxAgeSeconds;
    }

    /* renamed from: -deprecated_maxStaleSeconds  reason: not valid java name */
    public final int m6052deprecated_maxStaleSeconds() {
        return this.maxStaleSeconds;
    }

    /* renamed from: -deprecated_minFreshSeconds  reason: not valid java name */
    public final int m6053deprecated_minFreshSeconds() {
        return this.minFreshSeconds;
    }

    /* renamed from: -deprecated_mustRevalidate  reason: not valid java name */
    public final boolean m6054deprecated_mustRevalidate() {
        return this.mustRevalidate;
    }

    /* renamed from: -deprecated_noCache  reason: not valid java name */
    public final boolean m6055deprecated_noCache() {
        return this.noCache;
    }

    /* renamed from: -deprecated_noStore  reason: not valid java name */
    public final boolean m6056deprecated_noStore() {
        return this.noStore;
    }

    /* renamed from: -deprecated_noTransform  reason: not valid java name */
    public final boolean m6057deprecated_noTransform() {
        return this.noTransform;
    }

    /* renamed from: -deprecated_onlyIfCached  reason: not valid java name */
    public final boolean m6058deprecated_onlyIfCached() {
        return this.onlyIfCached;
    }

    /* renamed from: -deprecated_sMaxAgeSeconds  reason: not valid java name */
    public final int m6059deprecated_sMaxAgeSeconds() {
        return this.sMaxAgeSeconds;
    }

    public final boolean immutable() {
        return this.immutable;
    }

    public final boolean isPrivate() {
        return this.isPrivate;
    }

    public final boolean isPublic() {
        return this.isPublic;
    }

    public final int maxAgeSeconds() {
        return this.maxAgeSeconds;
    }

    public final int maxStaleSeconds() {
        return this.maxStaleSeconds;
    }

    public final int minFreshSeconds() {
        return this.minFreshSeconds;
    }

    public final boolean mustRevalidate() {
        return this.mustRevalidate;
    }

    public final boolean noCache() {
        return this.noCache;
    }

    public final boolean noStore() {
        return this.noStore;
    }

    public final boolean noTransform() {
        return this.noTransform;
    }

    public final boolean onlyIfCached() {
        return this.onlyIfCached;
    }

    public final int sMaxAgeSeconds() {
        return this.sMaxAgeSeconds;
    }

    public String toString() {
        String str = this.headerValue;
        if (str != null) {
            return str;
        }
        StringBuilder sb = new StringBuilder();
        if (this.noCache) {
            sb.append("no-cache, ");
        }
        if (this.noStore) {
            sb.append("no-store, ");
        }
        if (this.maxAgeSeconds != -1) {
            sb.append("max-age=");
            sb.append(this.maxAgeSeconds);
            sb.append(", ");
        }
        if (this.sMaxAgeSeconds != -1) {
            sb.append("s-maxage=");
            sb.append(this.sMaxAgeSeconds);
            sb.append(", ");
        }
        if (this.isPrivate) {
            sb.append("private, ");
        }
        if (this.isPublic) {
            sb.append("public, ");
        }
        if (this.mustRevalidate) {
            sb.append("must-revalidate, ");
        }
        if (this.maxStaleSeconds != -1) {
            sb.append("max-stale=");
            sb.append(this.maxStaleSeconds);
            sb.append(", ");
        }
        if (this.minFreshSeconds != -1) {
            sb.append("min-fresh=");
            sb.append(this.minFreshSeconds);
            sb.append(", ");
        }
        if (this.onlyIfCached) {
            sb.append("only-if-cached, ");
        }
        if (this.noTransform) {
            sb.append("no-transform, ");
        }
        if (this.immutable) {
            sb.append("immutable, ");
        }
        if (sb.length() == 0) {
            return "";
        }
        sb.delete(sb.length() - 2, sb.length());
        String sb2 = sb.toString();
        Intrinsics.m5821a((Object) sb2, "StringBuilder().apply(builderAction).toString()");
        this.headerValue = sb2;
        return sb2;
    }

    public /* synthetic */ CacheControl(boolean z, boolean z2, int i, int i2, boolean z3, boolean z4, boolean z5, int i3, int i4, boolean z6, boolean z7, boolean z8, String str, DefaultConstructorMarker fVar) {
        this(z, z2, i, i2, z3, z4, z5, i3, i4, z6, z7, z8, str);
    }
}
