package okhttp3;

import java.security.Principal;
import java.security.PublicKey;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import javax.net.ssl.SSLPeerUnverifiedException;
import okhttp3.internal.HostnamesKt;
import okhttp3.internal.tls.CertificateChainCleaner;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p251i.C1892h;
import p250f.p251i.Sets;
import p250f.p251i._Arrays;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p254l.p256c.TypeIntrinsics;
import p250f.p254l.p256c.p257r.KMarkers;
import p250f.p261p.C1937g;
import p262g.C1952h;

/* compiled from: CertificatePinner.kt */
public final class CertificatePinner {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final CertificatePinner DEFAULT = new Builder().build();
    public final CertificateChainCleaner certificateChainCleaner;
    public final Set<Pin> pins;

    /* compiled from: CertificatePinner.kt */
    public static final class Builder {
        public final List<Pin> pins = new ArrayList();

        public final Builder add(String str, String... strArr) {
            if (str == null) {
                Intrinsics.m5822a("pattern");
                throw null;
            } else if (strArr != null) {
                for (String newPin$okhttp : strArr) {
                    this.pins.add(CertificatePinner.Companion.newPin$okhttp(str, newPin$okhttp));
                }
                return this;
            } else {
                Intrinsics.m5822a("pins");
                throw null;
            }
        }

        public final CertificatePinner build() {
            Set set;
            List<Pin> list = this.pins;
            if (list != null) {
                int size = list.size();
                if (size == 0) {
                    set = Sets.f7581b;
                } else if (size != 1) {
                    set = new LinkedHashSet(C1050v.m4209c(list.size()));
                    _Arrays.m5802a(list, set);
                } else {
                    set = Collections.singleton(list.get(0));
                    Intrinsics.m5821a((Object) set, "java.util.Collections.singleton(element)");
                }
                return new CertificatePinner(set, (CertificateChainCleaner) null);
            }
            Intrinsics.m5822a("$this$toSet");
            throw null;
        }
    }

    /* compiled from: CertificatePinner.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Pin newPin$okhttp(String str, String str2) {
            if (str == null) {
                Intrinsics.m5822a("pattern");
                throw null;
            } else if (str2 != null) {
                boolean z = true;
                if ((!C1937g.m5864b(str, "*.", false, 2) || C1937g.m5840a((CharSequence) str, "*", 1, false, 4) != -1) && ((!C1937g.m5864b(str, "**.", false, 2) || C1937g.m5840a((CharSequence) str, "*", 2, false, 4) != -1) && C1937g.m5840a((CharSequence) str, "*", 0, false, 6) != -1)) {
                    z = false;
                }
                if (z) {
                    String canonicalHost = HostnamesKt.toCanonicalHost(str);
                    if (canonicalHost == null) {
                        throw new IllegalArgumentException(outline.m2941b("Invalid pattern: ", str));
                    } else if (C1937g.m5864b(str2, "sha1/", false, 2)) {
                        C1952h.C1953a aVar = C1952h.f7659f;
                        String substring = str2.substring(5);
                        Intrinsics.m5821a((Object) substring, "(this as java.lang.String).substring(startIndex)");
                        C1952h a = aVar.mo9550a(substring);
                        if (a != null) {
                            return new Pin(canonicalHost, "sha1/", a);
                        }
                        Intrinsics.m5820a();
                        throw null;
                    } else if (C1937g.m5864b(str2, "sha256/", false, 2)) {
                        C1952h.C1953a aVar2 = C1952h.f7659f;
                        String substring2 = str2.substring(7);
                        Intrinsics.m5821a((Object) substring2, "(this as java.lang.String).substring(startIndex)");
                        C1952h a2 = aVar2.mo9550a(substring2);
                        if (a2 != null) {
                            return new Pin(canonicalHost, "sha256/", a2);
                        }
                        Intrinsics.m5820a();
                        throw null;
                    } else {
                        throw new IllegalArgumentException(outline.m2941b("pins must start with 'sha256/' or 'sha1/': ", str2));
                    }
                } else {
                    throw new IllegalArgumentException(outline.m2941b("Unexpected pattern: ", str).toString());
                }
            } else {
                Intrinsics.m5822a("pin");
                throw null;
            }
        }

        public final String pin(Certificate certificate) {
            if (certificate == null) {
                Intrinsics.m5822a("certificate");
                throw null;
            } else if (certificate instanceof X509Certificate) {
                StringBuilder a = outline.m2937a("sha256/");
                a.append(toSha256ByteString$okhttp((X509Certificate) certificate).mo9535a());
                return a.toString();
            } else {
                throw new IllegalArgumentException("Certificate pinning requires X509 certificates".toString());
            }
        }

        public final C1952h toSha1ByteString$okhttp(X509Certificate x509Certificate) {
            if (x509Certificate != null) {
                C1952h.C1953a aVar = C1952h.f7659f;
                PublicKey publicKey = x509Certificate.getPublicKey();
                Intrinsics.m5821a((Object) publicKey, "publicKey");
                byte[] encoded = publicKey.getEncoded();
                Intrinsics.m5821a((Object) encoded, "publicKey.encoded");
                return C1952h.C1953a.m5962a(aVar, encoded, 0, 0, 3).mo9544e();
            }
            Intrinsics.m5822a("$this$toSha1ByteString");
            throw null;
        }

        public final C1952h toSha256ByteString$okhttp(X509Certificate x509Certificate) {
            if (x509Certificate != null) {
                C1952h.C1953a aVar = C1952h.f7659f;
                PublicKey publicKey = x509Certificate.getPublicKey();
                Intrinsics.m5821a((Object) publicKey, "publicKey");
                byte[] encoded = publicKey.getEncoded();
                Intrinsics.m5821a((Object) encoded, "publicKey.encoded");
                return C1952h.C1953a.m5962a(aVar, encoded, 0, 0, 3).mo9534a("SHA-256");
            }
            Intrinsics.m5822a("$this$toSha256ByteString");
            throw null;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: CertificatePinner.kt */
    public static final class Pin {
        public final C1952h hash;
        public final String hashAlgorithm;
        public final String pattern;

        public Pin(String str, String str2, C1952h hVar) {
            if (str == null) {
                Intrinsics.m5822a("pattern");
                throw null;
            } else if (str2 == null) {
                Intrinsics.m5822a("hashAlgorithm");
                throw null;
            } else if (hVar != null) {
                this.pattern = str;
                this.hashAlgorithm = str2;
                this.hash = hVar;
            } else {
                Intrinsics.m5822a("hash");
                throw null;
            }
        }

        private final String component1() {
            return this.pattern;
        }

        public static /* synthetic */ Pin copy$default(Pin pin, String str, String str2, C1952h hVar, int i, Object obj) {
            if ((i & 1) != 0) {
                str = pin.pattern;
            }
            if ((i & 2) != 0) {
                str2 = pin.hashAlgorithm;
            }
            if ((i & 4) != 0) {
                hVar = pin.hash;
            }
            return pin.copy(str, str2, hVar);
        }

        public final String component2() {
            return this.hashAlgorithm;
        }

        public final C1952h component3() {
            return this.hash;
        }

        public final Pin copy(String str, String str2, C1952h hVar) {
            if (str == null) {
                Intrinsics.m5822a("pattern");
                throw null;
            } else if (str2 == null) {
                Intrinsics.m5822a("hashAlgorithm");
                throw null;
            } else if (hVar != null) {
                return new Pin(str, str2, hVar);
            } else {
                Intrinsics.m5822a("hash");
                throw null;
            }
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof Pin)) {
                return false;
            }
            Pin pin = (Pin) obj;
            return Intrinsics.m5823a((Object) this.pattern, (Object) pin.pattern) && Intrinsics.m5823a((Object) this.hashAlgorithm, (Object) pin.hashAlgorithm) && Intrinsics.m5823a((Object) this.hash, (Object) pin.hash);
        }

        public final C1952h getHash() {
            return this.hash;
        }

        public final String getHashAlgorithm() {
            return this.hashAlgorithm;
        }

        public int hashCode() {
            String str = this.pattern;
            int i = 0;
            int hashCode = (str != null ? str.hashCode() : 0) * 31;
            String str2 = this.hashAlgorithm;
            int hashCode2 = (hashCode + (str2 != null ? str2.hashCode() : 0)) * 31;
            C1952h hVar = this.hash;
            if (hVar != null) {
                i = hVar.hashCode();
            }
            return hashCode2 + i;
        }

        public final boolean matches(String str) {
            if (str != null) {
                if (C1937g.m5864b(this.pattern, "**.", false, 2)) {
                    int length = this.pattern.length() - 3;
                    int length2 = str.length() - length;
                    if (!C1937g.m5855a(str, str.length() - length, this.pattern, 3, length, false, 16)) {
                        return false;
                    }
                    if (length2 == 0 || str.charAt(length2 - 1) == '.') {
                        return true;
                    }
                    return false;
                } else if (!C1937g.m5864b(this.pattern, "*.", false, 2)) {
                    return Intrinsics.m5823a((Object) str, (Object) this.pattern);
                } else {
                    int length3 = this.pattern.length() - 1;
                    int length4 = str.length() - length3;
                    if (!C1937g.m5855a(str, str.length() - length3, this.pattern, 1, length3, false, 16) || C1937g.m5860b(str, '.', length4 - 1, false, 4) != -1) {
                        return false;
                    }
                }
                return true;
            }
            Intrinsics.m5822a("hostname");
            throw null;
        }

        public String toString() {
            return this.hashAlgorithm + this.hash.mo9535a();
        }
    }

    public CertificatePinner(Set<Pin> set, CertificateChainCleaner certificateChainCleaner2) {
        if (set != null) {
            this.pins = set;
            this.certificateChainCleaner = certificateChainCleaner2;
            return;
        }
        Intrinsics.m5822a("pins");
        throw null;
    }

    public static final String pin(Certificate certificate) {
        return Companion.pin(certificate);
    }

    public final void check(String str, List<? extends Certificate> list) throws SSLPeerUnverifiedException {
        if (str == null) {
            Intrinsics.m5822a("hostname");
            throw null;
        } else if (list != null) {
            check$okhttp(str, new CertificatePinner$check$1(this, list, str));
        } else {
            Intrinsics.m5822a("peerCertificates");
            throw null;
        }
    }

    public final void check$okhttp(String str, C1896a<? extends List<? extends X509Certificate>> aVar) {
        Pin next;
        if (str == null) {
            Intrinsics.m5822a("hostname");
            throw null;
        } else if (aVar != null) {
            List<Pin> findMatchingPins$okhttp = findMatchingPins$okhttp(str);
            if (!findMatchingPins$okhttp.isEmpty()) {
                List<X509Certificate> list = (List) aVar.invoke();
                loop0:
                for (X509Certificate x509Certificate : list) {
                    Iterator<Pin> it = findMatchingPins$okhttp.iterator();
                    C1952h hVar = null;
                    C1952h hVar2 = null;
                    while (true) {
                        if (it.hasNext()) {
                            next = it.next();
                            String hashAlgorithm = next.getHashAlgorithm();
                            int hashCode = hashAlgorithm.hashCode();
                            if (hashCode == 109397962) {
                                if (!hashAlgorithm.equals("sha1/")) {
                                    break loop0;
                                }
                                if (hVar == null) {
                                    hVar = Companion.toSha1ByteString$okhttp(x509Certificate);
                                }
                                if (Intrinsics.m5823a((Object) next.getHash(), (Object) hVar)) {
                                    return;
                                }
                            } else if (hashCode != 2052263656 || !hashAlgorithm.equals("sha256/")) {
                                break loop0;
                            } else {
                                if (hVar2 == null) {
                                    hVar2 = Companion.toSha256ByteString$okhttp(x509Certificate);
                                }
                                if (Intrinsics.m5823a((Object) next.getHash(), (Object) hVar2)) {
                                    return;
                                }
                            }
                        }
                    }
                    StringBuilder a = outline.m2937a("unsupported hashAlgorithm: ");
                    a.append(next.getHashAlgorithm());
                    throw new AssertionError(a.toString());
                }
                StringBuilder a2 = outline.m2938a("Certificate pinning failure!", "\n  Peer certificate chain:");
                for (X509Certificate x509Certificate2 : list) {
                    a2.append("\n    ");
                    a2.append(Companion.pin(x509Certificate2));
                    a2.append(": ");
                    Principal subjectDN = x509Certificate2.getSubjectDN();
                    Intrinsics.m5821a((Object) subjectDN, "element.subjectDN");
                    a2.append(subjectDN.getName());
                }
                a2.append("\n  Pinned certificates for ");
                a2.append(str);
                a2.append(":");
                for (Pin append : findMatchingPins$okhttp) {
                    a2.append("\n    ");
                    a2.append(append);
                }
                String sb = a2.toString();
                Intrinsics.m5821a((Object) sb, "StringBuilder().apply(builderAction).toString()");
                throw new SSLPeerUnverifiedException(sb);
            }
        } else {
            Intrinsics.m5822a("cleanedPeerCertificatesFn");
            throw null;
        }
    }

    public boolean equals(Object obj) {
        if (obj instanceof CertificatePinner) {
            CertificatePinner certificatePinner = (CertificatePinner) obj;
            return Intrinsics.m5823a((Object) certificatePinner.pins, (Object) this.pins) && Intrinsics.m5823a((Object) certificatePinner.certificateChainCleaner, (Object) this.certificateChainCleaner);
        }
    }

    public final List<Pin> findMatchingPins$okhttp(String str) {
        if (str != null) {
            List list = C1892h.f7579b;
            for (Pin next : this.pins) {
                if (next.matches(str)) {
                    if (list.isEmpty()) {
                        list = new ArrayList();
                    }
                    Class<TypeIntrinsics> cls = TypeIntrinsics.class;
                    if (list instanceof KMarkers) {
                        ClassCastException classCastException = new ClassCastException(outline.m2934a(list.getClass().getName(), " cannot be cast to ", "kotlin.collections.MutableList"));
                        Intrinsics.m5819a(classCastException, cls.getName());
                        throw classCastException;
                    }
                    list.add(next);
                }
            }
            return list;
        }
        Intrinsics.m5822a("hostname");
        throw null;
    }

    public final CertificateChainCleaner getCertificateChainCleaner$okhttp() {
        return this.certificateChainCleaner;
    }

    public int hashCode() {
        int hashCode = (this.pins.hashCode() + 1517) * 41;
        CertificateChainCleaner certificateChainCleaner2 = this.certificateChainCleaner;
        return hashCode + (certificateChainCleaner2 != null ? certificateChainCleaner2.hashCode() : 0);
    }

    public final CertificatePinner withCertificateChainCleaner$okhttp(CertificateChainCleaner certificateChainCleaner2) {
        if (Intrinsics.m5823a((Object) this.certificateChainCleaner, (Object) certificateChainCleaner2)) {
            return this;
        }
        return new CertificatePinner(this.pins, certificateChainCleaner2);
    }

    public final void check(String str, Certificate... certificateArr) throws SSLPeerUnverifiedException {
        if (str == null) {
            Intrinsics.m5822a("hostname");
            throw null;
        } else if (certificateArr != null) {
            check(str, (List<? extends Certificate>) C1050v.m4202b((T[]) certificateArr));
        } else {
            Intrinsics.m5822a("peerCertificates");
            throw null;
        }
    }
}
