package okhttp3;

import androidx.recyclerview.widget.RecyclerView;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import okhttp3.internal.HostnamesKt;
import okhttp3.internal.Util;
import okhttp3.internal.http.DatesKt;
import org.codehaus.mojo.animal_sniffer.IgnoreJRERequirement;
import p085c.p086a.p087a.p088a.outline;
import p250f.p251i.C1892h;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p250f.p261p.Regex;

/* compiled from: Cookie.kt */
public final class Cookie {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final Pattern DAY_OF_MONTH_PATTERN = Pattern.compile("(\\d{1,2})[^\\d]*");
    public static final Pattern MONTH_PATTERN = Pattern.compile("(?i)(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec).*");
    public static final Pattern TIME_PATTERN = Pattern.compile("(\\d{1,2}):(\\d{1,2}):(\\d{1,2})[^\\d]*");
    public static final Pattern YEAR_PATTERN = Pattern.compile("(\\d{2,4})[^\\d]*");
    public final String domain;
    public final long expiresAt;
    public final boolean hostOnly;
    public final boolean httpOnly;
    public final String name;
    public final String path;
    public final boolean persistent;
    public final boolean secure;
    public final String value;

    /* compiled from: Cookie.kt */
    public static final class Companion {
        public Companion() {
        }

        private final int dateCharacterOffset(String str, int i, int i2, boolean z) {
            while (i < i2) {
                char charAt = str.charAt(i);
                if (((charAt < ' ' && charAt != 9) || charAt >= 127 || ('0' <= charAt && '9' >= charAt) || (('a' <= charAt && 'z' >= charAt) || (('A' <= charAt && 'Z' >= charAt) || charAt == ':'))) == (!z)) {
                    return i;
                }
                i++;
            }
            return i2;
        }

        /* access modifiers changed from: private */
        public final boolean domainMatch(String str, String str2) {
            if (Intrinsics.m5823a((Object) str, (Object) str2)) {
                return true;
            }
            if (!C1937g.m5859a(str, str2, false, 2) || str.charAt((str.length() - str2.length()) - 1) != '.' || Util.canParseAsIpAddress(str)) {
                return false;
            }
            return true;
        }

        private final String parseDomain(String str) {
            if (!C1937g.m5859a(str, ".", false, 2)) {
                String canonicalHost = HostnamesKt.toCanonicalHost(C1937g.m5847a(str, (CharSequence) "."));
                if (canonicalHost != null) {
                    return canonicalHost;
                }
                throw new IllegalArgumentException();
            }
            throw new IllegalArgumentException("Failed requirement.".toString());
        }

        private final long parseExpires(String str, int i, int i2) {
            String str2 = str;
            int i3 = i2;
            int dateCharacterOffset = dateCharacterOffset(str2, i, i3, false);
            Matcher matcher = Cookie.TIME_PATTERN.matcher(str2);
            int i4 = -1;
            int i5 = -1;
            int i6 = -1;
            int i7 = -1;
            int i8 = -1;
            int i9 = -1;
            while (dateCharacterOffset < i3) {
                int dateCharacterOffset2 = dateCharacterOffset(str2, dateCharacterOffset + 1, i3, true);
                matcher.region(dateCharacterOffset, dateCharacterOffset2);
                if (i5 == -1 && matcher.usePattern(Cookie.TIME_PATTERN).matches()) {
                    String group = matcher.group(1);
                    Intrinsics.m5821a((Object) group, "matcher.group(1)");
                    i5 = Integer.parseInt(group);
                    String group2 = matcher.group(2);
                    Intrinsics.m5821a((Object) group2, "matcher.group(2)");
                    i8 = Integer.parseInt(group2);
                    String group3 = matcher.group(3);
                    Intrinsics.m5821a((Object) group3, "matcher.group(3)");
                    i9 = Integer.parseInt(group3);
                } else if (i6 == -1 && matcher.usePattern(Cookie.DAY_OF_MONTH_PATTERN).matches()) {
                    String group4 = matcher.group(1);
                    Intrinsics.m5821a((Object) group4, "matcher.group(1)");
                    i6 = Integer.parseInt(group4);
                } else if (i7 == -1 && matcher.usePattern(Cookie.MONTH_PATTERN).matches()) {
                    String group5 = matcher.group(1);
                    Intrinsics.m5821a((Object) group5, "matcher.group(1)");
                    Locale locale = Locale.US;
                    Intrinsics.m5821a((Object) locale, "Locale.US");
                    String lowerCase = group5.toLowerCase(locale);
                    Intrinsics.m5821a((Object) lowerCase, "(this as java.lang.String).toLowerCase(locale)");
                    String pattern = Cookie.MONTH_PATTERN.pattern();
                    Intrinsics.m5821a((Object) pattern, "MONTH_PATTERN.pattern()");
                    i7 = C1937g.m5840a((CharSequence) pattern, lowerCase, 0, false, 6) / 4;
                } else if (i4 == -1 && matcher.usePattern(Cookie.YEAR_PATTERN).matches()) {
                    String group6 = matcher.group(1);
                    Intrinsics.m5821a((Object) group6, "matcher.group(1)");
                    i4 = Integer.parseInt(group6);
                }
                dateCharacterOffset = dateCharacterOffset(str2, dateCharacterOffset2 + 1, i3, false);
            }
            if (70 <= i4 && 99 >= i4) {
                i4 += 1900;
            }
            if (i4 >= 0 && 69 >= i4) {
                i4 += 2000;
            }
            if (i4 >= 1601) {
                if (i7 != -1) {
                    if (1 <= i6 && 31 >= i6) {
                        if (i5 >= 0 && 23 >= i5) {
                            if (i8 >= 0 && 59 >= i8) {
                                if (i9 >= 0 && 59 >= i9) {
                                    GregorianCalendar gregorianCalendar = new GregorianCalendar(Util.UTC);
                                    gregorianCalendar.setLenient(false);
                                    gregorianCalendar.set(1, i4);
                                    gregorianCalendar.set(2, i7 - 1);
                                    gregorianCalendar.set(5, i6);
                                    gregorianCalendar.set(11, i5);
                                    gregorianCalendar.set(12, i8);
                                    gregorianCalendar.set(13, i9);
                                    gregorianCalendar.set(14, 0);
                                    return gregorianCalendar.getTimeInMillis();
                                }
                                throw new IllegalArgumentException("Failed requirement.".toString());
                            }
                            throw new IllegalArgumentException("Failed requirement.".toString());
                        }
                        throw new IllegalArgumentException("Failed requirement.".toString());
                    }
                    throw new IllegalArgumentException("Failed requirement.".toString());
                }
                throw new IllegalArgumentException("Failed requirement.".toString());
            }
            throw new IllegalArgumentException("Failed requirement.".toString());
        }

        private final long parseMaxAge(String str) {
            try {
                long parseLong = Long.parseLong(str);
                if (parseLong <= 0) {
                    return Long.MIN_VALUE;
                }
                return parseLong;
            } catch (NumberFormatException e) {
                if (!new Regex("-?\\d+").mo9424a(str)) {
                    throw e;
                } else if (C1937g.m5864b(str, "-", false, 2)) {
                    return Long.MIN_VALUE;
                } else {
                    return RecyclerView.FOREVER_NS;
                }
            }
        }

        /* access modifiers changed from: private */
        public final boolean pathMatch(HttpUrl httpUrl, String str) {
            String encodedPath = httpUrl.encodedPath();
            if (Intrinsics.m5823a((Object) encodedPath, (Object) str)) {
                return true;
            }
            return C1937g.m5864b(encodedPath, str, false, 2) && (C1937g.m5859a(str, "/", false, 2) || encodedPath.charAt(str.length()) == '/');
        }

        public final Cookie parse(HttpUrl httpUrl, String str) {
            if (httpUrl == null) {
                Intrinsics.m5822a("url");
                throw null;
            } else if (str != null) {
                return parse$okhttp(System.currentTimeMillis(), httpUrl, str);
            } else {
                Intrinsics.m5822a("setCookie");
                throw null;
            }
        }

        /* JADX WARNING: No exception handlers in catch block: Catch:{  } */
        /* JADX WARNING: Removed duplicated region for block: B:64:0x0106  */
        /* JADX WARNING: Removed duplicated region for block: B:65:0x0109  */
        /* JADX WARNING: Removed duplicated region for block: B:73:0x0129 A[RETURN] */
        /* JADX WARNING: Removed duplicated region for block: B:74:0x012a  */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final okhttp3.Cookie parse$okhttp(long r24, okhttp3.HttpUrl r26, java.lang.String r27) {
            /*
                r23 = this;
                r0 = r23
                r7 = r27
                r8 = 0
                if (r26 == 0) goto L_0x016e
                if (r7 == 0) goto L_0x0167
                r2 = 59
                r3 = 0
                r4 = 0
                r5 = 6
                r6 = 0
                r1 = r27
                int r9 = okhttp3.internal.Util.delimiterOffset$default((java.lang.String) r1, (char) r2, (int) r3, (int) r4, (int) r5, (java.lang.Object) r6)
                r2 = 61
                r5 = 2
                r4 = r9
                int r1 = okhttp3.internal.Util.delimiterOffset$default((java.lang.String) r1, (char) r2, (int) r3, (int) r4, (int) r5, (java.lang.Object) r6)
                if (r1 != r9) goto L_0x0020
                return r8
            L_0x0020:
                r2 = 0
                r3 = 1
                java.lang.String r11 = okhttp3.internal.Util.trimSubstring$default(r7, r2, r1, r3, r8)
                int r4 = r11.length()
                if (r4 != 0) goto L_0x002e
                r4 = 1
                goto L_0x002f
            L_0x002e:
                r4 = 0
            L_0x002f:
                if (r4 != 0) goto L_0x0165
                int r4 = okhttp3.internal.Util.indexOfControlOrNonAscii(r11)
                r5 = -1
                if (r4 == r5) goto L_0x003a
                goto L_0x0165
            L_0x003a:
                int r1 = r1 + r3
                java.lang.String r12 = okhttp3.internal.Util.trimSubstring(r7, r1, r9)
                int r1 = okhttp3.internal.Util.indexOfControlOrNonAscii(r12)
                if (r1 == r5) goto L_0x0046
                return r8
            L_0x0046:
                int r9 = r9 + r3
                int r1 = r27.length()
                r4 = -1
                r15 = r4
                r6 = r8
                r10 = r6
                r17 = 0
                r18 = 0
                r19 = 0
                r20 = 1
                r21 = 253402300799999(0xe677d21fdbff, double:1.251973714024093E-309)
            L_0x005d:
                if (r9 >= r1) goto L_0x00cc
                r8 = 59
                int r8 = okhttp3.internal.Util.delimiterOffset((java.lang.String) r7, (char) r8, (int) r9, (int) r1)
                r13 = 61
                int r13 = okhttp3.internal.Util.delimiterOffset((java.lang.String) r7, (char) r13, (int) r9, (int) r8)
                java.lang.String r9 = okhttp3.internal.Util.trimSubstring(r7, r9, r13)
                if (r13 >= r8) goto L_0x0078
                int r13 = r13 + 1
                java.lang.String r13 = okhttp3.internal.Util.trimSubstring(r7, r13, r8)
                goto L_0x007a
            L_0x0078:
                java.lang.String r13 = ""
            L_0x007a:
                java.lang.String r14 = "expires"
                boolean r14 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r14, (boolean) r3)
                if (r14 == 0) goto L_0x008b
                int r9 = r13.length()     // Catch:{ IllegalArgumentException -> 0x00c8 }
                long r21 = r0.parseExpires(r13, r2, r9)     // Catch:{ IllegalArgumentException -> 0x00c8 }
                goto L_0x0097
            L_0x008b:
                java.lang.String r14 = "max-age"
                boolean r14 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r14, (boolean) r3)
                if (r14 == 0) goto L_0x009a
                long r15 = r0.parseMaxAge(r13)     // Catch:{  }
            L_0x0097:
                r19 = 1
                goto L_0x00c8
            L_0x009a:
                java.lang.String r14 = "domain"
                boolean r14 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r14, (boolean) r3)
                if (r14 == 0) goto L_0x00a9
                java.lang.String r6 = r0.parseDomain(r13)     // Catch:{ IllegalArgumentException -> 0x00c8 }
                r20 = 0
                goto L_0x00c8
            L_0x00a9:
                java.lang.String r14 = "path"
                boolean r14 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r14, (boolean) r3)
                if (r14 == 0) goto L_0x00b3
                r10 = r13
                goto L_0x00c8
            L_0x00b3:
                java.lang.String r13 = "secure"
                boolean r13 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r13, (boolean) r3)
                if (r13 == 0) goto L_0x00be
                r17 = 1
                goto L_0x00c8
            L_0x00be:
                java.lang.String r13 = "httponly"
                boolean r9 = p250f.p261p.C1937g.m5858a((java.lang.String) r9, (java.lang.String) r13, (boolean) r3)
                if (r9 == 0) goto L_0x00c8
                r18 = 1
            L_0x00c8:
                int r9 = r8 + 1
                r8 = 0
                goto L_0x005d
            L_0x00cc:
                r7 = -9223372036854775808
                int r1 = (r15 > r7 ? 1 : (r15 == r7 ? 0 : -1))
                if (r1 != 0) goto L_0x00d4
            L_0x00d2:
                r13 = r7
                goto L_0x0100
            L_0x00d4:
                int r1 = (r15 > r4 ? 1 : (r15 == r4 ? 0 : -1))
                if (r1 == 0) goto L_0x00fe
                r3 = 9223372036854775(0x20c49ba5e353f7, double:4.663754807431093E-308)
                int r1 = (r15 > r3 ? 1 : (r15 == r3 ? 0 : -1))
                if (r1 > 0) goto L_0x00e7
                r1 = 1000(0x3e8, float:1.401E-42)
                long r3 = (long) r1
                long r15 = r15 * r3
                goto L_0x00ec
            L_0x00e7:
                r15 = 9223372036854775807(0x7fffffffffffffff, double:NaN)
            L_0x00ec:
                long r3 = r24 + r15
                int r1 = (r3 > r24 ? 1 : (r3 == r24 ? 0 : -1))
                r7 = 253402300799999(0xe677d21fdbff, double:1.251973714024093E-309)
                if (r1 < 0) goto L_0x00d2
                int r1 = (r3 > r7 ? 1 : (r3 == r7 ? 0 : -1))
                if (r1 <= 0) goto L_0x00fc
                goto L_0x00d2
            L_0x00fc:
                r13 = r3
                goto L_0x0100
            L_0x00fe:
                r13 = r21
            L_0x0100:
                java.lang.String r1 = r26.host()
                if (r6 != 0) goto L_0x0109
                r15 = r1
                r3 = 0
                goto L_0x0113
            L_0x0109:
                boolean r3 = r0.domainMatch(r1, r6)
                if (r3 != 0) goto L_0x0111
                r3 = 0
                return r3
            L_0x0111:
                r3 = 0
                r15 = r6
            L_0x0113:
                int r1 = r1.length()
                int r4 = r15.length()
                if (r1 == r4) goto L_0x012a
                okhttp3.internal.publicsuffix.PublicSuffixDatabase$Companion r1 = okhttp3.internal.publicsuffix.PublicSuffixDatabase.Companion
                okhttp3.internal.publicsuffix.PublicSuffixDatabase r1 = r1.get()
                java.lang.String r1 = r1.getEffectiveTldPlusOne(r15)
                if (r1 != 0) goto L_0x012a
                return r3
            L_0x012a:
                java.lang.String r1 = "/"
                if (r10 == 0) goto L_0x0139
                r3 = 2
                boolean r3 = p250f.p261p.C1937g.m5864b((java.lang.String) r10, (java.lang.String) r1, (boolean) r2, (int) r3)
                if (r3 != 0) goto L_0x0136
                goto L_0x0139
            L_0x0136:
                r16 = r10
                goto L_0x015c
            L_0x0139:
                java.lang.String r3 = r26.encodedPath()
                r4 = 47
                r5 = 6
                int r4 = p250f.p261p.C1937g.m5860b(r3, r4, r2, r2, r5)
                if (r4 == 0) goto L_0x015a
                if (r3 == 0) goto L_0x0152
                java.lang.String r1 = r3.substring(r2, r4)
                java.lang.String r2 = "(this as java.lang.Strin…ing(startIndex, endIndex)"
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r1, (java.lang.String) r2)
                goto L_0x015a
            L_0x0152:
                f.e r1 = new f.e
                java.lang.String r2 = "null cannot be cast to non-null type java.lang.String"
                r1.<init>(r2)
                throw r1
            L_0x015a:
                r16 = r1
            L_0x015c:
                okhttp3.Cookie r1 = new okhttp3.Cookie
                r21 = 0
                r10 = r1
                r10.<init>(r11, r12, r13, r15, r16, r17, r18, r19, r20, r21)
                return r1
            L_0x0165:
                r1 = r8
                return r1
            L_0x0167:
                r1 = r8
                java.lang.String r2 = "setCookie"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r2)
                throw r1
            L_0x016e:
                r1 = r8
                java.lang.String r2 = "url"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r2)
                throw r1
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.Cookie.Companion.parse$okhttp(long, okhttp3.HttpUrl, java.lang.String):okhttp3.Cookie");
        }

        public final List<Cookie> parseAll(HttpUrl httpUrl, Headers headers) {
            ArrayList arrayList = null;
            if (httpUrl == null) {
                Intrinsics.m5822a("url");
                throw null;
            } else if (headers != null) {
                List<String> values = headers.values("Set-Cookie");
                int size = values.size();
                for (int i = 0; i < size; i++) {
                    Cookie parse = parse(httpUrl, values.get(i));
                    if (parse != null) {
                        if (arrayList == null) {
                            arrayList = new ArrayList();
                        }
                        arrayList.add(parse);
                    }
                }
                if (arrayList == null) {
                    return C1892h.f7579b;
                }
                List<Cookie> unmodifiableList = Collections.unmodifiableList(arrayList);
                Intrinsics.m5821a((Object) unmodifiableList, "Collections.unmodifiableList(cookies)");
                return unmodifiableList;
            } else {
                Intrinsics.m5822a("headers");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Cookie(String str, String str2, long j, String str3, String str4, boolean z, boolean z2, boolean z3, boolean z4) {
        this.name = str;
        this.value = str2;
        this.expiresAt = j;
        this.domain = str3;
        this.path = str4;
        this.secure = z;
        this.httpOnly = z2;
        this.persistent = z3;
        this.hostOnly = z4;
    }

    public static final Cookie parse(HttpUrl httpUrl, String str) {
        return Companion.parse(httpUrl, str);
    }

    public static final List<Cookie> parseAll(HttpUrl httpUrl, Headers headers) {
        return Companion.parseAll(httpUrl, headers);
    }

    /* renamed from: -deprecated_domain  reason: not valid java name */
    public final String m6068deprecated_domain() {
        return this.domain;
    }

    /* renamed from: -deprecated_expiresAt  reason: not valid java name */
    public final long m6069deprecated_expiresAt() {
        return this.expiresAt;
    }

    /* renamed from: -deprecated_hostOnly  reason: not valid java name */
    public final boolean m6070deprecated_hostOnly() {
        return this.hostOnly;
    }

    /* renamed from: -deprecated_httpOnly  reason: not valid java name */
    public final boolean m6071deprecated_httpOnly() {
        return this.httpOnly;
    }

    /* renamed from: -deprecated_name  reason: not valid java name */
    public final String m6072deprecated_name() {
        return this.name;
    }

    /* renamed from: -deprecated_path  reason: not valid java name */
    public final String m6073deprecated_path() {
        return this.path;
    }

    /* renamed from: -deprecated_persistent  reason: not valid java name */
    public final boolean m6074deprecated_persistent() {
        return this.persistent;
    }

    /* renamed from: -deprecated_secure  reason: not valid java name */
    public final boolean m6075deprecated_secure() {
        return this.secure;
    }

    /* renamed from: -deprecated_value  reason: not valid java name */
    public final String m6076deprecated_value() {
        return this.value;
    }

    public final String domain() {
        return this.domain;
    }

    public boolean equals(Object obj) {
        if (obj instanceof Cookie) {
            Cookie cookie = (Cookie) obj;
            return Intrinsics.m5823a((Object) cookie.name, (Object) this.name) && Intrinsics.m5823a((Object) cookie.value, (Object) this.value) && cookie.expiresAt == this.expiresAt && Intrinsics.m5823a((Object) cookie.domain, (Object) this.domain) && Intrinsics.m5823a((Object) cookie.path, (Object) this.path) && cookie.secure == this.secure && cookie.httpOnly == this.httpOnly && cookie.persistent == this.persistent && cookie.hostOnly == this.hostOnly;
        }
    }

    public final long expiresAt() {
        return this.expiresAt;
    }

    @IgnoreJRERequirement
    public int hashCode() {
        int hashCode = this.value.hashCode();
        int hashCode2 = Long.hashCode(this.expiresAt);
        int hashCode3 = this.domain.hashCode();
        int hashCode4 = this.path.hashCode();
        int hashCode5 = Boolean.hashCode(this.secure);
        int hashCode6 = Boolean.hashCode(this.httpOnly);
        int hashCode7 = Boolean.hashCode(this.persistent);
        return Boolean.hashCode(this.hostOnly) + ((hashCode7 + ((hashCode6 + ((hashCode5 + ((hashCode4 + ((hashCode3 + ((hashCode2 + ((hashCode + ((this.name.hashCode() + 527) * 31)) * 31)) * 31)) * 31)) * 31)) * 31)) * 31)) * 31);
    }

    public final boolean hostOnly() {
        return this.hostOnly;
    }

    public final boolean httpOnly() {
        return this.httpOnly;
    }

    public final boolean matches(HttpUrl httpUrl) {
        boolean z;
        if (httpUrl != null) {
            if (this.hostOnly) {
                z = Intrinsics.m5823a((Object) httpUrl.host(), (Object) this.domain);
            } else {
                z = Companion.domainMatch(httpUrl.host(), this.domain);
            }
            if (!z || !Companion.pathMatch(httpUrl, this.path)) {
                return false;
            }
            if (!this.secure || httpUrl.isHttps()) {
                return true;
            }
            return false;
        }
        Intrinsics.m5822a("url");
        throw null;
    }

    public final String name() {
        return this.name;
    }

    public final String path() {
        return this.path;
    }

    public final boolean persistent() {
        return this.persistent;
    }

    public final boolean secure() {
        return this.secure;
    }

    public String toString() {
        return toString$okhttp(false);
    }

    public final String toString$okhttp(boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append(this.name);
        sb.append('=');
        sb.append(this.value);
        if (this.persistent) {
            if (this.expiresAt == Long.MIN_VALUE) {
                sb.append("; max-age=0");
            } else {
                sb.append("; expires=");
                sb.append(DatesKt.toHttpDateString(new Date(this.expiresAt)));
            }
        }
        if (!this.hostOnly) {
            sb.append("; domain=");
            if (z) {
                sb.append(".");
            }
            sb.append(this.domain);
        }
        sb.append("; path=");
        sb.append(this.path);
        if (this.secure) {
            sb.append("; secure");
        }
        if (this.httpOnly) {
            sb.append("; httponly");
        }
        String sb2 = sb.toString();
        Intrinsics.m5821a((Object) sb2, "toString()");
        return sb2;
    }

    public final String value() {
        return this.value;
    }

    /* compiled from: Cookie.kt */
    public static final class Builder {
        public String domain;
        public long expiresAt = DatesKt.MAX_DATE;
        public boolean hostOnly;
        public boolean httpOnly;
        public String name;
        public String path = "/";
        public boolean persistent;
        public boolean secure;
        public String value;

        public final Cookie build() {
            String str = this.name;
            if (str != null) {
                String str2 = this.value;
                if (str2 != null) {
                    long j = this.expiresAt;
                    String str3 = this.domain;
                    if (str3 != null) {
                        return new Cookie(str, str2, j, str3, this.path, this.secure, this.httpOnly, this.persistent, this.hostOnly, (DefaultConstructorMarker) null);
                    }
                    throw new NullPointerException("builder.domain == null");
                }
                throw new NullPointerException("builder.value == null");
            }
            throw new NullPointerException("builder.name == null");
        }

        public final Builder domain(String str) {
            if (str != null) {
                return domain(str, false);
            }
            Intrinsics.m5822a("domain");
            throw null;
        }

        public final Builder expiresAt(long j) {
            if (j <= 0) {
                j = Long.MIN_VALUE;
            }
            if (j > DatesKt.MAX_DATE) {
                j = 253402300799999L;
            }
            this.expiresAt = j;
            this.persistent = true;
            return this;
        }

        public final Builder hostOnlyDomain(String str) {
            if (str != null) {
                return domain(str, true);
            }
            Intrinsics.m5822a("domain");
            throw null;
        }

        public final Builder httpOnly() {
            this.httpOnly = true;
            return this;
        }

        public final Builder name(String str) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (Intrinsics.m5823a((Object) C1937g.m5865c(str).toString(), (Object) str)) {
                this.name = str;
                return this;
            } else {
                throw new IllegalArgumentException("name is not trimmed".toString());
            }
        }

        public final Builder path(String str) {
            if (str == null) {
                Intrinsics.m5822a("path");
                throw null;
            } else if (C1937g.m5864b(str, "/", false, 2)) {
                this.path = str;
                return this;
            } else {
                throw new IllegalArgumentException("path must start with '/'".toString());
            }
        }

        public final Builder secure() {
            this.secure = true;
            return this;
        }

        public final Builder value(String str) {
            if (str == null) {
                Intrinsics.m5822a("value");
                throw null;
            } else if (Intrinsics.m5823a((Object) C1937g.m5865c(str).toString(), (Object) str)) {
                this.value = str;
                return this;
            } else {
                throw new IllegalArgumentException("value is not trimmed".toString());
            }
        }

        private final Builder domain(String str, boolean z) {
            String canonicalHost = HostnamesKt.toCanonicalHost(str);
            if (canonicalHost != null) {
                this.domain = canonicalHost;
                this.hostOnly = z;
                return this;
            }
            throw new IllegalArgumentException(outline.m2941b("unexpected domain: ", str));
        }
    }

    public /* synthetic */ Cookie(String str, String str2, long j, String str3, String str4, boolean z, boolean z2, boolean z3, boolean z4, DefaultConstructorMarker fVar) {
        this(str, str2, j, str3, str4, z, z2, z3, z4);
    }
}
