package okhttp3;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import okhttp3.internal.HostnamesKt;
import okhttp3.internal.Util;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.internal.publicsuffix.PublicSuffixDatabase;
import p085c.p086a.p087a.p088a.outline;
import p250f.TypeCastException;
import p250f.p251i.C1892h;
import p250f.p251i.Sets;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p258m.Progressions;
import p250f.p258m._Ranges;
import p250f.p261p.C1937g;
import p250f.p261p.Regex;
import p262g.C1948d;

/* compiled from: HttpUrl.kt */
public final class HttpUrl {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final String FORM_ENCODE_SET = " \"':;<=>@[]^`{}|/\\?#&!$(),~";
    public static final String FRAGMENT_ENCODE_SET = "";
    public static final String FRAGMENT_ENCODE_SET_URI = " \"#<>\\^`{|}";
    public static final char[] HEX_DIGITS = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
    public static final String PASSWORD_ENCODE_SET = " \"':;<=>@[]^`{}|/\\?#";
    public static final String PATH_SEGMENT_ENCODE_SET = " \"<>^`{}|/\\?#";
    public static final String PATH_SEGMENT_ENCODE_SET_URI = "[]";
    public static final String QUERY_COMPONENT_ENCODE_SET = " !\"#$&'(),/:;<=>?@[]\\^`{|}~";
    public static final String QUERY_COMPONENT_ENCODE_SET_URI = "\\^`{|}";
    public static final String QUERY_COMPONENT_REENCODE_SET = " \"'<>#&=";
    public static final String QUERY_ENCODE_SET = " \"'<>#";
    public static final String USERNAME_ENCODE_SET = " \"':;<=>@[]^`{}|/\\?#";
    public final String fragment;
    public final String host;
    public final boolean isHttps;
    public final String password;
    public final List<String> pathSegments;
    public final int port;
    public final List<String> queryNamesAndValues;
    public final String scheme;
    public final String url;
    public final String username;

    /* compiled from: HttpUrl.kt */
    public static final class Companion {
        public Companion() {
        }

        public static /* synthetic */ String canonicalize$okhttp$default(Companion companion, String str, int i, int i2, String str2, boolean z, boolean z2, boolean z3, boolean z4, Charset charset, int i3, Object obj) {
            int i4 = i3;
            return companion.canonicalize$okhttp(str, (i4 & 1) != 0 ? 0 : i, (i4 & 2) != 0 ? str.length() : i2, str2, (i4 & 8) != 0 ? false : z, (i4 & 16) != 0 ? false : z2, (i4 & 32) != 0 ? false : z3, (i4 & 64) != 0 ? false : z4, (i4 & 128) != 0 ? null : charset);
        }

        private final boolean isPercentEncoded(String str, int i, int i2) {
            int i3 = i + 2;
            if (i3 >= i2 || str.charAt(i) != '%' || Util.parseHexDigit(str.charAt(i + 1)) == -1 || Util.parseHexDigit(str.charAt(i3)) == -1) {
                return false;
            }
            return true;
        }

        /* access modifiers changed from: private */
        public final List<String> percentDecode(List<String> list, boolean z) {
            ArrayList arrayList = new ArrayList(list.size());
            Iterator<String> it = list.iterator();
            while (it.hasNext()) {
                String next = it.next();
                arrayList.add(next != null ? percentDecode$okhttp$default(this, next, 0, 0, z, 3, (Object) null) : null);
            }
            List<String> unmodifiableList = Collections.unmodifiableList(arrayList);
            Intrinsics.m5821a((Object) unmodifiableList, "Collections.unmodifiableList(result)");
            return unmodifiableList;
        }

        public static /* synthetic */ List percentDecode$default(Companion companion, List list, boolean z, int i, Object obj) {
            if ((i & 1) != 0) {
                z = false;
            }
            return companion.percentDecode(list, z);
        }

        public static /* synthetic */ String percentDecode$okhttp$default(Companion companion, String str, int i, int i2, boolean z, int i3, Object obj) {
            if ((i3 & 1) != 0) {
                i = 0;
            }
            if ((i3 & 2) != 0) {
                i2 = str.length();
            }
            if ((i3 & 4) != 0) {
                z = false;
            }
            return companion.percentDecode$okhttp(str, i, i2, z);
        }

        /* JADX WARNING: Code restructure failed: missing block: B:34:0x0061, code lost:
            if (isPercentEncoded(r15, r4, r2) == false) goto L_0x006e;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        private final void writeCanonicalized(p262g.C1948d r14, java.lang.String r15, int r16, int r17, java.lang.String r18, boolean r19, boolean r20, boolean r21, boolean r22, java.nio.charset.Charset r23) {
            /*
                r13 = this;
                r0 = r14
                r1 = r15
                r2 = r17
                r3 = r23
                r4 = 0
                r5 = r4
                r4 = r16
            L_0x000a:
                if (r4 >= r2) goto L_0x00c4
                if (r1 == 0) goto L_0x00bb
                int r6 = r15.codePointAt(r4)
                if (r19 == 0) goto L_0x002a
                r7 = 9
                if (r6 == r7) goto L_0x0025
                r7 = 10
                if (r6 == r7) goto L_0x0025
                r7 = 12
                if (r6 == r7) goto L_0x0025
                r7 = 13
                if (r6 == r7) goto L_0x0025
                goto L_0x002a
            L_0x0025:
                r7 = r13
                r11 = r18
                goto L_0x00b4
            L_0x002a:
                r7 = 43
                if (r6 != r7) goto L_0x003b
                if (r21 == 0) goto L_0x003b
                if (r19 == 0) goto L_0x0035
                java.lang.String r7 = "+"
                goto L_0x0037
            L_0x0035:
                java.lang.String r7 = "%2B"
            L_0x0037:
                r14.mo9468a((java.lang.String) r7)
                goto L_0x0025
            L_0x003b:
                r7 = 32
                r8 = 37
                if (r6 < r7) goto L_0x006b
                r7 = 127(0x7f, float:1.78E-43)
                if (r6 == r7) goto L_0x006b
                r7 = 128(0x80, float:1.794E-43)
                if (r6 < r7) goto L_0x004b
                if (r22 == 0) goto L_0x006b
            L_0x004b:
                char r7 = (char) r6
                r9 = 0
                r10 = 2
                r11 = r18
                boolean r7 = p250f.p261p.C1937g.m5851a((java.lang.CharSequence) r11, (char) r7, (boolean) r9, (int) r10)
                if (r7 != 0) goto L_0x0069
                if (r6 != r8) goto L_0x0064
                if (r19 == 0) goto L_0x0069
                if (r20 == 0) goto L_0x0064
                r7 = r13
                boolean r9 = r13.isPercentEncoded(r15, r4, r2)
                if (r9 != 0) goto L_0x0065
                goto L_0x006e
            L_0x0064:
                r7 = r13
            L_0x0065:
                r14.mo9480c((int) r6)
                goto L_0x00b4
            L_0x0069:
                r7 = r13
                goto L_0x006e
            L_0x006b:
                r7 = r13
                r11 = r18
            L_0x006e:
                if (r5 != 0) goto L_0x0075
                g.d r5 = new g.d
                r5.<init>()
            L_0x0075:
                if (r3 == 0) goto L_0x0089
                java.nio.charset.Charset r9 = java.nio.charset.StandardCharsets.UTF_8
                boolean r9 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r3, (java.lang.Object) r9)
                if (r9 == 0) goto L_0x0080
                goto L_0x0089
            L_0x0080:
                int r9 = java.lang.Character.charCount(r6)
                int r9 = r9 + r4
                r5.mo9470a(r15, r4, r9, r3)
                goto L_0x008c
            L_0x0089:
                r5.mo9480c((int) r6)
            L_0x008c:
                boolean r9 = r5.mo9501k()
                if (r9 != 0) goto L_0x00b4
                byte r9 = r5.readByte()
                r9 = r9 & 255(0xff, float:3.57E-43)
                r14.writeByte((int) r8)
                char[] r10 = okhttp3.HttpUrl.HEX_DIGITS
                int r12 = r9 >> 4
                r12 = r12 & 15
                char r10 = r10[r12]
                r14.writeByte((int) r10)
                char[] r10 = okhttp3.HttpUrl.HEX_DIGITS
                r9 = r9 & 15
                char r9 = r10[r9]
                r14.writeByte((int) r9)
                goto L_0x008c
            L_0x00b4:
                int r6 = java.lang.Character.charCount(r6)
                int r4 = r4 + r6
                goto L_0x000a
            L_0x00bb:
                r7 = r13
                f.e r0 = new f.e
                java.lang.String r1 = "null cannot be cast to non-null type java.lang.String"
                r0.<init>(r1)
                throw r0
            L_0x00c4:
                r7 = r13
                return
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.HttpUrl.Companion.writeCanonicalized(g.d, java.lang.String, int, int, java.lang.String, boolean, boolean, boolean, boolean, java.nio.charset.Charset):void");
        }

        private final void writePercentDecoded(C1948d dVar, String str, int i, int i2, boolean z) {
            int i3;
            while (i < i2) {
                if (str != null) {
                    int codePointAt = str.codePointAt(i);
                    if (codePointAt == 37 && (i3 = i + 2) < i2) {
                        int parseHexDigit = Util.parseHexDigit(str.charAt(i + 1));
                        int parseHexDigit2 = Util.parseHexDigit(str.charAt(i3));
                        if (!(parseHexDigit == -1 || parseHexDigit2 == -1)) {
                            dVar.writeByte((parseHexDigit << 4) + parseHexDigit2);
                            i = Character.charCount(codePointAt) + i3;
                        }
                    } else if (codePointAt == 43 && z) {
                        dVar.writeByte(32);
                        i++;
                    }
                    dVar.mo9480c(codePointAt);
                    i += Character.charCount(codePointAt);
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
                }
            }
        }

        /* renamed from: -deprecated_get  reason: not valid java name */
        public final HttpUrl m6108deprecated_get(String str) {
            if (str != null) {
                return get(str);
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        /* renamed from: -deprecated_parse  reason: not valid java name */
        public final HttpUrl m6111deprecated_parse(String str) {
            if (str != null) {
                return parse(str);
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        public final String canonicalize$okhttp(String str, int i, int i2, String str2, boolean z, boolean z2, boolean z3, boolean z4, Charset charset) {
            int i3 = i2;
            String str3 = str2;
            if (str == null) {
                Intrinsics.m5822a("$this$canonicalize");
                throw null;
            } else if (str3 != null) {
                int i4 = i;
                while (i4 < i3) {
                    int codePointAt = str.codePointAt(i4);
                    if (codePointAt >= 32 && codePointAt != 127 && ((codePointAt < 128 || z4) && !C1937g.m5851a((CharSequence) str3, (char) codePointAt, false, 2))) {
                        if (codePointAt == 37) {
                            if (z) {
                                if (z2) {
                                    if (!isPercentEncoded(str, i4, i3)) {
                                        C1948d dVar = new C1948d();
                                        int i5 = i;
                                        dVar.mo9469a(str, i, i4);
                                        writeCanonicalized(dVar, str, i4, i2, str2, z, z2, z3, z4, charset);
                                        return dVar.mo9494h();
                                    }
                                    if (codePointAt == 43 || !z3) {
                                        i4 += Character.charCount(codePointAt);
                                    } else {
                                        C1948d dVar2 = new C1948d();
                                        int i52 = i;
                                        dVar2.mo9469a(str, i, i4);
                                        writeCanonicalized(dVar2, str, i4, i2, str2, z, z2, z3, z4, charset);
                                        return dVar2.mo9494h();
                                    }
                                }
                            }
                        }
                        if (codePointAt == 43) {
                        }
                        i4 += Character.charCount(codePointAt);
                    }
                    C1948d dVar22 = new C1948d();
                    int i522 = i;
                    dVar22.mo9469a(str, i, i4);
                    writeCanonicalized(dVar22, str, i4, i2, str2, z, z2, z3, z4, charset);
                    return dVar22.mo9494h();
                }
                int i6 = i;
                String substring = str.substring(i, i2);
                Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                return substring;
            } else {
                Intrinsics.m5822a("encodeSet");
                throw null;
            }
        }

        public final int defaultPort(String str) {
            if (str != null) {
                int hashCode = str.hashCode();
                if (hashCode != 3213448) {
                    if (hashCode == 99617003 && str.equals("https")) {
                        return 443;
                    }
                } else if (str.equals("http")) {
                    return 80;
                }
                return -1;
            }
            Intrinsics.m5822a("scheme");
            throw null;
        }

        public final HttpUrl get(String str) {
            if (str != null) {
                return new Builder().parse$okhttp((HttpUrl) null, str).build();
            }
            Intrinsics.m5822a("$this$toHttpUrl");
            throw null;
        }

        public final HttpUrl parse(String str) {
            if (str != null) {
                try {
                    return get(str);
                } catch (IllegalArgumentException unused) {
                    return null;
                }
            } else {
                Intrinsics.m5822a("$this$toHttpUrlOrNull");
                throw null;
            }
        }

        public final String percentDecode$okhttp(String str, int i, int i2, boolean z) {
            if (str != null) {
                for (int i3 = i; i3 < i2; i3++) {
                    char charAt = str.charAt(i3);
                    if (charAt == '%' || (charAt == '+' && z)) {
                        C1948d dVar = new C1948d();
                        dVar.mo9469a(str, i, i3);
                        writePercentDecoded(dVar, str, i3, i2, z);
                        return dVar.mo9494h();
                    }
                }
                String substring = str.substring(i, i2);
                Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                return substring;
            }
            Intrinsics.m5822a("$this$percentDecode");
            throw null;
        }

        public final void toPathString$okhttp(List<String> list, StringBuilder sb) {
            if (list == null) {
                Intrinsics.m5822a("$this$toPathString");
                throw null;
            } else if (sb != null) {
                int size = list.size();
                for (int i = 0; i < size; i++) {
                    sb.append('/');
                    sb.append(list.get(i));
                }
            } else {
                Intrinsics.m5822a("out");
                throw null;
            }
        }

        public final List<String> toQueryNamesAndValues$okhttp(String str) {
            if (str != null) {
                ArrayList arrayList = new ArrayList();
                int i = 0;
                while (i <= str.length()) {
                    int a = C1937g.m5836a((CharSequence) str, '&', i, false, 4);
                    if (a == -1) {
                        a = str.length();
                    }
                    int a2 = C1937g.m5836a((CharSequence) str, '=', i, false, 4);
                    if (a2 == -1 || a2 > a) {
                        String substring = str.substring(i, a);
                        Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                        arrayList.add(substring);
                        arrayList.add((Object) null);
                    } else {
                        String substring2 = str.substring(i, a2);
                        Intrinsics.m5821a((Object) substring2, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                        arrayList.add(substring2);
                        String substring3 = str.substring(a2 + 1, a);
                        Intrinsics.m5821a((Object) substring3, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                        arrayList.add(substring3);
                    }
                    i = a + 1;
                }
                return arrayList;
            }
            Intrinsics.m5822a("$this$toQueryNamesAndValues");
            throw null;
        }

        public final void toQueryString$okhttp(List<String> list, StringBuilder sb) {
            if (list == null) {
                Intrinsics.m5822a("$this$toQueryString");
                throw null;
            } else if (sb != null) {
                Progressions a = _Ranges.m5827a((Progressions) _Ranges.m5828b(0, list.size()), 2);
                int i = a.f7599b;
                int i2 = a.f7600c;
                int i3 = a.f7601d;
                if (i3 >= 0) {
                    if (i > i2) {
                        return;
                    }
                } else if (i < i2) {
                    return;
                }
                while (true) {
                    String str = list.get(i);
                    String str2 = list.get(i + 1);
                    if (i > 0) {
                        sb.append('&');
                    }
                    sb.append(str);
                    if (str2 != null) {
                        sb.append('=');
                        sb.append(str2);
                    }
                    if (i != i2) {
                        i += i3;
                    } else {
                        return;
                    }
                }
            } else {
                Intrinsics.m5822a("out");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }

        /* renamed from: -deprecated_get  reason: not valid java name */
        public final HttpUrl m6110deprecated_get(URL url) {
            if (url != null) {
                return get(url);
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        public final HttpUrl get(URL url) {
            if (url != null) {
                String url2 = url.toString();
                Intrinsics.m5821a((Object) url2, "toString()");
                return parse(url2);
            }
            Intrinsics.m5822a("$this$toHttpUrlOrNull");
            throw null;
        }

        /* renamed from: -deprecated_get  reason: not valid java name */
        public final HttpUrl m6109deprecated_get(URI uri) {
            if (uri != null) {
                return get(uri);
            }
            Intrinsics.m5822a("uri");
            throw null;
        }

        public final HttpUrl get(URI uri) {
            if (uri != null) {
                String uri2 = uri.toString();
                Intrinsics.m5821a((Object) uri2, "toString()");
                return parse(uri2);
            }
            Intrinsics.m5822a("$this$toHttpUrlOrNull");
            throw null;
        }
    }

    public HttpUrl(String str, String str2, String str3, String str4, int i, List<String> list, List<String> list2, String str5, String str6) {
        if (str == null) {
            Intrinsics.m5822a("scheme");
            throw null;
        } else if (str2 == null) {
            Intrinsics.m5822a("username");
            throw null;
        } else if (str3 == null) {
            Intrinsics.m5822a("password");
            throw null;
        } else if (str4 == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.HOST);
            throw null;
        } else if (list == null) {
            Intrinsics.m5822a("pathSegments");
            throw null;
        } else if (str6 != null) {
            this.scheme = str;
            this.username = str2;
            this.password = str3;
            this.host = str4;
            this.port = i;
            this.pathSegments = list;
            this.queryNamesAndValues = list2;
            this.fragment = str5;
            this.url = str6;
            this.isHttps = Intrinsics.m5823a((Object) str, (Object) "https");
        } else {
            Intrinsics.m5822a("url");
            throw null;
        }
    }

    public static final int defaultPort(String str) {
        return Companion.defaultPort(str);
    }

    public static final HttpUrl get(String str) {
        return Companion.get(str);
    }

    public static final HttpUrl get(URI uri) {
        return Companion.get(uri);
    }

    public static final HttpUrl get(URL url2) {
        return Companion.get(url2);
    }

    public static final HttpUrl parse(String str) {
        return Companion.parse(str);
    }

    /* renamed from: -deprecated_encodedFragment  reason: not valid java name */
    public final String m6089deprecated_encodedFragment() {
        return encodedFragment();
    }

    /* renamed from: -deprecated_encodedPassword  reason: not valid java name */
    public final String m6090deprecated_encodedPassword() {
        return encodedPassword();
    }

    /* renamed from: -deprecated_encodedPath  reason: not valid java name */
    public final String m6091deprecated_encodedPath() {
        return encodedPath();
    }

    /* renamed from: -deprecated_encodedPathSegments  reason: not valid java name */
    public final List<String> m6092deprecated_encodedPathSegments() {
        return encodedPathSegments();
    }

    /* renamed from: -deprecated_encodedQuery  reason: not valid java name */
    public final String m6093deprecated_encodedQuery() {
        return encodedQuery();
    }

    /* renamed from: -deprecated_encodedUsername  reason: not valid java name */
    public final String m6094deprecated_encodedUsername() {
        return encodedUsername();
    }

    /* renamed from: -deprecated_fragment  reason: not valid java name */
    public final String m6095deprecated_fragment() {
        return this.fragment;
    }

    /* renamed from: -deprecated_host  reason: not valid java name */
    public final String m6096deprecated_host() {
        return this.host;
    }

    /* renamed from: -deprecated_password  reason: not valid java name */
    public final String m6097deprecated_password() {
        return this.password;
    }

    /* renamed from: -deprecated_pathSegments  reason: not valid java name */
    public final List<String> m6098deprecated_pathSegments() {
        return this.pathSegments;
    }

    /* renamed from: -deprecated_pathSize  reason: not valid java name */
    public final int m6099deprecated_pathSize() {
        return pathSize();
    }

    /* renamed from: -deprecated_port  reason: not valid java name */
    public final int m6100deprecated_port() {
        return this.port;
    }

    /* renamed from: -deprecated_query  reason: not valid java name */
    public final String m6101deprecated_query() {
        return query();
    }

    /* renamed from: -deprecated_queryParameterNames  reason: not valid java name */
    public final Set<String> m6102deprecated_queryParameterNames() {
        return queryParameterNames();
    }

    /* renamed from: -deprecated_querySize  reason: not valid java name */
    public final int m6103deprecated_querySize() {
        return querySize();
    }

    /* renamed from: -deprecated_scheme  reason: not valid java name */
    public final String m6104deprecated_scheme() {
        return this.scheme;
    }

    /* renamed from: -deprecated_uri  reason: not valid java name */
    public final URI m6105deprecated_uri() {
        return uri();
    }

    /* renamed from: -deprecated_url  reason: not valid java name */
    public final URL m6106deprecated_url() {
        return url();
    }

    /* renamed from: -deprecated_username  reason: not valid java name */
    public final String m6107deprecated_username() {
        return this.username;
    }

    public final String encodedFragment() {
        if (this.fragment == null) {
            return null;
        }
        int a = C1937g.m5836a((CharSequence) this.url, '#', 0, false, 6) + 1;
        String str = this.url;
        if (str != null) {
            String substring = str.substring(a);
            Intrinsics.m5821a((Object) substring, "(this as java.lang.String).substring(startIndex)");
            return substring;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    public final String encodedPassword() {
        if (this.password.length() == 0) {
            return "";
        }
        int a = C1937g.m5836a((CharSequence) this.url, ':', this.scheme.length() + 3, false, 4) + 1;
        int a2 = C1937g.m5836a((CharSequence) this.url, '@', 0, false, 6);
        String str = this.url;
        if (str != null) {
            String substring = str.substring(a, a2);
            Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            return substring;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    public final String encodedPath() {
        int a = C1937g.m5836a((CharSequence) this.url, '/', this.scheme.length() + 3, false, 4);
        String str = this.url;
        int delimiterOffset = Util.delimiterOffset(str, "?#", a, str.length());
        String str2 = this.url;
        if (str2 != null) {
            String substring = str2.substring(a, delimiterOffset);
            Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            return substring;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    public final List<String> encodedPathSegments() {
        int a = C1937g.m5836a((CharSequence) this.url, '/', this.scheme.length() + 3, false, 4);
        String str = this.url;
        int delimiterOffset = Util.delimiterOffset(str, "?#", a, str.length());
        ArrayList arrayList = new ArrayList();
        while (a < delimiterOffset) {
            int i = a + 1;
            int delimiterOffset2 = Util.delimiterOffset(this.url, '/', i, delimiterOffset);
            String str2 = this.url;
            if (str2 != null) {
                String substring = str2.substring(i, delimiterOffset2);
                Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                arrayList.add(substring);
                a = delimiterOffset2;
            } else {
                throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
            }
        }
        return arrayList;
    }

    public final String encodedQuery() {
        if (this.queryNamesAndValues == null) {
            return null;
        }
        int a = C1937g.m5836a((CharSequence) this.url, '?', 0, false, 6) + 1;
        String str = this.url;
        int delimiterOffset = Util.delimiterOffset(str, '#', a, str.length());
        String str2 = this.url;
        if (str2 != null) {
            String substring = str2.substring(a, delimiterOffset);
            Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            return substring;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    public final String encodedUsername() {
        if (this.username.length() == 0) {
            return "";
        }
        int length = this.scheme.length() + 3;
        String str = this.url;
        int delimiterOffset = Util.delimiterOffset(str, ":@", length, str.length());
        String str2 = this.url;
        if (str2 != null) {
            String substring = str2.substring(length, delimiterOffset);
            Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            return substring;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    public boolean equals(Object obj) {
        return (obj instanceof HttpUrl) && Intrinsics.m5823a((Object) ((HttpUrl) obj).url, (Object) this.url);
    }

    public final String fragment() {
        return this.fragment;
    }

    public int hashCode() {
        return this.url.hashCode();
    }

    public final String host() {
        return this.host;
    }

    public final boolean isHttps() {
        return this.isHttps;
    }

    public final Builder newBuilder() {
        Builder builder = new Builder();
        builder.setScheme$okhttp(this.scheme);
        builder.setEncodedUsername$okhttp(encodedUsername());
        builder.setEncodedPassword$okhttp(encodedPassword());
        builder.setHost$okhttp(this.host);
        builder.setPort$okhttp(this.port != Companion.defaultPort(this.scheme) ? this.port : -1);
        builder.getEncodedPathSegments$okhttp().clear();
        builder.getEncodedPathSegments$okhttp().addAll(encodedPathSegments());
        builder.encodedQuery(encodedQuery());
        builder.setEncodedFragment$okhttp(encodedFragment());
        return builder;
    }

    public final String password() {
        return this.password;
    }

    public final List<String> pathSegments() {
        return this.pathSegments;
    }

    public final int pathSize() {
        return this.pathSegments.size();
    }

    public final int port() {
        return this.port;
    }

    public final String query() {
        if (this.queryNamesAndValues == null) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        Companion.toQueryString$okhttp(this.queryNamesAndValues, sb);
        return sb.toString();
    }

    public final String queryParameter(String str) {
        if (str != null) {
            List<String> list = this.queryNamesAndValues;
            if (list == null) {
                return null;
            }
            Progressions a = _Ranges.m5827a((Progressions) _Ranges.m5828b(0, list.size()), 2);
            int i = a.f7599b;
            int i2 = a.f7600c;
            int i3 = a.f7601d;
            if (i3 < 0 ? i >= i2 : i <= i2) {
                while (!Intrinsics.m5823a((Object) str, (Object) this.queryNamesAndValues.get(i))) {
                    if (i != i2) {
                        i += i3;
                    }
                }
                return this.queryNamesAndValues.get(i + 1);
            }
            return null;
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final String queryParameterName(int i) {
        List<String> list = this.queryNamesAndValues;
        if (list != null) {
            String str = list.get(i * 2);
            if (str != null) {
                return str;
            }
            Intrinsics.m5820a();
            throw null;
        }
        throw new IndexOutOfBoundsException();
    }

    public final Set<String> queryParameterNames() {
        if (this.queryNamesAndValues == null) {
            return Sets.f7581b;
        }
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        Progressions a = _Ranges.m5827a((Progressions) _Ranges.m5828b(0, this.queryNamesAndValues.size()), 2);
        int i = a.f7599b;
        int i2 = a.f7600c;
        int i3 = a.f7601d;
        if (i3 < 0 ? i >= i2 : i <= i2) {
            while (true) {
                String str = this.queryNamesAndValues.get(i);
                if (str != null) {
                    linkedHashSet.add(str);
                    if (i == i2) {
                        break;
                    }
                    i += i3;
                } else {
                    Intrinsics.m5820a();
                    throw null;
                }
            }
        }
        Set<String> unmodifiableSet = Collections.unmodifiableSet(linkedHashSet);
        Intrinsics.m5821a((Object) unmodifiableSet, "Collections.unmodifiableSet(result)");
        return unmodifiableSet;
    }

    public final String queryParameterValue(int i) {
        List<String> list = this.queryNamesAndValues;
        if (list != null) {
            return list.get((i * 2) + 1);
        }
        throw new IndexOutOfBoundsException();
    }

    public final List<String> queryParameterValues(String str) {
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (this.queryNamesAndValues == null) {
            return C1892h.f7579b;
        } else {
            ArrayList arrayList = new ArrayList();
            Progressions a = _Ranges.m5827a((Progressions) _Ranges.m5828b(0, this.queryNamesAndValues.size()), 2);
            int i = a.f7599b;
            int i2 = a.f7600c;
            int i3 = a.f7601d;
            if (i3 < 0 ? i >= i2 : i <= i2) {
                while (true) {
                    if (Intrinsics.m5823a((Object) str, (Object) this.queryNamesAndValues.get(i))) {
                        arrayList.add(this.queryNamesAndValues.get(i + 1));
                    }
                    if (i == i2) {
                        break;
                    }
                    i += i3;
                }
            }
            List<String> unmodifiableList = Collections.unmodifiableList(arrayList);
            Intrinsics.m5821a((Object) unmodifiableList, "Collections.unmodifiableList(result)");
            return unmodifiableList;
        }
    }

    public final int querySize() {
        List<String> list = this.queryNamesAndValues;
        if (list != null) {
            return list.size() / 2;
        }
        return 0;
    }

    public final String redact() {
        Builder newBuilder = newBuilder("/...");
        if (newBuilder != null) {
            return newBuilder.username("").password("").build().toString();
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final HttpUrl resolve(String str) {
        if (str != null) {
            Builder newBuilder = newBuilder(str);
            if (newBuilder != null) {
                return newBuilder.build();
            }
            return null;
        }
        Intrinsics.m5822a("link");
        throw null;
    }

    public final String scheme() {
        return this.scheme;
    }

    public String toString() {
        return this.url;
    }

    public final String topPrivateDomain() {
        if (Util.canParseAsIpAddress(this.host)) {
            return null;
        }
        return PublicSuffixDatabase.Companion.get().getEffectiveTldPlusOne(this.host);
    }

    public final URI uri() {
        String builder = newBuilder().reencodeForUri$okhttp().toString();
        try {
            return new URI(builder);
        } catch (URISyntaxException e) {
            try {
                URI create = URI.create(new Regex("[\\u0000-\\u001F\\u007F-\\u009F\\p{javaWhitespace}]").mo9423a(builder, ""));
                Intrinsics.m5821a((Object) create, "URI.create(stripped)");
                return create;
            } catch (Exception unused) {
                throw new RuntimeException(e);
            }
        }
    }

    public final URL url() {
        try {
            return new URL(this.url);
        } catch (MalformedURLException e) {
            throw new RuntimeException(e);
        }
    }

    public final String username() {
        return this.username;
    }

    /* compiled from: HttpUrl.kt */
    public static final class Builder {
        public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
        public static final String INVALID_HOST = "Invalid URL host";
        public String encodedFragment;
        public String encodedPassword = "";
        public final List<String> encodedPathSegments;
        public List<String> encodedQueryNamesAndValues;
        public String encodedUsername = "";
        public String host;
        public int port = -1;
        public String scheme;

        /* compiled from: HttpUrl.kt */
        public static final class Companion {
            public Companion() {
            }

            /* access modifiers changed from: private */
            public final int parsePort(String str, int i, int i2) {
                try {
                    int parseInt = Integer.parseInt(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, i, i2, "", false, false, false, false, (Charset) null, 248, (Object) null));
                    if (1 <= parseInt && 65535 >= parseInt) {
                        return parseInt;
                    }
                    return -1;
                } catch (NumberFormatException unused) {
                    return -1;
                }
            }

            /* access modifiers changed from: private */
            public final int portColonOffset(String str, int i, int i2) {
                while (i < i2) {
                    char charAt = str.charAt(i);
                    if (charAt == ':') {
                        return i;
                    }
                    if (charAt == '[') {
                        do {
                            i++;
                            if (i >= i2) {
                                break;
                            }
                        } while (str.charAt(i) == ']');
                    }
                    i++;
                }
                return i2;
            }

            /* access modifiers changed from: private */
            public final int schemeDelimiterOffset(String str, int i, int i2) {
                if (i2 - i < 2) {
                    return -1;
                }
                char charAt = str.charAt(i);
                if ((charAt < 'a' || charAt > 'z') && (charAt < 'A' || charAt > 'Z')) {
                    return -1;
                }
                while (true) {
                    i++;
                    if (i >= i2) {
                        return -1;
                    }
                    char charAt2 = str.charAt(i);
                    if (('a' > charAt2 || 'z' < charAt2) && (('A' > charAt2 || 'Z' < charAt2) && (('0' > charAt2 || '9' < charAt2) && charAt2 != '+' && charAt2 != '-' && charAt2 != '.'))) {
                        if (charAt2 == ':') {
                            return i;
                        }
                        return -1;
                    }
                }
            }

            /* access modifiers changed from: private */
            public final int slashCount(String str, int i, int i2) {
                int i3 = 0;
                while (i < i2) {
                    char charAt = str.charAt(i);
                    if (charAt != '\\' && charAt != '/') {
                        break;
                    }
                    i3++;
                    i++;
                }
                return i3;
            }

            public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
                this();
            }
        }

        public Builder() {
            ArrayList arrayList = new ArrayList();
            this.encodedPathSegments = arrayList;
            arrayList.add("");
        }

        private final int effectivePort() {
            int i = this.port;
            if (i != -1) {
                return i;
            }
            Companion companion = HttpUrl.Companion;
            String str = this.scheme;
            if (str != null) {
                return companion.defaultPort(str);
            }
            Intrinsics.m5820a();
            throw null;
        }

        private final boolean isDot(String str) {
            return Intrinsics.m5823a((Object) str, (Object) ".") || C1937g.m5858a(str, "%2e", true);
        }

        private final boolean isDotDot(String str) {
            if (Intrinsics.m5823a((Object) str, (Object) "..") || C1937g.m5858a(str, "%2e.", true) || C1937g.m5858a(str, ".%2e", true) || C1937g.m5858a(str, "%2e%2e", true)) {
                return true;
            }
            return false;
        }

        private final void pop() {
            List<String> list = this.encodedPathSegments;
            if (!(list.remove(list.size() - 1).length() == 0) || !(!this.encodedPathSegments.isEmpty())) {
                this.encodedPathSegments.add("");
                return;
            }
            List<String> list2 = this.encodedPathSegments;
            list2.set(list2.size() - 1, "");
        }

        private final void push(String str, int i, int i2, boolean z, boolean z2) {
            String canonicalize$okhttp$default = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, i, i2, HttpUrl.PATH_SEGMENT_ENCODE_SET, z2, false, false, false, (Charset) null, 240, (Object) null);
            if (!isDot(canonicalize$okhttp$default)) {
                if (isDotDot(canonicalize$okhttp$default)) {
                    pop();
                    return;
                }
                List<String> list = this.encodedPathSegments;
                if (list.get(list.size() - 1).length() == 0) {
                    List<String> list2 = this.encodedPathSegments;
                    list2.set(list2.size() - 1, canonicalize$okhttp$default);
                } else {
                    this.encodedPathSegments.add(canonicalize$okhttp$default);
                }
                if (z) {
                    this.encodedPathSegments.add("");
                }
            }
        }

        private final void removeAllCanonicalQueryParameters(String str) {
            List<String> list = this.encodedQueryNamesAndValues;
            if (list != null) {
                Progressions a = _Ranges.m5827a(_Ranges.m5826a(list.size() - 2, 0), 2);
                int i = a.f7599b;
                int i2 = a.f7600c;
                int i3 = a.f7601d;
                if (i3 >= 0) {
                    if (i > i2) {
                        return;
                    }
                } else if (i < i2) {
                    return;
                }
                while (true) {
                    List<String> list2 = this.encodedQueryNamesAndValues;
                    if (list2 != null) {
                        if (Intrinsics.m5823a((Object) str, (Object) list2.get(i))) {
                            List<String> list3 = this.encodedQueryNamesAndValues;
                            if (list3 != null) {
                                list3.remove(i + 1);
                                List<String> list4 = this.encodedQueryNamesAndValues;
                                if (list4 != null) {
                                    list4.remove(i);
                                    List<String> list5 = this.encodedQueryNamesAndValues;
                                    if (list5 == null) {
                                        Intrinsics.m5820a();
                                        throw null;
                                    } else if (list5.isEmpty()) {
                                        this.encodedQueryNamesAndValues = null;
                                        return;
                                    }
                                } else {
                                    Intrinsics.m5820a();
                                    throw null;
                                }
                            } else {
                                Intrinsics.m5820a();
                                throw null;
                            }
                        }
                        if (i != i2) {
                            i += i3;
                        } else {
                            return;
                        }
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        }

        /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
            jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
            	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:47)
            	at jadx.core.utils.ErrorsCounter.methodError(ErrorsCounter.java:81)
            */
        /* JADX WARNING: Removed duplicated region for block: B:10:0x002c  */
        /* JADX WARNING: Removed duplicated region for block: B:18:0x0044 A[SYNTHETIC] */
        private final void resolvePath(java.lang.String r11, int r12, int r13) {
            /*
                r10 = this;
                if (r12 != r13) goto L_0x0003
                return
            L_0x0003:
                char r0 = r11.charAt(r12)
                r1 = 47
                java.lang.String r2 = ""
                r3 = 1
                if (r0 == r1) goto L_0x001e
                r1 = 92
                if (r0 != r1) goto L_0x0013
                goto L_0x001e
            L_0x0013:
                java.util.List<java.lang.String> r0 = r10.encodedPathSegments
                int r1 = r0.size()
                int r1 = r1 - r3
                r0.set(r1, r2)
                goto L_0x0029
            L_0x001e:
                java.util.List<java.lang.String> r0 = r10.encodedPathSegments
                r0.clear()
                java.util.List<java.lang.String> r0 = r10.encodedPathSegments
                r0.add(r2)
                goto L_0x0041
            L_0x0029:
                r6 = r12
                if (r6 >= r13) goto L_0x0044
                java.lang.String r12 = "/\\"
                int r12 = okhttp3.internal.Util.delimiterOffset((java.lang.String) r11, (java.lang.String) r12, (int) r6, (int) r13)
                if (r12 >= r13) goto L_0x0036
                r0 = 1
                goto L_0x0037
            L_0x0036:
                r0 = 0
            L_0x0037:
                r9 = 1
                r4 = r10
                r5 = r11
                r7 = r12
                r8 = r0
                r4.push(r5, r6, r7, r8, r9)
                if (r0 == 0) goto L_0x0029
            L_0x0041:
                int r12 = r12 + 1
                goto L_0x0029
            L_0x0044:
                return
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.HttpUrl.Builder.resolvePath(java.lang.String, int, int):void");
        }

        public final Builder addEncodedPathSegment(String str) {
            if (str != null) {
                push(str, 0, str.length(), false, true);
                return this;
            }
            Intrinsics.m5822a("encodedPathSegment");
            throw null;
        }

        public final Builder addEncodedPathSegments(String str) {
            if (str != null) {
                return addPathSegments(str, true);
            }
            Intrinsics.m5822a("encodedPathSegments");
            throw null;
        }

        public final Builder addEncodedQueryParameter(String str, String str2) {
            String str3 = null;
            if (str != null) {
                if (this.encodedQueryNamesAndValues == null) {
                    this.encodedQueryNamesAndValues = new ArrayList();
                }
                List<String> list = this.encodedQueryNamesAndValues;
                if (list != null) {
                    list.add(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.QUERY_COMPONENT_REENCODE_SET, true, false, true, false, (Charset) null, 211, (Object) null));
                    List<String> list2 = this.encodedQueryNamesAndValues;
                    if (list2 != null) {
                        if (str2 != null) {
                            str3 = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str2, 0, 0, HttpUrl.QUERY_COMPONENT_REENCODE_SET, true, false, true, false, (Charset) null, 211, (Object) null);
                        }
                        list2.add(str3);
                        return this;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5822a("encodedName");
            throw null;
        }

        public final Builder addPathSegment(String str) {
            if (str != null) {
                push(str, 0, str.length(), false, false);
                return this;
            }
            Intrinsics.m5822a("pathSegment");
            throw null;
        }

        public final Builder addPathSegments(String str) {
            if (str != null) {
                return addPathSegments(str, false);
            }
            Intrinsics.m5822a("pathSegments");
            throw null;
        }

        public final Builder addQueryParameter(String str, String str2) {
            String str3 = null;
            if (str != null) {
                if (this.encodedQueryNamesAndValues == null) {
                    this.encodedQueryNamesAndValues = new ArrayList();
                }
                List<String> list = this.encodedQueryNamesAndValues;
                if (list != null) {
                    list.add(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.QUERY_COMPONENT_ENCODE_SET, false, false, true, false, (Charset) null, 219, (Object) null));
                    List<String> list2 = this.encodedQueryNamesAndValues;
                    if (list2 != null) {
                        if (str2 != null) {
                            str3 = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str2, 0, 0, HttpUrl.QUERY_COMPONENT_ENCODE_SET, false, false, true, false, (Charset) null, 219, (Object) null);
                        }
                        list2.add(str3);
                        return this;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5822a("name");
            throw null;
        }

        public final HttpUrl build() {
            String str = this.scheme;
            if (str != null) {
                String percentDecode$okhttp$default = Companion.percentDecode$okhttp$default(HttpUrl.Companion, this.encodedUsername, 0, 0, false, 7, (Object) null);
                String percentDecode$okhttp$default2 = Companion.percentDecode$okhttp$default(HttpUrl.Companion, this.encodedPassword, 0, 0, false, 7, (Object) null);
                String str2 = this.host;
                if (str2 != null) {
                    int effectivePort = effectivePort();
                    List percentDecode$default = Companion.percentDecode$default(HttpUrl.Companion, this.encodedPathSegments, false, 1, (Object) null);
                    if (percentDecode$default != null) {
                        List<String> list = this.encodedQueryNamesAndValues;
                        List access$percentDecode = list != null ? HttpUrl.Companion.percentDecode(list, true) : null;
                        String str3 = this.encodedFragment;
                        return new HttpUrl(str, percentDecode$okhttp$default, percentDecode$okhttp$default2, str2, effectivePort, percentDecode$default, access$percentDecode, str3 != null ? Companion.percentDecode$okhttp$default(HttpUrl.Companion, str3, 0, 0, false, 7, (Object) null) : null, toString());
                    }
                    throw new TypeCastException("null cannot be cast to non-null type kotlin.collections.List<kotlin.String>");
                }
                throw new IllegalStateException("host == null");
            }
            throw new IllegalStateException("scheme == null");
        }

        public final Builder encodedFragment(String str) {
            this.encodedFragment = str != null ? Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, "", true, false, false, true, (Charset) null, 179, (Object) null) : null;
            return this;
        }

        public final Builder encodedPassword(String str) {
            if (str != null) {
                this.encodedPassword = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, " \"':;<=>@[]^`{}|/\\?#", true, false, false, false, (Charset) null, 243, (Object) null);
                return this;
            }
            Intrinsics.m5822a("encodedPassword");
            throw null;
        }

        public final Builder encodedPath(String str) {
            if (str == null) {
                Intrinsics.m5822a("encodedPath");
                throw null;
            } else if (C1937g.m5864b(str, "/", false, 2)) {
                resolvePath(str, 0, str.length());
                return this;
            } else {
                throw new IllegalArgumentException(outline.m2941b("unexpected encodedPath: ", str).toString());
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:1:0x0002, code lost:
            r13 = okhttp3.HttpUrl.Companion.canonicalize$okhttp$default(okhttp3.HttpUrl.Companion, r13, 0, 0, okhttp3.HttpUrl.QUERY_ENCODE_SET, true, false, true, false, (java.nio.charset.Charset) null, 211, (java.lang.Object) null);
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final okhttp3.HttpUrl.Builder encodedQuery(java.lang.String r13) {
            /*
                r12 = this;
                if (r13 == 0) goto L_0x001e
                okhttp3.HttpUrl$Companion r0 = okhttp3.HttpUrl.Companion
                r2 = 0
                r3 = 0
                r5 = 1
                r6 = 0
                r7 = 1
                r8 = 0
                r9 = 0
                r10 = 211(0xd3, float:2.96E-43)
                r11 = 0
                java.lang.String r4 = " \"'<>#"
                r1 = r13
                java.lang.String r13 = okhttp3.HttpUrl.Companion.canonicalize$okhttp$default(r0, r1, r2, r3, r4, r5, r6, r7, r8, r9, r10, r11)
                if (r13 == 0) goto L_0x001e
                okhttp3.HttpUrl$Companion r0 = okhttp3.HttpUrl.Companion
                java.util.List r13 = r0.toQueryNamesAndValues$okhttp(r13)
                goto L_0x001f
            L_0x001e:
                r13 = 0
            L_0x001f:
                r12.encodedQueryNamesAndValues = r13
                return r12
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.HttpUrl.Builder.encodedQuery(java.lang.String):okhttp3.HttpUrl$Builder");
        }

        public final Builder encodedUsername(String str) {
            if (str != null) {
                this.encodedUsername = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, " \"':;<=>@[]^`{}|/\\?#", true, false, false, false, (Charset) null, 243, (Object) null);
                return this;
            }
            Intrinsics.m5822a("encodedUsername");
            throw null;
        }

        public final Builder fragment(String str) {
            this.encodedFragment = str != null ? Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, "", false, false, false, true, (Charset) null, 187, (Object) null) : null;
            return this;
        }

        public final String getEncodedFragment$okhttp() {
            return this.encodedFragment;
        }

        public final String getEncodedPassword$okhttp() {
            return this.encodedPassword;
        }

        public final List<String> getEncodedPathSegments$okhttp() {
            return this.encodedPathSegments;
        }

        public final List<String> getEncodedQueryNamesAndValues$okhttp() {
            return this.encodedQueryNamesAndValues;
        }

        public final String getEncodedUsername$okhttp() {
            return this.encodedUsername;
        }

        public final String getHost$okhttp() {
            return this.host;
        }

        public final int getPort$okhttp() {
            return this.port;
        }

        public final String getScheme$okhttp() {
            return this.scheme;
        }

        public final Builder host(String str) {
            if (str != null) {
                String canonicalHost = HostnamesKt.toCanonicalHost(Companion.percentDecode$okhttp$default(HttpUrl.Companion, str, 0, 0, false, 7, (Object) null));
                if (canonicalHost != null) {
                    this.host = canonicalHost;
                    return this;
                }
                throw new IllegalArgumentException(outline.m2941b("unexpected host: ", str));
            }
            Intrinsics.m5822a(Http2ExchangeCodec.HOST);
            throw null;
        }

        public final Builder parse$okhttp(HttpUrl httpUrl, String str) {
            int i;
            int delimiterOffset;
            String str2;
            String str3;
            int i2;
            int i3;
            String str4 = str;
            if (str4 != null) {
                int indexOfFirstNonAsciiWhitespace$default = Util.indexOfFirstNonAsciiWhitespace$default(str4, 0, 0, 3, (Object) null);
                int indexOfLastNonAsciiWhitespace$default = Util.indexOfLastNonAsciiWhitespace$default(str4, indexOfFirstNonAsciiWhitespace$default, 0, 2, (Object) null);
                int access$schemeDelimiterOffset = Companion.schemeDelimiterOffset(str4, indexOfFirstNonAsciiWhitespace$default, indexOfLastNonAsciiWhitespace$default);
                String str5 = "(this as java.lang.Strin…ing(startIndex, endIndex)";
                char c = 65535;
                if (access$schemeDelimiterOffset != -1) {
                    if (C1937g.m5856a(str4, "https:", indexOfFirstNonAsciiWhitespace$default, true)) {
                        this.scheme = "https";
                        indexOfFirstNonAsciiWhitespace$default += 6;
                    } else if (C1937g.m5856a(str4, "http:", indexOfFirstNonAsciiWhitespace$default, true)) {
                        this.scheme = "http";
                        indexOfFirstNonAsciiWhitespace$default += 5;
                    } else {
                        StringBuilder a = outline.m2937a("Expected URL scheme 'http' or 'https' but was '");
                        String substring = str4.substring(0, access$schemeDelimiterOffset);
                        Intrinsics.m5821a((Object) substring, str5);
                        a.append(substring);
                        a.append("'");
                        throw new IllegalArgumentException(a.toString());
                    }
                } else if (httpUrl != null) {
                    this.scheme = httpUrl.scheme();
                } else {
                    throw new IllegalArgumentException("Expected URL scheme 'http' or 'https' but no colon was found");
                }
                int access$slashCount = Companion.slashCount(str4, indexOfFirstNonAsciiWhitespace$default, indexOfLastNonAsciiWhitespace$default);
                char c2 = '?';
                char c3 = '#';
                if (access$slashCount >= 2 || httpUrl == null || (!Intrinsics.m5823a((Object) httpUrl.scheme(), (Object) this.scheme))) {
                    int i4 = indexOfFirstNonAsciiWhitespace$default + access$slashCount;
                    boolean z = false;
                    boolean z2 = false;
                    while (true) {
                        delimiterOffset = Util.delimiterOffset(str4, "@/\\?#", i4, indexOfLastNonAsciiWhitespace$default);
                        char charAt = delimiterOffset != indexOfLastNonAsciiWhitespace$default ? str4.charAt(delimiterOffset) : 65535;
                        if (charAt == c || charAt == c3 || charAt == '/' || charAt == '\\' || charAt == c2) {
                            i = indexOfLastNonAsciiWhitespace$default;
                            String str6 = str5;
                            int i5 = delimiterOffset;
                            int access$portColonOffset = Companion.portColonOffset(str4, i4, i5);
                            int i6 = access$portColonOffset + 1;
                        } else {
                            if (charAt != '@') {
                                i2 = indexOfLastNonAsciiWhitespace$default;
                                str3 = str5;
                            } else {
                                if (!z) {
                                    int delimiterOffset2 = Util.delimiterOffset(str4, ':', i4, delimiterOffset);
                                    int i7 = delimiterOffset2;
                                    String str7 = "%40";
                                    i2 = indexOfLastNonAsciiWhitespace$default;
                                    i3 = delimiterOffset;
                                    String canonicalize$okhttp$default = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, i4, delimiterOffset2, " \"':;<=>@[]^`{}|/\\?#", true, false, false, false, (Charset) null, 240, (Object) null);
                                    if (z2) {
                                        canonicalize$okhttp$default = this.encodedUsername + str7 + canonicalize$okhttp$default;
                                    }
                                    this.encodedUsername = canonicalize$okhttp$default;
                                    int i8 = i7;
                                    if (i8 != i3) {
                                        this.encodedPassword = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, i8 + 1, i3, " \"':;<=>@[]^`{}|/\\?#", true, false, false, false, (Charset) null, 240, (Object) null);
                                        z = true;
                                    }
                                    z2 = true;
                                    str3 = str5;
                                } else {
                                    i2 = indexOfLastNonAsciiWhitespace$default;
                                    i3 = delimiterOffset;
                                    StringBuilder sb = new StringBuilder();
                                    sb.append(this.encodedPassword);
                                    sb.append("%40");
                                    str3 = str5;
                                    StringBuilder sb2 = sb;
                                    sb2.append(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, i4, i3, " \"':;<=>@[]^`{}|/\\?#", true, false, false, false, (Charset) null, 240, (Object) null));
                                    this.encodedPassword = sb2.toString();
                                }
                                i4 = i3 + 1;
                            }
                            c3 = '#';
                            c2 = '?';
                            c = 65535;
                            indexOfLastNonAsciiWhitespace$default = i2;
                            str5 = str3;
                        }
                    }
                    i = indexOfLastNonAsciiWhitespace$default;
                    String str62 = str5;
                    int i52 = delimiterOffset;
                    int access$portColonOffset2 = Companion.portColonOffset(str4, i4, i52);
                    int i62 = access$portColonOffset2 + 1;
                    if (i62 < i52) {
                        this.host = HostnamesKt.toCanonicalHost(Companion.percentDecode$okhttp$default(HttpUrl.Companion, str, i4, access$portColonOffset2, false, 4, (Object) null));
                        int access$parsePort = Companion.parsePort(str4, i62, i52);
                        this.port = access$parsePort;
                        if (access$parsePort != -1) {
                            str2 = str62;
                        } else {
                            StringBuilder a2 = outline.m2937a("Invalid URL port: \"");
                            String substring2 = str4.substring(i62, i52);
                            Intrinsics.m5821a((Object) substring2, str62);
                            a2.append(substring2);
                            a2.append('\"');
                            throw new IllegalArgumentException(a2.toString().toString());
                        }
                    } else {
                        str2 = str62;
                        this.host = HostnamesKt.toCanonicalHost(Companion.percentDecode$okhttp$default(HttpUrl.Companion, str, i4, access$portColonOffset2, false, 4, (Object) null));
                        Companion companion = HttpUrl.Companion;
                        String str8 = this.scheme;
                        if (str8 != null) {
                            this.port = companion.defaultPort(str8);
                        } else {
                            Intrinsics.m5820a();
                            throw null;
                        }
                    }
                    if (this.host != null) {
                        indexOfFirstNonAsciiWhitespace$default = i52;
                    } else {
                        StringBuilder a3 = outline.m2937a("Invalid URL host: \"");
                        String substring3 = str4.substring(i4, access$portColonOffset2);
                        Intrinsics.m5821a((Object) substring3, str2);
                        a3.append(substring3);
                        a3.append('\"');
                        throw new IllegalArgumentException(a3.toString().toString());
                    }
                } else {
                    this.encodedUsername = httpUrl.encodedUsername();
                    this.encodedPassword = httpUrl.encodedPassword();
                    this.host = httpUrl.host();
                    this.port = httpUrl.port();
                    this.encodedPathSegments.clear();
                    this.encodedPathSegments.addAll(httpUrl.encodedPathSegments());
                    if (indexOfFirstNonAsciiWhitespace$default == indexOfLastNonAsciiWhitespace$default || str4.charAt(indexOfFirstNonAsciiWhitespace$default) == '#') {
                        encodedQuery(httpUrl.encodedQuery());
                    }
                    i = indexOfLastNonAsciiWhitespace$default;
                }
                int i9 = i;
                int delimiterOffset3 = Util.delimiterOffset(str4, "?#", indexOfFirstNonAsciiWhitespace$default, i9);
                resolvePath(str4, indexOfFirstNonAsciiWhitespace$default, delimiterOffset3);
                if (delimiterOffset3 < i9 && str4.charAt(delimiterOffset3) == '?') {
                    int delimiterOffset4 = Util.delimiterOffset(str4, '#', delimiterOffset3, i9);
                    Companion companion2 = HttpUrl.Companion;
                    this.encodedQueryNamesAndValues = companion2.toQueryNamesAndValues$okhttp(Companion.canonicalize$okhttp$default(companion2, str, delimiterOffset3 + 1, delimiterOffset4, HttpUrl.QUERY_ENCODE_SET, true, false, true, false, (Charset) null, 208, (Object) null));
                    delimiterOffset3 = delimiterOffset4;
                }
                if (delimiterOffset3 < i9 && str4.charAt(delimiterOffset3) == '#') {
                    this.encodedFragment = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, delimiterOffset3 + 1, i9, "", true, false, false, true, (Charset) null, 176, (Object) null);
                }
                return this;
            }
            Intrinsics.m5822a("input");
            throw null;
        }

        public final Builder password(String str) {
            if (str != null) {
                this.encodedPassword = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, " \"':;<=>@[]^`{}|/\\?#", false, false, false, false, (Charset) null, 251, (Object) null);
                return this;
            }
            Intrinsics.m5822a("password");
            throw null;
        }

        public final Builder port(int i) {
            boolean z = true;
            if (1 > i || 65535 < i) {
                z = false;
            }
            if (z) {
                this.port = i;
                return this;
            }
            throw new IllegalArgumentException(outline.m2930a("unexpected port: ", i).toString());
        }

        /* JADX WARNING: Code restructure failed: missing block: B:1:0x0002, code lost:
            r13 = okhttp3.HttpUrl.Companion.canonicalize$okhttp$default(okhttp3.HttpUrl.Companion, r13, 0, 0, okhttp3.HttpUrl.QUERY_ENCODE_SET, false, false, true, false, (java.nio.charset.Charset) null, 219, (java.lang.Object) null);
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final okhttp3.HttpUrl.Builder query(java.lang.String r13) {
            /*
                r12 = this;
                if (r13 == 0) goto L_0x001e
                okhttp3.HttpUrl$Companion r0 = okhttp3.HttpUrl.Companion
                r2 = 0
                r3 = 0
                r5 = 0
                r6 = 0
                r7 = 1
                r8 = 0
                r9 = 0
                r10 = 219(0xdb, float:3.07E-43)
                r11 = 0
                java.lang.String r4 = " \"'<>#"
                r1 = r13
                java.lang.String r13 = okhttp3.HttpUrl.Companion.canonicalize$okhttp$default(r0, r1, r2, r3, r4, r5, r6, r7, r8, r9, r10, r11)
                if (r13 == 0) goto L_0x001e
                okhttp3.HttpUrl$Companion r0 = okhttp3.HttpUrl.Companion
                java.util.List r13 = r0.toQueryNamesAndValues$okhttp(r13)
                goto L_0x001f
            L_0x001e:
                r13 = 0
            L_0x001f:
                r12.encodedQueryNamesAndValues = r13
                return r12
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.HttpUrl.Builder.query(java.lang.String):okhttp3.HttpUrl$Builder");
        }

        public final Builder reencodeForUri$okhttp() {
            String str = this.host;
            String str2 = null;
            this.host = str != null ? new Regex("[\"<>^`{|}]").mo9423a(str, "") : null;
            int size = this.encodedPathSegments.size();
            for (int i = 0; i < size; i++) {
                List<String> list = this.encodedPathSegments;
                list.set(i, Companion.canonicalize$okhttp$default(HttpUrl.Companion, list.get(i), 0, 0, HttpUrl.PATH_SEGMENT_ENCODE_SET_URI, true, true, false, false, (Charset) null, 227, (Object) null));
            }
            List<String> list2 = this.encodedQueryNamesAndValues;
            if (list2 != null) {
                int size2 = list2.size();
                for (int i2 = 0; i2 < size2; i2++) {
                    String str3 = list2.get(i2);
                    list2.set(i2, str3 != null ? Companion.canonicalize$okhttp$default(HttpUrl.Companion, str3, 0, 0, HttpUrl.QUERY_COMPONENT_ENCODE_SET_URI, true, true, true, false, (Charset) null, 195, (Object) null) : null);
                }
            }
            String str4 = this.encodedFragment;
            if (str4 != null) {
                str2 = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str4, 0, 0, HttpUrl.FRAGMENT_ENCODE_SET_URI, true, true, false, true, (Charset) null, 163, (Object) null);
            }
            this.encodedFragment = str2;
            return this;
        }

        public final Builder removeAllEncodedQueryParameters(String str) {
            if (str == null) {
                Intrinsics.m5822a("encodedName");
                throw null;
            } else if (this.encodedQueryNamesAndValues == null) {
                return this;
            } else {
                removeAllCanonicalQueryParameters(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.QUERY_COMPONENT_REENCODE_SET, true, false, true, false, (Charset) null, 211, (Object) null));
                return this;
            }
        }

        public final Builder removeAllQueryParameters(String str) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (this.encodedQueryNamesAndValues == null) {
                return this;
            } else {
                removeAllCanonicalQueryParameters(Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.QUERY_COMPONENT_ENCODE_SET, false, false, true, false, (Charset) null, 219, (Object) null));
                return this;
            }
        }

        public final Builder removePathSegment(int i) {
            this.encodedPathSegments.remove(i);
            if (this.encodedPathSegments.isEmpty()) {
                this.encodedPathSegments.add("");
            }
            return this;
        }

        public final Builder scheme(String str) {
            if (str != null) {
                if (C1937g.m5858a(str, "http", true)) {
                    this.scheme = "http";
                } else if (C1937g.m5858a(str, "https", true)) {
                    this.scheme = "https";
                } else {
                    throw new IllegalArgumentException(outline.m2941b("unexpected scheme: ", str));
                }
                return this;
            }
            Intrinsics.m5822a("scheme");
            throw null;
        }

        public final void setEncodedFragment$okhttp(String str) {
            this.encodedFragment = str;
        }

        public final void setEncodedPassword$okhttp(String str) {
            if (str != null) {
                this.encodedPassword = str;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final Builder setEncodedPathSegment(int i, String str) {
            if (str != null) {
                String canonicalize$okhttp$default = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.PATH_SEGMENT_ENCODE_SET, true, false, false, false, (Charset) null, 243, (Object) null);
                this.encodedPathSegments.set(i, canonicalize$okhttp$default);
                if (!isDot(canonicalize$okhttp$default) && !isDotDot(canonicalize$okhttp$default)) {
                    return this;
                }
                throw new IllegalArgumentException(outline.m2941b("unexpected path segment: ", str).toString());
            }
            Intrinsics.m5822a("encodedPathSegment");
            throw null;
        }

        public final void setEncodedQueryNamesAndValues$okhttp(List<String> list) {
            this.encodedQueryNamesAndValues = list;
        }

        public final Builder setEncodedQueryParameter(String str, String str2) {
            if (str != null) {
                removeAllEncodedQueryParameters(str);
                addEncodedQueryParameter(str, str2);
                return this;
            }
            Intrinsics.m5822a("encodedName");
            throw null;
        }

        public final void setEncodedUsername$okhttp(String str) {
            if (str != null) {
                this.encodedUsername = str;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setHost$okhttp(String str) {
            this.host = str;
        }

        public final Builder setPathSegment(int i, String str) {
            if (str != null) {
                String canonicalize$okhttp$default = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, HttpUrl.PATH_SEGMENT_ENCODE_SET, false, false, false, false, (Charset) null, 251, (Object) null);
                if (!isDot(canonicalize$okhttp$default) && !isDotDot(canonicalize$okhttp$default)) {
                    this.encodedPathSegments.set(i, canonicalize$okhttp$default);
                    return this;
                }
                throw new IllegalArgumentException(outline.m2941b("unexpected path segment: ", str).toString());
            }
            Intrinsics.m5822a("pathSegment");
            throw null;
        }

        public final void setPort$okhttp(int i) {
            this.port = i;
        }

        public final Builder setQueryParameter(String str, String str2) {
            if (str != null) {
                removeAllQueryParameters(str);
                addQueryParameter(str, str2);
                return this;
            }
            Intrinsics.m5822a("name");
            throw null;
        }

        public final void setScheme$okhttp(String str) {
            this.scheme = str;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:14:0x0033, code lost:
            if ((r6.encodedPassword.length() > 0) != false) goto L_0x0035;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:39:0x0094, code lost:
            if (r1 != r5.defaultPort(r3)) goto L_0x009b;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public java.lang.String toString() {
            /*
                r6 = this;
                java.lang.StringBuilder r0 = new java.lang.StringBuilder
                r0.<init>()
                java.lang.String r1 = r6.scheme
                if (r1 == 0) goto L_0x0012
                r0.append(r1)
                java.lang.String r1 = "://"
                r0.append(r1)
                goto L_0x0017
            L_0x0012:
                java.lang.String r1 = "//"
                r0.append(r1)
            L_0x0017:
                java.lang.String r1 = r6.encodedUsername
                int r1 = r1.length()
                r2 = 1
                r3 = 0
                if (r1 <= 0) goto L_0x0023
                r1 = 1
                goto L_0x0024
            L_0x0023:
                r1 = 0
            L_0x0024:
                r4 = 58
                if (r1 != 0) goto L_0x0035
                java.lang.String r1 = r6.encodedPassword
                int r1 = r1.length()
                if (r1 <= 0) goto L_0x0032
                r1 = 1
                goto L_0x0033
            L_0x0032:
                r1 = 0
            L_0x0033:
                if (r1 == 0) goto L_0x0053
            L_0x0035:
                java.lang.String r1 = r6.encodedUsername
                r0.append(r1)
                java.lang.String r1 = r6.encodedPassword
                int r1 = r1.length()
                if (r1 <= 0) goto L_0x0043
                goto L_0x0044
            L_0x0043:
                r2 = 0
            L_0x0044:
                if (r2 == 0) goto L_0x004e
                r0.append(r4)
                java.lang.String r1 = r6.encodedPassword
                r0.append(r1)
            L_0x004e:
                r1 = 64
                r0.append(r1)
            L_0x0053:
                java.lang.String r1 = r6.host
                r2 = 0
                if (r1 == 0) goto L_0x007b
                if (r1 == 0) goto L_0x0077
                r5 = 2
                boolean r1 = p250f.p261p.C1937g.m5851a((java.lang.CharSequence) r1, (char) r4, (boolean) r3, (int) r5)
                if (r1 == 0) goto L_0x0071
                r1 = 91
                r0.append(r1)
                java.lang.String r1 = r6.host
                r0.append(r1)
                r1 = 93
                r0.append(r1)
                goto L_0x007b
            L_0x0071:
                java.lang.String r1 = r6.host
                r0.append(r1)
                goto L_0x007b
            L_0x0077:
                p250f.p254l.p256c.Intrinsics.m5820a()
                throw r2
            L_0x007b:
                int r1 = r6.port
                r3 = -1
                if (r1 != r3) goto L_0x0084
                java.lang.String r1 = r6.scheme
                if (r1 == 0) goto L_0x00a1
            L_0x0084:
                int r1 = r6.effectivePort()
                java.lang.String r3 = r6.scheme
                if (r3 == 0) goto L_0x009b
                okhttp3.HttpUrl$Companion r5 = okhttp3.HttpUrl.Companion
                if (r3 == 0) goto L_0x0097
                int r3 = r5.defaultPort(r3)
                if (r1 == r3) goto L_0x00a1
                goto L_0x009b
            L_0x0097:
                p250f.p254l.p256c.Intrinsics.m5820a()
                throw r2
            L_0x009b:
                r0.append(r4)
                r0.append(r1)
            L_0x00a1:
                okhttp3.HttpUrl$Companion r1 = okhttp3.HttpUrl.Companion
                java.util.List<java.lang.String> r3 = r6.encodedPathSegments
                r1.toPathString$okhttp(r3, r0)
                java.util.List<java.lang.String> r1 = r6.encodedQueryNamesAndValues
                if (r1 == 0) goto L_0x00bf
                r1 = 63
                r0.append(r1)
                okhttp3.HttpUrl$Companion r1 = okhttp3.HttpUrl.Companion
                java.util.List<java.lang.String> r3 = r6.encodedQueryNamesAndValues
                if (r3 == 0) goto L_0x00bb
                r1.toQueryString$okhttp(r3, r0)
                goto L_0x00bf
            L_0x00bb:
                p250f.p254l.p256c.Intrinsics.m5820a()
                throw r2
            L_0x00bf:
                java.lang.String r1 = r6.encodedFragment
                if (r1 == 0) goto L_0x00cd
                r1 = 35
                r0.append(r1)
                java.lang.String r1 = r6.encodedFragment
                r0.append(r1)
            L_0x00cd:
                java.lang.String r0 = r0.toString()
                java.lang.String r1 = "StringBuilder().apply(builderAction).toString()"
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r0, (java.lang.String) r1)
                return r0
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.HttpUrl.Builder.toString():java.lang.String");
        }

        public final Builder username(String str) {
            if (str != null) {
                this.encodedUsername = Companion.canonicalize$okhttp$default(HttpUrl.Companion, str, 0, 0, " \"':;<=>@[]^`{}|/\\?#", false, false, false, false, (Charset) null, 251, (Object) null);
                return this;
            }
            Intrinsics.m5822a("username");
            throw null;
        }

        private final Builder addPathSegments(String str, boolean z) {
            int i = 0;
            do {
                int delimiterOffset = Util.delimiterOffset(str, "/\\", i, str.length());
                push(str, i, delimiterOffset, delimiterOffset < str.length(), z);
                i = delimiterOffset + 1;
            } while (i <= str.length());
            return this;
        }
    }

    public final Builder newBuilder(String str) {
        if (str != null) {
            try {
                return new Builder().parse$okhttp(this, str);
            } catch (IllegalArgumentException unused) {
                return null;
            }
        } else {
            Intrinsics.m5822a("link");
            throw null;
        }
    }
}
