package okhttp3;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import java.net.URL;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.internal.Util;
import okhttp3.internal.http.HttpMethod;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.Tuples;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;

/* compiled from: Request.kt */
public final class Request {
    public final RequestBody body;
    public final Headers headers;
    public CacheControl lazyCacheControl;
    public final String method;
    public final Map<Class<?>, Object> tags;
    public final HttpUrl url;

    /* compiled from: Request.kt */
    public static class Builder {
        public RequestBody body;
        public Headers.Builder headers;
        public String method;
        public Map<Class<?>, Object> tags;
        public HttpUrl url;

        public Builder() {
            this.tags = new LinkedHashMap();
            this.method = "GET";
            this.headers = new Headers.Builder();
        }

        public static /* synthetic */ Builder delete$default(Builder builder, RequestBody requestBody, int i, Object obj) {
            if (obj == null) {
                if ((i & 1) != 0) {
                    requestBody = Util.EMPTY_REQUEST;
                }
                return builder.delete(requestBody);
            }
            throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: delete");
        }

        public Builder addHeader(String str, String str2) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (str2 != null) {
                this.headers.add(str, str2);
                return this;
            } else {
                Intrinsics.m5822a("value");
                throw null;
            }
        }

        public Request build() {
            HttpUrl httpUrl = this.url;
            if (httpUrl != null) {
                return new Request(httpUrl, this.method, this.headers.build(), this.body, Util.toImmutableMap(this.tags));
            }
            throw new IllegalStateException("url == null".toString());
        }

        public Builder cacheControl(CacheControl cacheControl) {
            if (cacheControl != null) {
                String cacheControl2 = cacheControl.toString();
                if (cacheControl2.length() == 0) {
                    return removeHeader("Cache-Control");
                }
                return header("Cache-Control", cacheControl2);
            }
            Intrinsics.m5822a("cacheControl");
            throw null;
        }

        public Builder delete() {
            return delete$default(this, (RequestBody) null, 1, (Object) null);
        }

        public Builder delete(RequestBody requestBody) {
            return method("DELETE", requestBody);
        }

        public Builder get() {
            return method("GET", (RequestBody) null);
        }

        public final RequestBody getBody$okhttp() {
            return this.body;
        }

        public final Headers.Builder getHeaders$okhttp() {
            return this.headers;
        }

        public final String getMethod$okhttp() {
            return this.method;
        }

        public final Map<Class<?>, Object> getTags$okhttp() {
            return this.tags;
        }

        public final HttpUrl getUrl$okhttp() {
            return this.url;
        }

        public Builder head() {
            return method("HEAD", (RequestBody) null);
        }

        public Builder header(String str, String str2) {
            if (str == null) {
                Intrinsics.m5822a("name");
                throw null;
            } else if (str2 != null) {
                this.headers.set(str, str2);
                return this;
            } else {
                Intrinsics.m5822a("value");
                throw null;
            }
        }

        public Builder headers(Headers headers2) {
            if (headers2 != null) {
                this.headers = headers2.newBuilder();
                return this;
            }
            Intrinsics.m5822a("headers");
            throw null;
        }

        public Builder method(String str, RequestBody requestBody) {
            if (str != null) {
                if (str.length() > 0) {
                    if (requestBody == null) {
                        if (!(!HttpMethod.requiresRequestBody(str))) {
                            throw new IllegalArgumentException(outline.m2934a("method ", str, " must have a request body.").toString());
                        }
                    } else if (!HttpMethod.permitsRequestBody(str)) {
                        throw new IllegalArgumentException(outline.m2934a("method ", str, " must not have a request body.").toString());
                    }
                    this.method = str;
                    this.body = requestBody;
                    return this;
                }
                throw new IllegalArgumentException("method.isEmpty() == true".toString());
            }
            Intrinsics.m5822a("method");
            throw null;
        }

        public Builder patch(RequestBody requestBody) {
            if (requestBody != null) {
                return method("PATCH", requestBody);
            }
            Intrinsics.m5822a("body");
            throw null;
        }

        public Builder post(RequestBody requestBody) {
            if (requestBody != null) {
                return method("POST", requestBody);
            }
            Intrinsics.m5822a("body");
            throw null;
        }

        public Builder put(RequestBody requestBody) {
            if (requestBody != null) {
                return method("PUT", requestBody);
            }
            Intrinsics.m5822a("body");
            throw null;
        }

        public Builder removeHeader(String str) {
            if (str != null) {
                this.headers.removeAll(str);
                return this;
            }
            Intrinsics.m5822a("name");
            throw null;
        }

        public final void setBody$okhttp(RequestBody requestBody) {
            this.body = requestBody;
        }

        public final void setHeaders$okhttp(Headers.Builder builder) {
            if (builder != null) {
                this.headers = builder;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setMethod$okhttp(String str) {
            if (str != null) {
                this.method = str;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setTags$okhttp(Map<Class<?>, Object> map) {
            if (map != null) {
                this.tags = map;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setUrl$okhttp(HttpUrl httpUrl) {
            this.url = httpUrl;
        }

        public Builder tag(Object obj) {
            return tag(Object.class, obj);
        }

        public Builder url(HttpUrl httpUrl) {
            if (httpUrl != null) {
                this.url = httpUrl;
                return this;
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        public <T> Builder tag(Class<? super T> cls, T t) {
            if (cls != null) {
                if (t == null) {
                    this.tags.remove(cls);
                } else {
                    if (this.tags.isEmpty()) {
                        this.tags = new LinkedHashMap();
                    }
                    Map<Class<?>, Object> map = this.tags;
                    Object cast = cls.cast(t);
                    if (cast != null) {
                        map.put(cls, cast);
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
                return this;
            }
            Intrinsics.m5822a(AnalyticAttribute.TYPE_ATTRIBUTE);
            throw null;
        }

        public Builder url(String str) {
            if (str != null) {
                if (C1937g.m5863b(str, "ws:", true)) {
                    StringBuilder a = outline.m2937a("http:");
                    String substring = str.substring(3);
                    Intrinsics.m5821a((Object) substring, "(this as java.lang.String).substring(startIndex)");
                    a.append(substring);
                    str = a.toString();
                } else if (C1937g.m5863b(str, "wss:", true)) {
                    StringBuilder a2 = outline.m2937a("https:");
                    String substring2 = str.substring(4);
                    Intrinsics.m5821a((Object) substring2, "(this as java.lang.String).substring(startIndex)");
                    a2.append(substring2);
                    str = a2.toString();
                }
                return url(HttpUrl.Companion.get(str));
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        public Builder(Request request) {
            LinkedHashMap linkedHashMap;
            if (request != null) {
                this.tags = new LinkedHashMap();
                this.url = request.url();
                this.method = request.method();
                this.body = request.body();
                if (request.getTags$okhttp().isEmpty()) {
                    linkedHashMap = new LinkedHashMap();
                } else {
                    Map<Class<?>, Object> tags$okhttp = request.getTags$okhttp();
                    if (tags$okhttp != null) {
                        linkedHashMap = new LinkedHashMap(tags$okhttp);
                    } else {
                        Intrinsics.m5822a("$this$toMutableMap");
                        throw null;
                    }
                }
                this.tags = linkedHashMap;
                this.headers = request.headers().newBuilder();
                return;
            }
            Intrinsics.m5822a("request");
            throw null;
        }

        public Builder url(URL url2) {
            if (url2 != null) {
                HttpUrl.Companion companion = HttpUrl.Companion;
                String url3 = url2.toString();
                Intrinsics.m5821a((Object) url3, "url.toString()");
                return url(companion.get(url3));
            }
            Intrinsics.m5822a("url");
            throw null;
        }
    }

    public Request(HttpUrl httpUrl, String str, Headers headers2, RequestBody requestBody, Map<Class<?>, ? extends Object> map) {
        if (httpUrl == null) {
            Intrinsics.m5822a("url");
            throw null;
        } else if (str == null) {
            Intrinsics.m5822a("method");
            throw null;
        } else if (headers2 == null) {
            Intrinsics.m5822a("headers");
            throw null;
        } else if (map != null) {
            this.url = httpUrl;
            this.method = str;
            this.headers = headers2;
            this.body = requestBody;
            this.tags = map;
        } else {
            Intrinsics.m5822a("tags");
            throw null;
        }
    }

    /* renamed from: -deprecated_body  reason: not valid java name */
    public final RequestBody m6150deprecated_body() {
        return this.body;
    }

    /* renamed from: -deprecated_cacheControl  reason: not valid java name */
    public final CacheControl m6151deprecated_cacheControl() {
        return cacheControl();
    }

    /* renamed from: -deprecated_headers  reason: not valid java name */
    public final Headers m6152deprecated_headers() {
        return this.headers;
    }

    /* renamed from: -deprecated_method  reason: not valid java name */
    public final String m6153deprecated_method() {
        return this.method;
    }

    /* renamed from: -deprecated_url  reason: not valid java name */
    public final HttpUrl m6154deprecated_url() {
        return this.url;
    }

    public final RequestBody body() {
        return this.body;
    }

    public final CacheControl cacheControl() {
        CacheControl cacheControl = this.lazyCacheControl;
        if (cacheControl != null) {
            return cacheControl;
        }
        CacheControl parse = CacheControl.Companion.parse(this.headers);
        this.lazyCacheControl = parse;
        return parse;
    }

    public final Map<Class<?>, Object> getTags$okhttp() {
        return this.tags;
    }

    public final String header(String str) {
        if (str != null) {
            return this.headers.get(str);
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final Headers headers() {
        return this.headers;
    }

    public final boolean isHttps() {
        return this.url.isHttps();
    }

    public final String method() {
        return this.method;
    }

    public final Builder newBuilder() {
        return new Builder(this);
    }

    public final Object tag() {
        return tag(Object.class);
    }

    public String toString() {
        StringBuilder a = outline.m2937a("Request{method=");
        a.append(this.method);
        a.append(", url=");
        a.append(this.url);
        if (this.headers.size() != 0) {
            a.append(", headers=[");
            int i = 0;
            for (Object next : this.headers) {
                int i2 = i + 1;
                if (i >= 0) {
                    Tuples cVar = (Tuples) next;
                    String str = (String) cVar.f7561b;
                    String str2 = (String) cVar.f7562c;
                    if (i > 0) {
                        a.append(", ");
                    }
                    outline.m2940a(a, str, ':', str2);
                    i = i2;
                } else {
                    C1050v.m4220e();
                    throw null;
                }
            }
            a.append(']');
        }
        if (!this.tags.isEmpty()) {
            a.append(", tags=");
            a.append(this.tags);
        }
        a.append('}');
        String sb = a.toString();
        Intrinsics.m5821a((Object) sb, "StringBuilder().apply(builderAction).toString()");
        return sb;
    }

    public final HttpUrl url() {
        return this.url;
    }

    public final List<String> headers(String str) {
        if (str != null) {
            return this.headers.values(str);
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final <T> T tag(Class<? extends T> cls) {
        if (cls != null) {
            return cls.cast(this.tags.get(cls));
        }
        Intrinsics.m5822a(AnalyticAttribute.TYPE_ATTRIBUTE);
        throw null;
    }
}
