package okhttp3.internal;

import java.net.IDN;
import java.net.InetAddress;
import java.util.Arrays;
import java.util.Locale;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.C1948d;

/* compiled from: hostnames.kt */
public final class HostnamesKt {
    public static final boolean containsInvalidHostnameAsciiCodes(String str) {
        int length = str.length();
        for (int i = 0; i < length; i++) {
            char charAt = str.charAt(i);
            if (charAt <= 31 || charAt >= 127 || C1937g.m5836a((CharSequence) " #%/:?@[\\]", charAt, 0, false, 6) != -1) {
                return true;
            }
        }
        return false;
    }

    public static final boolean decodeIpv4Suffix(String str, int i, int i2, byte[] bArr, int i3) {
        int i4 = i3;
        while (i < i2) {
            if (i4 == bArr.length) {
                return false;
            }
            if (i4 != i3) {
                if (str.charAt(i) != '.') {
                    return false;
                }
                i++;
            }
            int i5 = i;
            int i6 = 0;
            while (i5 < i2) {
                char charAt = str.charAt(i5);
                if (charAt < '0' || charAt > '9') {
                    break;
                } else if ((i6 == 0 && i != i5) || (i6 = ((i6 * 10) + charAt) - 48) > 255) {
                    return false;
                } else {
                    i5++;
                }
            }
            if (i5 - i == 0) {
                return false;
            }
            bArr[i4] = (byte) i6;
            i4++;
            i = i5;
        }
        if (i4 == i3 + 4) {
            return true;
        }
        return false;
    }

    public static final InetAddress decodeIpv6(String str, int i, int i2) {
        byte[] bArr = new byte[16];
        int i3 = 0;
        int i4 = -1;
        int i5 = -1;
        while (true) {
            if (i >= i2) {
                break;
            } else if (i3 == 16) {
                return null;
            } else {
                int i6 = i + 2;
                if (i6 > i2 || !C1937g.m5857a(str, "::", i, false, 4)) {
                    if (i3 != 0) {
                        if (C1937g.m5857a(str, ":", i, false, 4)) {
                            i++;
                        } else if (!C1937g.m5857a(str, ".", i, false, 4) || !decodeIpv4Suffix(str, i5, i2, bArr, i3 - 2)) {
                            return null;
                        } else {
                            i3 += 2;
                        }
                    }
                    i5 = i;
                } else if (i4 != -1) {
                    return null;
                } else {
                    i3 += 2;
                    i4 = i3;
                    if (i6 == i2) {
                        break;
                    }
                    i5 = i6;
                }
                i = i5;
                int i7 = 0;
                while (i < i2) {
                    int parseHexDigit = Util.parseHexDigit(str.charAt(i));
                    if (parseHexDigit == -1) {
                        break;
                    }
                    i7 = (i7 << 4) + parseHexDigit;
                    i++;
                }
                int i8 = i - i5;
                if (i8 == 0 || i8 > 4) {
                    return null;
                }
                int i9 = i3 + 1;
                bArr[i3] = (byte) ((i7 >>> 8) & 255);
                i3 = i9 + 1;
                bArr[i9] = (byte) (i7 & 255);
            }
        }
        if (i3 != 16) {
            if (i4 == -1) {
                return null;
            }
            int i10 = i3 - i4;
            System.arraycopy(bArr, i4, bArr, 16 - i10, i10);
            Arrays.fill(bArr, i4, (16 - i3) + i4, (byte) 0);
        }
        return InetAddress.getByAddress(bArr);
    }

    public static final String inet6AddressToAscii(byte[] bArr) {
        int i = 0;
        int i2 = -1;
        int i3 = 0;
        int i4 = 0;
        while (i3 < bArr.length) {
            int i5 = i3;
            while (i5 < 16 && bArr[i5] == 0 && bArr[i5 + 1] == 0) {
                i5 += 2;
            }
            int i6 = i5 - i3;
            if (i6 > i4 && i6 >= 4) {
                i2 = i3;
                i4 = i6;
            }
            i3 = i5 + 2;
        }
        C1948d dVar = new C1948d();
        while (i < bArr.length) {
            if (i == i2) {
                dVar.writeByte(58);
                i += i4;
                if (i == 16) {
                    dVar.writeByte(58);
                }
            } else {
                if (i > 0) {
                    dVar.writeByte(58);
                }
                dVar.mo9465a((long) ((Util.and(bArr[i], 255) << 8) | Util.and(bArr[i + 1], 255)));
                i += 2;
            }
        }
        return dVar.mo9494h();
    }

    public static final String toCanonicalHost(String str) {
        InetAddress inetAddress;
        if (str != null) {
            boolean z = false;
            if (C1937g.m5853a((CharSequence) str, (CharSequence) ":", false, 2)) {
                if (!C1937g.m5864b(str, "[", false, 2) || !C1937g.m5859a(str, "]", false, 2)) {
                    inetAddress = decodeIpv6(str, 0, str.length());
                } else {
                    inetAddress = decodeIpv6(str, 1, str.length() - 1);
                }
                if (inetAddress == null) {
                    return null;
                }
                byte[] address = inetAddress.getAddress();
                if (address.length == 16) {
                    Intrinsics.m5821a((Object) address, "address");
                    return inet6AddressToAscii(address);
                } else if (address.length == 4) {
                    return inetAddress.getHostAddress();
                } else {
                    throw new AssertionError("Invalid IPv6 address: '" + str + '\'');
                }
            } else {
                try {
                    String ascii = IDN.toASCII(str);
                    Intrinsics.m5821a((Object) ascii, "IDN.toASCII(host)");
                    Locale locale = Locale.US;
                    Intrinsics.m5821a((Object) locale, "Locale.US");
                    String lowerCase = ascii.toLowerCase(locale);
                    Intrinsics.m5821a((Object) lowerCase, "(this as java.lang.String).toLowerCase(locale)");
                    if (lowerCase.length() == 0) {
                        z = true;
                    }
                    if (!z && !containsInvalidHostnameAsciiCodes(lowerCase)) {
                        return lowerCase;
                    }
                    return null;
                } catch (IllegalArgumentException unused) {
                    return null;
                }
            }
        } else {
            Intrinsics.m5822a("$this$toCanonicalHost");
            throw null;
        }
    }
}
