package okhttp3.internal;

import java.io.Closeable;
import java.io.IOException;
import java.lang.reflect.Field;
import java.net.InetSocketAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketAddress;
import java.net.SocketTimeoutException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;
import okhttp3.EventListener;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.http2.Header;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.Unit;
import p250f.p251i.Iterators;
import p250f.p251i.Maps;
import p250f.p251i._Arrays;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p258m.Ranges;
import p250f.p258m._Ranges;
import p250f.p261p.C1937g;
import p250f.p261p.Charsets;
import p250f.p261p.Regex;
import p262g.BufferedSink;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;
import p262g.C1954p;
import p262g.Source;

/* compiled from: Util.kt */
public final class Util {
    public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
    public static final Headers EMPTY_HEADERS = Headers.Companion.mo9926of(new String[0]);
    public static final RequestBody EMPTY_REQUEST = RequestBody.Companion.create$default(RequestBody.Companion, EMPTY_BYTE_ARRAY, (MediaType) null, 0, 0, 7, (Object) null);
    public static final ResponseBody EMPTY_RESPONSE = ResponseBody.Companion.create$default(ResponseBody.Companion, EMPTY_BYTE_ARRAY, (MediaType) null, 1, (Object) null);
    public static final C1954p UNICODE_BOMS;
    public static final TimeZone UTC;
    public static final Regex VERIFY_AS_IP_ADDRESS = new Regex("([0-9a-fA-F]*:[0-9a-fA-F:.]*)|([\\d.]+)");
    public static final boolean assertionsEnabled = OkHttpClient.class.desiredAssertionStatus();
    public static final String okHttpName;

    static {
        int i;
        int i2 = 1;
        C1954p.C1955a aVar = C1954p.f7678d;
        C1952h[] hVarArr = {C1952h.f7659f.mo9551b("efbbbf"), C1952h.f7659f.mo9551b("feff"), C1952h.f7659f.mo9551b("fffe"), C1952h.f7659f.mo9551b("0000ffff"), C1952h.f7659f.mo9551b("ffff0000")};
        List c = C1050v.m4213c((T[]) hVarArr);
        ArrayList arrayList = (ArrayList) c;
        if (arrayList.size() > 1) {
            Collections.sort(c);
        }
        ArrayList arrayList2 = new ArrayList(5);
        for (int i3 = 0; i3 < 5; i3++) {
            C1952h hVar = hVarArr[i3];
            arrayList2.add(-1);
        }
        Object[] array = arrayList2.toArray(new Integer[0]);
        if (array != null) {
            Integer[] numArr = (Integer[]) array;
            Integer[] numArr2 = (Integer[]) Arrays.copyOf(numArr, numArr.length);
            if (numArr2 != null) {
                ArrayList arrayList3 = numArr2.length == 0 ? new ArrayList() : new ArrayList(new p250f.p251i.Collections(numArr2, true));
                int i4 = 0;
                int i5 = 0;
                while (i4 < 5) {
                    C1952h hVar2 = hVarArr[i4];
                    int i6 = i5 + 1;
                    int size = arrayList.size();
                    int size2 = arrayList.size();
                    if (size < 0) {
                        throw new IllegalArgumentException("fromIndex (" + 0 + ") is greater than toIndex (" + size + ").");
                    } else if (size <= size2) {
                        int i7 = size - 1;
                        int i8 = 0;
                        while (true) {
                            if (i8 > i7) {
                                i = -(i8 + 1);
                                break;
                            }
                            i = (i8 + i7) >>> i2;
                            Comparable comparable = (Comparable) arrayList.get(i);
                            int compareTo = comparable == hVar2 ? 0 : comparable == null ? -1 : hVar2 == null ? 1 : comparable.compareTo(hVar2);
                            if (compareTo >= 0) {
                                if (compareTo <= 0) {
                                    break;
                                }
                                i7 = i - 1;
                            } else {
                                i8 = i + 1;
                            }
                            i2 = 1;
                        }
                        arrayList3.set(i, Integer.valueOf(i5));
                        i4++;
                        i5 = i6;
                        i2 = 1;
                    } else {
                        throw new IndexOutOfBoundsException("toIndex (" + size + ") is greater than size (" + size2 + ").");
                    }
                }
                if (((C1952h) arrayList.get(0)).mo9540b() > 0) {
                    int i9 = 0;
                    while (i9 < arrayList.size()) {
                        C1952h hVar3 = (C1952h) arrayList.get(i9);
                        int i10 = i9 + 1;
                        int i11 = i10;
                        while (i11 < arrayList.size()) {
                            C1952h hVar4 = (C1952h) arrayList.get(i11);
                            if (!hVar4.mo9539a(hVar3)) {
                                continue;
                                break;
                            }
                            if (!(hVar4.mo9540b() != hVar3.mo9540b())) {
                                throw new IllegalArgumentException(("duplicate option: " + hVar4).toString());
                            } else if (((Number) arrayList3.get(i11)).intValue() > ((Number) arrayList3.get(i9)).intValue()) {
                                arrayList.remove(i11);
                                arrayList3.remove(i11);
                            } else {
                                i11++;
                            }
                        }
                        i9 = i10;
                    }
                    C1948d dVar = new C1948d();
                    aVar.mo9566a(0, dVar, 0, c, 0, arrayList.size(), arrayList3);
                    int[] iArr = new int[((int) aVar.mo9565a(dVar))];
                    int i12 = 0;
                    while (!dVar.mo9501k()) {
                        iArr[i12] = dVar.readInt();
                        i12++;
                    }
                    Object[] copyOf = Arrays.copyOf(hVarArr, 5);
                    Intrinsics.m5821a((Object) copyOf, "java.util.Arrays.copyOf(this, size)");
                    UNICODE_BOMS = new C1954p((C1952h[]) copyOf, iArr, (DefaultConstructorMarker) null);
                    TimeZone timeZone = TimeZone.getTimeZone("GMT");
                    if (timeZone != null) {
                        UTC = timeZone;
                        String name = OkHttpClient.class.getName();
                        Intrinsics.m5821a((Object) name, "OkHttpClient::class.java.name");
                        String a = C1937g.m5847a(name, (CharSequence) "okhttp3.");
                        if (a != null) {
                            if (C1937g.m5862b((CharSequence) a, (CharSequence) "Client", false, 2)) {
                                a = a.substring(0, a.length() - "Client".length());
                                Intrinsics.m5821a((Object) a, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                            }
                            okHttpName = a;
                            return;
                        }
                        Intrinsics.m5822a("$this$removeSuffix");
                        throw null;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                throw new IllegalArgumentException("the empty byte string is not a supported option".toString());
            }
            Intrinsics.m5822a("elements");
            throw null;
        }
        throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
    }

    public static final <E> void addIfAbsent(List<E> list, E e) {
        if (list == null) {
            Intrinsics.m5822a("$this$addIfAbsent");
            throw null;
        } else if (!list.contains(e)) {
            list.add(e);
        }
    }

    public static final int and(byte b, int i) {
        return b & i;
    }

    public static final int and(short s, int i) {
        return s & i;
    }

    public static final long and(int i, long j) {
        return ((long) i) & j;
    }

    public static final EventListener.Factory asFactory(EventListener eventListener) {
        if (eventListener != null) {
            return new Util$asFactory$1(eventListener);
        }
        Intrinsics.m5822a("$this$asFactory");
        throw null;
    }

    public static final void assertThreadDoesntHoldLock(Object obj) {
        if (obj == null) {
            Intrinsics.m5822a("$this$assertThreadDoesntHoldLock");
            throw null;
        } else if (assertionsEnabled && Thread.holdsLock(obj)) {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(obj);
            throw new AssertionError(a.toString());
        }
    }

    public static final void assertThreadHoldsLock(Object obj) {
        if (obj == null) {
            Intrinsics.m5822a("$this$assertThreadHoldsLock");
            throw null;
        } else if (assertionsEnabled && !Thread.holdsLock(obj)) {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(obj);
            throw new AssertionError(a.toString());
        }
    }

    public static final boolean canParseAsIpAddress(String str) {
        if (str != null) {
            return VERIFY_AS_IP_ADDRESS.mo9424a(str);
        }
        Intrinsics.m5822a("$this$canParseAsIpAddress");
        throw null;
    }

    public static final boolean canReuseConnectionFor(HttpUrl httpUrl, HttpUrl httpUrl2) {
        if (httpUrl == null) {
            Intrinsics.m5822a("$this$canReuseConnectionFor");
            throw null;
        } else if (httpUrl2 != null) {
            return Intrinsics.m5823a((Object) httpUrl.host(), (Object) httpUrl2.host()) && httpUrl.port() == httpUrl2.port() && Intrinsics.m5823a((Object) httpUrl.scheme(), (Object) httpUrl2.scheme());
        } else {
            Intrinsics.m5822a("other");
            throw null;
        }
    }

    public static final int checkDuration(String str, long j, TimeUnit timeUnit) {
        if (str != null) {
            boolean z = true;
            int i = (j > 0 ? 1 : (j == 0 ? 0 : -1));
            if (i >= 0) {
                if (timeUnit != null) {
                    long millis = timeUnit.toMillis(j);
                    if (millis <= ((long) Integer.MAX_VALUE)) {
                        if (millis == 0 && i > 0) {
                            z = false;
                        }
                        if (z) {
                            return (int) millis;
                        }
                        throw new IllegalArgumentException(outline.m2941b(str, " too small.").toString());
                    }
                    throw new IllegalArgumentException(outline.m2941b(str, " too large.").toString());
                }
                throw new IllegalStateException("unit == null".toString());
            }
            throw new IllegalStateException(outline.m2941b(str, " < 0").toString());
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public static final void checkOffsetAndCount(long j, long j2, long j3) {
        if ((j2 | j3) < 0 || j2 > j || j - j2 < j3) {
            throw new ArrayIndexOutOfBoundsException();
        }
    }

    public static final void closeQuietly(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (RuntimeException e) {
                throw e;
            } catch (Exception unused) {
            }
        } else {
            Intrinsics.m5822a("$this$closeQuietly");
            throw null;
        }
    }

    public static final String[] concat(String[] strArr, String str) {
        if (strArr == null) {
            Intrinsics.m5822a("$this$concat");
            throw null;
        } else if (str != null) {
            Object[] copyOf = Arrays.copyOf(strArr, strArr.length + 1);
            Intrinsics.m5821a((Object) copyOf, "java.util.Arrays.copyOf(this, newSize)");
            String[] strArr2 = (String[]) copyOf;
            strArr2[strArr2.length - 1] = str;
            return strArr2;
        } else {
            Intrinsics.m5822a("value");
            throw null;
        }
    }

    public static final int delimiterOffset(String str, String str2, int i, int i2) {
        if (str == null) {
            Intrinsics.m5822a("$this$delimiterOffset");
            throw null;
        } else if (str2 != null) {
            while (i < i2) {
                if (C1937g.m5851a((CharSequence) str2, str.charAt(i), false, 2)) {
                    return i;
                }
                i++;
            }
            return i2;
        } else {
            Intrinsics.m5822a("delimiters");
            throw null;
        }
    }

    public static /* synthetic */ int delimiterOffset$default(String str, String str2, int i, int i2, int i3, Object obj) {
        if ((i3 & 2) != 0) {
            i = 0;
        }
        if ((i3 & 4) != 0) {
            i2 = str.length();
        }
        return delimiterOffset(str, str2, i, i2);
    }

    public static final boolean discard(Source zVar, int i, TimeUnit timeUnit) {
        if (zVar == null) {
            Intrinsics.m5822a("$this$discard");
            throw null;
        } else if (timeUnit != null) {
            try {
                return skipAll(zVar, i, timeUnit);
            } catch (IOException unused) {
                return false;
            }
        } else {
            Intrinsics.m5822a("timeUnit");
            throw null;
        }
    }

    public static final String format(String str, Object... objArr) {
        if (str == null) {
            Intrinsics.m5822a("format");
            throw null;
        } else if (objArr != null) {
            Locale locale = Locale.US;
            Intrinsics.m5821a((Object) locale, "Locale.US");
            Object[] copyOf = Arrays.copyOf(objArr, objArr.length);
            String format = String.format(locale, str, Arrays.copyOf(copyOf, copyOf.length));
            Intrinsics.m5821a((Object) format, "java.lang.String.format(locale, format, *args)");
            return format;
        } else {
            Intrinsics.m5822a("args");
            throw null;
        }
    }

    public static final boolean hasIntersection(String[] strArr, String[] strArr2, Comparator<? super String> comparator) {
        if (strArr == null) {
            Intrinsics.m5822a("$this$hasIntersection");
            throw null;
        } else if (comparator != null) {
            if (!(strArr.length == 0) && strArr2 != null) {
                if (!(strArr2.length == 0)) {
                    for (String str : strArr) {
                        for (String compare : strArr2) {
                            if (comparator.compare(str, compare) == 0) {
                                return true;
                            }
                        }
                    }
                }
            }
            return false;
        } else {
            Intrinsics.m5822a("comparator");
            throw null;
        }
    }

    public static final long headersContentLength(Response response) {
        if (response != null) {
            String str = response.headers().get("Content-Length");
            if (str != null) {
                return toLongOrDefault(str, -1);
            }
            return -1;
        }
        Intrinsics.m5822a("$this$headersContentLength");
        throw null;
    }

    public static final void ignoreIoExceptions(C1896a<Unit> aVar) {
        if (aVar != null) {
            try {
                aVar.invoke();
            } catch (IOException unused) {
            }
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    @SafeVarargs
    public static final <T> List<T> immutableListOf(T... tArr) {
        if (tArr != null) {
            Object[] objArr = (Object[]) tArr.clone();
            List<T> unmodifiableList = Collections.unmodifiableList(Arrays.asList(Arrays.copyOf(objArr, objArr.length)));
            Intrinsics.m5821a((Object) unmodifiableList, "Collections.unmodifiable…sList(*elements.clone()))");
            return unmodifiableList;
        }
        Intrinsics.m5822a("elements");
        throw null;
    }

    public static final int indexOf(String[] strArr, String str, Comparator<String> comparator) {
        if (strArr == null) {
            Intrinsics.m5822a("$this$indexOf");
            throw null;
        } else if (str == null) {
            Intrinsics.m5822a("value");
            throw null;
        } else if (comparator != null) {
            int length = strArr.length;
            for (int i = 0; i < length; i++) {
                if (comparator.compare(strArr[i], str) == 0) {
                    return i;
                }
            }
            return -1;
        } else {
            Intrinsics.m5822a("comparator");
            throw null;
        }
    }

    public static final int indexOfControlOrNonAscii(String str) {
        if (str != null) {
            int length = str.length();
            for (int i = 0; i < length; i++) {
                char charAt = str.charAt(i);
                if (charAt <= 31 || charAt >= 127) {
                    return i;
                }
            }
            return -1;
        }
        Intrinsics.m5822a("$this$indexOfControlOrNonAscii");
        throw null;
    }

    public static final int indexOfFirstNonAsciiWhitespace(String str, int i, int i2) {
        if (str != null) {
            while (i < i2) {
                char charAt = str.charAt(i);
                if (charAt != 9 && charAt != 10 && charAt != 12 && charAt != 13 && charAt != ' ') {
                    return i;
                }
                i++;
            }
            return i2;
        }
        Intrinsics.m5822a("$this$indexOfFirstNonAsciiWhitespace");
        throw null;
    }

    public static /* synthetic */ int indexOfFirstNonAsciiWhitespace$default(String str, int i, int i2, int i3, Object obj) {
        if ((i3 & 1) != 0) {
            i = 0;
        }
        if ((i3 & 2) != 0) {
            i2 = str.length();
        }
        return indexOfFirstNonAsciiWhitespace(str, i, i2);
    }

    public static final int indexOfLastNonAsciiWhitespace(String str, int i, int i2) {
        if (str != null) {
            int i3 = i2 - 1;
            if (i3 >= i) {
                while (true) {
                    char charAt = str.charAt(i3);
                    if (charAt == 9 || charAt == 10 || charAt == 12 || charAt == 13 || charAt == ' ') {
                        if (i3 == i) {
                            break;
                        }
                        i3--;
                    } else {
                        return i3 + 1;
                    }
                }
            }
            return i;
        }
        Intrinsics.m5822a("$this$indexOfLastNonAsciiWhitespace");
        throw null;
    }

    public static /* synthetic */ int indexOfLastNonAsciiWhitespace$default(String str, int i, int i2, int i3, Object obj) {
        if ((i3 & 1) != 0) {
            i = 0;
        }
        if ((i3 & 2) != 0) {
            i2 = str.length();
        }
        return indexOfLastNonAsciiWhitespace(str, i, i2);
    }

    public static final int indexOfNonWhitespace(String str, int i) {
        if (str != null) {
            int length = str.length();
            while (i < length) {
                char charAt = str.charAt(i);
                if (charAt != ' ' && charAt != 9) {
                    return i;
                }
                i++;
            }
            return str.length();
        }
        Intrinsics.m5822a("$this$indexOfNonWhitespace");
        throw null;
    }

    public static /* synthetic */ int indexOfNonWhitespace$default(String str, int i, int i2, Object obj) {
        if ((i2 & 1) != 0) {
            i = 0;
        }
        return indexOfNonWhitespace(str, i);
    }

    public static final String[] intersect(String[] strArr, String[] strArr2, Comparator<? super String> comparator) {
        if (strArr == null) {
            Intrinsics.m5822a("$this$intersect");
            throw null;
        } else if (strArr2 == null) {
            Intrinsics.m5822a("other");
            throw null;
        } else if (comparator != null) {
            ArrayList arrayList = new ArrayList();
            for (String str : strArr) {
                int length = strArr2.length;
                int i = 0;
                while (true) {
                    if (i >= length) {
                        break;
                    } else if (comparator.compare(str, strArr2[i]) == 0) {
                        arrayList.add(str);
                        break;
                    } else {
                        i++;
                    }
                }
            }
            Object[] array = arrayList.toArray(new String[0]);
            if (array != null) {
                return (String[]) array;
            }
            throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
        } else {
            Intrinsics.m5822a("comparator");
            throw null;
        }
    }

    public static final boolean isHealthy(Socket socket, BufferedSource gVar) {
        int soTimeout;
        if (socket == null) {
            Intrinsics.m5822a("$this$isHealthy");
            throw null;
        } else if (gVar != null) {
            try {
                soTimeout = socket.getSoTimeout();
                socket.setSoTimeout(1);
                boolean z = !gVar.mo9501k();
                socket.setSoTimeout(soTimeout);
                return z;
            } catch (SocketTimeoutException unused) {
                return true;
            } catch (IOException unused2) {
                return false;
            } catch (Throwable th) {
                socket.setSoTimeout(soTimeout);
                throw th;
            }
        } else {
            Intrinsics.m5822a("source");
            throw null;
        }
    }

    public static final void notify(Object obj) {
        if (obj != null) {
            obj.notify();
        } else {
            Intrinsics.m5822a("$this$notify");
            throw null;
        }
    }

    public static final void notifyAll(Object obj) {
        if (obj != null) {
            obj.notifyAll();
        } else {
            Intrinsics.m5822a("$this$notifyAll");
            throw null;
        }
    }

    public static final int parseHexDigit(char c) {
        if ('0' <= c && '9' >= c) {
            return c - '0';
        }
        char c2 = 'a';
        if ('a' > c || 'f' < c) {
            c2 = 'A';
            if ('A' > c || 'F' < c) {
                return -1;
            }
        }
        return (c - c2) + 10;
    }

    public static final String peerName(Socket socket) {
        if (socket != null) {
            SocketAddress remoteSocketAddress = socket.getRemoteSocketAddress();
            if (!(remoteSocketAddress instanceof InetSocketAddress)) {
                return remoteSocketAddress.toString();
            }
            String hostName = ((InetSocketAddress) remoteSocketAddress).getHostName();
            Intrinsics.m5821a((Object) hostName, "address.hostName");
            return hostName;
        }
        Intrinsics.m5822a("$this$peerName");
        throw null;
    }

    public static final Charset readBomAsCharset(BufferedSource gVar, Charset charset) throws IOException {
        Charset charset2;
        if (gVar == null) {
            Intrinsics.m5822a("$this$readBomAsCharset");
            throw null;
        } else if (charset != null) {
            int a = gVar.mo9458a(UNICODE_BOMS);
            if (a == -1) {
                return charset;
            }
            if (a == 0) {
                Charset charset3 = StandardCharsets.UTF_8;
                Intrinsics.m5821a((Object) charset3, "UTF_8");
                return charset3;
            } else if (a == 1) {
                Charset charset4 = StandardCharsets.UTF_16BE;
                Intrinsics.m5821a((Object) charset4, "UTF_16BE");
                return charset4;
            } else if (a != 2) {
                if (a == 3) {
                    Charsets aVar = Charsets.f7621d;
                    charset2 = Charsets.f7620c;
                    if (charset2 == null) {
                        charset2 = Charset.forName("UTF-32BE");
                        Intrinsics.m5821a((Object) charset2, "Charset.forName(\"UTF-32BE\")");
                        Charsets.f7620c = charset2;
                    }
                } else if (a == 4) {
                    Charsets aVar2 = Charsets.f7621d;
                    charset2 = Charsets.f7619b;
                    if (charset2 == null) {
                        charset2 = Charset.forName("UTF-32LE");
                        Intrinsics.m5821a((Object) charset2, "Charset.forName(\"UTF-32LE\")");
                        Charsets.f7619b = charset2;
                    }
                } else {
                    throw new AssertionError();
                }
                return charset2;
            } else {
                Charset charset5 = StandardCharsets.UTF_16LE;
                Intrinsics.m5821a((Object) charset5, "UTF_16LE");
                return charset5;
            }
        } else {
            Intrinsics.m5822a("default");
            throw null;
        }
    }

    public static final <T> T readFieldOrNull(Object obj, Class<T> cls, String str) {
        Object readFieldOrNull;
        Class<Object> cls2 = Object.class;
        if (obj == null) {
            Intrinsics.m5822a("instance");
            throw null;
        } else if (cls == null) {
            Intrinsics.m5822a("fieldType");
            throw null;
        } else if (str != null) {
            Class cls3 = obj.getClass();
            while (!Intrinsics.m5823a((Object) cls3, (Object) cls2)) {
                try {
                    Field declaredField = cls3.getDeclaredField(str);
                    Intrinsics.m5821a((Object) declaredField, "field");
                    declaredField.setAccessible(true);
                    Object obj2 = declaredField.get(obj);
                    if (!cls.isInstance(obj2)) {
                        return null;
                    }
                    return cls.cast(obj2);
                } catch (NoSuchFieldException unused) {
                    cls3 = cls3.getSuperclass();
                    Intrinsics.m5821a((Object) cls3, "c.superclass");
                }
            }
            if (!(!Intrinsics.m5823a((Object) str, (Object) "delegate")) || (readFieldOrNull = readFieldOrNull(obj, cls2, "delegate")) == null) {
                return null;
            }
            return readFieldOrNull(readFieldOrNull, cls, str);
        } else {
            Intrinsics.m5822a("fieldName");
            throw null;
        }
    }

    public static final int readMedium(BufferedSource gVar) throws IOException {
        if (gVar != null) {
            return and(gVar.readByte(), 255) | (and(gVar.readByte(), 255) << 16) | (and(gVar.readByte(), 255) << 8);
        }
        Intrinsics.m5822a("$this$readMedium");
        throw null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:14:0x004e, code lost:
        if (r5 == androidx.recyclerview.widget.RecyclerView.FOREVER_NS) goto L_0x0050;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0050, code lost:
        r11.timeout().clearDeadline();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0058, code lost:
        r11.timeout().deadlineNanoTime(r0 + r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x007b, code lost:
        if (r5 != androidx.recyclerview.widget.RecyclerView.FOREVER_NS) goto L_0x0058;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:0x007e, code lost:
        return r12;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public static final boolean skipAll(p262g.Source r11, int r12, java.util.concurrent.TimeUnit r13) throws java.io.IOException {
        /*
            r0 = 0
            if (r11 == 0) goto L_0x0085
            if (r13 == 0) goto L_0x007f
            long r0 = java.lang.System.nanoTime()
            g.a0 r2 = r11.timeout()
            boolean r2 = r2.hasDeadline()
            r3 = 9223372036854775807(0x7fffffffffffffff, double:NaN)
            if (r2 == 0) goto L_0x0022
            g.a0 r2 = r11.timeout()
            long r5 = r2.deadlineNanoTime()
            long r5 = r5 - r0
            goto L_0x0023
        L_0x0022:
            r5 = r3
        L_0x0023:
            g.a0 r2 = r11.timeout()
            long r7 = (long) r12
            long r12 = r13.toNanos(r7)
            long r12 = java.lang.Math.min(r5, r12)
            long r12 = r12 + r0
            r2.deadlineNanoTime(r12)
            g.d r12 = new g.d     // Catch:{ InterruptedIOException -> 0x0077, all -> 0x0061 }
            r12.<init>()     // Catch:{ InterruptedIOException -> 0x0077, all -> 0x0061 }
        L_0x0039:
            r7 = 8192(0x2000, double:4.0474E-320)
            long r7 = r11.read(r12, r7)     // Catch:{ InterruptedIOException -> 0x0077, all -> 0x0061 }
            r9 = -1
            int r13 = (r7 > r9 ? 1 : (r7 == r9 ? 0 : -1))
            if (r13 == 0) goto L_0x004b
            long r7 = r12.f7648c     // Catch:{ InterruptedIOException -> 0x0077, all -> 0x0061 }
            r12.skip(r7)     // Catch:{ InterruptedIOException -> 0x0077, all -> 0x0061 }
            goto L_0x0039
        L_0x004b:
            r12 = 1
            int r13 = (r5 > r3 ? 1 : (r5 == r3 ? 0 : -1))
            if (r13 != 0) goto L_0x0058
        L_0x0050:
            g.a0 r11 = r11.timeout()
            r11.clearDeadline()
            goto L_0x007e
        L_0x0058:
            g.a0 r11 = r11.timeout()
            long r0 = r0 + r5
            r11.deadlineNanoTime(r0)
            goto L_0x007e
        L_0x0061:
            r12 = move-exception
            int r13 = (r5 > r3 ? 1 : (r5 == r3 ? 0 : -1))
            if (r13 != 0) goto L_0x006e
            g.a0 r11 = r11.timeout()
            r11.clearDeadline()
            goto L_0x0076
        L_0x006e:
            g.a0 r11 = r11.timeout()
            long r0 = r0 + r5
            r11.deadlineNanoTime(r0)
        L_0x0076:
            throw r12
        L_0x0077:
            r12 = 0
            int r13 = (r5 > r3 ? 1 : (r5 == r3 ? 0 : -1))
            if (r13 != 0) goto L_0x0058
            goto L_0x0050
        L_0x007e:
            return r12
        L_0x007f:
            java.lang.String r11 = "timeUnit"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r11)
            throw r0
        L_0x0085:
            java.lang.String r11 = "$this$skipAll"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r11)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.Util.skipAll(g.z, int, java.util.concurrent.TimeUnit):boolean");
    }

    public static final ThreadFactory threadFactory(String str, boolean z) {
        if (str != null) {
            return new Util$threadFactory$1(str, z);
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public static final void threadName(String str, C1896a<Unit> aVar) {
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (aVar != null) {
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "currentThread");
            String name = currentThread.getName();
            currentThread.setName(str);
            try {
                aVar.invoke();
            } finally {
                currentThread.setName(name);
            }
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    public static final List<Header> toHeaderList(Headers headers) {
        if (headers != null) {
            Ranges b = _Ranges.m5828b(0, headers.size());
            ArrayList arrayList = new ArrayList(C1050v.m4134a(b, 10));
            Iterator it = b.iterator();
            while (it.hasNext()) {
                int a = ((Iterators) it).mo9356a();
                arrayList.add(new Header(headers.name(a), headers.value(a)));
            }
            return arrayList;
        }
        Intrinsics.m5822a("$this$toHeaderList");
        throw null;
    }

    public static final Headers toHeaders(List<Header> list) {
        if (list != null) {
            Headers.Builder builder = new Headers.Builder();
            for (Header next : list) {
                builder.addLenient$okhttp(next.component1().mo9547g(), next.component2().mo9547g());
            }
            return builder.build();
        }
        Intrinsics.m5822a("$this$toHeaders");
        throw null;
    }

    public static final String toHexString(long j) {
        String hexString = Long.toHexString(j);
        Intrinsics.m5821a((Object) hexString, "java.lang.Long.toHexString(this)");
        return hexString;
    }

    public static final String toHostHeader(HttpUrl httpUrl, boolean z) {
        String str;
        if (httpUrl != null) {
            if (C1937g.m5853a((CharSequence) httpUrl.host(), (CharSequence) ":", false, 2)) {
                str = '[' + httpUrl.host() + ']';
            } else {
                str = httpUrl.host();
            }
            if (!z && httpUrl.port() == HttpUrl.Companion.defaultPort(httpUrl.scheme())) {
                return str;
            }
            return str + ':' + httpUrl.port();
        }
        Intrinsics.m5822a("$this$toHostHeader");
        throw null;
    }

    public static /* synthetic */ String toHostHeader$default(HttpUrl httpUrl, boolean z, int i, Object obj) {
        if ((i & 1) != 0) {
            z = false;
        }
        return toHostHeader(httpUrl, z);
    }

    public static final <T> List<T> toImmutableList(List<? extends T> list) {
        if (list != null) {
            List<T> unmodifiableList = Collections.unmodifiableList(_Arrays.m5804a(list));
            Intrinsics.m5821a((Object) unmodifiableList, "Collections.unmodifiableList(toMutableList())");
            return unmodifiableList;
        }
        Intrinsics.m5822a("$this$toImmutableList");
        throw null;
    }

    public static final <K, V> Map<K, V> toImmutableMap(Map<K, ? extends V> map) {
        if (map == null) {
            Intrinsics.m5822a("$this$toImmutableMap");
            throw null;
        } else if (map.isEmpty()) {
            return Maps.f7580b;
        } else {
            Map<K, V> unmodifiableMap = Collections.unmodifiableMap(new LinkedHashMap(map));
            Intrinsics.m5821a((Object) unmodifiableMap, "Collections.unmodifiableMap(LinkedHashMap(this))");
            return unmodifiableMap;
        }
    }

    public static final long toLongOrDefault(String str, long j) {
        if (str != null) {
            try {
                return Long.parseLong(str);
            } catch (NumberFormatException unused) {
                return j;
            }
        } else {
            Intrinsics.m5822a("$this$toLongOrDefault");
            throw null;
        }
    }

    public static final int toNonNegativeInt(String str, int i) {
        if (str != null) {
            try {
                long parseLong = Long.parseLong(str);
                if (parseLong > ((long) Integer.MAX_VALUE)) {
                    return Integer.MAX_VALUE;
                }
                if (parseLong < 0) {
                    return 0;
                }
                return (int) parseLong;
            } catch (NumberFormatException unused) {
            }
        }
        return i;
    }

    public static final String trimSubstring(String str, int i, int i2) {
        if (str != null) {
            int indexOfFirstNonAsciiWhitespace = indexOfFirstNonAsciiWhitespace(str, i, i2);
            String substring = str.substring(indexOfFirstNonAsciiWhitespace, indexOfLastNonAsciiWhitespace(str, indexOfFirstNonAsciiWhitespace, i2));
            Intrinsics.m5821a((Object) substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            return substring;
        }
        Intrinsics.m5822a("$this$trimSubstring");
        throw null;
    }

    public static /* synthetic */ String trimSubstring$default(String str, int i, int i2, int i3, Object obj) {
        if ((i3 & 1) != 0) {
            i = 0;
        }
        if ((i3 & 2) != 0) {
            i2 = str.length();
        }
        return trimSubstring(str, i, i2);
    }

    public static final void wait(Object obj) {
        if (obj != null) {
            obj.wait();
        } else {
            Intrinsics.m5822a("$this$wait");
            throw null;
        }
    }

    public static final Throwable withSuppressed(Exception exc, List<? extends Exception> list) {
        if (exc == null) {
            Intrinsics.m5822a("$this$withSuppressed");
            throw null;
        } else if (list != null) {
            if (list.size() > 1) {
                System.out.println(list);
            }
            for (Exception addSuppressed : list) {
                exc.addSuppressed(addSuppressed);
            }
            return exc;
        } else {
            Intrinsics.m5822a("suppressed");
            throw null;
        }
    }

    public static final void writeMedium(BufferedSink fVar, int i) throws IOException {
        if (fVar != null) {
            fVar.writeByte((i >>> 16) & 255);
            fVar.writeByte((i >>> 8) & 255);
            fVar.writeByte(i & 255);
            return;
        }
        Intrinsics.m5822a("$this$writeMedium");
        throw null;
    }

    public static /* synthetic */ int delimiterOffset$default(String str, char c, int i, int i2, int i3, Object obj) {
        if ((i3 & 2) != 0) {
            i = 0;
        }
        if ((i3 & 4) != 0) {
            i2 = str.length();
        }
        return delimiterOffset(str, c, i, i2);
    }

    public static final String toHexString(int i) {
        String hexString = Integer.toHexString(i);
        Intrinsics.m5821a((Object) hexString, "Integer.toHexString(this)");
        return hexString;
    }

    public static final int delimiterOffset(String str, char c, int i, int i2) {
        if (str != null) {
            while (i < i2) {
                if (str.charAt(i) == c) {
                    return i;
                }
                i++;
            }
            return i2;
        }
        Intrinsics.m5822a("$this$delimiterOffset");
        throw null;
    }

    public static final void closeQuietly(Socket socket) {
        if (socket != null) {
            try {
                socket.close();
            } catch (AssertionError e) {
                throw e;
            } catch (RuntimeException e2) {
                throw e2;
            } catch (Exception unused) {
            }
        } else {
            Intrinsics.m5822a("$this$closeQuietly");
            throw null;
        }
    }

    public static final void closeQuietly(ServerSocket serverSocket) {
        if (serverSocket != null) {
            try {
                serverSocket.close();
            } catch (RuntimeException e) {
                throw e;
            } catch (Exception unused) {
            }
        } else {
            Intrinsics.m5822a("$this$closeQuietly");
            throw null;
        }
    }

    public static final int skipAll(C1948d dVar, byte b) {
        if (dVar != null) {
            int i = 0;
            while (!dVar.mo9501k() && dVar.mo9485e(0) == b) {
                i++;
                dVar.readByte();
            }
            return i;
        }
        Intrinsics.m5822a("$this$skipAll");
        throw null;
    }
}
