package okhttp3.internal.cache;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.httpclient.HttpResponseEntityImpl;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.Constants;
import java.io.Closeable;
import java.io.IOException;
import okhttp3.Cache;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okhttp3.internal.cache.CacheStrategy;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.HttpMethod;
import okhttp3.internal.http.RealResponseBody;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.Sink;
import p262g.Source;

@Instrumented
/* compiled from: CacheInterceptor.kt */
public final class CacheInterceptor implements Interceptor {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final Cache cache;

    @Instrumented
    /* compiled from: CacheInterceptor.kt */
    public static final class Companion {
        public Companion() {
        }

        /* access modifiers changed from: private */
        public final Headers combine(Headers headers, Headers headers2) {
            Headers.Builder builder = new Headers.Builder();
            int size = headers.size();
            for (int i = 0; i < size; i++) {
                String name = headers.name(i);
                String value = headers.value(i);
                if ((!C1937g.m5858a("Warning", name, true) || !C1937g.m5864b(value, DiskLruCache.VERSION_1, false, 2)) && (isContentSpecificHeader(name) || !isEndToEnd(name) || headers2.get(name) == null)) {
                    builder.addLenient$okhttp(name, value);
                }
            }
            int size2 = headers2.size();
            for (int i2 = 0; i2 < size2; i2++) {
                String name2 = headers2.name(i2);
                if (!isContentSpecificHeader(name2) && isEndToEnd(name2)) {
                    builder.addLenient$okhttp(name2, headers2.value(i2));
                }
            }
            return builder.build();
        }

        private final boolean isContentSpecificHeader(String str) {
            if (C1937g.m5858a("Content-Length", str, true) || C1937g.m5858a(Constants.Network.CONTENT_ENCODING_HEADER, str, true) || C1937g.m5858a(Constants.Network.CONTENT_TYPE_HEADER, str, true)) {
                return true;
            }
            return false;
        }

        private final boolean isEndToEnd(String str) {
            if (C1937g.m5858a("Connection", str, true) || C1937g.m5858a("Keep-Alive", str, true) || C1937g.m5858a("Proxy-Authenticate", str, true) || C1937g.m5858a("Proxy-Authorization", str, true) || C1937g.m5858a("TE", str, true) || C1937g.m5858a("Trailers", str, true) || C1937g.m5858a(HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER, str, true) || C1937g.m5858a("Upgrade", str, true)) {
                return false;
            }
            return true;
        }

        /* access modifiers changed from: private */
        public final Response stripBody(Response response) {
            if ((response != null ? response.body() : null) == null) {
                return response;
            }
            Response.Builder newBuilder = !(response instanceof Response.Builder) ? response.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) response);
            return (!(newBuilder instanceof Response.Builder) ? newBuilder.body((ResponseBody) null) : OkHttp3Instrumentation.body(newBuilder, (ResponseBody) null)).build();
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public CacheInterceptor(Cache cache2) {
        this.cache = cache2;
    }

    private final Response cacheWritingResponse(CacheRequest cacheRequest, Response response) throws IOException {
        if (cacheRequest == null) {
            return response;
        }
        Sink body = cacheRequest.body();
        ResponseBody body2 = response.body();
        if (body2 != null) {
            CacheInterceptor$cacheWritingResponse$cacheWritingSource$1 cacheInterceptor$cacheWritingResponse$cacheWritingSource$1 = new CacheInterceptor$cacheWritingResponse$cacheWritingSource$1(body2.source(), cacheRequest, C1050v.m4147a(body));
            String header$default = Response.header$default(response, Constants.Network.CONTENT_TYPE_HEADER, (String) null, 2, (Object) null);
            long contentLength = response.body().contentLength();
            Response.Builder newBuilder = !(response instanceof Response.Builder) ? response.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) response);
            RealResponseBody realResponseBody = new RealResponseBody(header$default, contentLength, C1050v.m4148a((Source) cacheInterceptor$cacheWritingResponse$cacheWritingSource$1));
            return (!(newBuilder instanceof Response.Builder) ? newBuilder.body(realResponseBody) : OkHttp3Instrumentation.body(newBuilder, realResponseBody)).build();
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final Cache getCache$okhttp() {
        return this.cache;
    }

    public Response intercept(Interceptor.Chain chain) throws IOException {
        ResponseBody body;
        ResponseBody body2;
        if (chain != null) {
            Cache cache2 = this.cache;
            Response response = cache2 != null ? cache2.get$okhttp(chain.request()) : null;
            CacheStrategy compute = new CacheStrategy.Factory(System.currentTimeMillis(), chain.request(), response).compute();
            Request networkRequest = compute.getNetworkRequest();
            Response cacheResponse = compute.getCacheResponse();
            Cache cache3 = this.cache;
            if (cache3 != null) {
                cache3.trackResponse$okhttp(compute);
            }
            if (!(response == null || cacheResponse != null || (body2 = response.body()) == null)) {
                Util.closeQuietly((Closeable) body2);
            }
            if (networkRequest == null && cacheResponse == null) {
                Response.Builder message = new Response.Builder().request(chain.request()).protocol(Protocol.HTTP_1_1).code(504).message("Unsatisfiable Request (only-if-cached)");
                ResponseBody responseBody = Util.EMPTY_RESPONSE;
                return (!(message instanceof Response.Builder) ? message.body(responseBody) : OkHttp3Instrumentation.body(message, responseBody)).sentRequestAtMillis(-1).receivedResponseAtMillis(System.currentTimeMillis()).build();
            } else if (networkRequest != null) {
                try {
                    Response proceed = chain.proceed(networkRequest);
                    if (!(proceed != null || response == null || body == null)) {
                    }
                    if (cacheResponse != null) {
                        if (proceed == null || proceed.code() != 304) {
                            ResponseBody body3 = cacheResponse.body();
                            if (body3 != null) {
                                Util.closeQuietly((Closeable) body3);
                            }
                        } else {
                            Response build = (!(cacheResponse instanceof Response.Builder) ? cacheResponse.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) cacheResponse)).headers(Companion.combine(cacheResponse.headers(), proceed.headers())).sentRequestAtMillis(proceed.sentRequestAtMillis()).receivedResponseAtMillis(proceed.receivedResponseAtMillis()).cacheResponse(Companion.stripBody(cacheResponse)).networkResponse(Companion.stripBody(proceed)).build();
                            ResponseBody body4 = proceed.body();
                            if (body4 != null) {
                                body4.close();
                                Cache cache4 = this.cache;
                                if (cache4 != null) {
                                    cache4.trackConditionalCacheHit$okhttp();
                                    this.cache.update$okhttp(cacheResponse, build);
                                    return build;
                                }
                                Intrinsics.m5820a();
                                throw null;
                            }
                            Intrinsics.m5820a();
                            throw null;
                        }
                    }
                    if (proceed != null) {
                        Response build2 = (!(proceed instanceof Response.Builder) ? proceed.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) proceed)).cacheResponse(Companion.stripBody(cacheResponse)).networkResponse(Companion.stripBody(proceed)).build();
                        if (this.cache != null) {
                            if (HttpHeaders.promisesBody(build2) && CacheStrategy.Companion.isCacheable(build2, networkRequest)) {
                                return cacheWritingResponse(this.cache.put$okhttp(build2), build2);
                            }
                            if (HttpMethod.INSTANCE.invalidatesCache(networkRequest.method())) {
                                try {
                                    this.cache.remove$okhttp(networkRequest);
                                } catch (IOException unused) {
                                }
                            }
                        }
                        return build2;
                    }
                    Intrinsics.m5820a();
                    throw null;
                } finally {
                    if (!(response == null || (body = response.body()) == null)) {
                        Util.closeQuietly((Closeable) body);
                    }
                }
            } else if (cacheResponse != null) {
                return (!(cacheResponse instanceof Response.Builder) ? cacheResponse.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) cacheResponse)).cacheResponse(Companion.stripBody(cacheResponse)).build();
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        } else {
            Intrinsics.m5822a("chain");
            throw null;
        }
    }
}
