package okhttp3.internal.cache;

import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.Closeable;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.Flushable;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.p269io.FileSystem;
import okhttp3.internal.platform.Platform;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p250f.p261p.Regex;
import p262g.BufferedSink;
import p262g.Sink;
import p262g.Source;

/* compiled from: DiskLruCache.kt */
public final class DiskLruCache implements Closeable, Flushable {
    public static final long ANY_SEQUENCE_NUMBER = -1;
    public static final String CLEAN = CLEAN;
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final String DIRTY = DIRTY;
    public static final String JOURNAL_FILE = JOURNAL_FILE;
    public static final String JOURNAL_FILE_BACKUP = JOURNAL_FILE_BACKUP;
    public static final String JOURNAL_FILE_TEMP = JOURNAL_FILE_TEMP;
    public static final Regex LEGAL_KEY_PATTERN = new Regex("[a-z0-9_-]{1,120}");
    public static final String MAGIC = MAGIC;
    public static final String READ = READ;
    public static final String REMOVE = REMOVE;
    public static final String VERSION_1 = VERSION_1;
    public final int appVersion;
    public final TaskQueue cleanupQueue;
    public final DiskLruCache$cleanupTask$1 cleanupTask;
    public boolean closed;
    public final File directory;
    public final FileSystem fileSystem;
    public boolean hasJournalErrors;
    public boolean initialized;
    public final File journalFile;
    public final File journalFileBackup;
    public final File journalFileTmp;
    public BufferedSink journalWriter;
    public final LinkedHashMap<String, Entry> lruEntries;
    public long maxSize;
    public boolean mostRecentRebuildFailed;
    public boolean mostRecentTrimFailed;
    public long nextSequenceNumber;
    public int redundantOpCount;
    public long size;
    public final int valueCount;

    /* compiled from: DiskLruCache.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: DiskLruCache.kt */
    public final class Editor {
        public boolean done;
        public final Entry entry;
        public final /* synthetic */ DiskLruCache this$0;
        public final boolean[] written;

        public Editor(DiskLruCache diskLruCache, Entry entry2) {
            boolean[] zArr = null;
            if (entry2 != null) {
                this.this$0 = diskLruCache;
                this.entry = entry2;
                this.written = !entry2.getReadable$okhttp() ? new boolean[diskLruCache.getValueCount$okhttp()] : zArr;
                return;
            }
            Intrinsics.m5822a("entry");
            throw null;
        }

        public final void abort() throws IOException {
            synchronized (this.this$0) {
                if (!this.done) {
                    if (Intrinsics.m5823a((Object) this.entry.getCurrentEditor$okhttp(), (Object) this)) {
                        this.this$0.completeEdit$okhttp(this, false);
                    }
                    this.done = true;
                } else {
                    throw new IllegalStateException("Check failed.".toString());
                }
            }
        }

        public final void commit() throws IOException {
            synchronized (this.this$0) {
                if (!this.done) {
                    if (Intrinsics.m5823a((Object) this.entry.getCurrentEditor$okhttp(), (Object) this)) {
                        this.this$0.completeEdit$okhttp(this, true);
                    }
                    this.done = true;
                } else {
                    throw new IllegalStateException("Check failed.".toString());
                }
            }
        }

        public final void detach$okhttp() {
            if (Intrinsics.m5823a((Object) this.entry.getCurrentEditor$okhttp(), (Object) this)) {
                int valueCount$okhttp = this.this$0.getValueCount$okhttp();
                for (int i = 0; i < valueCount$okhttp; i++) {
                    try {
                        this.this$0.getFileSystem$okhttp().delete(this.entry.getDirtyFiles$okhttp().get(i));
                    } catch (IOException unused) {
                    }
                }
                this.entry.setCurrentEditor$okhttp((Editor) null);
            }
        }

        public final Entry getEntry$okhttp() {
            return this.entry;
        }

        public final boolean[] getWritten$okhttp() {
            return this.written;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:28:?, code lost:
            r5 = new p262g.Okio();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:30:0x0059, code lost:
            return r5;
         */
        /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0053 */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final p262g.Sink newSink(int r5) {
            /*
                r4 = this;
                okhttp3.internal.cache.DiskLruCache r0 = r4.this$0
                monitor-enter(r0)
                boolean r1 = r4.done     // Catch:{ all -> 0x0066 }
                r2 = 1
                r1 = r1 ^ r2
                if (r1 == 0) goto L_0x005a
                okhttp3.internal.cache.DiskLruCache$Entry r1 = r4.entry     // Catch:{ all -> 0x0066 }
                okhttp3.internal.cache.DiskLruCache$Editor r1 = r1.getCurrentEditor$okhttp()     // Catch:{ all -> 0x0066 }
                boolean r1 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r1, (java.lang.Object) r4)     // Catch:{ all -> 0x0066 }
                r1 = r1 ^ r2
                if (r1 == 0) goto L_0x001d
                g.c r5 = new g.c     // Catch:{ all -> 0x0066 }
                r5.<init>()     // Catch:{ all -> 0x0066 }
                monitor-exit(r0)
                return r5
            L_0x001d:
                okhttp3.internal.cache.DiskLruCache$Entry r1 = r4.entry     // Catch:{ all -> 0x0066 }
                boolean r1 = r1.getReadable$okhttp()     // Catch:{ all -> 0x0066 }
                if (r1 != 0) goto L_0x0031
                boolean[] r1 = r4.written     // Catch:{ all -> 0x0066 }
                if (r1 == 0) goto L_0x002c
                r1[r5] = r2     // Catch:{ all -> 0x0066 }
                goto L_0x0031
            L_0x002c:
                p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0066 }
                r5 = 0
                throw r5
            L_0x0031:
                okhttp3.internal.cache.DiskLruCache$Entry r1 = r4.entry     // Catch:{ all -> 0x0066 }
                java.util.List r1 = r1.getDirtyFiles$okhttp()     // Catch:{ all -> 0x0066 }
                java.lang.Object r1 = r1.get(r5)     // Catch:{ all -> 0x0066 }
                java.io.File r1 = (java.io.File) r1     // Catch:{ all -> 0x0066 }
                okhttp3.internal.cache.DiskLruCache r2 = r4.this$0     // Catch:{ FileNotFoundException -> 0x0053 }
                okhttp3.internal.io.FileSystem r2 = r2.getFileSystem$okhttp()     // Catch:{ FileNotFoundException -> 0x0053 }
                g.x r1 = r2.sink(r1)     // Catch:{ FileNotFoundException -> 0x0053 }
                okhttp3.internal.cache.FaultHidingSink r2 = new okhttp3.internal.cache.FaultHidingSink     // Catch:{ all -> 0x0066 }
                okhttp3.internal.cache.DiskLruCache$Editor$newSink$$inlined$synchronized$lambda$1 r3 = new okhttp3.internal.cache.DiskLruCache$Editor$newSink$$inlined$synchronized$lambda$1     // Catch:{ all -> 0x0066 }
                r3.<init>(r4, r5)     // Catch:{ all -> 0x0066 }
                r2.<init>(r1, r3)     // Catch:{ all -> 0x0066 }
                monitor-exit(r0)
                return r2
            L_0x0053:
                g.c r5 = new g.c     // Catch:{ all -> 0x0066 }
                r5.<init>()     // Catch:{ all -> 0x0066 }
                monitor-exit(r0)
                return r5
            L_0x005a:
                java.lang.String r5 = "Check failed."
                java.lang.IllegalStateException r1 = new java.lang.IllegalStateException     // Catch:{ all -> 0x0066 }
                java.lang.String r5 = r5.toString()     // Catch:{ all -> 0x0066 }
                r1.<init>(r5)     // Catch:{ all -> 0x0066 }
                throw r1     // Catch:{ all -> 0x0066 }
            L_0x0066:
                r5 = move-exception
                monitor-exit(r0)
                throw r5
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.Editor.newSink(int):g.x");
        }

        /* JADX WARNING: Code restructure failed: missing block: B:16:0x003a, code lost:
            return null;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public final p262g.Source newSource(int r5) {
            /*
                r4 = this;
                okhttp3.internal.cache.DiskLruCache r0 = r4.this$0
                monitor-enter(r0)
                boolean r1 = r4.done     // Catch:{ all -> 0x0047 }
                r1 = r1 ^ 1
                if (r1 == 0) goto L_0x003b
                okhttp3.internal.cache.DiskLruCache$Entry r1 = r4.entry     // Catch:{ all -> 0x0047 }
                boolean r1 = r1.getReadable$okhttp()     // Catch:{ all -> 0x0047 }
                r2 = 0
                if (r1 == 0) goto L_0x0039
                okhttp3.internal.cache.DiskLruCache$Entry r1 = r4.entry     // Catch:{ all -> 0x0047 }
                okhttp3.internal.cache.DiskLruCache$Editor r1 = r1.getCurrentEditor$okhttp()     // Catch:{ all -> 0x0047 }
                boolean r1 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r1, (java.lang.Object) r4)     // Catch:{ all -> 0x0047 }
                r1 = r1 ^ 1
                if (r1 == 0) goto L_0x0021
                goto L_0x0039
            L_0x0021:
                okhttp3.internal.cache.DiskLruCache r1 = r4.this$0     // Catch:{ FileNotFoundException -> 0x0037 }
                okhttp3.internal.io.FileSystem r1 = r1.getFileSystem$okhttp()     // Catch:{ FileNotFoundException -> 0x0037 }
                okhttp3.internal.cache.DiskLruCache$Entry r3 = r4.entry     // Catch:{ FileNotFoundException -> 0x0037 }
                java.util.List r3 = r3.getCleanFiles$okhttp()     // Catch:{ FileNotFoundException -> 0x0037 }
                java.lang.Object r5 = r3.get(r5)     // Catch:{ FileNotFoundException -> 0x0037 }
                java.io.File r5 = (java.io.File) r5     // Catch:{ FileNotFoundException -> 0x0037 }
                g.z r2 = r1.source(r5)     // Catch:{ FileNotFoundException -> 0x0037 }
            L_0x0037:
                monitor-exit(r0)
                return r2
            L_0x0039:
                monitor-exit(r0)
                return r2
            L_0x003b:
                java.lang.String r5 = "Check failed."
                java.lang.IllegalStateException r1 = new java.lang.IllegalStateException     // Catch:{ all -> 0x0047 }
                java.lang.String r5 = r5.toString()     // Catch:{ all -> 0x0047 }
                r1.<init>(r5)     // Catch:{ all -> 0x0047 }
                throw r1     // Catch:{ all -> 0x0047 }
            L_0x0047:
                r5 = move-exception
                monitor-exit(r0)
                throw r5
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.Editor.newSource(int):g.z");
        }
    }

    /* compiled from: DiskLruCache.kt */
    public final class Entry {
        public final List<File> cleanFiles;
        public Editor currentEditor;
        public final List<File> dirtyFiles;
        public final String key;
        public final long[] lengths;
        public boolean readable;
        public long sequenceNumber;
        public final /* synthetic */ DiskLruCache this$0;

        public Entry(DiskLruCache diskLruCache, String str) {
            if (str != null) {
                this.this$0 = diskLruCache;
                this.key = str;
                this.lengths = new long[diskLruCache.getValueCount$okhttp()];
                this.cleanFiles = new ArrayList();
                this.dirtyFiles = new ArrayList();
                StringBuilder sb = new StringBuilder(this.key);
                sb.append('.');
                int length = sb.length();
                int valueCount$okhttp = diskLruCache.getValueCount$okhttp();
                for (int i = 0; i < valueCount$okhttp; i++) {
                    sb.append(i);
                    this.cleanFiles.add(new File(diskLruCache.getDirectory(), sb.toString()));
                    sb.append(".tmp");
                    this.dirtyFiles.add(new File(diskLruCache.getDirectory(), sb.toString()));
                    sb.setLength(length);
                }
                return;
            }
            Intrinsics.m5822a("key");
            throw null;
        }

        private final IOException invalidLengths(List<String> list) throws IOException {
            throw new IOException("unexpected journal line: " + list);
        }

        public final List<File> getCleanFiles$okhttp() {
            return this.cleanFiles;
        }

        public final Editor getCurrentEditor$okhttp() {
            return this.currentEditor;
        }

        public final List<File> getDirtyFiles$okhttp() {
            return this.dirtyFiles;
        }

        public final String getKey$okhttp() {
            return this.key;
        }

        public final long[] getLengths$okhttp() {
            return this.lengths;
        }

        public final boolean getReadable$okhttp() {
            return this.readable;
        }

        public final long getSequenceNumber$okhttp() {
            return this.sequenceNumber;
        }

        public final void setCurrentEditor$okhttp(Editor editor) {
            this.currentEditor = editor;
        }

        public final void setLengths$okhttp(List<String> list) throws IOException {
            if (list == null) {
                Intrinsics.m5822a("strings");
                throw null;
            } else if (list.size() == this.this$0.getValueCount$okhttp()) {
                try {
                    int size = list.size();
                    for (int i = 0; i < size; i++) {
                        this.lengths[i] = Long.parseLong(list.get(i));
                    }
                } catch (NumberFormatException unused) {
                    throw invalidLengths(list);
                }
            } else {
                throw invalidLengths(list);
            }
        }

        public final void setReadable$okhttp(boolean z) {
            this.readable = z;
        }

        public final void setSequenceNumber$okhttp(long j) {
            this.sequenceNumber = j;
        }

        public final Snapshot snapshot$okhttp() {
            DiskLruCache diskLruCache = this.this$0;
            if (!Util.assertionsEnabled || Thread.holdsLock(diskLruCache)) {
                ArrayList<Source> arrayList = new ArrayList<>();
                long[] jArr = (long[]) this.lengths.clone();
                try {
                    int valueCount$okhttp = this.this$0.getValueCount$okhttp();
                    for (int i = 0; i < valueCount$okhttp; i++) {
                        arrayList.add(this.this$0.getFileSystem$okhttp().source(this.cleanFiles.get(i)));
                    }
                    return new Snapshot(this.this$0, this.key, this.sequenceNumber, arrayList, jArr);
                } catch (FileNotFoundException unused) {
                    for (Source closeQuietly : arrayList) {
                        Util.closeQuietly((Closeable) closeQuietly);
                    }
                    try {
                        this.this$0.removeEntry$okhttp(this);
                        return null;
                    } catch (IOException unused2) {
                        return null;
                    }
                }
            } else {
                StringBuilder a = outline.m2937a("Thread ");
                Thread currentThread = Thread.currentThread();
                Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
                a.append(currentThread.getName());
                a.append(" MUST hold lock on ");
                a.append(diskLruCache);
                throw new AssertionError(a.toString());
            }
        }

        public final void writeLengths$okhttp(BufferedSink fVar) throws IOException {
            if (fVar != null) {
                for (long h : this.lengths) {
                    fVar.writeByte(32).mo9493h(h);
                }
                return;
            }
            Intrinsics.m5822a("writer");
            throw null;
        }
    }

    /* compiled from: DiskLruCache.kt */
    public final class Snapshot implements Closeable {
        public final String key;
        public final long[] lengths;
        public final long sequenceNumber;
        public final List<Source> sources;
        public final /* synthetic */ DiskLruCache this$0;

        public Snapshot(DiskLruCache diskLruCache, String str, long j, List<? extends Source> list, long[] jArr) {
            if (str == null) {
                Intrinsics.m5822a("key");
                throw null;
            } else if (list == null) {
                Intrinsics.m5822a("sources");
                throw null;
            } else if (jArr != null) {
                this.this$0 = diskLruCache;
                this.key = str;
                this.sequenceNumber = j;
                this.sources = list;
                this.lengths = jArr;
            } else {
                Intrinsics.m5822a("lengths");
                throw null;
            }
        }

        public void close() {
            for (Source closeQuietly : this.sources) {
                Util.closeQuietly((Closeable) closeQuietly);
            }
        }

        public final Editor edit() throws IOException {
            return this.this$0.edit(this.key, this.sequenceNumber);
        }

        public final long getLength(int i) {
            return this.lengths[i];
        }

        public final Source getSource(int i) {
            return this.sources.get(i);
        }

        public final String key() {
            return this.key;
        }
    }

    public DiskLruCache(FileSystem fileSystem2, File file, int i, int i2, long j, TaskRunner taskRunner) {
        if (fileSystem2 == null) {
            Intrinsics.m5822a("fileSystem");
            throw null;
        } else if (file == null) {
            Intrinsics.m5822a("directory");
            throw null;
        } else if (taskRunner != null) {
            this.fileSystem = fileSystem2;
            this.directory = file;
            this.appVersion = i;
            this.valueCount = i2;
            this.maxSize = j;
            boolean z = true;
            this.lruEntries = new LinkedHashMap<>(0, 0.75f, true);
            this.cleanupQueue = taskRunner.newQueue();
            this.cleanupTask = new DiskLruCache$cleanupTask$1(this, outline.m2935a(new StringBuilder(), Util.okHttpName, " Cache"));
            if (j > 0) {
                if (this.valueCount <= 0 ? false : z) {
                    this.journalFile = new File(this.directory, JOURNAL_FILE);
                    this.journalFileTmp = new File(this.directory, JOURNAL_FILE_TEMP);
                    this.journalFileBackup = new File(this.directory, JOURNAL_FILE_BACKUP);
                    return;
                }
                throw new IllegalArgumentException("valueCount <= 0".toString());
            }
            throw new IllegalArgumentException("maxSize <= 0".toString());
        } else {
            Intrinsics.m5822a("taskRunner");
            throw null;
        }
    }

    private final synchronized void checkNotClosed() {
        if (!(!this.closed)) {
            throw new IllegalStateException("cache is closed".toString());
        }
    }

    public static /* synthetic */ Editor edit$default(DiskLruCache diskLruCache, String str, long j, int i, Object obj) throws IOException {
        if ((i & 2) != 0) {
            j = ANY_SEQUENCE_NUMBER;
        }
        return diskLruCache.edit(str, j);
    }

    /* access modifiers changed from: private */
    public final boolean journalRebuildRequired() {
        int i = this.redundantOpCount;
        return i >= 2000 && i >= this.lruEntries.size();
    }

    private final BufferedSink newJournalWriter() throws FileNotFoundException {
        return C1050v.m4147a((Sink) new FaultHidingSink(this.fileSystem.appendingSink(this.journalFile), new DiskLruCache$newJournalWriter$faultHidingSink$1(this)));
    }

    private final void processJournal() throws IOException {
        this.fileSystem.delete(this.journalFileTmp);
        Iterator<Entry> it = this.lruEntries.values().iterator();
        while (it.hasNext()) {
            Entry next = it.next();
            Intrinsics.m5821a((Object) next, "i.next()");
            Entry entry = next;
            int i = 0;
            if (entry.getCurrentEditor$okhttp() == null) {
                int i2 = this.valueCount;
                while (i < i2) {
                    this.size += entry.getLengths$okhttp()[i];
                    i++;
                }
            } else {
                entry.setCurrentEditor$okhttp((Editor) null);
                int i3 = this.valueCount;
                while (i < i3) {
                    this.fileSystem.delete(entry.getCleanFiles$okhttp().get(i));
                    this.fileSystem.delete(entry.getDirtyFiles$okhttp().get(i));
                    i++;
                }
                it.remove();
            }
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(5:18|19|(1:21)(1:22)|23|24) */
    /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
        r9.redundantOpCount = r7 - r9.lruEntries.size();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0071, code lost:
        if (r1.mo9501k() == false) goto L_0x0073;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0073, code lost:
        rebuildJournal$okhttp();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0077, code lost:
        r9.journalWriter = newJournalWriter();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x007d, code lost:
        p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r1, (java.lang.Throwable) null);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0081, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x00b2, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x00b3, code lost:
        p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r1, r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x00b6, code lost:
        throw r2;
     */
    /* JADX WARNING: Missing exception handler attribute for start block: B:18:0x0064 */
    /* JADX WARNING: Unknown top exception splitter block from list: {B:25:0x0082=Splitter:B:25:0x0082, B:18:0x0064=Splitter:B:18:0x0064} */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final void readJournal() throws java.io.IOException {
        /*
            r9 = this;
            java.lang.String r0 = ", "
            okhttp3.internal.io.FileSystem r1 = r9.fileSystem
            java.io.File r2 = r9.journalFile
            g.z r1 = r1.source(r2)
            g.g r1 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4148a((p262g.Source) r1)
            java.lang.String r2 = r1.mo9496i()     // Catch:{ all -> 0x00b0 }
            java.lang.String r3 = r1.mo9496i()     // Catch:{ all -> 0x00b0 }
            java.lang.String r4 = r1.mo9496i()     // Catch:{ all -> 0x00b0 }
            java.lang.String r5 = r1.mo9496i()     // Catch:{ all -> 0x00b0 }
            java.lang.String r6 = r1.mo9496i()     // Catch:{ all -> 0x00b0 }
            java.lang.String r7 = MAGIC     // Catch:{ all -> 0x00b0 }
            boolean r7 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r7, (java.lang.Object) r2)     // Catch:{ all -> 0x00b0 }
            r8 = 1
            r7 = r7 ^ r8
            if (r7 != 0) goto L_0x0082
            java.lang.String r7 = VERSION_1     // Catch:{ all -> 0x00b0 }
            boolean r7 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r7, (java.lang.Object) r3)     // Catch:{ all -> 0x00b0 }
            r7 = r7 ^ r8
            if (r7 != 0) goto L_0x0082
            int r7 = r9.appVersion     // Catch:{ all -> 0x00b0 }
            java.lang.String r7 = java.lang.String.valueOf(r7)     // Catch:{ all -> 0x00b0 }
            boolean r4 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r7, (java.lang.Object) r4)     // Catch:{ all -> 0x00b0 }
            r4 = r4 ^ r8
            if (r4 != 0) goto L_0x0082
            int r4 = r9.valueCount     // Catch:{ all -> 0x00b0 }
            java.lang.String r4 = java.lang.String.valueOf(r4)     // Catch:{ all -> 0x00b0 }
            boolean r4 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r4, (java.lang.Object) r5)     // Catch:{ all -> 0x00b0 }
            r4 = r4 ^ r8
            if (r4 != 0) goto L_0x0082
            int r4 = r6.length()     // Catch:{ all -> 0x00b0 }
            r7 = 0
            if (r4 <= 0) goto L_0x0057
            goto L_0x0058
        L_0x0057:
            r8 = 0
        L_0x0058:
            if (r8 != 0) goto L_0x0082
        L_0x005a:
            java.lang.String r0 = r1.mo9496i()     // Catch:{ EOFException -> 0x0064 }
            r9.readJournalLine(r0)     // Catch:{ EOFException -> 0x0064 }
            int r7 = r7 + 1
            goto L_0x005a
        L_0x0064:
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r0 = r9.lruEntries     // Catch:{ all -> 0x00b0 }
            int r0 = r0.size()     // Catch:{ all -> 0x00b0 }
            int r7 = r7 - r0
            r9.redundantOpCount = r7     // Catch:{ all -> 0x00b0 }
            boolean r0 = r1.mo9501k()     // Catch:{ all -> 0x00b0 }
            if (r0 != 0) goto L_0x0077
            r9.rebuildJournal$okhttp()     // Catch:{ all -> 0x00b0 }
            goto L_0x007d
        L_0x0077:
            g.f r0 = r9.newJournalWriter()     // Catch:{ all -> 0x00b0 }
            r9.journalWriter = r0     // Catch:{ all -> 0x00b0 }
        L_0x007d:
            r0 = 0
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r1, (java.lang.Throwable) r0)
            return
        L_0x0082:
            java.io.IOException r4 = new java.io.IOException     // Catch:{ all -> 0x00b0 }
            java.lang.StringBuilder r7 = new java.lang.StringBuilder     // Catch:{ all -> 0x00b0 }
            r7.<init>()     // Catch:{ all -> 0x00b0 }
            java.lang.String r8 = "unexpected journal header: ["
            r7.append(r8)     // Catch:{ all -> 0x00b0 }
            r7.append(r2)     // Catch:{ all -> 0x00b0 }
            r7.append(r0)     // Catch:{ all -> 0x00b0 }
            r7.append(r3)     // Catch:{ all -> 0x00b0 }
            r7.append(r0)     // Catch:{ all -> 0x00b0 }
            r7.append(r5)     // Catch:{ all -> 0x00b0 }
            r7.append(r0)     // Catch:{ all -> 0x00b0 }
            r7.append(r6)     // Catch:{ all -> 0x00b0 }
            r0 = 93
            r7.append(r0)     // Catch:{ all -> 0x00b0 }
            java.lang.String r0 = r7.toString()     // Catch:{ all -> 0x00b0 }
            r4.<init>(r0)     // Catch:{ all -> 0x00b0 }
            throw r4     // Catch:{ all -> 0x00b0 }
        L_0x00b0:
            r0 = move-exception
            throw r0     // Catch:{ all -> 0x00b2 }
        L_0x00b2:
            r2 = move-exception
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r1, (java.lang.Throwable) r0)
            throw r2
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.readJournal():void");
    }

    private final void readJournalLine(String str) throws IOException {
        String str2;
        int a = C1937g.m5836a((CharSequence) str, (char) SafeJsonPrimitive.NULL_CHAR, 0, false, 6);
        if (a != -1) {
            int i = a + 1;
            int a2 = C1937g.m5836a((CharSequence) str, (char) SafeJsonPrimitive.NULL_CHAR, i, false, 4);
            if (a2 == -1) {
                if (str != null) {
                    str2 = str.substring(i);
                    Intrinsics.m5821a((Object) str2, "(this as java.lang.String).substring(startIndex)");
                    if (a == REMOVE.length() && C1937g.m5864b(str, REMOVE, false, 2)) {
                        this.lruEntries.remove(str2);
                        return;
                    }
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
                }
            } else if (str != null) {
                str2 = str.substring(i, a2);
                Intrinsics.m5821a((Object) str2, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            } else {
                throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
            }
            Entry entry = this.lruEntries.get(str2);
            if (entry == null) {
                entry = new Entry(this, str2);
                this.lruEntries.put(str2, entry);
            }
            if (a2 != -1 && a == CLEAN.length() && C1937g.m5864b(str, CLEAN, false, 2)) {
                int i2 = a2 + 1;
                if (str != null) {
                    String substring = str.substring(i2);
                    Intrinsics.m5821a((Object) substring, "(this as java.lang.String).substring(startIndex)");
                    List a3 = C1937g.m5850a((CharSequence) substring, new char[]{SafeJsonPrimitive.NULL_CHAR}, false, 0, 6);
                    entry.setReadable$okhttp(true);
                    entry.setCurrentEditor$okhttp((Editor) null);
                    entry.setLengths$okhttp(a3);
                    return;
                }
                throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
            } else if (a2 == -1 && a == DIRTY.length() && C1937g.m5864b(str, DIRTY, false, 2)) {
                entry.setCurrentEditor$okhttp(new Editor(this, entry));
            } else if (a2 != -1 || a != READ.length() || !C1937g.m5864b(str, READ, false, 2)) {
                throw new IOException(outline.m2941b("unexpected journal line: ", str));
            }
        } else {
            throw new IOException(outline.m2941b("unexpected journal line: ", str));
        }
    }

    private final void validateKey(String str) {
        if (!LEGAL_KEY_PATTERN.mo9424a(str)) {
            throw new IllegalArgumentException(("keys must match regex [a-z0-9_-]{1,120}: \"" + str + '\"').toString());
        }
    }

    public synchronized void close() throws IOException {
        if (this.initialized) {
            if (!this.closed) {
                Collection<Entry> values = this.lruEntries.values();
                Intrinsics.m5821a((Object) values, "lruEntries.values");
                Object[] array = values.toArray(new Entry[0]);
                if (array != null) {
                    for (Entry entry : (Entry[]) array) {
                        if (entry.getCurrentEditor$okhttp() != null) {
                            Editor currentEditor$okhttp = entry.getCurrentEditor$okhttp();
                            if (currentEditor$okhttp != null) {
                                currentEditor$okhttp.abort();
                            } else {
                                Intrinsics.m5820a();
                                throw null;
                            }
                        }
                    }
                    trimToSize();
                    BufferedSink fVar = this.journalWriter;
                    if (fVar != null) {
                        fVar.close();
                        this.journalWriter = null;
                        this.closed = true;
                        return;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
            }
        }
        this.closed = true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:53:0x0125, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized void completeEdit$okhttp(okhttp3.internal.cache.DiskLruCache.Editor r10, boolean r11) throws java.io.IOException {
        /*
            r9 = this;
            monitor-enter(r9)
            java.lang.String r0 = "editor"
            r1 = 0
            if (r10 == 0) goto L_0x0136
            okhttp3.internal.cache.DiskLruCache$Entry r0 = r10.getEntry$okhttp()     // Catch:{ all -> 0x013a }
            okhttp3.internal.cache.DiskLruCache$Editor r2 = r0.getCurrentEditor$okhttp()     // Catch:{ all -> 0x013a }
            boolean r2 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r2, (java.lang.Object) r10)     // Catch:{ all -> 0x013a }
            if (r2 == 0) goto L_0x012a
            r2 = 0
            if (r11 == 0) goto L_0x0064
            boolean r3 = r0.getReadable$okhttp()     // Catch:{ all -> 0x013a }
            if (r3 != 0) goto L_0x0064
            int r3 = r9.valueCount     // Catch:{ all -> 0x013a }
            r4 = 0
        L_0x0020:
            if (r4 >= r3) goto L_0x0064
            boolean[] r5 = r10.getWritten$okhttp()     // Catch:{ all -> 0x013a }
            if (r5 == 0) goto L_0x0060
            boolean r5 = r5[r4]     // Catch:{ all -> 0x013a }
            if (r5 == 0) goto L_0x0046
            okhttp3.internal.io.FileSystem r5 = r9.fileSystem     // Catch:{ all -> 0x013a }
            java.util.List r6 = r0.getDirtyFiles$okhttp()     // Catch:{ all -> 0x013a }
            java.lang.Object r6 = r6.get(r4)     // Catch:{ all -> 0x013a }
            java.io.File r6 = (java.io.File) r6     // Catch:{ all -> 0x013a }
            boolean r5 = r5.exists(r6)     // Catch:{ all -> 0x013a }
            if (r5 != 0) goto L_0x0043
            r10.abort()     // Catch:{ all -> 0x013a }
            monitor-exit(r9)
            return
        L_0x0043:
            int r4 = r4 + 1
            goto L_0x0020
        L_0x0046:
            r10.abort()     // Catch:{ all -> 0x013a }
            java.lang.IllegalStateException r10 = new java.lang.IllegalStateException     // Catch:{ all -> 0x013a }
            java.lang.StringBuilder r11 = new java.lang.StringBuilder     // Catch:{ all -> 0x013a }
            r11.<init>()     // Catch:{ all -> 0x013a }
            java.lang.String r0 = "Newly created entry didn't create value for index "
            r11.append(r0)     // Catch:{ all -> 0x013a }
            r11.append(r4)     // Catch:{ all -> 0x013a }
            java.lang.String r11 = r11.toString()     // Catch:{ all -> 0x013a }
            r10.<init>(r11)     // Catch:{ all -> 0x013a }
            throw r10     // Catch:{ all -> 0x013a }
        L_0x0060:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x013a }
            throw r1
        L_0x0064:
            int r10 = r9.valueCount     // Catch:{ all -> 0x013a }
        L_0x0066:
            if (r2 >= r10) goto L_0x00ac
            java.util.List r3 = r0.getDirtyFiles$okhttp()     // Catch:{ all -> 0x013a }
            java.lang.Object r3 = r3.get(r2)     // Catch:{ all -> 0x013a }
            java.io.File r3 = (java.io.File) r3     // Catch:{ all -> 0x013a }
            if (r11 == 0) goto L_0x00a4
            okhttp3.internal.io.FileSystem r4 = r9.fileSystem     // Catch:{ all -> 0x013a }
            boolean r4 = r4.exists(r3)     // Catch:{ all -> 0x013a }
            if (r4 == 0) goto L_0x00a9
            java.util.List r4 = r0.getCleanFiles$okhttp()     // Catch:{ all -> 0x013a }
            java.lang.Object r4 = r4.get(r2)     // Catch:{ all -> 0x013a }
            java.io.File r4 = (java.io.File) r4     // Catch:{ all -> 0x013a }
            okhttp3.internal.io.FileSystem r5 = r9.fileSystem     // Catch:{ all -> 0x013a }
            r5.rename(r3, r4)     // Catch:{ all -> 0x013a }
            long[] r3 = r0.getLengths$okhttp()     // Catch:{ all -> 0x013a }
            r5 = r3[r2]     // Catch:{ all -> 0x013a }
            okhttp3.internal.io.FileSystem r3 = r9.fileSystem     // Catch:{ all -> 0x013a }
            long r3 = r3.size(r4)     // Catch:{ all -> 0x013a }
            long[] r7 = r0.getLengths$okhttp()     // Catch:{ all -> 0x013a }
            r7[r2] = r3     // Catch:{ all -> 0x013a }
            long r7 = r9.size     // Catch:{ all -> 0x013a }
            long r7 = r7 - r5
            long r7 = r7 + r3
            r9.size = r7     // Catch:{ all -> 0x013a }
            goto L_0x00a9
        L_0x00a4:
            okhttp3.internal.io.FileSystem r4 = r9.fileSystem     // Catch:{ all -> 0x013a }
            r4.delete(r3)     // Catch:{ all -> 0x013a }
        L_0x00a9:
            int r2 = r2 + 1
            goto L_0x0066
        L_0x00ac:
            int r10 = r9.redundantOpCount     // Catch:{ all -> 0x013a }
            r2 = 1
            int r10 = r10 + r2
            r9.redundantOpCount = r10     // Catch:{ all -> 0x013a }
            r0.setCurrentEditor$okhttp(r1)     // Catch:{ all -> 0x013a }
            g.f r10 = r9.journalWriter     // Catch:{ all -> 0x013a }
            if (r10 == 0) goto L_0x0126
            boolean r1 = r0.getReadable$okhttp()     // Catch:{ all -> 0x013a }
            r3 = 10
            r4 = 32
            if (r1 != 0) goto L_0x00e3
            if (r11 == 0) goto L_0x00c6
            goto L_0x00e3
        L_0x00c6:
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r11 = r9.lruEntries     // Catch:{ all -> 0x013a }
            java.lang.String r1 = r0.getKey$okhttp()     // Catch:{ all -> 0x013a }
            r11.remove(r1)     // Catch:{ all -> 0x013a }
            java.lang.String r11 = REMOVE     // Catch:{ all -> 0x013a }
            g.f r11 = r10.mo9468a((java.lang.String) r11)     // Catch:{ all -> 0x013a }
            r11.writeByte(r4)     // Catch:{ all -> 0x013a }
            java.lang.String r11 = r0.getKey$okhttp()     // Catch:{ all -> 0x013a }
            r10.mo9468a((java.lang.String) r11)     // Catch:{ all -> 0x013a }
            r10.writeByte(r3)     // Catch:{ all -> 0x013a }
            goto L_0x0108
        L_0x00e3:
            r0.setReadable$okhttp(r2)     // Catch:{ all -> 0x013a }
            java.lang.String r1 = CLEAN     // Catch:{ all -> 0x013a }
            g.f r1 = r10.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x013a }
            r1.writeByte(r4)     // Catch:{ all -> 0x013a }
            java.lang.String r1 = r0.getKey$okhttp()     // Catch:{ all -> 0x013a }
            r10.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x013a }
            r0.writeLengths$okhttp(r10)     // Catch:{ all -> 0x013a }
            r10.writeByte(r3)     // Catch:{ all -> 0x013a }
            if (r11 == 0) goto L_0x0108
            long r1 = r9.nextSequenceNumber     // Catch:{ all -> 0x013a }
            r3 = 1
            long r3 = r3 + r1
            r9.nextSequenceNumber = r3     // Catch:{ all -> 0x013a }
            r0.setSequenceNumber$okhttp(r1)     // Catch:{ all -> 0x013a }
        L_0x0108:
            r10.flush()     // Catch:{ all -> 0x013a }
            long r10 = r9.size     // Catch:{ all -> 0x013a }
            long r0 = r9.maxSize     // Catch:{ all -> 0x013a }
            int r2 = (r10 > r0 ? 1 : (r10 == r0 ? 0 : -1))
            if (r2 > 0) goto L_0x0119
            boolean r10 = r9.journalRebuildRequired()     // Catch:{ all -> 0x013a }
            if (r10 == 0) goto L_0x0124
        L_0x0119:
            okhttp3.internal.concurrent.TaskQueue r0 = r9.cleanupQueue     // Catch:{ all -> 0x013a }
            okhttp3.internal.cache.DiskLruCache$cleanupTask$1 r1 = r9.cleanupTask     // Catch:{ all -> 0x013a }
            r2 = 0
            r4 = 2
            r5 = 0
            okhttp3.internal.concurrent.TaskQueue.schedule$default(r0, r1, r2, r4, r5)     // Catch:{ all -> 0x013a }
        L_0x0124:
            monitor-exit(r9)
            return
        L_0x0126:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x013a }
            throw r1
        L_0x012a:
            java.lang.String r10 = "Check failed."
            java.lang.IllegalStateException r11 = new java.lang.IllegalStateException     // Catch:{ all -> 0x013a }
            java.lang.String r10 = r10.toString()     // Catch:{ all -> 0x013a }
            r11.<init>(r10)     // Catch:{ all -> 0x013a }
            throw r11     // Catch:{ all -> 0x013a }
        L_0x0136:
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)     // Catch:{ all -> 0x013a }
            throw r1
        L_0x013a:
            r10 = move-exception
            monitor-exit(r9)
            throw r10
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.completeEdit$okhttp(okhttp3.internal.cache.DiskLruCache$Editor, boolean):void");
    }

    public final void delete() throws IOException {
        close();
        this.fileSystem.deleteContents(this.directory);
    }

    public final Editor edit(String str) throws IOException {
        return edit$default(this, str, 0, 2, (Object) null);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0028, code lost:
        return null;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized okhttp3.internal.cache.DiskLruCache.Editor edit(java.lang.String r9, long r10) throws java.io.IOException {
        /*
            r8 = this;
            monitor-enter(r8)
            java.lang.String r0 = "key"
            r1 = 0
            if (r9 == 0) goto L_0x0087
            r8.initialize()     // Catch:{ all -> 0x008b }
            r8.checkNotClosed()     // Catch:{ all -> 0x008b }
            r8.validateKey(r9)     // Catch:{ all -> 0x008b }
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r0 = r8.lruEntries     // Catch:{ all -> 0x008b }
            java.lang.Object r0 = r0.get(r9)     // Catch:{ all -> 0x008b }
            okhttp3.internal.cache.DiskLruCache$Entry r0 = (okhttp3.internal.cache.DiskLruCache.Entry) r0     // Catch:{ all -> 0x008b }
            long r2 = ANY_SEQUENCE_NUMBER     // Catch:{ all -> 0x008b }
            int r4 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1))
            if (r4 == 0) goto L_0x0029
            if (r0 == 0) goto L_0x0027
            long r2 = r0.getSequenceNumber$okhttp()     // Catch:{ all -> 0x008b }
            int r4 = (r2 > r10 ? 1 : (r2 == r10 ? 0 : -1))
            if (r4 == 0) goto L_0x0029
        L_0x0027:
            monitor-exit(r8)
            return r1
        L_0x0029:
            if (r0 == 0) goto L_0x0030
            okhttp3.internal.cache.DiskLruCache$Editor r10 = r0.getCurrentEditor$okhttp()     // Catch:{ all -> 0x008b }
            goto L_0x0031
        L_0x0030:
            r10 = r1
        L_0x0031:
            if (r10 == 0) goto L_0x0035
            monitor-exit(r8)
            return r1
        L_0x0035:
            boolean r10 = r8.mostRecentTrimFailed     // Catch:{ all -> 0x008b }
            if (r10 != 0) goto L_0x007a
            boolean r10 = r8.mostRecentRebuildFailed     // Catch:{ all -> 0x008b }
            if (r10 == 0) goto L_0x003e
            goto L_0x007a
        L_0x003e:
            g.f r10 = r8.journalWriter     // Catch:{ all -> 0x008b }
            if (r10 == 0) goto L_0x0076
            java.lang.String r11 = DIRTY     // Catch:{ all -> 0x008b }
            g.f r11 = r10.mo9468a((java.lang.String) r11)     // Catch:{ all -> 0x008b }
            r2 = 32
            g.f r11 = r11.writeByte(r2)     // Catch:{ all -> 0x008b }
            g.f r11 = r11.mo9468a((java.lang.String) r9)     // Catch:{ all -> 0x008b }
            r2 = 10
            r11.writeByte(r2)     // Catch:{ all -> 0x008b }
            r10.flush()     // Catch:{ all -> 0x008b }
            boolean r10 = r8.hasJournalErrors     // Catch:{ all -> 0x008b }
            if (r10 == 0) goto L_0x0060
            monitor-exit(r8)
            return r1
        L_0x0060:
            if (r0 != 0) goto L_0x006c
            okhttp3.internal.cache.DiskLruCache$Entry r0 = new okhttp3.internal.cache.DiskLruCache$Entry     // Catch:{ all -> 0x008b }
            r0.<init>(r8, r9)     // Catch:{ all -> 0x008b }
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r10 = r8.lruEntries     // Catch:{ all -> 0x008b }
            r10.put(r9, r0)     // Catch:{ all -> 0x008b }
        L_0x006c:
            okhttp3.internal.cache.DiskLruCache$Editor r9 = new okhttp3.internal.cache.DiskLruCache$Editor     // Catch:{ all -> 0x008b }
            r9.<init>(r8, r0)     // Catch:{ all -> 0x008b }
            r0.setCurrentEditor$okhttp(r9)     // Catch:{ all -> 0x008b }
            monitor-exit(r8)
            return r9
        L_0x0076:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x008b }
            throw r1
        L_0x007a:
            okhttp3.internal.concurrent.TaskQueue r2 = r8.cleanupQueue     // Catch:{ all -> 0x008b }
            okhttp3.internal.cache.DiskLruCache$cleanupTask$1 r3 = r8.cleanupTask     // Catch:{ all -> 0x008b }
            r4 = 0
            r6 = 2
            r7 = 0
            okhttp3.internal.concurrent.TaskQueue.schedule$default(r2, r3, r4, r6, r7)     // Catch:{ all -> 0x008b }
            monitor-exit(r8)
            return r1
        L_0x0087:
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)     // Catch:{ all -> 0x008b }
            throw r1
        L_0x008b:
            r9 = move-exception
            monitor-exit(r8)
            throw r9
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.edit(java.lang.String, long):okhttp3.internal.cache.DiskLruCache$Editor");
    }

    public final synchronized void evictAll() throws IOException {
        initialize();
        Collection<Entry> values = this.lruEntries.values();
        Intrinsics.m5821a((Object) values, "lruEntries.values");
        Object[] array = values.toArray(new Entry[0]);
        if (array != null) {
            for (Entry entry : (Entry[]) array) {
                Intrinsics.m5821a((Object) entry, "entry");
                removeEntry$okhttp(entry);
            }
            this.mostRecentTrimFailed = false;
        } else {
            throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
        }
    }

    public synchronized void flush() throws IOException {
        if (this.initialized) {
            checkNotClosed();
            trimToSize();
            BufferedSink fVar = this.journalWriter;
            if (fVar != null) {
                fVar.flush();
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x005d, code lost:
        return r0;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized okhttp3.internal.cache.DiskLruCache.Snapshot get(java.lang.String r8) throws java.io.IOException {
        /*
            r7 = this;
            monitor-enter(r7)
            java.lang.String r0 = "key"
            r1 = 0
            if (r8 == 0) goto L_0x0066
            r7.initialize()     // Catch:{ all -> 0x006a }
            r7.checkNotClosed()     // Catch:{ all -> 0x006a }
            r7.validateKey(r8)     // Catch:{ all -> 0x006a }
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r0 = r7.lruEntries     // Catch:{ all -> 0x006a }
            java.lang.Object r0 = r0.get(r8)     // Catch:{ all -> 0x006a }
            okhttp3.internal.cache.DiskLruCache$Entry r0 = (okhttp3.internal.cache.DiskLruCache.Entry) r0     // Catch:{ all -> 0x006a }
            if (r0 == 0) goto L_0x0064
            java.lang.String r2 = "lruEntries[key] ?: return null"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r0, (java.lang.String) r2)     // Catch:{ all -> 0x006a }
            boolean r2 = r0.getReadable$okhttp()     // Catch:{ all -> 0x006a }
            if (r2 != 0) goto L_0x0026
            monitor-exit(r7)
            return r1
        L_0x0026:
            okhttp3.internal.cache.DiskLruCache$Snapshot r0 = r0.snapshot$okhttp()     // Catch:{ all -> 0x006a }
            if (r0 == 0) goto L_0x0062
            int r2 = r7.redundantOpCount     // Catch:{ all -> 0x006a }
            int r2 = r2 + 1
            r7.redundantOpCount = r2     // Catch:{ all -> 0x006a }
            g.f r2 = r7.journalWriter     // Catch:{ all -> 0x006a }
            if (r2 == 0) goto L_0x005e
            java.lang.String r1 = READ     // Catch:{ all -> 0x006a }
            g.f r1 = r2.mo9468a((java.lang.String) r1)     // Catch:{ all -> 0x006a }
            r2 = 32
            g.f r1 = r1.writeByte(r2)     // Catch:{ all -> 0x006a }
            g.f r8 = r1.mo9468a((java.lang.String) r8)     // Catch:{ all -> 0x006a }
            r1 = 10
            r8.writeByte(r1)     // Catch:{ all -> 0x006a }
            boolean r8 = r7.journalRebuildRequired()     // Catch:{ all -> 0x006a }
            if (r8 == 0) goto L_0x005c
            okhttp3.internal.concurrent.TaskQueue r1 = r7.cleanupQueue     // Catch:{ all -> 0x006a }
            okhttp3.internal.cache.DiskLruCache$cleanupTask$1 r2 = r7.cleanupTask     // Catch:{ all -> 0x006a }
            r3 = 0
            r5 = 2
            r6 = 0
            okhttp3.internal.concurrent.TaskQueue.schedule$default(r1, r2, r3, r5, r6)     // Catch:{ all -> 0x006a }
        L_0x005c:
            monitor-exit(r7)
            return r0
        L_0x005e:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x006a }
            throw r1
        L_0x0062:
            monitor-exit(r7)
            return r1
        L_0x0064:
            monitor-exit(r7)
            return r1
        L_0x0066:
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)     // Catch:{ all -> 0x006a }
            throw r1
        L_0x006a:
            r8 = move-exception
            monitor-exit(r7)
            throw r8
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.get(java.lang.String):okhttp3.internal.cache.DiskLruCache$Snapshot");
    }

    public final boolean getClosed$okhttp() {
        return this.closed;
    }

    public final File getDirectory() {
        return this.directory;
    }

    public final FileSystem getFileSystem$okhttp() {
        return this.fileSystem;
    }

    public final LinkedHashMap<String, Entry> getLruEntries$okhttp() {
        return this.lruEntries;
    }

    public final synchronized long getMaxSize() {
        return this.maxSize;
    }

    public final int getValueCount$okhttp() {
        return this.valueCount;
    }

    public final synchronized void initialize() throws IOException {
        if (Util.assertionsEnabled) {
            if (!Thread.holdsLock(this)) {
                StringBuilder sb = new StringBuilder();
                sb.append("Thread ");
                Thread currentThread = Thread.currentThread();
                Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
                sb.append(currentThread.getName());
                sb.append(" MUST hold lock on ");
                sb.append(this);
                throw new AssertionError(sb.toString());
            }
        }
        if (!this.initialized) {
            if (this.fileSystem.exists(this.journalFileBackup)) {
                if (this.fileSystem.exists(this.journalFile)) {
                    this.fileSystem.delete(this.journalFileBackup);
                } else {
                    this.fileSystem.rename(this.journalFileBackup, this.journalFile);
                }
            }
            if (this.fileSystem.exists(this.journalFile)) {
                try {
                    readJournal();
                    processJournal();
                    this.initialized = true;
                    return;
                } catch (IOException e) {
                    Platform platform = Platform.Companion.get();
                    platform.log("DiskLruCache " + this.directory + " is corrupt: " + e.getMessage() + ", removing", 5, e);
                    delete();
                    this.closed = false;
                } catch (Throwable th) {
                    this.closed = false;
                    throw th;
                }
            }
            rebuildJournal$okhttp();
            this.initialized = true;
        }
    }

    public final synchronized boolean isClosed() {
        return this.closed;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:25:0x00be, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
        p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x00c2, code lost:
        throw r2;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized void rebuildJournal$okhttp() throws java.io.IOException {
        /*
            r7 = this;
            monitor-enter(r7)
            g.f r0 = r7.journalWriter     // Catch:{ all -> 0x00c3 }
            if (r0 == 0) goto L_0x0008
            r0.close()     // Catch:{ all -> 0x00c3 }
        L_0x0008:
            okhttp3.internal.io.FileSystem r0 = r7.fileSystem     // Catch:{ all -> 0x00c3 }
            java.io.File r1 = r7.journalFileTmp     // Catch:{ all -> 0x00c3 }
            g.x r0 = r0.sink(r1)     // Catch:{ all -> 0x00c3 }
            g.f r0 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4147a((p262g.Sink) r0)     // Catch:{ all -> 0x00c3 }
            r1 = 0
            java.lang.String r2 = MAGIC     // Catch:{ all -> 0x00bc }
            g.f r2 = r0.mo9468a((java.lang.String) r2)     // Catch:{ all -> 0x00bc }
            r3 = 10
            r2.writeByte(r3)     // Catch:{ all -> 0x00bc }
            java.lang.String r2 = VERSION_1     // Catch:{ all -> 0x00bc }
            g.f r2 = r0.mo9468a((java.lang.String) r2)     // Catch:{ all -> 0x00bc }
            r2.writeByte(r3)     // Catch:{ all -> 0x00bc }
            int r2 = r7.appVersion     // Catch:{ all -> 0x00bc }
            long r4 = (long) r2     // Catch:{ all -> 0x00bc }
            g.f r2 = r0.mo9493h(r4)     // Catch:{ all -> 0x00bc }
            r2.writeByte(r3)     // Catch:{ all -> 0x00bc }
            int r2 = r7.valueCount     // Catch:{ all -> 0x00bc }
            long r4 = (long) r2     // Catch:{ all -> 0x00bc }
            g.f r2 = r0.mo9493h(r4)     // Catch:{ all -> 0x00bc }
            r2.writeByte(r3)     // Catch:{ all -> 0x00bc }
            r0.writeByte(r3)     // Catch:{ all -> 0x00bc }
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r2 = r7.lruEntries     // Catch:{ all -> 0x00bc }
            java.util.Collection r2 = r2.values()     // Catch:{ all -> 0x00bc }
            java.util.Iterator r2 = r2.iterator()     // Catch:{ all -> 0x00bc }
        L_0x004a:
            boolean r4 = r2.hasNext()     // Catch:{ all -> 0x00bc }
            if (r4 == 0) goto L_0x0089
            java.lang.Object r4 = r2.next()     // Catch:{ all -> 0x00bc }
            okhttp3.internal.cache.DiskLruCache$Entry r4 = (okhttp3.internal.cache.DiskLruCache.Entry) r4     // Catch:{ all -> 0x00bc }
            okhttp3.internal.cache.DiskLruCache$Editor r5 = r4.getCurrentEditor$okhttp()     // Catch:{ all -> 0x00bc }
            r6 = 32
            if (r5 == 0) goto L_0x0072
            java.lang.String r5 = DIRTY     // Catch:{ all -> 0x00bc }
            g.f r5 = r0.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x00bc }
            r5.writeByte(r6)     // Catch:{ all -> 0x00bc }
            java.lang.String r4 = r4.getKey$okhttp()     // Catch:{ all -> 0x00bc }
            r0.mo9468a((java.lang.String) r4)     // Catch:{ all -> 0x00bc }
            r0.writeByte(r3)     // Catch:{ all -> 0x00bc }
            goto L_0x004a
        L_0x0072:
            java.lang.String r5 = CLEAN     // Catch:{ all -> 0x00bc }
            g.f r5 = r0.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x00bc }
            r5.writeByte(r6)     // Catch:{ all -> 0x00bc }
            java.lang.String r5 = r4.getKey$okhttp()     // Catch:{ all -> 0x00bc }
            r0.mo9468a((java.lang.String) r5)     // Catch:{ all -> 0x00bc }
            r4.writeLengths$okhttp(r0)     // Catch:{ all -> 0x00bc }
            r0.writeByte(r3)     // Catch:{ all -> 0x00bc }
            goto L_0x004a
        L_0x0089:
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, (java.lang.Throwable) r1)     // Catch:{ all -> 0x00c3 }
            okhttp3.internal.io.FileSystem r0 = r7.fileSystem     // Catch:{ all -> 0x00c3 }
            java.io.File r1 = r7.journalFile     // Catch:{ all -> 0x00c3 }
            boolean r0 = r0.exists(r1)     // Catch:{ all -> 0x00c3 }
            if (r0 == 0) goto L_0x009f
            okhttp3.internal.io.FileSystem r0 = r7.fileSystem     // Catch:{ all -> 0x00c3 }
            java.io.File r1 = r7.journalFile     // Catch:{ all -> 0x00c3 }
            java.io.File r2 = r7.journalFileBackup     // Catch:{ all -> 0x00c3 }
            r0.rename(r1, r2)     // Catch:{ all -> 0x00c3 }
        L_0x009f:
            okhttp3.internal.io.FileSystem r0 = r7.fileSystem     // Catch:{ all -> 0x00c3 }
            java.io.File r1 = r7.journalFileTmp     // Catch:{ all -> 0x00c3 }
            java.io.File r2 = r7.journalFile     // Catch:{ all -> 0x00c3 }
            r0.rename(r1, r2)     // Catch:{ all -> 0x00c3 }
            okhttp3.internal.io.FileSystem r0 = r7.fileSystem     // Catch:{ all -> 0x00c3 }
            java.io.File r1 = r7.journalFileBackup     // Catch:{ all -> 0x00c3 }
            r0.delete(r1)     // Catch:{ all -> 0x00c3 }
            g.f r0 = r7.newJournalWriter()     // Catch:{ all -> 0x00c3 }
            r7.journalWriter = r0     // Catch:{ all -> 0x00c3 }
            r0 = 0
            r7.hasJournalErrors = r0     // Catch:{ all -> 0x00c3 }
            r7.mostRecentRebuildFailed = r0     // Catch:{ all -> 0x00c3 }
            monitor-exit(r7)
            return
        L_0x00bc:
            r1 = move-exception
            throw r1     // Catch:{ all -> 0x00be }
        L_0x00be:
            r2 = move-exception
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, (java.lang.Throwable) r1)     // Catch:{ all -> 0x00c3 }
            throw r2     // Catch:{ all -> 0x00c3 }
        L_0x00c3:
            r0 = move-exception
            monitor-exit(r7)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.rebuildJournal$okhttp():void");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x002f, code lost:
        return r7;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final synchronized boolean remove(java.lang.String r7) throws java.io.IOException {
        /*
            r6 = this;
            monitor-enter(r6)
            java.lang.String r0 = "key"
            if (r7 == 0) goto L_0x0032
            r6.initialize()     // Catch:{ all -> 0x0037 }
            r6.checkNotClosed()     // Catch:{ all -> 0x0037 }
            r6.validateKey(r7)     // Catch:{ all -> 0x0037 }
            java.util.LinkedHashMap<java.lang.String, okhttp3.internal.cache.DiskLruCache$Entry> r0 = r6.lruEntries     // Catch:{ all -> 0x0037 }
            java.lang.Object r7 = r0.get(r7)     // Catch:{ all -> 0x0037 }
            okhttp3.internal.cache.DiskLruCache$Entry r7 = (okhttp3.internal.cache.DiskLruCache.Entry) r7     // Catch:{ all -> 0x0037 }
            r0 = 0
            if (r7 == 0) goto L_0x0030
            java.lang.String r1 = "lruEntries[key] ?: return false"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r7, (java.lang.String) r1)     // Catch:{ all -> 0x0037 }
            boolean r7 = r6.removeEntry$okhttp(r7)     // Catch:{ all -> 0x0037 }
            if (r7 == 0) goto L_0x002e
            long r1 = r6.size     // Catch:{ all -> 0x0037 }
            long r3 = r6.maxSize     // Catch:{ all -> 0x0037 }
            int r5 = (r1 > r3 ? 1 : (r1 == r3 ? 0 : -1))
            if (r5 > 0) goto L_0x002e
            r6.mostRecentTrimFailed = r0     // Catch:{ all -> 0x0037 }
        L_0x002e:
            monitor-exit(r6)
            return r7
        L_0x0030:
            monitor-exit(r6)
            return r0
        L_0x0032:
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)     // Catch:{ all -> 0x0037 }
            r7 = 0
            throw r7
        L_0x0037:
            r7 = move-exception
            monitor-exit(r6)
            throw r7
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache.DiskLruCache.remove(java.lang.String):boolean");
    }

    public final boolean removeEntry$okhttp(Entry entry) throws IOException {
        if (entry != null) {
            Editor currentEditor$okhttp = entry.getCurrentEditor$okhttp();
            if (currentEditor$okhttp != null) {
                currentEditor$okhttp.detach$okhttp();
            }
            int i = this.valueCount;
            for (int i2 = 0; i2 < i; i2++) {
                this.fileSystem.delete(entry.getCleanFiles$okhttp().get(i2));
                this.size -= entry.getLengths$okhttp()[i2];
                entry.getLengths$okhttp()[i2] = 0;
            }
            this.redundantOpCount++;
            BufferedSink fVar = this.journalWriter;
            if (fVar != null) {
                fVar.mo9468a(REMOVE).writeByte(32).mo9468a(entry.getKey$okhttp()).writeByte(10);
                this.lruEntries.remove(entry.getKey$okhttp());
                if (journalRebuildRequired()) {
                    TaskQueue.schedule$default(this.cleanupQueue, this.cleanupTask, 0, 2, (Object) null);
                }
                return true;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("entry");
        throw null;
    }

    public final void setClosed$okhttp(boolean z) {
        this.closed = z;
    }

    public final synchronized void setMaxSize(long j) {
        this.maxSize = j;
        if (this.initialized) {
            TaskQueue.schedule$default(this.cleanupQueue, this.cleanupTask, 0, 2, (Object) null);
        }
    }

    public final synchronized long size() throws IOException {
        initialize();
        return this.size;
    }

    public final synchronized Iterator<Snapshot> snapshots() throws IOException {
        initialize();
        return new DiskLruCache$snapshots$1(this);
    }

    public final void trimToSize() throws IOException {
        while (this.size > this.maxSize) {
            Entry next = this.lruEntries.values().iterator().next();
            Intrinsics.m5821a((Object) next, "lruEntries.values.iterator().next()");
            removeEntry$okhttp(next);
        }
        this.mostRecentTrimFailed = false;
    }
}
