package okhttp3.internal.cache2;

import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.channels.FileChannel;
import okhttp3.internal.Util;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.C1948d;
import p262g.C1952h;
import p262g.Source;
import p262g.Timeout;

/* compiled from: Relay.kt */
public final class Relay {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final long FILE_HEADER_SIZE = 32;
    public static final C1952h PREFIX_CLEAN = C1952h.f7659f.mo9552c("OkHttp cache v1\n");
    public static final C1952h PREFIX_DIRTY = C1952h.f7659f.mo9552c("OkHttp DIRTY :(\n");
    public static final int SOURCE_FILE = 2;
    public static final int SOURCE_UPSTREAM = 1;
    public final C1948d buffer;
    public final long bufferMaxSize;
    public boolean complete;
    public RandomAccessFile file;
    public final C1952h metadata;
    public int sourceCount;
    public Source upstream;
    public final C1948d upstreamBuffer;
    public long upstreamPos;
    public Thread upstreamReader;

    /* compiled from: Relay.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Relay edit(File file, Source zVar, C1952h hVar, long j) throws IOException {
            if (file == null) {
                Intrinsics.m5822a("file");
                throw null;
            } else if (zVar == null) {
                Intrinsics.m5822a("upstream");
                throw null;
            } else if (hVar != null) {
                RandomAccessFile randomAccessFile = new RandomAccessFile(file, "rw");
                Relay relay = new Relay(randomAccessFile, zVar, 0, hVar, j, (DefaultConstructorMarker) null);
                randomAccessFile.setLength(0);
                relay.writeHeader(Relay.PREFIX_DIRTY, -1, -1);
                return relay;
            } else {
                Intrinsics.m5822a("metadata");
                throw null;
            }
        }

        public final Relay read(File file) throws IOException {
            if (file != null) {
                RandomAccessFile randomAccessFile = new RandomAccessFile(file, "rw");
                FileChannel channel = randomAccessFile.getChannel();
                Intrinsics.m5821a((Object) channel, "randomAccessFile.channel");
                FileOperator fileOperator = new FileOperator(channel);
                C1948d dVar = new C1948d();
                fileOperator.read(0, dVar, 32);
                if (!(!Intrinsics.m5823a((Object) dVar.mo9477b((long) Relay.PREFIX_CLEAN.mo9540b()), (Object) Relay.PREFIX_CLEAN))) {
                    long readLong = dVar.readLong();
                    long readLong2 = dVar.readLong();
                    C1948d dVar2 = new C1948d();
                    fileOperator.read(readLong + 32, dVar2, readLong2);
                    return new Relay(randomAccessFile, (Source) null, readLong, dVar2.mo9486e(), 0, (DefaultConstructorMarker) null);
                }
                throw new IOException("unreadable cache file");
            }
            Intrinsics.m5822a("file");
            throw null;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: Relay.kt */
    public final class RelaySource implements Source {
        public FileOperator fileOperator;
        public long sourcePos;
        public final Timeout timeout = new Timeout();

        public RelaySource() {
            RandomAccessFile file = Relay.this.getFile();
            if (file != null) {
                FileChannel channel = file.getChannel();
                Intrinsics.m5821a((Object) channel, "file!!.channel");
                this.fileOperator = new FileOperator(channel);
                return;
            }
            Intrinsics.m5820a();
            throw null;
        }

        public void close() throws IOException {
            if (this.fileOperator != null) {
                RandomAccessFile randomAccessFile = null;
                this.fileOperator = null;
                synchronized (Relay.this) {
                    Relay relay = Relay.this;
                    relay.setSourceCount(relay.getSourceCount() - 1);
                    if (Relay.this.getSourceCount() == 0) {
                        RandomAccessFile file = Relay.this.getFile();
                        Relay.this.setFile((RandomAccessFile) null);
                        randomAccessFile = file;
                    }
                }
                if (randomAccessFile != null) {
                    Util.closeQuietly((Closeable) randomAccessFile);
                }
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:100:0x01a6, code lost:
            throw new p250f.TypeCastException("null cannot be cast to non-null type java.lang.Object");
         */
        /* JADX WARNING: Code restructure failed: missing block: B:101:0x01a7, code lost:
            r3.notifyAll();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:103:0x01ab, code lost:
            throw r0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:30:0x0084, code lost:
            if (r5 != 2) goto L_0x00aa;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:31:0x0086, code lost:
            r2 = java.lang.Math.min(r2, r1.this$0.getUpstreamPos() - r1.sourcePos);
            r5 = r1.fileOperator;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:32:0x0095, code lost:
            if (r5 == null) goto L_0x00a6;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:33:0x0097, code lost:
            r5.read(r1.sourcePos + 32, r23, r2);
            r1.sourcePos += r2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:34:0x00a5, code lost:
            return r2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:35:0x00a6, code lost:
            p250f.p254l.p256c.Intrinsics.m5820a();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:36:0x00a9, code lost:
            throw null;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:38:?, code lost:
            r0 = r1.this$0.getUpstream();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:39:0x00b0, code lost:
            if (r0 == null) goto L_0x018e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:40:0x00b2, code lost:
            r9 = r0.read(r1.this$0.getUpstreamBuffer(), r1.this$0.getBufferMaxSize());
         */
        /* JADX WARNING: Code restructure failed: missing block: B:41:0x00c4, code lost:
            if (r9 != -1) goto L_0x00ed;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:42:0x00c6, code lost:
            r1.this$0.commit(r1.this$0.getUpstreamPos());
         */
        /* JADX WARNING: Code restructure failed: missing block: B:43:0x00d1, code lost:
            r2 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:44:0x00d3, code lost:
            monitor-enter(r2);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:46:?, code lost:
            r1.this$0.setUpstreamReader((java.lang.Thread) null);
            r0 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:47:0x00db, code lost:
            if (r0 == null) goto L_0x00e2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:48:0x00dd, code lost:
            r0.notifyAll();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:49:0x00e0, code lost:
            monitor-exit(r2);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:50:0x00e1, code lost:
            return -1;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:53:0x00e9, code lost:
            throw new p250f.TypeCastException("null cannot be cast to non-null type java.lang.Object");
         */
        /* JADX WARNING: Code restructure failed: missing block: B:58:?, code lost:
            r2 = java.lang.Math.min(r9, r2);
            r11 = r9;
            r1.this$0.getUpstreamBuffer().mo9466a(r23, 0, r2);
            r1.sourcePos += r2;
            r0 = r1.fileOperator;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:59:0x0107, code lost:
            if (r0 == null) goto L_0x018a;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:60:0x0109, code lost:
            r0.write(r1.this$0.getUpstreamPos() + 32, r1.this$0.getUpstreamBuffer().clone(), r11);
            r5 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:61:0x0124, code lost:
            monitor-enter(r5);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:63:?, code lost:
            r1.this$0.getBuffer().write(r1.this$0.getUpstreamBuffer(), r11);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:64:0x0144, code lost:
            if (r1.this$0.getBuffer().f7648c <= r1.this$0.getBufferMaxSize()) goto L_0x0161;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:65:0x0146, code lost:
            r1.this$0.getBuffer().skip(r1.this$0.getBuffer().f7648c - r1.this$0.getBufferMaxSize());
         */
        /* JADX WARNING: Code restructure failed: missing block: B:66:0x015f, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:68:0x0161, code lost:
            r0 = r1.this$0;
            r0.setUpstreamPos(r0.getUpstreamPos() + r11);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:70:?, code lost:
            monitor-exit(r5);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:71:0x016c, code lost:
            r5 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:72:0x016e, code lost:
            monitor-enter(r5);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:74:?, code lost:
            r1.this$0.setUpstreamReader((java.lang.Thread) null);
            r0 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:75:0x0176, code lost:
            if (r0 == null) goto L_0x017d;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:76:0x0178, code lost:
            r0.notifyAll();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:77:0x017b, code lost:
            monitor-exit(r5);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:78:0x017c, code lost:
            return r2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:81:0x0184, code lost:
            throw new p250f.TypeCastException("null cannot be cast to non-null type java.lang.Object");
         */
        /* JADX WARNING: Code restructure failed: missing block: B:87:0x0189, code lost:
            throw r0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:88:0x018a, code lost:
            p250f.p254l.p256c.Intrinsics.m5820a();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:89:0x018d, code lost:
            throw null;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:91:?, code lost:
            p250f.p254l.p256c.Intrinsics.m5820a();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:92:0x0191, code lost:
            throw null;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:93:0x0192, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:95:0x0195, code lost:
            monitor-enter(r1.this$0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:97:?, code lost:
            r1.this$0.setUpstreamReader((java.lang.Thread) null);
            r3 = r1.this$0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:98:0x019d, code lost:
            if (r3 == null) goto L_0x019f;
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public long read(p262g.C1948d r23, long r24) throws java.io.IOException {
            /*
                r22 = this;
                r1 = r22
                r2 = r24
                r4 = 0
                if (r23 == 0) goto L_0x01be
                okhttp3.internal.cache2.FileOperator r0 = r1.fileOperator
                r5 = 1
                if (r0 == 0) goto L_0x000e
                r0 = 1
                goto L_0x000f
            L_0x000e:
                r0 = 0
            L_0x000f:
                if (r0 == 0) goto L_0x01b2
                okhttp3.internal.cache2.Relay r11 = okhttp3.internal.cache2.Relay.this
                monitor-enter(r11)
            L_0x0014:
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                long r6 = r0.getUpstreamPos()     // Catch:{ all -> 0x01af }
                long r8 = r1.sourcePos     // Catch:{ all -> 0x01af }
                r0 = 2
                r12 = -1
                int r10 = (r8 > r6 ? 1 : (r8 == r6 ? 0 : -1))
                if (r10 == 0) goto L_0x005e
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                long r5 = r5.getUpstreamPos()     // Catch:{ all -> 0x01af }
                okhttp3.internal.cache2.Relay r7 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                g.d r7 = r7.getBuffer()     // Catch:{ all -> 0x01af }
                long r7 = r7.f7648c     // Catch:{ all -> 0x01af }
                long r5 = r5 - r7
                long r7 = r1.sourcePos     // Catch:{ all -> 0x01af }
                int r9 = (r7 > r5 ? 1 : (r7 == r5 ? 0 : -1))
                if (r9 >= 0) goto L_0x003a
                r5 = 2
                goto L_0x0081
            L_0x003a:
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                long r7 = r0.getUpstreamPos()     // Catch:{ all -> 0x01af }
                long r9 = r1.sourcePos     // Catch:{ all -> 0x01af }
                long r7 = r7 - r9
                long r2 = java.lang.Math.min(r2, r7)     // Catch:{ all -> 0x01af }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                g.d r0 = r0.getBuffer()     // Catch:{ all -> 0x01af }
                long r7 = r1.sourcePos     // Catch:{ all -> 0x01af }
                long r7 = r7 - r5
                r5 = r0
                r6 = r23
                r9 = r2
                r5.mo9466a((p262g.C1948d) r6, (long) r7, (long) r9)     // Catch:{ all -> 0x01af }
                long r4 = r1.sourcePos     // Catch:{ all -> 0x01af }
                long r4 = r4 + r2
                r1.sourcePos = r4     // Catch:{ all -> 0x01af }
                monitor-exit(r11)
                return r2
            L_0x005e:
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                boolean r6 = r6.getComplete()     // Catch:{ all -> 0x01af }
                if (r6 == 0) goto L_0x0068
                monitor-exit(r11)
                return r12
            L_0x0068:
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                java.lang.Thread r6 = r6.getUpstreamReader()     // Catch:{ all -> 0x01af }
                if (r6 == 0) goto L_0x0078
                g.a0 r0 = r1.timeout     // Catch:{ all -> 0x01af }
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                r0.waitUntilNotified(r6)     // Catch:{ all -> 0x01af }
                goto L_0x0014
            L_0x0078:
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01af }
                java.lang.Thread r7 = java.lang.Thread.currentThread()     // Catch:{ all -> 0x01af }
                r6.setUpstreamReader(r7)     // Catch:{ all -> 0x01af }
            L_0x0081:
                monitor-exit(r11)
                r14 = 32
                if (r5 != r0) goto L_0x00aa
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this
                long r5 = r0.getUpstreamPos()
                long r7 = r1.sourcePos
                long r5 = r5 - r7
                long r2 = java.lang.Math.min(r2, r5)
                okhttp3.internal.cache2.FileOperator r5 = r1.fileOperator
                if (r5 == 0) goto L_0x00a6
                long r6 = r1.sourcePos
                long r6 = r6 + r14
                r8 = r23
                r9 = r2
                r5.read(r6, r8, r9)
                long r4 = r1.sourcePos
                long r4 = r4 + r2
                r1.sourcePos = r4
                return r2
            L_0x00a6:
                p250f.p254l.p256c.Intrinsics.m5820a()
                throw r4
            L_0x00aa:
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                g.z r0 = r0.getUpstream()     // Catch:{ all -> 0x0192 }
                if (r0 == 0) goto L_0x018e
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                g.d r5 = r5.getUpstreamBuffer()     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                long r6 = r6.getBufferMaxSize()     // Catch:{ all -> 0x0192 }
                long r9 = r0.read(r5, r6)     // Catch:{ all -> 0x0192 }
                int r0 = (r9 > r12 ? 1 : (r9 == r12 ? 0 : -1))
                if (r0 != 0) goto L_0x00ed
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r2 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                long r2 = r2.getUpstreamPos()     // Catch:{ all -> 0x0192 }
                r0.commit(r2)     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r2 = okhttp3.internal.cache2.Relay.this
                monitor-enter(r2)
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x00ea }
                r0.setUpstreamReader(r4)     // Catch:{ all -> 0x00ea }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x00ea }
                if (r0 == 0) goto L_0x00e2
                r0.notifyAll()     // Catch:{ all -> 0x00ea }
                monitor-exit(r2)
                return r12
            L_0x00e2:
                f.e r0 = new f.e     // Catch:{ all -> 0x00ea }
                java.lang.String r3 = "null cannot be cast to non-null type java.lang.Object"
                r0.<init>(r3)     // Catch:{ all -> 0x00ea }
                throw r0     // Catch:{ all -> 0x00ea }
            L_0x00ea:
                r0 = move-exception
                monitor-exit(r2)
                throw r0
            L_0x00ed:
                long r2 = java.lang.Math.min(r9, r2)     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                g.d r5 = r0.getUpstreamBuffer()     // Catch:{ all -> 0x0192 }
                r7 = 0
                r6 = r23
                r11 = r9
                r9 = r2
                r5.mo9466a((p262g.C1948d) r6, (long) r7, (long) r9)     // Catch:{ all -> 0x0192 }
                long r5 = r1.sourcePos     // Catch:{ all -> 0x0192 }
                long r5 = r5 + r2
                r1.sourcePos = r5     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.FileOperator r0 = r1.fileOperator     // Catch:{ all -> 0x0192 }
                if (r0 == 0) goto L_0x018a
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                long r5 = r5.getUpstreamPos()     // Catch:{ all -> 0x0192 }
                long r17 = r5 + r14
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                g.d r5 = r5.getUpstreamBuffer()     // Catch:{ all -> 0x0192 }
                g.d r19 = r5.clone()     // Catch:{ all -> 0x0192 }
                r16 = r0
                r20 = r11
                r16.write(r17, r19, r20)     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0192 }
                monitor-enter(r5)     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                g.d r0 = r0.getBuffer()     // Catch:{ all -> 0x015f }
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                g.d r6 = r6.getUpstreamBuffer()     // Catch:{ all -> 0x015f }
                r0.write(r6, r11)     // Catch:{ all -> 0x015f }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                g.d r0 = r0.getBuffer()     // Catch:{ all -> 0x015f }
                long r6 = r0.f7648c     // Catch:{ all -> 0x015f }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                long r8 = r0.getBufferMaxSize()     // Catch:{ all -> 0x015f }
                int r0 = (r6 > r8 ? 1 : (r6 == r8 ? 0 : -1))
                if (r0 <= 0) goto L_0x0161
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                g.d r0 = r0.getBuffer()     // Catch:{ all -> 0x015f }
                okhttp3.internal.cache2.Relay r6 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                g.d r6 = r6.getBuffer()     // Catch:{ all -> 0x015f }
                long r6 = r6.f7648c     // Catch:{ all -> 0x015f }
                okhttp3.internal.cache2.Relay r8 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                long r8 = r8.getBufferMaxSize()     // Catch:{ all -> 0x015f }
                long r6 = r6 - r8
                r0.skip(r6)     // Catch:{ all -> 0x015f }
                goto L_0x0161
            L_0x015f:
                r0 = move-exception
                goto L_0x0188
            L_0x0161:
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x015f }
                long r6 = r0.getUpstreamPos()     // Catch:{ all -> 0x015f }
                long r6 = r6 + r11
                r0.setUpstreamPos(r6)     // Catch:{ all -> 0x015f }
                monitor-exit(r5)     // Catch:{ all -> 0x0192 }
                okhttp3.internal.cache2.Relay r5 = okhttp3.internal.cache2.Relay.this
                monitor-enter(r5)
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0185 }
                r0.setUpstreamReader(r4)     // Catch:{ all -> 0x0185 }
                okhttp3.internal.cache2.Relay r0 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x0185 }
                if (r0 == 0) goto L_0x017d
                r0.notifyAll()     // Catch:{ all -> 0x0185 }
                monitor-exit(r5)
                return r2
            L_0x017d:
                f.e r0 = new f.e     // Catch:{ all -> 0x0185 }
                java.lang.String r2 = "null cannot be cast to non-null type java.lang.Object"
                r0.<init>(r2)     // Catch:{ all -> 0x0185 }
                throw r0     // Catch:{ all -> 0x0185 }
            L_0x0185:
                r0 = move-exception
                monitor-exit(r5)
                throw r0
            L_0x0188:
                monitor-exit(r5)     // Catch:{ all -> 0x0192 }
                throw r0     // Catch:{ all -> 0x0192 }
            L_0x018a:
                p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0192 }
                throw r4
            L_0x018e:
                p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0192 }
                throw r4
            L_0x0192:
                r0 = move-exception
                okhttp3.internal.cache2.Relay r2 = okhttp3.internal.cache2.Relay.this
                monitor-enter(r2)
                okhttp3.internal.cache2.Relay r3 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01ac }
                r3.setUpstreamReader(r4)     // Catch:{ all -> 0x01ac }
                okhttp3.internal.cache2.Relay r3 = okhttp3.internal.cache2.Relay.this     // Catch:{ all -> 0x01ac }
                if (r3 != 0) goto L_0x01a7
                f.e r0 = new f.e     // Catch:{ all -> 0x01ac }
                java.lang.String r3 = "null cannot be cast to non-null type java.lang.Object"
                r0.<init>(r3)     // Catch:{ all -> 0x01ac }
                throw r0     // Catch:{ all -> 0x01ac }
            L_0x01a7:
                r3.notifyAll()     // Catch:{ all -> 0x01ac }
                monitor-exit(r2)
                throw r0
            L_0x01ac:
                r0 = move-exception
                monitor-exit(r2)
                throw r0
            L_0x01af:
                r0 = move-exception
                monitor-exit(r11)
                throw r0
            L_0x01b2:
                java.lang.IllegalStateException r0 = new java.lang.IllegalStateException
                java.lang.String r2 = "Check failed."
                java.lang.String r2 = r2.toString()
                r0.<init>(r2)
                throw r0
            L_0x01be:
                java.lang.String r0 = "sink"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)
                throw r4
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.cache2.Relay.RelaySource.read(g.d, long):long");
        }

        public Timeout timeout() {
            return this.timeout;
        }
    }

    public Relay(RandomAccessFile randomAccessFile, Source zVar, long j, C1952h hVar, long j2) {
        this.file = randomAccessFile;
        this.upstream = zVar;
        this.upstreamPos = j;
        this.metadata = hVar;
        this.bufferMaxSize = j2;
        this.upstreamBuffer = new C1948d();
        this.complete = this.upstream == null;
        this.buffer = new C1948d();
    }

    /* access modifiers changed from: private */
    public final void writeHeader(C1952h hVar, long j, long j2) throws IOException {
        C1948d dVar = new C1948d();
        dVar.mo9467a(hVar);
        dVar.mo9499j(j);
        dVar.mo9499j(j2);
        if (dVar.f7648c == 32) {
            RandomAccessFile randomAccessFile = this.file;
            if (randomAccessFile != null) {
                FileChannel channel = randomAccessFile.getChannel();
                Intrinsics.m5821a((Object) channel, "file!!.channel");
                new FileOperator(channel).write(0, dVar, 32);
                return;
            }
            Intrinsics.m5820a();
            throw null;
        }
        throw new IllegalArgumentException("Failed requirement.".toString());
    }

    private final void writeMetadata(long j) throws IOException {
        C1948d dVar = new C1948d();
        dVar.mo9467a(this.metadata);
        RandomAccessFile randomAccessFile = this.file;
        if (randomAccessFile != null) {
            FileChannel channel = randomAccessFile.getChannel();
            Intrinsics.m5821a((Object) channel, "file!!.channel");
            new FileOperator(channel).write(32 + j, dVar, (long) this.metadata.mo9540b());
            return;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final void commit(long j) throws IOException {
        writeMetadata(j);
        RandomAccessFile randomAccessFile = this.file;
        if (randomAccessFile != null) {
            randomAccessFile.getChannel().force(false);
            writeHeader(PREFIX_CLEAN, j, (long) this.metadata.mo9540b());
            RandomAccessFile randomAccessFile2 = this.file;
            if (randomAccessFile2 != null) {
                randomAccessFile2.getChannel().force(false);
                synchronized (this) {
                    this.complete = true;
                }
                Source zVar = this.upstream;
                if (zVar != null) {
                    Util.closeQuietly((Closeable) zVar);
                }
                this.upstream = null;
                return;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final C1948d getBuffer() {
        return this.buffer;
    }

    public final long getBufferMaxSize() {
        return this.bufferMaxSize;
    }

    public final boolean getComplete() {
        return this.complete;
    }

    public final RandomAccessFile getFile() {
        return this.file;
    }

    public final int getSourceCount() {
        return this.sourceCount;
    }

    public final Source getUpstream() {
        return this.upstream;
    }

    public final C1948d getUpstreamBuffer() {
        return this.upstreamBuffer;
    }

    public final long getUpstreamPos() {
        return this.upstreamPos;
    }

    public final Thread getUpstreamReader() {
        return this.upstreamReader;
    }

    public final boolean isClosed() {
        return this.file == null;
    }

    public final C1952h metadata() {
        return this.metadata;
    }

    public final Source newSource() {
        synchronized (this) {
            if (this.file == null) {
                return null;
            }
            this.sourceCount++;
            return new RelaySource();
        }
    }

    public final void setComplete(boolean z) {
        this.complete = z;
    }

    public final void setFile(RandomAccessFile randomAccessFile) {
        this.file = randomAccessFile;
    }

    public final void setSourceCount(int i) {
        this.sourceCount = i;
    }

    public final void setUpstream(Source zVar) {
        this.upstream = zVar;
    }

    public final void setUpstreamPos(long j) {
        this.upstreamPos = j;
    }

    public final void setUpstreamReader(Thread thread) {
        this.upstreamReader = thread;
    }

    public /* synthetic */ Relay(RandomAccessFile randomAccessFile, Source zVar, long j, C1952h hVar, long j2, DefaultConstructorMarker fVar) {
        this(randomAccessFile, zVar, j, hVar, j2);
    }
}
