package okhttp3.internal.concurrent;

import com.newrelic.agent.android.harvest.HarvestConfiguration;
import com.newrelic.agent.android.util.Reachability;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;
import okhttp3.internal.http2.Http2Connection;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: TaskLogger.kt */
public final class TaskLoggerKt {
    public static final String formatDuration(long j) {
        String str;
        if (j <= ((long) -999500000)) {
            str = ((j - ((long) 500000000)) / ((long) Http2Connection.DEGRADED_PONG_TIMEOUT_NS)) + " s ";
        } else if (j <= ((long) -999500)) {
            str = ((j - ((long) 500000)) / ((long) 1000000)) + " ms";
        } else if (j <= 0) {
            str = ((j - ((long) Reachability.REACHABILITY_TIMEOUT)) / ((long) HarvestConfiguration.DEFAULT_MAX_TRANSACTION_COUNT)) + " µs";
        } else if (j < ((long) 999500)) {
            str = ((j + ((long) Reachability.REACHABILITY_TIMEOUT)) / ((long) HarvestConfiguration.DEFAULT_MAX_TRANSACTION_COUNT)) + " µs";
        } else if (j < ((long) 999500000)) {
            str = ((j + ((long) 500000)) / ((long) 1000000)) + " ms";
        } else {
            str = ((j + ((long) 500000000)) / ((long) Http2Connection.DEGRADED_PONG_TIMEOUT_NS)) + " s ";
        }
        String format = String.format("%6s", Arrays.copyOf(new Object[]{str}, 1));
        Intrinsics.m5821a((Object) format, "java.lang.String.format(format, *args)");
        return format;
    }

    public static final void log(Task task, TaskQueue taskQueue, String str) {
        Logger logger = TaskRunner.Companion.getLogger();
        StringBuilder sb = new StringBuilder();
        sb.append(taskQueue.getName$okhttp());
        sb.append(SafeJsonPrimitive.NULL_CHAR);
        String format = String.format("%-22s", Arrays.copyOf(new Object[]{str}, 1));
        Intrinsics.m5821a((Object) format, "java.lang.String.format(format, *args)");
        sb.append(format);
        sb.append(": ");
        sb.append(task.getName());
        logger.fine(sb.toString());
    }

    public static final <T> T logElapsed(Task task, TaskQueue taskQueue, C1896a<? extends T> aVar) {
        if (task == null) {
            Intrinsics.m5822a("task");
            throw null;
        } else if (taskQueue == null) {
            Intrinsics.m5822a("queue");
            throw null;
        } else if (aVar != null) {
            long j = -1;
            boolean isLoggable = TaskRunner.Companion.getLogger().isLoggable(Level.FINE);
            if (isLoggable) {
                j = taskQueue.getTaskRunner$okhttp().getBackend().nanoTime();
                log(task, taskQueue, "starting");
            }
            try {
                T invoke = aVar.invoke();
                if (isLoggable) {
                    long nanoTime = taskQueue.getTaskRunner$okhttp().getBackend().nanoTime() - j;
                    StringBuilder a = outline.m2937a("finished run in ");
                    a.append(formatDuration(nanoTime));
                    log(task, taskQueue, a.toString());
                }
                return invoke;
            } catch (Throwable th) {
                if (isLoggable) {
                    long nanoTime2 = taskQueue.getTaskRunner$okhttp().getBackend().nanoTime() - j;
                    StringBuilder a2 = outline.m2937a("failed a run in ");
                    a2.append(formatDuration(nanoTime2));
                    log(task, taskQueue, a2.toString());
                }
                throw th;
            }
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    public static final void taskLog(Task task, TaskQueue taskQueue, C1896a<String> aVar) {
        if (task == null) {
            Intrinsics.m5822a("task");
            throw null;
        } else if (taskQueue == null) {
            Intrinsics.m5822a("queue");
            throw null;
        } else if (aVar == null) {
            Intrinsics.m5822a("messageBlock");
            throw null;
        } else if (TaskRunner.Companion.getLogger().isLoggable(Level.FINE)) {
            log(task, taskQueue, aVar.invoke());
        }
    }
}
