package okhttp3.internal.concurrent;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.logging.Level;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p250f.Unit;
import p250f.p251i._Arrays;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: TaskQueue.kt */
public final class TaskQueue {
    public Task activeTask;
    public boolean cancelActiveTask;
    public final List<Task> futureTasks;
    public final String name;
    public boolean shutdown;
    public final TaskRunner taskRunner;

    /* compiled from: TaskQueue.kt */
    public static final class AwaitIdleTask extends Task {
        public final CountDownLatch latch = new CountDownLatch(1);

        public AwaitIdleTask() {
            super(outline.m2935a(new StringBuilder(), Util.okHttpName, " awaitIdle"), false);
        }

        public final CountDownLatch getLatch() {
            return this.latch;
        }

        public long runOnce() {
            this.latch.countDown();
            return -1;
        }
    }

    public TaskQueue(TaskRunner taskRunner2, String str) {
        if (taskRunner2 == null) {
            Intrinsics.m5822a("taskRunner");
            throw null;
        } else if (str != null) {
            this.taskRunner = taskRunner2;
            this.name = str;
            this.futureTasks = new ArrayList();
        } else {
            Intrinsics.m5822a("name");
            throw null;
        }
    }

    public static /* synthetic */ void execute$default(TaskQueue taskQueue, String str, long j, boolean z, C1896a aVar, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        boolean z2 = (i & 4) != 0 ? true : z;
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (aVar != null) {
            taskQueue.schedule(new TaskQueue$execute$1(aVar, str, z2, str, z2), j);
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    public static /* synthetic */ void schedule$default(TaskQueue taskQueue, Task task, long j, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        taskQueue.schedule(task, j);
    }

    public final void cancelAll() {
        if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            synchronized (this.taskRunner) {
                if (cancelAllAndDecide$okhttp()) {
                    this.taskRunner.kickCoordinator$okhttp(this);
                }
            }
            return;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST NOT hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    public final boolean cancelAllAndDecide$okhttp() {
        Task task = this.activeTask;
        if (task != null) {
            if (task == null) {
                Intrinsics.m5820a();
                throw null;
            } else if (task.getCancelable()) {
                this.cancelActiveTask = true;
            }
        }
        boolean z = false;
        for (int size = this.futureTasks.size() - 1; size >= 0; size--) {
            if (this.futureTasks.get(size).getCancelable()) {
                Task task2 = this.futureTasks.get(size);
                if (TaskRunner.Companion.getLogger().isLoggable(Level.FINE)) {
                    TaskLoggerKt.log(task2, this, "canceled");
                }
                this.futureTasks.remove(size);
                z = true;
            }
        }
        return z;
    }

    public final void execute(String str, long j, boolean z, C1896a<Unit> aVar) {
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (aVar != null) {
            schedule(new TaskQueue$execute$1(aVar, str, z, str, z), j);
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    public final Task getActiveTask$okhttp() {
        return this.activeTask;
    }

    public final boolean getCancelActiveTask$okhttp() {
        return this.cancelActiveTask;
    }

    public final List<Task> getFutureTasks$okhttp() {
        return this.futureTasks;
    }

    public final String getName$okhttp() {
        return this.name;
    }

    public final List<Task> getScheduledTasks() {
        List<Task> a;
        synchronized (this.taskRunner) {
            a = _Arrays.m5803a(this.futureTasks);
        }
        return a;
    }

    public final boolean getShutdown$okhttp() {
        return this.shutdown;
    }

    public final TaskRunner getTaskRunner$okhttp() {
        return this.taskRunner;
    }

    public final CountDownLatch idleLatch() {
        synchronized (this.taskRunner) {
            if (this.activeTask != null || !this.futureTasks.isEmpty()) {
                Task task = this.activeTask;
                if (task instanceof AwaitIdleTask) {
                    CountDownLatch latch = ((AwaitIdleTask) task).getLatch();
                    return latch;
                }
                for (Task next : this.futureTasks) {
                    if (next instanceof AwaitIdleTask) {
                        CountDownLatch latch2 = ((AwaitIdleTask) next).getLatch();
                        return latch2;
                    }
                }
                AwaitIdleTask awaitIdleTask = new AwaitIdleTask();
                if (scheduleAndDecide$okhttp(awaitIdleTask, 0, false)) {
                    this.taskRunner.kickCoordinator$okhttp(this);
                }
                CountDownLatch latch3 = awaitIdleTask.getLatch();
                return latch3;
            }
            CountDownLatch countDownLatch = new CountDownLatch(0);
            return countDownLatch;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0023, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x004a, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void schedule(okhttp3.internal.concurrent.Task r3, long r4) {
        /*
            r2 = this;
            if (r3 == 0) goto L_0x004e
            okhttp3.internal.concurrent.TaskRunner r0 = r2.taskRunner
            monitor-enter(r0)
            boolean r1 = r2.shutdown     // Catch:{ all -> 0x004b }
            if (r1 == 0) goto L_0x003d
            boolean r4 = r3.getCancelable()     // Catch:{ all -> 0x004b }
            if (r4 == 0) goto L_0x0024
            okhttp3.internal.concurrent.TaskRunner$Companion r4 = okhttp3.internal.concurrent.TaskRunner.Companion     // Catch:{ all -> 0x004b }
            java.util.logging.Logger r4 = r4.getLogger()     // Catch:{ all -> 0x004b }
            java.util.logging.Level r5 = java.util.logging.Level.FINE     // Catch:{ all -> 0x004b }
            boolean r4 = r4.isLoggable(r5)     // Catch:{ all -> 0x004b }
            if (r4 == 0) goto L_0x0022
            java.lang.String r4 = "schedule canceled (queue is shutdown)"
            okhttp3.internal.concurrent.TaskLoggerKt.log(r3, r2, r4)     // Catch:{ all -> 0x004b }
        L_0x0022:
            monitor-exit(r0)
            return
        L_0x0024:
            okhttp3.internal.concurrent.TaskRunner$Companion r4 = okhttp3.internal.concurrent.TaskRunner.Companion     // Catch:{ all -> 0x004b }
            java.util.logging.Logger r4 = r4.getLogger()     // Catch:{ all -> 0x004b }
            java.util.logging.Level r5 = java.util.logging.Level.FINE     // Catch:{ all -> 0x004b }
            boolean r4 = r4.isLoggable(r5)     // Catch:{ all -> 0x004b }
            if (r4 == 0) goto L_0x0037
            java.lang.String r4 = "schedule failed (queue is shutdown)"
            okhttp3.internal.concurrent.TaskLoggerKt.log(r3, r2, r4)     // Catch:{ all -> 0x004b }
        L_0x0037:
            java.util.concurrent.RejectedExecutionException r3 = new java.util.concurrent.RejectedExecutionException     // Catch:{ all -> 0x004b }
            r3.<init>()     // Catch:{ all -> 0x004b }
            throw r3     // Catch:{ all -> 0x004b }
        L_0x003d:
            r1 = 0
            boolean r3 = r2.scheduleAndDecide$okhttp(r3, r4, r1)     // Catch:{ all -> 0x004b }
            if (r3 == 0) goto L_0x0049
            okhttp3.internal.concurrent.TaskRunner r3 = r2.taskRunner     // Catch:{ all -> 0x004b }
            r3.kickCoordinator$okhttp(r2)     // Catch:{ all -> 0x004b }
        L_0x0049:
            monitor-exit(r0)
            return
        L_0x004b:
            r3 = move-exception
            monitor-exit(r0)
            throw r3
        L_0x004e:
            java.lang.String r3 = "task"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r3)
            r3 = 0
            throw r3
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.concurrent.TaskQueue.schedule(okhttp3.internal.concurrent.Task, long):void");
    }

    public final boolean scheduleAndDecide$okhttp(Task task, long j, boolean z) {
        String str;
        if (task != null) {
            task.initQueue$okhttp(this);
            long nanoTime = this.taskRunner.getBackend().nanoTime();
            long j2 = nanoTime + j;
            int indexOf = this.futureTasks.indexOf(task);
            if (indexOf != -1) {
                if (task.getNextExecuteNanoTime$okhttp() <= j2) {
                    if (TaskRunner.Companion.getLogger().isLoggable(Level.FINE)) {
                        TaskLoggerKt.log(task, this, "already scheduled");
                    }
                    return false;
                }
                this.futureTasks.remove(indexOf);
            }
            task.setNextExecuteNanoTime$okhttp(j2);
            if (TaskRunner.Companion.getLogger().isLoggable(Level.FINE)) {
                if (z) {
                    StringBuilder a = outline.m2937a("run again after ");
                    a.append(TaskLoggerKt.formatDuration(j2 - nanoTime));
                    str = a.toString();
                } else {
                    StringBuilder a2 = outline.m2937a("scheduled after ");
                    a2.append(TaskLoggerKt.formatDuration(j2 - nanoTime));
                    str = a2.toString();
                }
                TaskLoggerKt.log(task, this, str);
            }
            Iterator<Task> it = this.futureTasks.iterator();
            int i = 0;
            while (true) {
                if (!it.hasNext()) {
                    i = -1;
                    break;
                }
                if (it.next().getNextExecuteNanoTime$okhttp() - nanoTime > j) {
                    break;
                }
                i++;
            }
            if (i == -1) {
                i = this.futureTasks.size();
            }
            this.futureTasks.add(i, task);
            if (i == 0) {
                return true;
            }
            return false;
        }
        Intrinsics.m5822a("task");
        throw null;
    }

    public final void setActiveTask$okhttp(Task task) {
        this.activeTask = task;
    }

    public final void setCancelActiveTask$okhttp(boolean z) {
        this.cancelActiveTask = z;
    }

    public final void setShutdown$okhttp(boolean z) {
        this.shutdown = z;
    }

    public final void shutdown() {
        if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            synchronized (this.taskRunner) {
                this.shutdown = true;
                if (cancelAllAndDecide$okhttp()) {
                    this.taskRunner.kickCoordinator$okhttp(this);
                }
            }
            return;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST NOT hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    public String toString() {
        return this.name;
    }

    public static /* synthetic */ void schedule$default(TaskQueue taskQueue, String str, long j, C1896a aVar, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (aVar != null) {
            taskQueue.schedule(new TaskQueue$schedule$2(aVar, str, str), j);
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }

    public final void schedule(String str, long j, C1896a<Long> aVar) {
        if (str == null) {
            Intrinsics.m5822a("name");
            throw null;
        } else if (aVar != null) {
            schedule(new TaskQueue$schedule$2(aVar, str, str), j);
        } else {
            Intrinsics.m5822a("block");
            throw null;
        }
    }
}
