package okhttp3.internal.connection;

import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.ProtocolException;
import java.net.UnknownServiceException;
import java.security.cert.CertificateException;
import java.util.Arrays;
import java.util.List;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSocket;
import okhttp3.ConnectionSpec;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: ConnectionSpecSelector.kt */
public final class ConnectionSpecSelector {
    public final List<ConnectionSpec> connectionSpecs;
    public boolean isFallback;
    public boolean isFallbackPossible;
    public int nextModeIndex;

    public ConnectionSpecSelector(List<ConnectionSpec> list) {
        if (list != null) {
            this.connectionSpecs = list;
        } else {
            Intrinsics.m5822a("connectionSpecs");
            throw null;
        }
    }

    private final boolean isFallbackPossible(SSLSocket sSLSocket) {
        int size = this.connectionSpecs.size();
        for (int i = this.nextModeIndex; i < size; i++) {
            if (this.connectionSpecs.get(i).isCompatible(sSLSocket)) {
                return true;
            }
        }
        return false;
    }

    public final ConnectionSpec configureSecureSocket(SSLSocket sSLSocket) throws IOException {
        ConnectionSpec connectionSpec;
        if (sSLSocket != null) {
            int i = this.nextModeIndex;
            int size = this.connectionSpecs.size();
            while (true) {
                if (i >= size) {
                    connectionSpec = null;
                    break;
                }
                connectionSpec = this.connectionSpecs.get(i);
                if (connectionSpec.isCompatible(sSLSocket)) {
                    this.nextModeIndex = i + 1;
                    break;
                }
                i++;
            }
            if (connectionSpec == null) {
                StringBuilder a = outline.m2937a("Unable to find acceptable protocols. isFallback=");
                a.append(this.isFallback);
                a.append(',');
                a.append(" modes=");
                a.append(this.connectionSpecs);
                a.append(',');
                a.append(" supported protocols=");
                String[] enabledProtocols = sSLSocket.getEnabledProtocols();
                if (enabledProtocols == null) {
                    Intrinsics.m5820a();
                    throw null;
                }
                String arrays = Arrays.toString(enabledProtocols);
                Intrinsics.m5821a((Object) arrays, "java.util.Arrays.toString(this)");
                a.append(arrays);
                throw new UnknownServiceException(a.toString());
            }
            this.isFallbackPossible = isFallbackPossible(sSLSocket);
            connectionSpec.apply$okhttp(sSLSocket, this.isFallback);
            return connectionSpec;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public final boolean connectionFailed(IOException iOException) {
        if (iOException != null) {
            this.isFallback = true;
            if (this.isFallbackPossible && !(iOException instanceof ProtocolException) && !(iOException instanceof InterruptedIOException) && ((!(iOException instanceof SSLHandshakeException) || !(iOException.getCause() instanceof CertificateException)) && !(iOException instanceof SSLPeerUnverifiedException) && (iOException instanceof SSLException))) {
                return true;
            }
            return false;
        }
        Intrinsics.m5822a("e");
        throw null;
    }
}
