package okhttp3.internal.connection;

import java.io.IOException;
import java.io.InterruptedIOException;
import java.lang.ref.Reference;
import java.lang.ref.WeakReference;
import java.net.Socket;
import java.util.Iterator;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSocketFactory;
import okhttp3.Address;
import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.CertificatePinner;
import okhttp3.Dispatcher;
import okhttp3.EventListener;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.internal.platform.Platform;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.Intrinsics;
import p262g.AsyncTimeout;

/* compiled from: RealCall.kt */
public final class RealCall implements Call {
    public Object callStackTrace;
    public boolean canceled;
    public final OkHttpClient client;
    public RealConnection connection;
    public final RealConnectionPool connectionPool;
    public final EventListener eventListener;
    public Exchange exchange;
    public ExchangeFinder exchangeFinder;
    public boolean exchangeRequestDone;
    public boolean exchangeResponseDone;
    public boolean executed;
    public final boolean forWebSocket;
    public Exchange interceptorScopedExchange;
    public boolean noMoreExchanges;
    public final Request originalRequest;
    public final RealCall$timeout$1 timeout;
    public boolean timeoutEarlyExit;

    /* compiled from: RealCall.kt */
    public final class AsyncCall implements Runnable {
        public volatile AtomicInteger callsPerHost;
        public final Callback responseCallback;
        public final /* synthetic */ RealCall this$0;

        public AsyncCall(RealCall realCall, Callback callback) {
            if (callback != null) {
                this.this$0 = realCall;
                this.responseCallback = callback;
                this.callsPerHost = new AtomicInteger(0);
                return;
            }
            Intrinsics.m5822a("responseCallback");
            throw null;
        }

        public final void executeOn(ExecutorService executorService) {
            if (executorService != null) {
                Dispatcher dispatcher = this.this$0.getClient().dispatcher();
                if (!Util.assertionsEnabled || !Thread.holdsLock(dispatcher)) {
                    try {
                        executorService.execute(this);
                    } catch (RejectedExecutionException e) {
                        InterruptedIOException interruptedIOException = new InterruptedIOException("executor rejected");
                        interruptedIOException.initCause(e);
                        this.this$0.noMoreExchanges$okhttp(interruptedIOException);
                        this.responseCallback.onFailure(this.this$0, interruptedIOException);
                        this.this$0.getClient().dispatcher().finished$okhttp(this);
                    } catch (Throwable th) {
                        this.this$0.getClient().dispatcher().finished$okhttp(this);
                        throw th;
                    }
                } else {
                    StringBuilder a = outline.m2937a("Thread ");
                    Thread currentThread = Thread.currentThread();
                    Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
                    a.append(currentThread.getName());
                    a.append(" MUST NOT hold lock on ");
                    a.append(dispatcher);
                    throw new AssertionError(a.toString());
                }
            } else {
                Intrinsics.m5822a("executorService");
                throw null;
            }
        }

        public final RealCall getCall() {
            return this.this$0;
        }

        public final AtomicInteger getCallsPerHost() {
            return this.callsPerHost;
        }

        public final String getHost() {
            return this.this$0.getOriginalRequest().url().host();
        }

        public final Request getRequest() {
            return this.this$0.getOriginalRequest();
        }

        public final void reuseCallsPerHostFrom(AsyncCall asyncCall) {
            if (asyncCall != null) {
                this.callsPerHost = asyncCall.callsPerHost;
            } else {
                Intrinsics.m5822a("other");
                throw null;
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:18:0x0052 A[Catch:{ all -> 0x0073, all -> 0x00be }] */
        /* JADX WARNING: Removed duplicated region for block: B:25:0x0079 A[Catch:{ all -> 0x0073, all -> 0x00be }] */
        /* JADX WARNING: Removed duplicated region for block: B:26:0x009b A[Catch:{ all -> 0x0073, all -> 0x00be }] */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public void run() {
            /*
                r6 = this;
                java.lang.String r0 = "OkHttp "
                java.lang.StringBuilder r0 = p085c.p086a.p087a.p088a.outline.m2937a(r0)
                okhttp3.internal.connection.RealCall r1 = r6.this$0
                java.lang.String r1 = r1.redactedUrl$okhttp()
                r0.append(r1)
                java.lang.String r0 = r0.toString()
                java.lang.Thread r1 = java.lang.Thread.currentThread()
                java.lang.String r2 = "currentThread"
                p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r1, (java.lang.String) r2)
                java.lang.String r2 = r1.getName()
                r1.setName(r0)
                okhttp3.internal.connection.RealCall r0 = r6.this$0     // Catch:{ all -> 0x00be }
                okhttp3.internal.connection.RealCall$timeout$1 r0 = r0.timeout     // Catch:{ all -> 0x00be }
                r0.enter()     // Catch:{ all -> 0x00be }
                okhttp3.internal.connection.RealCall r0 = r6.this$0     // Catch:{ IOException -> 0x0075, all -> 0x0049 }
                okhttp3.Response r0 = r0.getResponseWithInterceptorChain$okhttp()     // Catch:{ IOException -> 0x0075, all -> 0x0049 }
                r3 = 1
                okhttp3.Callback r4 = r6.responseCallback     // Catch:{ IOException -> 0x0047, all -> 0x0045 }
                okhttp3.internal.connection.RealCall r5 = r6.this$0     // Catch:{ IOException -> 0x0047, all -> 0x0045 }
                r4.onResponse(r5, r0)     // Catch:{ IOException -> 0x0047, all -> 0x0045 }
                okhttp3.internal.connection.RealCall r0 = r6.this$0     // Catch:{ all -> 0x00be }
                okhttp3.OkHttpClient r0 = r0.getClient()     // Catch:{ all -> 0x00be }
            L_0x0040:
                okhttp3.Dispatcher r0 = r0.dispatcher()     // Catch:{ all -> 0x00be }
                goto L_0x00a9
            L_0x0045:
                r0 = move-exception
                goto L_0x004b
            L_0x0047:
                r0 = move-exception
                goto L_0x0077
            L_0x0049:
                r0 = move-exception
                r3 = 0
            L_0x004b:
                okhttp3.internal.connection.RealCall r4 = r6.this$0     // Catch:{ all -> 0x0073 }
                r4.cancel()     // Catch:{ all -> 0x0073 }
                if (r3 != 0) goto L_0x0072
                java.io.IOException r3 = new java.io.IOException     // Catch:{ all -> 0x0073 }
                java.lang.StringBuilder r4 = new java.lang.StringBuilder     // Catch:{ all -> 0x0073 }
                r4.<init>()     // Catch:{ all -> 0x0073 }
                java.lang.String r5 = "canceled due to "
                r4.append(r5)     // Catch:{ all -> 0x0073 }
                r4.append(r0)     // Catch:{ all -> 0x0073 }
                java.lang.String r4 = r4.toString()     // Catch:{ all -> 0x0073 }
                r3.<init>(r4)     // Catch:{ all -> 0x0073 }
                r3.addSuppressed(r0)     // Catch:{ all -> 0x0073 }
                okhttp3.Callback r4 = r6.responseCallback     // Catch:{ all -> 0x0073 }
                okhttp3.internal.connection.RealCall r5 = r6.this$0     // Catch:{ all -> 0x0073 }
                r4.onFailure(r5, r3)     // Catch:{ all -> 0x0073 }
            L_0x0072:
                throw r0     // Catch:{ all -> 0x0073 }
            L_0x0073:
                r0 = move-exception
                goto L_0x00b0
            L_0x0075:
                r0 = move-exception
                r3 = 0
            L_0x0077:
                if (r3 == 0) goto L_0x009b
                okhttp3.internal.platform.Platform$Companion r3 = okhttp3.internal.platform.Platform.Companion     // Catch:{ all -> 0x0073 }
                okhttp3.internal.platform.Platform r3 = r3.get()     // Catch:{ all -> 0x0073 }
                java.lang.StringBuilder r4 = new java.lang.StringBuilder     // Catch:{ all -> 0x0073 }
                r4.<init>()     // Catch:{ all -> 0x0073 }
                java.lang.String r5 = "Callback failure for "
                r4.append(r5)     // Catch:{ all -> 0x0073 }
                okhttp3.internal.connection.RealCall r5 = r6.this$0     // Catch:{ all -> 0x0073 }
                java.lang.String r5 = r5.toLoggableString()     // Catch:{ all -> 0x0073 }
                r4.append(r5)     // Catch:{ all -> 0x0073 }
                java.lang.String r4 = r4.toString()     // Catch:{ all -> 0x0073 }
                r5 = 4
                r3.log(r4, r5, r0)     // Catch:{ all -> 0x0073 }
                goto L_0x00a2
            L_0x009b:
                okhttp3.Callback r3 = r6.responseCallback     // Catch:{ all -> 0x0073 }
                okhttp3.internal.connection.RealCall r4 = r6.this$0     // Catch:{ all -> 0x0073 }
                r3.onFailure(r4, r0)     // Catch:{ all -> 0x0073 }
            L_0x00a2:
                okhttp3.internal.connection.RealCall r0 = r6.this$0     // Catch:{ all -> 0x00be }
                okhttp3.OkHttpClient r0 = r0.getClient()     // Catch:{ all -> 0x00be }
                goto L_0x0040
            L_0x00a9:
                r0.finished$okhttp((okhttp3.internal.connection.RealCall.AsyncCall) r6)     // Catch:{ all -> 0x00be }
                r1.setName(r2)
                return
            L_0x00b0:
                okhttp3.internal.connection.RealCall r3 = r6.this$0     // Catch:{ all -> 0x00be }
                okhttp3.OkHttpClient r3 = r3.getClient()     // Catch:{ all -> 0x00be }
                okhttp3.Dispatcher r3 = r3.dispatcher()     // Catch:{ all -> 0x00be }
                r3.finished$okhttp((okhttp3.internal.connection.RealCall.AsyncCall) r6)     // Catch:{ all -> 0x00be }
                throw r0     // Catch:{ all -> 0x00be }
            L_0x00be:
                r0 = move-exception
                r1.setName(r2)
                throw r0
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealCall.AsyncCall.run():void");
        }
    }

    /* compiled from: RealCall.kt */
    public static final class CallReference extends WeakReference<RealCall> {
        public final Object callStackTrace;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public CallReference(RealCall realCall, Object obj) {
            super(realCall);
            if (realCall != null) {
                this.callStackTrace = obj;
                return;
            }
            Intrinsics.m5822a("referent");
            throw null;
        }

        public final Object getCallStackTrace() {
            return this.callStackTrace;
        }
    }

    public RealCall(OkHttpClient okHttpClient, Request request, boolean z) {
        if (okHttpClient == null) {
            Intrinsics.m5822a("client");
            throw null;
        } else if (request != null) {
            this.client = okHttpClient;
            this.originalRequest = request;
            this.forWebSocket = z;
            this.connectionPool = okHttpClient.connectionPool().getDelegate$okhttp();
            this.eventListener = this.client.eventListenerFactory().create(this);
            RealCall$timeout$1 realCall$timeout$1 = new RealCall$timeout$1(this);
            realCall$timeout$1.timeout((long) this.client.callTimeoutMillis(), TimeUnit.MILLISECONDS);
            this.timeout = realCall$timeout$1;
        } else {
            Intrinsics.m5822a("originalRequest");
            throw null;
        }
    }

    private final void callStart() {
        this.callStackTrace = Platform.Companion.get().getStackTraceForCloseable("response.body().close()");
        this.eventListener.callStart(this);
    }

    private final Address createAddress(HttpUrl httpUrl) {
        CertificatePinner certificatePinner;
        HostnameVerifier hostnameVerifier;
        SSLSocketFactory sSLSocketFactory;
        if (httpUrl.isHttps()) {
            SSLSocketFactory sslSocketFactory = this.client.sslSocketFactory();
            hostnameVerifier = this.client.hostnameVerifier();
            sSLSocketFactory = sslSocketFactory;
            certificatePinner = this.client.certificatePinner();
        } else {
            sSLSocketFactory = null;
            hostnameVerifier = null;
            certificatePinner = null;
        }
        return new Address(httpUrl.host(), httpUrl.port(), this.client.dns(), this.client.socketFactory(), sSLSocketFactory, hostnameVerifier, certificatePinner, this.client.proxyAuthenticator(), this.client.proxy(), this.client.protocols(), this.client.connectionSpecs(), this.client.proxySelector());
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x0014 A[Catch:{ all -> 0x000e }] */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x0071  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final <E extends java.io.IOException> E maybeReleaseConnection(E r7, boolean r8) {
        /*
            r6 = this;
            okhttp3.internal.connection.RealConnectionPool r0 = r6.connectionPool
            monitor-enter(r0)
            r1 = 0
            r2 = 1
            if (r8 == 0) goto L_0x0011
            okhttp3.internal.connection.Exchange r3 = r6.exchange     // Catch:{ all -> 0x000e }
            if (r3 != 0) goto L_0x000c
            goto L_0x0011
        L_0x000c:
            r3 = 0
            goto L_0x0012
        L_0x000e:
            r7 = move-exception
            goto L_0x007d
        L_0x0011:
            r3 = 1
        L_0x0012:
            if (r3 == 0) goto L_0x0071
            okhttp3.internal.connection.RealConnection r3 = r6.connection     // Catch:{ all -> 0x000e }
            okhttp3.internal.connection.RealConnection r4 = r6.connection     // Catch:{ all -> 0x000e }
            r5 = 0
            if (r4 == 0) goto L_0x002a
            okhttp3.internal.connection.Exchange r4 = r6.exchange     // Catch:{ all -> 0x000e }
            if (r4 != 0) goto L_0x002a
            if (r8 != 0) goto L_0x0025
            boolean r8 = r6.noMoreExchanges     // Catch:{ all -> 0x000e }
            if (r8 == 0) goto L_0x002a
        L_0x0025:
            java.net.Socket r8 = r6.releaseConnectionNoEvents$okhttp()     // Catch:{ all -> 0x000e }
            goto L_0x002b
        L_0x002a:
            r8 = r5
        L_0x002b:
            okhttp3.internal.connection.RealConnection r4 = r6.connection     // Catch:{ all -> 0x000e }
            if (r4 == 0) goto L_0x0030
            r3 = r5
        L_0x0030:
            boolean r4 = r6.noMoreExchanges     // Catch:{ all -> 0x000e }
            if (r4 == 0) goto L_0x003a
            okhttp3.internal.connection.Exchange r4 = r6.exchange     // Catch:{ all -> 0x000e }
            if (r4 != 0) goto L_0x003a
            r4 = 1
            goto L_0x003b
        L_0x003a:
            r4 = 0
        L_0x003b:
            monitor-exit(r0)
            if (r8 == 0) goto L_0x0041
            okhttp3.internal.Util.closeQuietly((java.net.Socket) r8)
        L_0x0041:
            r8 = r3
            okhttp3.Connection r8 = (okhttp3.Connection) r8
            if (r8 == 0) goto L_0x0054
            okhttp3.EventListener r8 = r6.eventListener
            okhttp3.Connection r3 = (okhttp3.Connection) r3
            if (r3 == 0) goto L_0x0050
            r8.connectionReleased(r6, r3)
            goto L_0x0054
        L_0x0050:
            p250f.p254l.p256c.Intrinsics.m5820a()
            throw r5
        L_0x0054:
            if (r4 == 0) goto L_0x0070
            if (r7 == 0) goto L_0x0059
            r1 = 1
        L_0x0059:
            java.io.IOException r7 = r6.timeoutExit(r7)
            if (r1 == 0) goto L_0x006b
            okhttp3.EventListener r8 = r6.eventListener
            if (r7 == 0) goto L_0x0067
            r8.callFailed(r6, r7)
            goto L_0x0070
        L_0x0067:
            p250f.p254l.p256c.Intrinsics.m5820a()
            throw r5
        L_0x006b:
            okhttp3.EventListener r8 = r6.eventListener
            r8.callEnd(r6)
        L_0x0070:
            return r7
        L_0x0071:
            java.lang.String r7 = "cannot release connection while it is in use"
            java.lang.IllegalStateException r8 = new java.lang.IllegalStateException     // Catch:{ all -> 0x000e }
            java.lang.String r7 = r7.toString()     // Catch:{ all -> 0x000e }
            r8.<init>(r7)     // Catch:{ all -> 0x000e }
            throw r8     // Catch:{ all -> 0x000e }
        L_0x007d:
            monitor-exit(r0)
            throw r7
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealCall.maybeReleaseConnection(java.io.IOException, boolean):java.io.IOException");
    }

    private final <E extends IOException> E timeoutExit(E e) {
        if (this.timeoutEarlyExit || !this.timeout.exit()) {
            return e;
        }
        E interruptedIOException = new InterruptedIOException("timeout");
        if (e != null) {
            interruptedIOException.initCause(e);
        }
        return interruptedIOException;
    }

    /* access modifiers changed from: private */
    public final String toLoggableString() {
        StringBuilder sb = new StringBuilder();
        sb.append(isCanceled() ? "canceled " : "");
        sb.append(this.forWebSocket ? "web socket" : "call");
        sb.append(" to ");
        sb.append(redactedUrl$okhttp());
        return sb.toString();
    }

    public final void acquireConnectionNoEvents(RealConnection realConnection) {
        if (realConnection != null) {
            RealConnectionPool realConnectionPool = this.connectionPool;
            if (!Util.assertionsEnabled || Thread.holdsLock(realConnectionPool)) {
                if (this.connection == null) {
                    this.connection = realConnection;
                    realConnection.getCalls().add(new CallReference(this, this.callStackTrace));
                    return;
                }
                throw new IllegalStateException("Check failed.".toString());
            }
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(realConnectionPool);
            throw new AssertionError(a.toString());
        }
        Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
        throw null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x001c, code lost:
        if (r1 == null) goto L_0x0022;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x001e, code lost:
        r1.cancel();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0022, code lost:
        if (r2 == null) goto L_0x0027;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0024, code lost:
        r2.cancel();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0027, code lost:
        r3.eventListener.canceled(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x002c, code lost:
        return;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void cancel() {
        /*
            r3 = this;
            okhttp3.internal.connection.RealConnectionPool r0 = r3.connectionPool
            monitor-enter(r0)
            boolean r1 = r3.canceled     // Catch:{ all -> 0x002d }
            if (r1 == 0) goto L_0x0009
            monitor-exit(r0)
            return
        L_0x0009:
            r1 = 1
            r3.canceled = r1     // Catch:{ all -> 0x002d }
            okhttp3.internal.connection.Exchange r1 = r3.exchange     // Catch:{ all -> 0x002d }
            okhttp3.internal.connection.ExchangeFinder r2 = r3.exchangeFinder     // Catch:{ all -> 0x002d }
            if (r2 == 0) goto L_0x0019
            okhttp3.internal.connection.RealConnection r2 = r2.connectingConnection()     // Catch:{ all -> 0x002d }
            if (r2 == 0) goto L_0x0019
            goto L_0x001b
        L_0x0019:
            okhttp3.internal.connection.RealConnection r2 = r3.connection     // Catch:{ all -> 0x002d }
        L_0x001b:
            monitor-exit(r0)
            if (r1 == 0) goto L_0x0022
            r1.cancel()
            goto L_0x0027
        L_0x0022:
            if (r2 == 0) goto L_0x0027
            r2.cancel()
        L_0x0027:
            okhttp3.EventListener r0 = r3.eventListener
            r0.canceled(r3)
            return
        L_0x002d:
            r1 = move-exception
            monitor-exit(r0)
            throw r1
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealCall.cancel():void");
    }

    public void enqueue(Callback callback) {
        if (callback != null) {
            synchronized (this) {
                if (!this.executed) {
                    this.executed = true;
                } else {
                    throw new IllegalStateException("Already Executed".toString());
                }
            }
            callStart();
            this.client.dispatcher().enqueue$okhttp(new AsyncCall(this, callback));
            return;
        }
        Intrinsics.m5822a("responseCallback");
        throw null;
    }

    public final void enterNetworkInterceptorExchange(Request request, boolean z) {
        if (request != null) {
            boolean z2 = true;
            if (this.interceptorScopedExchange == null) {
                if (this.exchange != null) {
                    z2 = false;
                }
                if (!z2) {
                    throw new IllegalStateException("cannot make a new request because the previous response is still open: please call response.close()".toString());
                } else if (z) {
                    this.exchangeFinder = new ExchangeFinder(this.connectionPool, createAddress(request.url()), this, this.eventListener);
                }
            } else {
                throw new IllegalStateException("Check failed.".toString());
            }
        } else {
            Intrinsics.m5822a("request");
            throw null;
        }
    }

    public Response execute() {
        synchronized (this) {
            if (!this.executed) {
                this.executed = true;
            } else {
                throw new IllegalStateException("Already Executed".toString());
            }
        }
        this.timeout.enter();
        callStart();
        try {
            this.client.dispatcher().executed$okhttp(this);
            return getResponseWithInterceptorChain$okhttp();
        } finally {
            this.client.dispatcher().finished$okhttp(this);
        }
    }

    public final void exitNetworkInterceptorExchange$okhttp(boolean z) {
        boolean z2 = true;
        if (!this.noMoreExchanges) {
            if (z) {
                Exchange exchange2 = this.exchange;
                if (exchange2 != null) {
                    exchange2.detachWithViolence();
                }
                if (this.exchange != null) {
                    z2 = false;
                }
                if (!z2) {
                    throw new IllegalStateException("Check failed.".toString());
                }
            }
            this.interceptorScopedExchange = null;
            return;
        }
        throw new IllegalStateException("released".toString());
    }

    public final OkHttpClient getClient() {
        return this.client;
    }

    public final RealConnection getConnection() {
        return this.connection;
    }

    public final boolean getForWebSocket() {
        return this.forWebSocket;
    }

    public final Exchange getInterceptorScopedExchange$okhttp() {
        return this.interceptorScopedExchange;
    }

    public final Request getOriginalRequest() {
        return this.originalRequest;
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x00a2  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final okhttp3.Response getResponseWithInterceptorChain$okhttp() throws java.io.IOException {
        /*
            r10 = this;
            java.util.ArrayList r2 = new java.util.ArrayList
            r2.<init>()
            okhttp3.OkHttpClient r0 = r10.client
            java.util.List r0 = r0.interceptors()
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4187a(r2, r0)
            okhttp3.internal.http.RetryAndFollowUpInterceptor r0 = new okhttp3.internal.http.RetryAndFollowUpInterceptor
            okhttp3.OkHttpClient r1 = r10.client
            r0.<init>(r1)
            r2.add(r0)
            okhttp3.internal.http.BridgeInterceptor r0 = new okhttp3.internal.http.BridgeInterceptor
            okhttp3.OkHttpClient r1 = r10.client
            okhttp3.CookieJar r1 = r1.cookieJar()
            r0.<init>(r1)
            r2.add(r0)
            okhttp3.internal.cache.CacheInterceptor r0 = new okhttp3.internal.cache.CacheInterceptor
            okhttp3.OkHttpClient r1 = r10.client
            okhttp3.Cache r1 = r1.cache()
            r0.<init>(r1)
            r2.add(r0)
            okhttp3.internal.connection.ConnectInterceptor r0 = okhttp3.internal.connection.ConnectInterceptor.INSTANCE
            r2.add(r0)
            boolean r0 = r10.forWebSocket
            if (r0 != 0) goto L_0x0046
            okhttp3.OkHttpClient r0 = r10.client
            java.util.List r0 = r0.networkInterceptors()
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4187a(r2, r0)
        L_0x0046:
            okhttp3.internal.http.CallServerInterceptor r0 = new okhttp3.internal.http.CallServerInterceptor
            boolean r1 = r10.forWebSocket
            r0.<init>(r1)
            r2.add(r0)
            okhttp3.internal.http.RealInterceptorChain r9 = new okhttp3.internal.http.RealInterceptorChain
            r3 = 0
            r4 = 0
            okhttp3.Request r5 = r10.originalRequest
            okhttp3.OkHttpClient r0 = r10.client
            int r6 = r0.connectTimeoutMillis()
            okhttp3.OkHttpClient r0 = r10.client
            int r7 = r0.readTimeoutMillis()
            okhttp3.OkHttpClient r0 = r10.client
            int r8 = r0.writeTimeoutMillis()
            r0 = r9
            r1 = r10
            r0.<init>(r1, r2, r3, r4, r5, r6, r7, r8)
            r0 = 0
            r1 = 0
            okhttp3.Request r2 = r10.originalRequest     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            okhttp3.Response r2 = r9.proceed(r2)     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            boolean r3 = r10.isCanceled()     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            if (r3 != 0) goto L_0x007f
            r10.noMoreExchanges$okhttp(r1)
            return r2
        L_0x007f:
            okhttp3.internal.Util.closeQuietly((java.io.Closeable) r2)     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            java.io.IOException r2 = new java.io.IOException     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            java.lang.String r3 = "Canceled"
            r2.<init>(r3)     // Catch:{ IOException -> 0x008c, all -> 0x008a }
            throw r2     // Catch:{ IOException -> 0x008c, all -> 0x008a }
        L_0x008a:
            r2 = move-exception
            goto L_0x00a0
        L_0x008c:
            r0 = move-exception
            r2 = 1
            java.io.IOException r0 = r10.noMoreExchanges$okhttp(r0)     // Catch:{ all -> 0x009d }
            if (r0 != 0) goto L_0x009c
            f.e r0 = new f.e     // Catch:{ all -> 0x009d }
            java.lang.String r3 = "null cannot be cast to non-null type kotlin.Throwable"
            r0.<init>(r3)     // Catch:{ all -> 0x009d }
            throw r0     // Catch:{ all -> 0x009d }
        L_0x009c:
            throw r0     // Catch:{ all -> 0x009d }
        L_0x009d:
            r0 = move-exception
            r2 = r0
            r0 = 1
        L_0x00a0:
            if (r0 != 0) goto L_0x00a5
            r10.noMoreExchanges$okhttp(r1)
        L_0x00a5:
            throw r2
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealCall.getResponseWithInterceptorChain$okhttp():okhttp3.Response");
    }

    public final Exchange initExchange$okhttp(RealInterceptorChain realInterceptorChain) {
        if (realInterceptorChain != null) {
            synchronized (this.connectionPool) {
                boolean z = true;
                if (!this.noMoreExchanges) {
                    if (this.exchange != null) {
                        z = false;
                    }
                    if (!z) {
                        throw new IllegalStateException("Check failed.".toString());
                    }
                } else {
                    throw new IllegalStateException("released".toString());
                }
            }
            ExchangeFinder exchangeFinder2 = this.exchangeFinder;
            if (exchangeFinder2 != null) {
                ExchangeCodec find = exchangeFinder2.find(this.client, realInterceptorChain);
                EventListener eventListener2 = this.eventListener;
                ExchangeFinder exchangeFinder3 = this.exchangeFinder;
                if (exchangeFinder3 != null) {
                    Exchange exchange2 = new Exchange(this, eventListener2, exchangeFinder3, find);
                    this.interceptorScopedExchange = exchange2;
                    synchronized (this.connectionPool) {
                        this.exchange = exchange2;
                        this.exchangeRequestDone = false;
                        this.exchangeResponseDone = false;
                    }
                    return exchange2;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("chain");
        throw null;
    }

    public boolean isCanceled() {
        boolean z;
        synchronized (this.connectionPool) {
            z = this.canceled;
        }
        return z;
    }

    public synchronized boolean isExecuted() {
        return this.executed;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:32:0x0048, code lost:
        if (r2 == false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:?, code lost:
        return maybeReleaseConnection(r7, false);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:?, code lost:
        return r7;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final <E extends java.io.IOException> E messageDone$okhttp(okhttp3.internal.connection.Exchange r4, boolean r5, boolean r6, E r7) {
        /*
            r3 = this;
            r0 = 0
            if (r4 == 0) goto L_0x0052
            okhttp3.internal.connection.RealConnectionPool r1 = r3.connectionPool
            monitor-enter(r1)
            okhttp3.internal.connection.Exchange r2 = r3.exchange     // Catch:{ all -> 0x004f }
            boolean r4 = p250f.p254l.p256c.Intrinsics.m5823a((java.lang.Object) r4, (java.lang.Object) r2)     // Catch:{ all -> 0x004f }
            r2 = 1
            r4 = r4 ^ r2
            if (r4 == 0) goto L_0x0012
            monitor-exit(r1)
            return r7
        L_0x0012:
            r4 = 0
            if (r5 == 0) goto L_0x001b
            boolean r5 = r3.exchangeRequestDone     // Catch:{ all -> 0x004f }
            r5 = r5 ^ r2
            r3.exchangeRequestDone = r2     // Catch:{ all -> 0x004f }
            goto L_0x001c
        L_0x001b:
            r5 = 0
        L_0x001c:
            if (r6 == 0) goto L_0x0025
            boolean r6 = r3.exchangeResponseDone     // Catch:{ all -> 0x004f }
            if (r6 != 0) goto L_0x0023
            r5 = 1
        L_0x0023:
            r3.exchangeResponseDone = r2     // Catch:{ all -> 0x004f }
        L_0x0025:
            boolean r6 = r3.exchangeRequestDone     // Catch:{ all -> 0x004f }
            if (r6 == 0) goto L_0x0046
            boolean r6 = r3.exchangeResponseDone     // Catch:{ all -> 0x004f }
            if (r6 == 0) goto L_0x0046
            if (r5 == 0) goto L_0x0046
            okhttp3.internal.connection.Exchange r5 = r3.exchange     // Catch:{ all -> 0x004f }
            if (r5 == 0) goto L_0x0042
            okhttp3.internal.connection.RealConnection r5 = r5.getConnection$okhttp()     // Catch:{ all -> 0x004f }
            int r6 = r5.getSuccessCount$okhttp()     // Catch:{ all -> 0x004f }
            int r6 = r6 + r2
            r5.setSuccessCount$okhttp(r6)     // Catch:{ all -> 0x004f }
            r3.exchange = r0     // Catch:{ all -> 0x004f }
            goto L_0x0047
        L_0x0042:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x004f }
            throw r0
        L_0x0046:
            r2 = 0
        L_0x0047:
            monitor-exit(r1)
            if (r2 == 0) goto L_0x004e
            java.io.IOException r7 = r3.maybeReleaseConnection(r7, r4)
        L_0x004e:
            return r7
        L_0x004f:
            r4 = move-exception
            monitor-exit(r1)
            throw r4
        L_0x0052:
            java.lang.String r4 = "exchange"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r4)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealCall.messageDone$okhttp(okhttp3.internal.connection.Exchange, boolean, boolean, java.io.IOException):java.io.IOException");
    }

    public final IOException noMoreExchanges$okhttp(IOException iOException) {
        synchronized (this.connectionPool) {
            this.noMoreExchanges = true;
        }
        return maybeReleaseConnection(iOException, false);
    }

    public final String redactedUrl$okhttp() {
        return this.originalRequest.url().redact();
    }

    public final Socket releaseConnectionNoEvents$okhttp() {
        RealConnectionPool realConnectionPool = this.connectionPool;
        if (!Util.assertionsEnabled || Thread.holdsLock(realConnectionPool)) {
            RealConnection realConnection = this.connection;
            if (realConnection != null) {
                Iterator<Reference<RealCall>> it = realConnection.getCalls().iterator();
                boolean z = false;
                int i = 0;
                while (true) {
                    if (!it.hasNext()) {
                        i = -1;
                        break;
                    } else if (Intrinsics.m5823a((Object) (RealCall) it.next().get(), (Object) this)) {
                        break;
                    } else {
                        i++;
                    }
                }
                if (i != -1) {
                    z = true;
                }
                if (z) {
                    RealConnection realConnection2 = this.connection;
                    if (realConnection2 != null) {
                        realConnection2.getCalls().remove(i);
                        this.connection = null;
                        if (realConnection2.getCalls().isEmpty()) {
                            realConnection2.setIdleAtNs$okhttp(System.nanoTime());
                            if (this.connectionPool.connectionBecameIdle(realConnection2)) {
                                return realConnection2.socket();
                            }
                        }
                        return null;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                throw new IllegalStateException("Check failed.".toString());
            }
            Intrinsics.m5820a();
            throw null;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST hold lock on ");
        a.append(realConnectionPool);
        throw new AssertionError(a.toString());
    }

    public Request request() {
        return this.originalRequest;
    }

    public final boolean retryAfterFailure() {
        ExchangeFinder exchangeFinder2 = this.exchangeFinder;
        if (exchangeFinder2 != null) {
            return exchangeFinder2.retryAfterFailure();
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final void setConnection(RealConnection realConnection) {
        this.connection = realConnection;
    }

    public final void timeoutEarlyExit() {
        if (!this.timeoutEarlyExit) {
            this.timeoutEarlyExit = true;
            this.timeout.exit();
            return;
        }
        throw new IllegalStateException("Check failed.".toString());
    }

    public AsyncTimeout timeout() {
        return this.timeout;
    }

    public RealCall clone() {
        return new RealCall(this.client, this.originalRequest, this.forWebSocket);
    }
}
