package okhttp3.internal.connection;

import androidx.recyclerview.widget.RecyclerView;
import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.lang.ref.Reference;
import java.net.ConnectException;
import java.net.Proxy;
import java.net.Socket;
import java.net.SocketException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.SSLPeerUnverifiedException;
import okhttp3.Address;
import okhttp3.Call;
import okhttp3.CertificatePinner;
import okhttp3.Connection;
import okhttp3.EventListener;
import okhttp3.Handshake;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.Route;
import okhttp3.internal.Util;
import okhttp3.internal.Version;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http1.Http1ExchangeCodec;
import okhttp3.internal.http2.ConnectionShutdownException;
import okhttp3.internal.http2.ErrorCode;
import okhttp3.internal.http2.Http2Connection;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.internal.http2.Http2Stream;
import okhttp3.internal.http2.Settings;
import okhttp3.internal.http2.StreamResetException;
import okhttp3.internal.p270ws.RealWebSocket;
import okhttp3.internal.platform.Platform;
import okhttp3.internal.tls.OkHostnameVerifier;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSink;
import p262g.BufferedSource;

@Instrumented
/* compiled from: RealConnection.kt */
public final class RealConnection extends Http2Connection.Listener implements Connection {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final long IDLE_CONNECTION_HEALTHY_NS = 10000000000L;
    public static final int MAX_TUNNEL_ATTEMPTS = 21;
    public static final String NPE_THROW_WITH_NULL = "throw with null exception";
    public int allocationLimit;
    public final List<Reference<RealCall>> calls;
    public final RealConnectionPool connectionPool;
    public Handshake handshake;
    public Http2Connection http2Connection;
    public long idleAtNs;
    public boolean noCoalescedConnections;
    public boolean noNewExchanges;
    public Protocol protocol;
    public Socket rawSocket;
    public int refusedStreamCount;
    public final Route route;
    public int routeFailureCount;
    public BufferedSink sink;
    public Socket socket;
    public BufferedSource source;
    public int successCount;

    /* compiled from: RealConnection.kt */
    public static final class Companion {
        public Companion() {
        }

        public final RealConnection newTestConnection(RealConnectionPool realConnectionPool, Route route, Socket socket, long j) {
            if (realConnectionPool == null) {
                Intrinsics.m5822a("connectionPool");
                throw null;
            } else if (route == null) {
                Intrinsics.m5822a("route");
                throw null;
            } else if (socket != null) {
                RealConnection realConnection = new RealConnection(realConnectionPool, route);
                realConnection.socket = socket;
                realConnection.setIdleAtNs$okhttp(j);
                return realConnection;
            } else {
                Intrinsics.m5822a("socket");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public final /* synthetic */ class WhenMappings {
        public static final /* synthetic */ int[] $EnumSwitchMapping$0;

        static {
            int[] iArr = new int[Proxy.Type.values().length];
            $EnumSwitchMapping$0 = iArr;
            iArr[Proxy.Type.DIRECT.ordinal()] = 1;
            $EnumSwitchMapping$0[Proxy.Type.HTTP.ordinal()] = 2;
        }
    }

    public RealConnection(RealConnectionPool realConnectionPool, Route route2) {
        if (realConnectionPool == null) {
            Intrinsics.m5822a("connectionPool");
            throw null;
        } else if (route2 != null) {
            this.connectionPool = realConnectionPool;
            this.route = route2;
            this.allocationLimit = 1;
            this.calls = new ArrayList();
            this.idleAtNs = RecyclerView.FOREVER_NS;
        } else {
            Intrinsics.m5822a("route");
            throw null;
        }
    }

    private final boolean certificateSupportHost(HttpUrl httpUrl, Handshake handshake2) {
        List<Certificate> peerCertificates = handshake2.peerCertificates();
        if (!peerCertificates.isEmpty()) {
            OkHostnameVerifier okHostnameVerifier = OkHostnameVerifier.INSTANCE;
            String host = httpUrl.host();
            Certificate certificate = peerCertificates.get(0);
            if (certificate == null) {
                throw new TypeCastException("null cannot be cast to non-null type java.security.cert.X509Certificate");
            } else if (okHostnameVerifier.verify(host, (X509Certificate) certificate)) {
                return true;
            }
        }
        return false;
    }

    private final void connectSocket(int i, int i2, Call call, EventListener eventListener) throws IOException {
        Socket socket2;
        int i3;
        Proxy proxy = this.route.proxy();
        Address address = this.route.address();
        Proxy.Type type = proxy.type();
        if (type != null && ((i3 = WhenMappings.$EnumSwitchMapping$0[type.ordinal()]) == 1 || i3 == 2)) {
            socket2 = address.socketFactory().createSocket();
            if (socket2 == null) {
                Intrinsics.m5820a();
                throw null;
            }
        } else {
            socket2 = new Socket(proxy);
        }
        this.rawSocket = socket2;
        eventListener.connectStart(call, this.route.socketAddress(), proxy);
        socket2.setSoTimeout(i2);
        try {
            Platform.Companion.get().connectSocket(socket2, this.route.socketAddress(), i);
            try {
                this.source = C1050v.m4148a(C1050v.m4196b(socket2));
                this.sink = C1050v.m4147a(C1050v.m4151a(socket2));
            } catch (NullPointerException e) {
                if (Intrinsics.m5823a((Object) e.getMessage(), (Object) NPE_THROW_WITH_NULL)) {
                    throw new IOException(e);
                }
            }
        } catch (ConnectException e2) {
            StringBuilder a = outline.m2937a("Failed to connect to ");
            a.append(this.route.socketAddress());
            ConnectException connectException = new ConnectException(a.toString());
            connectException.initCause(e2);
            throw connectException;
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r2v1, resolved type: javax.net.ssl.SSLSocket} */
    /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r2v3, resolved type: java.lang.String} */
    /* JADX WARNING: type inference failed for: r2v0 */
    /* JADX WARNING: type inference failed for: r2v2 */
    /* JADX WARNING: type inference failed for: r2v6 */
    /* JADX WARNING: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x018c  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x0197  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final void connectTls(okhttp3.internal.connection.ConnectionSpecSelector r11) throws java.io.IOException {
        /*
            r10 = this;
            okhttp3.Route r0 = r10.route
            okhttp3.Address r0 = r0.address()
            javax.net.ssl.SSLSocketFactory r1 = r0.sslSocketFactory()
            r2 = 0
            if (r1 == 0) goto L_0x0186
            java.net.Socket r3 = r10.rawSocket     // Catch:{ all -> 0x0184 }
            okhttp3.HttpUrl r4 = r0.url()     // Catch:{ all -> 0x0184 }
            java.lang.String r4 = r4.host()     // Catch:{ all -> 0x0184 }
            okhttp3.HttpUrl r5 = r0.url()     // Catch:{ all -> 0x0184 }
            int r5 = r5.port()     // Catch:{ all -> 0x0184 }
            r6 = 1
            java.net.Socket r1 = r1.createSocket(r3, r4, r5, r6)     // Catch:{ all -> 0x0184 }
            if (r1 == 0) goto L_0x017c
            javax.net.ssl.SSLSocket r1 = (javax.net.ssl.SSLSocket) r1     // Catch:{ all -> 0x0184 }
            okhttp3.ConnectionSpec r11 = r11.configureSecureSocket(r1)     // Catch:{ all -> 0x0179 }
            boolean r3 = r11.supportsTlsExtensions()     // Catch:{ all -> 0x0179 }
            if (r3 == 0) goto L_0x0047
            okhttp3.internal.platform.Platform$Companion r3 = okhttp3.internal.platform.Platform.Companion     // Catch:{ all -> 0x0179 }
            okhttp3.internal.platform.Platform r3 = r3.get()     // Catch:{ all -> 0x0179 }
            okhttp3.HttpUrl r4 = r0.url()     // Catch:{ all -> 0x0179 }
            java.lang.String r4 = r4.host()     // Catch:{ all -> 0x0179 }
            java.util.List r5 = r0.protocols()     // Catch:{ all -> 0x0179 }
            r3.configureTlsExtensions(r1, r4, r5)     // Catch:{ all -> 0x0179 }
        L_0x0047:
            r1.startHandshake()     // Catch:{ all -> 0x0179 }
            javax.net.ssl.SSLSession r3 = r1.getSession()     // Catch:{ all -> 0x0179 }
            okhttp3.Handshake$Companion r4 = okhttp3.Handshake.Companion     // Catch:{ all -> 0x0179 }
            java.lang.String r5 = "sslSocketSession"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r3, (java.lang.String) r5)     // Catch:{ all -> 0x0179 }
            okhttp3.Handshake r4 = r4.get(r3)     // Catch:{ all -> 0x0179 }
            javax.net.ssl.HostnameVerifier r5 = r0.hostnameVerifier()     // Catch:{ all -> 0x0179 }
            if (r5 == 0) goto L_0x0175
            okhttp3.HttpUrl r7 = r0.url()     // Catch:{ all -> 0x0179 }
            java.lang.String r7 = r7.host()     // Catch:{ all -> 0x0179 }
            boolean r3 = r5.verify(r7, r3)     // Catch:{ all -> 0x0179 }
            if (r3 != 0) goto L_0x0106
            java.util.List r11 = r4.peerCertificates()     // Catch:{ all -> 0x0179 }
            boolean r3 = r11.isEmpty()     // Catch:{ all -> 0x0179 }
            r3 = r3 ^ r6
            if (r3 == 0) goto L_0x00e2
            r3 = 0
            java.lang.Object r11 = r11.get(r3)     // Catch:{ all -> 0x0179 }
            if (r11 != 0) goto L_0x0087
            f.e r11 = new f.e     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = "null cannot be cast to non-null type java.security.cert.X509Certificate"
            r11.<init>(r0)     // Catch:{ all -> 0x0179 }
            throw r11     // Catch:{ all -> 0x0179 }
        L_0x0087:
            java.security.cert.X509Certificate r11 = (java.security.cert.X509Certificate) r11     // Catch:{ all -> 0x0179 }
            javax.net.ssl.SSLPeerUnverifiedException r3 = new javax.net.ssl.SSLPeerUnverifiedException     // Catch:{ all -> 0x0179 }
            java.lang.StringBuilder r4 = new java.lang.StringBuilder     // Catch:{ all -> 0x0179 }
            r4.<init>()     // Catch:{ all -> 0x0179 }
            java.lang.String r5 = "\n              |Hostname "
            r4.append(r5)     // Catch:{ all -> 0x0179 }
            okhttp3.HttpUrl r0 = r0.url()     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r0.host()     // Catch:{ all -> 0x0179 }
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = " not verified:\n              |    certificate: "
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            okhttp3.CertificatePinner$Companion r0 = okhttp3.CertificatePinner.Companion     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r0.pin(r11)     // Catch:{ all -> 0x0179 }
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = "\n              |    DN: "
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            java.security.Principal r0 = r11.getSubjectDN()     // Catch:{ all -> 0x0179 }
            java.lang.String r5 = "cert.subjectDN"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r0, (java.lang.String) r5)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r0.getName()     // Catch:{ all -> 0x0179 }
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = "\n              |    subjectAltNames: "
            r4.append(r0)     // Catch:{ all -> 0x0179 }
            okhttp3.internal.tls.OkHostnameVerifier r0 = okhttp3.internal.tls.OkHostnameVerifier.INSTANCE     // Catch:{ all -> 0x0179 }
            java.util.List r11 = r0.allSubjectAltNames(r11)     // Catch:{ all -> 0x0179 }
            r4.append(r11)     // Catch:{ all -> 0x0179 }
            java.lang.String r11 = "\n              "
            r4.append(r11)     // Catch:{ all -> 0x0179 }
            java.lang.String r11 = r4.toString()     // Catch:{ all -> 0x0179 }
            java.lang.String r11 = p250f.p261p.C1937g.m5848a((java.lang.String) r11, (java.lang.String) r2, (int) r6)     // Catch:{ all -> 0x0179 }
            r3.<init>(r11)     // Catch:{ all -> 0x0179 }
            throw r3     // Catch:{ all -> 0x0179 }
        L_0x00e2:
            javax.net.ssl.SSLPeerUnverifiedException r11 = new javax.net.ssl.SSLPeerUnverifiedException     // Catch:{ all -> 0x0179 }
            java.lang.StringBuilder r2 = new java.lang.StringBuilder     // Catch:{ all -> 0x0179 }
            r2.<init>()     // Catch:{ all -> 0x0179 }
            java.lang.String r3 = "Hostname "
            r2.append(r3)     // Catch:{ all -> 0x0179 }
            okhttp3.HttpUrl r0 = r0.url()     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r0.host()     // Catch:{ all -> 0x0179 }
            r2.append(r0)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = " not verified (no certificates)"
            r2.append(r0)     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r2.toString()     // Catch:{ all -> 0x0179 }
            r11.<init>(r0)     // Catch:{ all -> 0x0179 }
            throw r11     // Catch:{ all -> 0x0179 }
        L_0x0106:
            okhttp3.CertificatePinner r3 = r0.certificatePinner()     // Catch:{ all -> 0x0179 }
            if (r3 == 0) goto L_0x0171
            okhttp3.Handshake r5 = new okhttp3.Handshake     // Catch:{ all -> 0x0179 }
            okhttp3.TlsVersion r6 = r4.tlsVersion()     // Catch:{ all -> 0x0179 }
            okhttp3.CipherSuite r7 = r4.cipherSuite()     // Catch:{ all -> 0x0179 }
            java.util.List r8 = r4.localCertificates()     // Catch:{ all -> 0x0179 }
            okhttp3.internal.connection.RealConnection$connectTls$1 r9 = new okhttp3.internal.connection.RealConnection$connectTls$1     // Catch:{ all -> 0x0179 }
            r9.<init>(r3, r4, r0)     // Catch:{ all -> 0x0179 }
            r5.<init>(r6, r7, r8, r9)     // Catch:{ all -> 0x0179 }
            r10.handshake = r5     // Catch:{ all -> 0x0179 }
            okhttp3.HttpUrl r0 = r0.url()     // Catch:{ all -> 0x0179 }
            java.lang.String r0 = r0.host()     // Catch:{ all -> 0x0179 }
            okhttp3.internal.connection.RealConnection$connectTls$2 r4 = new okhttp3.internal.connection.RealConnection$connectTls$2     // Catch:{ all -> 0x0179 }
            r4.<init>(r10)     // Catch:{ all -> 0x0179 }
            r3.check$okhttp(r0, r4)     // Catch:{ all -> 0x0179 }
            boolean r11 = r11.supportsTlsExtensions()     // Catch:{ all -> 0x0179 }
            if (r11 == 0) goto L_0x0144
            okhttp3.internal.platform.Platform$Companion r11 = okhttp3.internal.platform.Platform.Companion     // Catch:{ all -> 0x0179 }
            okhttp3.internal.platform.Platform r11 = r11.get()     // Catch:{ all -> 0x0179 }
            java.lang.String r2 = r11.getSelectedProtocol(r1)     // Catch:{ all -> 0x0179 }
        L_0x0144:
            r10.socket = r1     // Catch:{ all -> 0x0179 }
            g.z r11 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4196b((java.net.Socket) r1)     // Catch:{ all -> 0x0179 }
            g.g r11 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4148a((p262g.Source) r11)     // Catch:{ all -> 0x0179 }
            r10.source = r11     // Catch:{ all -> 0x0179 }
            g.x r11 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4151a((java.net.Socket) r1)     // Catch:{ all -> 0x0179 }
            g.f r11 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4147a((p262g.Sink) r11)     // Catch:{ all -> 0x0179 }
            r10.sink = r11     // Catch:{ all -> 0x0179 }
            if (r2 == 0) goto L_0x0163
            okhttp3.Protocol$Companion r11 = okhttp3.Protocol.Companion     // Catch:{ all -> 0x0179 }
            okhttp3.Protocol r11 = r11.get(r2)     // Catch:{ all -> 0x0179 }
            goto L_0x0165
        L_0x0163:
            okhttp3.Protocol r11 = okhttp3.Protocol.HTTP_1_1     // Catch:{ all -> 0x0179 }
        L_0x0165:
            r10.protocol = r11     // Catch:{ all -> 0x0179 }
            okhttp3.internal.platform.Platform$Companion r11 = okhttp3.internal.platform.Platform.Companion
            okhttp3.internal.platform.Platform r11 = r11.get()
            r11.afterHandshake(r1)
            return
        L_0x0171:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0179 }
            throw r2
        L_0x0175:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0179 }
            throw r2
        L_0x0179:
            r11 = move-exception
            r2 = r1
            goto L_0x018a
        L_0x017c:
            f.e r11 = new f.e     // Catch:{ all -> 0x0184 }
            java.lang.String r0 = "null cannot be cast to non-null type javax.net.ssl.SSLSocket"
            r11.<init>(r0)     // Catch:{ all -> 0x0184 }
            throw r11     // Catch:{ all -> 0x0184 }
        L_0x0184:
            r11 = move-exception
            goto L_0x018a
        L_0x0186:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x0184 }
            throw r2
        L_0x018a:
            if (r2 == 0) goto L_0x0195
            okhttp3.internal.platform.Platform$Companion r0 = okhttp3.internal.platform.Platform.Companion
            okhttp3.internal.platform.Platform r0 = r0.get()
            r0.afterHandshake(r2)
        L_0x0195:
            if (r2 == 0) goto L_0x019a
            okhttp3.internal.Util.closeQuietly((java.net.Socket) r2)
        L_0x019a:
            throw r11
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealConnection.connectTls(okhttp3.internal.connection.ConnectionSpecSelector):void");
    }

    private final void connectTunnel(int i, int i2, int i3, Call call, EventListener eventListener) throws IOException {
        Request createTunnelRequest = createTunnelRequest();
        HttpUrl url = createTunnelRequest.url();
        int i4 = 0;
        while (i4 < 21) {
            connectSocket(i, i2, call, eventListener);
            createTunnelRequest = createTunnel(i2, i3, createTunnelRequest, url);
            if (createTunnelRequest != null) {
                Socket socket2 = this.rawSocket;
                if (socket2 != null) {
                    Util.closeQuietly(socket2);
                }
                this.rawSocket = null;
                this.sink = null;
                this.source = null;
                eventListener.connectEnd(call, this.route.socketAddress(), this.route.proxy(), (Protocol) null);
                i4++;
            } else {
                return;
            }
        }
    }

    private final Request createTunnel(int i, int i2, Request request, HttpUrl httpUrl) throws IOException {
        StringBuilder a = outline.m2937a("CONNECT ");
        a.append(Util.toHostHeader(httpUrl, true));
        a.append(" HTTP/1.1");
        String sb = a.toString();
        while (true) {
            BufferedSource gVar = this.source;
            if (gVar != null) {
                BufferedSink fVar = this.sink;
                if (fVar != null) {
                    Http1ExchangeCodec http1ExchangeCodec = new Http1ExchangeCodec((OkHttpClient) null, this, gVar, fVar);
                    gVar.timeout().timeout((long) i, TimeUnit.MILLISECONDS);
                    fVar.timeout().timeout((long) i2, TimeUnit.MILLISECONDS);
                    http1ExchangeCodec.writeRequest(request.headers(), sb);
                    http1ExchangeCodec.finishRequest();
                    Response.Builder readResponseHeaders = http1ExchangeCodec.readResponseHeaders(false);
                    if (readResponseHeaders != null) {
                        Response build = readResponseHeaders.request(request).build();
                        http1ExchangeCodec.skipConnectBody(build);
                        int code = build.code();
                        if (code != 200) {
                            if (code == 407) {
                                Request authenticate = this.route.address().proxyAuthenticator().authenticate(this.route, build);
                                if (authenticate == null) {
                                    throw new IOException("Failed to authenticate with proxy");
                                } else if (C1937g.m5858a("close", Response.header$default(build, "Connection", (String) null, 2, (Object) null), true)) {
                                    return authenticate;
                                } else {
                                    request = authenticate;
                                }
                            } else {
                                StringBuilder a2 = outline.m2937a("Unexpected response code for CONNECT: ");
                                a2.append(build.code());
                                throw new IOException(a2.toString());
                            }
                        } else if (gVar.getBuffer().mo9501k() && fVar.getBuffer().mo9501k()) {
                            return null;
                        } else {
                            throw new IOException("TLS tunnel buffered too many bytes!");
                        }
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                } else {
                    Intrinsics.m5820a();
                    throw null;
                }
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        }
    }

    private final Request createTunnelRequest() throws IOException {
        Request.Builder header = new Request.Builder().url(this.route.address().url()).method("CONNECT", (RequestBody) null).header(Constants.Network.HOST_HEADER, Util.toHostHeader(this.route.address().url(), true)).header("Proxy-Connection", "Keep-Alive").header(Constants.Network.USER_AGENT_HEADER, Version.userAgent);
        Request build = !(header instanceof Request.Builder) ? header.build() : OkHttp3Instrumentation.build(header);
        Response.Builder message = new Response.Builder().request(build).protocol(Protocol.HTTP_1_1).code(407).message("Preemptive Authenticate");
        ResponseBody responseBody = Util.EMPTY_RESPONSE;
        Request authenticate = this.route.address().proxyAuthenticator().authenticate(this.route, (!(message instanceof Response.Builder) ? message.body(responseBody) : OkHttp3Instrumentation.body(message, responseBody)).sentRequestAtMillis(-1).receivedResponseAtMillis(-1).header("Proxy-Authenticate", "OkHttp-Preemptive").build());
        return authenticate != null ? authenticate : build;
    }

    private final void establishProtocol(ConnectionSpecSelector connectionSpecSelector, int i, Call call, EventListener eventListener) throws IOException {
        if (this.route.address().sslSocketFactory() != null) {
            eventListener.secureConnectStart(call);
            connectTls(connectionSpecSelector);
            eventListener.secureConnectEnd(call, this.handshake);
            if (this.protocol == Protocol.HTTP_2) {
                startHttp2(i);
            }
        } else if (this.route.address().protocols().contains(Protocol.H2_PRIOR_KNOWLEDGE)) {
            this.socket = this.rawSocket;
            this.protocol = Protocol.H2_PRIOR_KNOWLEDGE;
            startHttp2(i);
        } else {
            this.socket = this.rawSocket;
            this.protocol = Protocol.HTTP_1_1;
        }
    }

    private final boolean routeMatchesAny(List<Route> list) {
        boolean z;
        if (!(list instanceof Collection) || !list.isEmpty()) {
            for (Route route2 : list) {
                if (route2.proxy().type() == Proxy.Type.DIRECT && this.route.proxy().type() == Proxy.Type.DIRECT && Intrinsics.m5823a((Object) this.route.socketAddress(), (Object) route2.socketAddress())) {
                    z = true;
                    continue;
                } else {
                    z = false;
                    continue;
                }
                if (z) {
                    return true;
                }
            }
        }
        return false;
    }

    private final void startHttp2(int i) throws IOException {
        Socket socket2 = this.socket;
        if (socket2 != null) {
            BufferedSource gVar = this.source;
            if (gVar != null) {
                BufferedSink fVar = this.sink;
                if (fVar != null) {
                    socket2.setSoTimeout(0);
                    Http2Connection build = new Http2Connection.Builder(true, TaskRunner.INSTANCE).socket(socket2, this.route.address().url().host(), gVar, fVar).listener(this).pingIntervalMillis(i).build();
                    this.http2Connection = build;
                    this.allocationLimit = Http2Connection.Companion.getDEFAULT_SETTINGS().getMaxConcurrentStreams();
                    Http2Connection.start$default(build, false, (TaskRunner) null, 3, (Object) null);
                    return;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final void cancel() {
        Socket socket2 = this.rawSocket;
        if (socket2 != null) {
            Util.closeQuietly(socket2);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x008e A[Catch:{ IOException -> 0x00eb }] */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00a7  */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x00d1  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x00de  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00f5  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00fc  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x0126  */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x012c  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void connect(int r17, int r18, int r19, int r20, boolean r21, okhttp3.Call r22, okhttp3.EventListener r23) {
        /*
            r16 = this;
            r7 = r16
            r8 = r22
            r9 = r23
            r10 = 0
            if (r8 == 0) goto L_0x0159
            if (r9 == 0) goto L_0x0153
            okhttp3.Protocol r0 = r7.protocol
            r11 = 1
            if (r0 != 0) goto L_0x0012
            r0 = 1
            goto L_0x0013
        L_0x0012:
            r0 = 0
        L_0x0013:
            if (r0 == 0) goto L_0x0147
            okhttp3.Route r0 = r7.route
            okhttp3.Address r0 = r0.address()
            java.util.List r0 = r0.connectionSpecs()
            okhttp3.internal.connection.ConnectionSpecSelector r12 = new okhttp3.internal.connection.ConnectionSpecSelector
            r12.<init>(r0)
            okhttp3.Route r1 = r7.route
            okhttp3.Address r1 = r1.address()
            javax.net.ssl.SSLSocketFactory r1 = r1.sslSocketFactory()
            if (r1 != 0) goto L_0x0073
            okhttp3.ConnectionSpec r1 = okhttp3.ConnectionSpec.CLEARTEXT
            boolean r0 = r0.contains(r1)
            if (r0 == 0) goto L_0x0066
            okhttp3.Route r0 = r7.route
            okhttp3.Address r0 = r0.address()
            okhttp3.HttpUrl r0 = r0.url()
            java.lang.String r0 = r0.host()
            okhttp3.internal.platform.Platform$Companion r1 = okhttp3.internal.platform.Platform.Companion
            okhttp3.internal.platform.Platform r1 = r1.get()
            boolean r1 = r1.isCleartextTrafficPermitted(r0)
            if (r1 == 0) goto L_0x0053
            goto L_0x0085
        L_0x0053:
            okhttp3.internal.connection.RouteException r1 = new okhttp3.internal.connection.RouteException
            java.net.UnknownServiceException r2 = new java.net.UnknownServiceException
            java.lang.String r3 = "CLEARTEXT communication to "
            java.lang.String r4 = " not permitted by network security policy"
            java.lang.String r0 = p085c.p086a.p087a.p088a.outline.m2934a((java.lang.String) r3, (java.lang.String) r0, (java.lang.String) r4)
            r2.<init>(r0)
            r1.<init>(r2)
            throw r1
        L_0x0066:
            okhttp3.internal.connection.RouteException r0 = new okhttp3.internal.connection.RouteException
            java.net.UnknownServiceException r1 = new java.net.UnknownServiceException
            java.lang.String r2 = "CLEARTEXT communication not enabled for client"
            r1.<init>(r2)
            r0.<init>(r1)
            throw r0
        L_0x0073:
            okhttp3.Route r0 = r7.route
            okhttp3.Address r0 = r0.address()
            java.util.List r0 = r0.protocols()
            okhttp3.Protocol r1 = okhttp3.Protocol.H2_PRIOR_KNOWLEDGE
            boolean r0 = r0.contains(r1)
            if (r0 != 0) goto L_0x013a
        L_0x0085:
            r13 = r10
        L_0x0086:
            okhttp3.Route r0 = r7.route     // Catch:{ IOException -> 0x00eb }
            boolean r0 = r0.requiresTunnel()     // Catch:{ IOException -> 0x00eb }
            if (r0 == 0) goto L_0x00a7
            r1 = r16
            r2 = r17
            r3 = r18
            r4 = r19
            r5 = r22
            r6 = r23
            r1.connectTunnel(r2, r3, r4, r5, r6)     // Catch:{ IOException -> 0x00eb }
            java.net.Socket r0 = r7.rawSocket     // Catch:{ IOException -> 0x00eb }
            if (r0 != 0) goto L_0x00a2
            goto L_0x00c4
        L_0x00a2:
            r14 = r17
            r15 = r18
            goto L_0x00ae
        L_0x00a7:
            r14 = r17
            r15 = r18
            r7.connectSocket(r14, r15, r8, r9)     // Catch:{ IOException -> 0x00e7 }
        L_0x00ae:
            r6 = r20
            r7.establishProtocol(r12, r6, r8, r9)     // Catch:{ IOException -> 0x00e5 }
            okhttp3.Route r0 = r7.route     // Catch:{ IOException -> 0x00e5 }
            java.net.InetSocketAddress r0 = r0.socketAddress()     // Catch:{ IOException -> 0x00e5 }
            okhttp3.Route r1 = r7.route     // Catch:{ IOException -> 0x00e5 }
            java.net.Proxy r1 = r1.proxy()     // Catch:{ IOException -> 0x00e5 }
            okhttp3.Protocol r2 = r7.protocol     // Catch:{ IOException -> 0x00e5 }
            r9.connectEnd(r8, r0, r1, r2)     // Catch:{ IOException -> 0x00e5 }
        L_0x00c4:
            okhttp3.Route r0 = r7.route
            boolean r0 = r0.requiresTunnel()
            if (r0 == 0) goto L_0x00de
            java.net.Socket r0 = r7.rawSocket
            if (r0 == 0) goto L_0x00d1
            goto L_0x00de
        L_0x00d1:
            okhttp3.internal.connection.RouteException r0 = new okhttp3.internal.connection.RouteException
            java.net.ProtocolException r1 = new java.net.ProtocolException
            java.lang.String r2 = "Too many tunnel connections attempted: 21"
            r1.<init>(r2)
            r0.<init>(r1)
            throw r0
        L_0x00de:
            long r0 = java.lang.System.nanoTime()
            r7.idleAtNs = r0
            return
        L_0x00e5:
            r0 = move-exception
            goto L_0x00f1
        L_0x00e7:
            r0 = move-exception
        L_0x00e8:
            r6 = r20
            goto L_0x00f1
        L_0x00eb:
            r0 = move-exception
            r14 = r17
            r15 = r18
            goto L_0x00e8
        L_0x00f1:
            java.net.Socket r1 = r7.socket
            if (r1 == 0) goto L_0x00f8
            okhttp3.internal.Util.closeQuietly((java.net.Socket) r1)
        L_0x00f8:
            java.net.Socket r1 = r7.rawSocket
            if (r1 == 0) goto L_0x00ff
            okhttp3.internal.Util.closeQuietly((java.net.Socket) r1)
        L_0x00ff:
            r7.socket = r10
            r7.rawSocket = r10
            r7.source = r10
            r7.sink = r10
            r7.handshake = r10
            r7.protocol = r10
            r7.http2Connection = r10
            r7.allocationLimit = r11
            okhttp3.Route r1 = r7.route
            java.net.InetSocketAddress r3 = r1.socketAddress()
            okhttp3.Route r1 = r7.route
            java.net.Proxy r4 = r1.proxy()
            r5 = 0
            r1 = r23
            r2 = r22
            r6 = r0
            r1.connectFailed(r2, r3, r4, r5, r6)
            if (r13 != 0) goto L_0x012c
            okhttp3.internal.connection.RouteException r13 = new okhttp3.internal.connection.RouteException
            r13.<init>(r0)
            goto L_0x012f
        L_0x012c:
            r13.addConnectException(r0)
        L_0x012f:
            if (r21 == 0) goto L_0x0139
            boolean r0 = r12.connectionFailed(r0)
            if (r0 == 0) goto L_0x0139
            goto L_0x0086
        L_0x0139:
            throw r13
        L_0x013a:
            okhttp3.internal.connection.RouteException r0 = new okhttp3.internal.connection.RouteException
            java.net.UnknownServiceException r1 = new java.net.UnknownServiceException
            java.lang.String r2 = "H2_PRIOR_KNOWLEDGE cannot be used with HTTPS"
            r1.<init>(r2)
            r0.<init>(r1)
            throw r0
        L_0x0147:
            java.lang.IllegalStateException r0 = new java.lang.IllegalStateException
            java.lang.String r1 = "already connected"
            java.lang.String r1 = r1.toString()
            r0.<init>(r1)
            throw r0
        L_0x0153:
            java.lang.String r0 = "eventListener"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)
            throw r10
        L_0x0159:
            java.lang.String r0 = "call"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)
            throw r10
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealConnection.connect(int, int, int, int, boolean, okhttp3.Call, okhttp3.EventListener):void");
    }

    public final void connectFailed$okhttp(OkHttpClient okHttpClient, Route route2, IOException iOException) {
        if (okHttpClient == null) {
            Intrinsics.m5822a("client");
            throw null;
        } else if (route2 == null) {
            Intrinsics.m5822a("failedRoute");
            throw null;
        } else if (iOException != null) {
            if (route2.proxy().type() != Proxy.Type.DIRECT) {
                Address address = route2.address();
                address.proxySelector().connectFailed(address.url().uri(), route2.proxy().address(), iOException);
            }
            okHttpClient.getRouteDatabase().failed(route2);
        } else {
            Intrinsics.m5822a("failure");
            throw null;
        }
    }

    public final List<Reference<RealCall>> getCalls() {
        return this.calls;
    }

    public final RealConnectionPool getConnectionPool() {
        return this.connectionPool;
    }

    public final long getIdleAtNs$okhttp() {
        return this.idleAtNs;
    }

    public final boolean getNoNewExchanges() {
        return this.noNewExchanges;
    }

    public final int getRouteFailureCount$okhttp() {
        return this.routeFailureCount;
    }

    public final int getSuccessCount$okhttp() {
        return this.successCount;
    }

    public Handshake handshake() {
        return this.handshake;
    }

    public final boolean isEligible$okhttp(Address address, List<Route> list) {
        if (address == null) {
            Intrinsics.m5822a("address");
            throw null;
        } else if (this.calls.size() >= this.allocationLimit || this.noNewExchanges || !this.route.address().equalsNonHost$okhttp(address)) {
            return false;
        } else {
            if (Intrinsics.m5823a((Object) address.url().host(), (Object) route().address().url().host())) {
                return true;
            }
            if (this.http2Connection == null || list == null || !routeMatchesAny(list) || address.hostnameVerifier() != OkHostnameVerifier.INSTANCE || !supportsUrl(address.url())) {
                return false;
            }
            try {
                CertificatePinner certificatePinner = address.certificatePinner();
                if (certificatePinner != null) {
                    String host = address.url().host();
                    Handshake handshake2 = handshake();
                    if (handshake2 != null) {
                        certificatePinner.check(host, (List<? extends Certificate>) handshake2.peerCertificates());
                        return true;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                Intrinsics.m5820a();
                throw null;
            } catch (SSLPeerUnverifiedException unused) {
                return false;
            }
        }
    }

    public final boolean isHealthy(boolean z) {
        long nanoTime = System.nanoTime();
        Socket socket2 = this.rawSocket;
        if (socket2 != null) {
            Socket socket3 = this.socket;
            if (socket3 != null) {
                BufferedSource gVar = this.source;
                if (gVar == null) {
                    Intrinsics.m5820a();
                    throw null;
                } else if (socket2.isClosed() || socket3.isClosed() || socket3.isInputShutdown() || socket3.isOutputShutdown()) {
                    return false;
                } else {
                    Http2Connection http2Connection2 = this.http2Connection;
                    if (http2Connection2 != null) {
                        return http2Connection2.isHealthy(nanoTime);
                    }
                    if (nanoTime - this.idleAtNs < IDLE_CONNECTION_HEALTHY_NS || !z) {
                        return true;
                    }
                    return Util.isHealthy(socket3, gVar);
                }
            } else {
                Intrinsics.m5820a();
                throw null;
            }
        } else {
            Intrinsics.m5820a();
            throw null;
        }
    }

    public final boolean isMultiplexed() {
        return this.http2Connection != null;
    }

    public final ExchangeCodec newCodec$okhttp(OkHttpClient okHttpClient, RealInterceptorChain realInterceptorChain) throws SocketException {
        if (okHttpClient == null) {
            Intrinsics.m5822a("client");
            throw null;
        } else if (realInterceptorChain != null) {
            Socket socket2 = this.socket;
            if (socket2 != null) {
                BufferedSource gVar = this.source;
                if (gVar != null) {
                    BufferedSink fVar = this.sink;
                    if (fVar != null) {
                        Http2Connection http2Connection2 = this.http2Connection;
                        if (http2Connection2 != null) {
                            return new Http2ExchangeCodec(okHttpClient, this, realInterceptorChain, http2Connection2);
                        }
                        socket2.setSoTimeout(realInterceptorChain.readTimeoutMillis());
                        gVar.timeout().timeout((long) realInterceptorChain.getReadTimeoutMillis$okhttp(), TimeUnit.MILLISECONDS);
                        fVar.timeout().timeout((long) realInterceptorChain.getWriteTimeoutMillis$okhttp(), TimeUnit.MILLISECONDS);
                        return new Http1ExchangeCodec(okHttpClient, this, gVar, fVar);
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5820a();
            throw null;
        } else {
            Intrinsics.m5822a("chain");
            throw null;
        }
    }

    public final RealWebSocket.Streams newWebSocketStreams$okhttp(Exchange exchange) throws SocketException {
        if (exchange != null) {
            Socket socket2 = this.socket;
            if (socket2 != null) {
                BufferedSource gVar = this.source;
                if (gVar != null) {
                    BufferedSink fVar = this.sink;
                    if (fVar != null) {
                        socket2.setSoTimeout(0);
                        noNewExchanges();
                        return new RealConnection$newWebSocketStreams$1(exchange, gVar, fVar, true, gVar, fVar);
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
                Intrinsics.m5820a();
                throw null;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("exchange");
        throw null;
    }

    public final void noCoalescedConnections() {
        RealConnectionPool realConnectionPool = this.connectionPool;
        if (!Util.assertionsEnabled || !Thread.holdsLock(realConnectionPool)) {
            synchronized (this.connectionPool) {
                this.noCoalescedConnections = true;
            }
            return;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST NOT hold lock on ");
        a.append(realConnectionPool);
        throw new AssertionError(a.toString());
    }

    public final void noNewExchanges() {
        RealConnectionPool realConnectionPool = this.connectionPool;
        if (!Util.assertionsEnabled || !Thread.holdsLock(realConnectionPool)) {
            synchronized (this.connectionPool) {
                this.noNewExchanges = true;
            }
            return;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST NOT hold lock on ");
        a.append(realConnectionPool);
        throw new AssertionError(a.toString());
    }

    public void onSettings(Http2Connection http2Connection2, Settings settings) {
        if (http2Connection2 == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        } else if (settings != null) {
            synchronized (this.connectionPool) {
                this.allocationLimit = settings.getMaxConcurrentStreams();
            }
        } else {
            Intrinsics.m5822a("settings");
            throw null;
        }
    }

    public void onStream(Http2Stream http2Stream) throws IOException {
        if (http2Stream != null) {
            http2Stream.close(ErrorCode.REFUSED_STREAM, (IOException) null);
        } else {
            Intrinsics.m5822a("stream");
            throw null;
        }
    }

    public Protocol protocol() {
        Protocol protocol2 = this.protocol;
        if (protocol2 != null) {
            return protocol2;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public Route route() {
        return this.route;
    }

    public final void setIdleAtNs$okhttp(long j) {
        this.idleAtNs = j;
    }

    public final void setNoNewExchanges(boolean z) {
        this.noNewExchanges = z;
    }

    public final void setRouteFailureCount$okhttp(int i) {
        this.routeFailureCount = i;
    }

    public final void setSuccessCount$okhttp(int i) {
        this.successCount = i;
    }

    public Socket socket() {
        Socket socket2 = this.socket;
        if (socket2 != null) {
            return socket2;
        }
        Intrinsics.m5820a();
        throw null;
    }

    public final boolean supportsUrl(HttpUrl httpUrl) {
        Handshake handshake2;
        if (httpUrl != null) {
            HttpUrl url = this.route.address().url();
            if (httpUrl.port() != url.port()) {
                return false;
            }
            if (Intrinsics.m5823a((Object) httpUrl.host(), (Object) url.host())) {
                return true;
            }
            if (this.noCoalescedConnections || (handshake2 = this.handshake) == null) {
                return false;
            }
            if (handshake2 == null) {
                Intrinsics.m5820a();
                throw null;
            } else if (certificateSupportHost(httpUrl, handshake2)) {
                return true;
            } else {
                return false;
            }
        } else {
            Intrinsics.m5822a("url");
            throw null;
        }
    }

    public String toString() {
        Object obj;
        StringBuilder a = outline.m2937a("Connection{");
        a.append(this.route.address().url().host());
        a.append(':');
        a.append(this.route.address().url().port());
        a.append(',');
        a.append(" proxy=");
        a.append(this.route.proxy());
        a.append(" hostAddress=");
        a.append(this.route.socketAddress());
        a.append(" cipherSuite=");
        Handshake handshake2 = this.handshake;
        if (handshake2 == null || (obj = handshake2.cipherSuite()) == null) {
            obj = "none";
        }
        a.append(obj);
        a.append(" protocol=");
        a.append(this.protocol);
        a.append('}');
        return a.toString();
    }

    public final void trackFailure$okhttp(RealCall realCall, IOException iOException) {
        if (realCall != null) {
            RealConnectionPool realConnectionPool = this.connectionPool;
            if (!Util.assertionsEnabled || !Thread.holdsLock(realConnectionPool)) {
                synchronized (this.connectionPool) {
                    if (iOException instanceof StreamResetException) {
                        if (((StreamResetException) iOException).errorCode == ErrorCode.REFUSED_STREAM) {
                            int i = this.refusedStreamCount + 1;
                            this.refusedStreamCount = i;
                            if (i > 1) {
                                this.noNewExchanges = true;
                                this.routeFailureCount++;
                            }
                        } else if (((StreamResetException) iOException).errorCode != ErrorCode.CANCEL || !realCall.isCanceled()) {
                            this.noNewExchanges = true;
                            this.routeFailureCount++;
                        }
                    } else if (!isMultiplexed() || (iOException instanceof ConnectionShutdownException)) {
                        this.noNewExchanges = true;
                        if (this.successCount == 0) {
                            if (iOException != null) {
                                connectFailed$okhttp(realCall.getClient(), this.route, iOException);
                            }
                            this.routeFailureCount++;
                        }
                    }
                }
                return;
            }
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(realConnectionPool);
            throw new AssertionError(a.toString());
        }
        Intrinsics.m5822a("call");
        throw null;
    }
}
