package okhttp3.internal.connection;

import java.lang.ref.Reference;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.TimeUnit;
import okhttp3.Address;
import okhttp3.ConnectionPool;
import okhttp3.Route;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.internal.platform.Platform;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: RealConnectionPool.kt */
public final class RealConnectionPool {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final TaskQueue cleanupQueue;
    public final RealConnectionPool$cleanupTask$1 cleanupTask;
    public final ArrayDeque<RealConnection> connections;
    public final long keepAliveDurationNs;
    public final int maxIdleConnections;

    /* compiled from: RealConnectionPool.kt */
    public static final class Companion {
        public Companion() {
        }

        public final RealConnectionPool get(ConnectionPool connectionPool) {
            if (connectionPool != null) {
                return connectionPool.getDelegate$okhttp();
            }
            Intrinsics.m5822a("connectionPool");
            throw null;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public RealConnectionPool(TaskRunner taskRunner, int i, long j, TimeUnit timeUnit) {
        if (taskRunner == null) {
            Intrinsics.m5822a("taskRunner");
            throw null;
        } else if (timeUnit != null) {
            this.maxIdleConnections = i;
            this.keepAliveDurationNs = timeUnit.toNanos(j);
            this.cleanupQueue = taskRunner.newQueue();
            this.cleanupTask = new RealConnectionPool$cleanupTask$1(this, outline.m2935a(new StringBuilder(), Util.okHttpName, " ConnectionPool"));
            this.connections = new ArrayDeque<>();
            if (!(j > 0)) {
                throw new IllegalArgumentException(outline.m2931a("keepAliveDuration <= 0: ", j).toString());
            }
        } else {
            Intrinsics.m5822a("timeUnit");
            throw null;
        }
    }

    private final int pruneAndGetAllocationCount(RealConnection realConnection, long j) {
        List<Reference<RealCall>> calls = realConnection.getCalls();
        int i = 0;
        while (i < calls.size()) {
            Reference reference = calls.get(i);
            if (reference.get() != null) {
                i++;
            } else {
                StringBuilder a = outline.m2937a("A connection to ");
                a.append(realConnection.route().address().url());
                a.append(" was leaked. ");
                a.append("Did you forget to close a response body?");
                Platform.Companion.get().logCloseableLeak(a.toString(), ((RealCall.CallReference) reference).getCallStackTrace());
                calls.remove(i);
                realConnection.setNoNewExchanges(true);
                if (calls.isEmpty()) {
                    realConnection.setIdleAtNs$okhttp(j - this.keepAliveDurationNs);
                    return 0;
                }
            }
        }
        return calls.size();
    }

    public final boolean callAcquirePooledConnection(Address address, RealCall realCall, List<Route> list, boolean z) {
        if (address == null) {
            Intrinsics.m5822a("address");
            throw null;
        } else if (realCall == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            Iterator<RealConnection> it = this.connections.iterator();
            while (it.hasNext()) {
                RealConnection next = it.next();
                if ((!z || next.isMultiplexed()) && next.isEligible$okhttp(address, list)) {
                    Intrinsics.m5821a((Object) next, Http2ExchangeCodec.CONNECTION);
                    realCall.acquireConnectionNoEvents(next);
                    return true;
                }
            }
            return false;
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:34:0x0066, code lost:
        if (r6 == null) goto L_0x0072;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0068, code lost:
        okhttp3.internal.Util.closeQuietly(r6.socket());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:36:0x0071, code lost:
        return 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x0072, code lost:
        p250f.p254l.p256c.Intrinsics.m5820a();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:38:0x0075, code lost:
        throw null;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final long cleanup(long r12) {
        /*
            r11 = this;
            monitor-enter(r11)
            java.util.ArrayDeque<okhttp3.internal.connection.RealConnection> r0 = r11.connections     // Catch:{ all -> 0x0076 }
            java.util.Iterator r0 = r0.iterator()     // Catch:{ all -> 0x0076 }
            r1 = 0
            r2 = 0
            r3 = -9223372036854775808
            r6 = r1
            r4 = r3
            r3 = 0
        L_0x000e:
            boolean r7 = r0.hasNext()     // Catch:{ all -> 0x0076 }
            if (r7 == 0) goto L_0x0037
            java.lang.Object r7 = r0.next()     // Catch:{ all -> 0x0076 }
            okhttp3.internal.connection.RealConnection r7 = (okhttp3.internal.connection.RealConnection) r7     // Catch:{ all -> 0x0076 }
            java.lang.String r8 = "connection"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r7, (java.lang.String) r8)     // Catch:{ all -> 0x0076 }
            int r8 = r11.pruneAndGetAllocationCount(r7, r12)     // Catch:{ all -> 0x0076 }
            if (r8 <= 0) goto L_0x0028
            int r3 = r3 + 1
            goto L_0x000e
        L_0x0028:
            int r2 = r2 + 1
            long r8 = r7.getIdleAtNs$okhttp()     // Catch:{ all -> 0x0076 }
            long r8 = r12 - r8
            int r10 = (r8 > r4 ? 1 : (r8 == r4 ? 0 : -1))
            if (r10 <= 0) goto L_0x000e
            r6 = r7
            r4 = r8
            goto L_0x000e
        L_0x0037:
            long r12 = r11.keepAliveDurationNs     // Catch:{ all -> 0x0076 }
            int r0 = (r4 > r12 ? 1 : (r4 == r12 ? 0 : -1))
            if (r0 >= 0) goto L_0x0053
            int r12 = r11.maxIdleConnections     // Catch:{ all -> 0x0076 }
            if (r2 <= r12) goto L_0x0042
            goto L_0x0053
        L_0x0042:
            if (r2 <= 0) goto L_0x0049
            long r12 = r11.keepAliveDurationNs     // Catch:{ all -> 0x0076 }
            long r12 = r12 - r4
            monitor-exit(r11)
            return r12
        L_0x0049:
            if (r3 <= 0) goto L_0x004f
            long r12 = r11.keepAliveDurationNs     // Catch:{ all -> 0x0076 }
            monitor-exit(r11)
            return r12
        L_0x004f:
            r12 = -1
            monitor-exit(r11)
            return r12
        L_0x0053:
            java.util.ArrayDeque<okhttp3.internal.connection.RealConnection> r12 = r11.connections     // Catch:{ all -> 0x0076 }
            r12.remove(r6)     // Catch:{ all -> 0x0076 }
            java.util.ArrayDeque<okhttp3.internal.connection.RealConnection> r12 = r11.connections     // Catch:{ all -> 0x0076 }
            boolean r12 = r12.isEmpty()     // Catch:{ all -> 0x0076 }
            if (r12 == 0) goto L_0x0065
            okhttp3.internal.concurrent.TaskQueue r12 = r11.cleanupQueue     // Catch:{ all -> 0x0076 }
            r12.cancelAll()     // Catch:{ all -> 0x0076 }
        L_0x0065:
            monitor-exit(r11)
            if (r6 == 0) goto L_0x0072
            java.net.Socket r12 = r6.socket()
            okhttp3.internal.Util.closeQuietly((java.net.Socket) r12)
            r12 = 0
            return r12
        L_0x0072:
            p250f.p254l.p256c.Intrinsics.m5820a()
            throw r1
        L_0x0076:
            r12 = move-exception
            monitor-exit(r11)
            throw r12
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.connection.RealConnectionPool.cleanup(long):long");
    }

    public final boolean connectionBecameIdle(RealConnection realConnection) {
        if (realConnection == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        } else if (Util.assertionsEnabled && !Thread.holdsLock(this)) {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        } else if (realConnection.getNoNewExchanges() || this.maxIdleConnections == 0) {
            this.connections.remove(realConnection);
            if (this.connections.isEmpty()) {
                this.cleanupQueue.cancelAll();
            }
            return true;
        } else {
            TaskQueue.schedule$default(this.cleanupQueue, this.cleanupTask, 0, 2, (Object) null);
            return false;
        }
    }

    public final synchronized int connectionCount() {
        return this.connections.size();
    }

    public final void evictAll() {
        ArrayList<RealConnection> arrayList = new ArrayList<>();
        synchronized (this) {
            Iterator<RealConnection> it = this.connections.iterator();
            Intrinsics.m5821a((Object) it, "connections.iterator()");
            while (it.hasNext()) {
                RealConnection next = it.next();
                if (next.getCalls().isEmpty()) {
                    next.setNoNewExchanges(true);
                    Intrinsics.m5821a((Object) next, Http2ExchangeCodec.CONNECTION);
                    arrayList.add(next);
                    it.remove();
                }
            }
            if (this.connections.isEmpty()) {
                this.cleanupQueue.cancelAll();
            }
        }
        for (RealConnection socket : arrayList) {
            Util.closeQuietly(socket.socket());
        }
    }

    public final synchronized int idleConnectionCount() {
        int i;
        ArrayDeque<RealConnection> arrayDeque = this.connections;
        i = 0;
        if (!(arrayDeque instanceof Collection) || !arrayDeque.isEmpty()) {
            for (RealConnection calls : arrayDeque) {
                if (calls.getCalls().isEmpty()) {
                    i++;
                    if (i < 0) {
                        throw new ArithmeticException("Count overflow has happened.");
                    }
                }
            }
        }
        return i;
    }

    public final void put(RealConnection realConnection) {
        if (realConnection == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        } else if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            this.connections.add(realConnection);
            TaskQueue.schedule$default(this.cleanupQueue, this.cleanupTask, 0, 2, (Object) null);
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }
}
