package okhttp3.internal.http;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.httpclient.HttpResponseEntityImpl;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.util.List;
import okhttp3.Cookie;
import okhttp3.CookieJar;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okhttp3.internal.Version;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.GzipSource;
import p262g.Source;

@Instrumented
/* compiled from: BridgeInterceptor.kt */
public final class BridgeInterceptor implements Interceptor {
    public final CookieJar cookieJar;

    public BridgeInterceptor(CookieJar cookieJar2) {
        if (cookieJar2 != null) {
            this.cookieJar = cookieJar2;
        } else {
            Intrinsics.m5822a("cookieJar");
            throw null;
        }
    }

    private final String cookieHeader(List<Cookie> list) {
        StringBuilder sb = new StringBuilder();
        int i = 0;
        for (T next : list) {
            int i2 = i + 1;
            if (i >= 0) {
                Cookie cookie = (Cookie) next;
                if (i > 0) {
                    sb.append("; ");
                }
                sb.append(cookie.name());
                sb.append('=');
                sb.append(cookie.value());
                i = i2;
            } else {
                C1050v.m4220e();
                throw null;
            }
        }
        String sb2 = sb.toString();
        Intrinsics.m5821a((Object) sb2, "StringBuilder().apply(builderAction).toString()");
        return sb2;
    }

    public Response intercept(Interceptor.Chain chain) throws IOException {
        ResponseBody body;
        if (chain != null) {
            Request request = chain.request();
            Request.Builder newBuilder = request.newBuilder();
            RequestBody body2 = request.body();
            if (body2 != null) {
                MediaType contentType = body2.contentType();
                if (contentType != null) {
                    newBuilder.header(Constants.Network.CONTENT_TYPE_HEADER, contentType.toString());
                }
                long contentLength = body2.contentLength();
                if (contentLength != -1) {
                    newBuilder.header("Content-Length", String.valueOf(contentLength));
                    newBuilder.removeHeader(HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER);
                } else {
                    newBuilder.header(HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER, HttpResponseEntityImpl.ENCODING_CHUNKED);
                    newBuilder.removeHeader("Content-Length");
                }
            }
            boolean z = false;
            if (request.header(Constants.Network.HOST_HEADER) == null) {
                newBuilder.header(Constants.Network.HOST_HEADER, Util.toHostHeader$default(request.url(), false, 1, (Object) null));
            }
            if (request.header("Connection") == null) {
                newBuilder.header("Connection", "Keep-Alive");
            }
            if (request.header("Accept-Encoding") == null && request.header("Range") == null) {
                newBuilder.header("Accept-Encoding", "gzip");
                z = true;
            }
            List<Cookie> loadForRequest = this.cookieJar.loadForRequest(request.url());
            if (!loadForRequest.isEmpty()) {
                newBuilder.header("Cookie", cookieHeader(loadForRequest));
            }
            if (request.header(Constants.Network.USER_AGENT_HEADER) == null) {
                newBuilder.header(Constants.Network.USER_AGENT_HEADER, Version.userAgent);
            }
            Response proceed = chain.proceed(!(newBuilder instanceof Request.Builder) ? newBuilder.build() : OkHttp3Instrumentation.build(newBuilder));
            HttpHeaders.receiveHeaders(this.cookieJar, request.url(), proceed.headers());
            Response.Builder request2 = (!(proceed instanceof Response.Builder) ? proceed.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) proceed)).request(request);
            if (z && C1937g.m5858a("gzip", Response.header$default(proceed, Constants.Network.CONTENT_ENCODING_HEADER, (String) null, 2, (Object) null), true) && HttpHeaders.promisesBody(proceed) && (body = proceed.body()) != null) {
                GzipSource mVar = new GzipSource(body.source());
                request2.headers(proceed.headers().newBuilder().removeAll(Constants.Network.CONTENT_ENCODING_HEADER).removeAll("Content-Length").build());
                OkHttp3Instrumentation.body(request2, new RealResponseBody(Response.header$default(proceed, Constants.Network.CONTENT_TYPE_HEADER, (String) null, 2, (Object) null), -1, C1050v.m4148a((Source) mVar)));
            }
            return request2.build();
        }
        Intrinsics.m5822a("chain");
        throw null;
    }
}
