package okhttp3.internal.http;

import com.newrelic.agent.android.instrumentation.Instrumented;
import com.newrelic.agent.android.instrumentation.okhttp3.OkHttp3Instrumentation;
import java.io.IOException;
import java.net.ProtocolException;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okhttp3.internal.connection.Exchange;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSink;

@Instrumented
/* compiled from: CallServerInterceptor.kt */
public final class CallServerInterceptor implements Interceptor {
    public final boolean forWebSocket;

    public CallServerInterceptor(boolean z) {
        this.forWebSocket = z;
    }

    public Response intercept(Interceptor.Chain chain) throws IOException {
        boolean z;
        Response.Builder builder;
        Response response;
        Long l = null;
        if (chain != null) {
            RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
            Exchange exchange$okhttp = realInterceptorChain.getExchange$okhttp();
            if (exchange$okhttp != null) {
                Request request$okhttp = realInterceptorChain.getRequest$okhttp();
                RequestBody body = request$okhttp.body();
                long currentTimeMillis = System.currentTimeMillis();
                exchange$okhttp.writeRequestHeaders(request$okhttp);
                if (!HttpMethod.permitsRequestBody(request$okhttp.method()) || body == null) {
                    exchange$okhttp.noRequestBody();
                    builder = null;
                    z = true;
                } else {
                    if (C1937g.m5858a("100-continue", request$okhttp.header("Expect"), true)) {
                        exchange$okhttp.flushRequest();
                        builder = exchange$okhttp.readResponseHeaders(true);
                        exchange$okhttp.responseHeadersStart();
                        z = false;
                    } else {
                        builder = null;
                        z = true;
                    }
                    if (builder != null) {
                        exchange$okhttp.noRequestBody();
                        if (!exchange$okhttp.getConnection$okhttp().isMultiplexed()) {
                            exchange$okhttp.noNewExchangesOnConnection();
                        }
                    } else if (body.isDuplex()) {
                        exchange$okhttp.flushRequest();
                        body.writeTo(C1050v.m4147a(exchange$okhttp.createRequestBody(request$okhttp, true)));
                    } else {
                        BufferedSink a = C1050v.m4147a(exchange$okhttp.createRequestBody(request$okhttp, false));
                        body.writeTo(a);
                        a.close();
                    }
                }
                if (body == null || !body.isDuplex()) {
                    exchange$okhttp.finishRequest();
                }
                if (builder == null) {
                    builder = exchange$okhttp.readResponseHeaders(false);
                    if (builder == null) {
                        Intrinsics.m5820a();
                        throw null;
                    } else if (z) {
                        exchange$okhttp.responseHeadersStart();
                        z = false;
                    }
                }
                Response build = builder.request(request$okhttp).handshake(exchange$okhttp.getConnection$okhttp().handshake()).sentRequestAtMillis(currentTimeMillis).receivedResponseAtMillis(System.currentTimeMillis()).build();
                int code = build.code();
                if (code == 100) {
                    Response.Builder readResponseHeaders = exchange$okhttp.readResponseHeaders(false);
                    if (readResponseHeaders != null) {
                        if (z) {
                            exchange$okhttp.responseHeadersStart();
                        }
                        build = readResponseHeaders.request(request$okhttp).handshake(exchange$okhttp.getConnection$okhttp().handshake()).sentRequestAtMillis(currentTimeMillis).receivedResponseAtMillis(System.currentTimeMillis()).build();
                        code = build.code();
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
                exchange$okhttp.responseHeadersEnd(build);
                if (!this.forWebSocket || code != 101) {
                    Response.Builder newBuilder = !(build instanceof Response.Builder) ? build.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) build);
                    ResponseBody openResponseBody = exchange$okhttp.openResponseBody(build);
                    response = (!(newBuilder instanceof Response.Builder) ? newBuilder.body(openResponseBody) : OkHttp3Instrumentation.body(newBuilder, openResponseBody)).build();
                } else {
                    Response.Builder newBuilder2 = !(build instanceof Response.Builder) ? build.newBuilder() : OkHttp3Instrumentation.newBuilder((Response.Builder) build);
                    ResponseBody responseBody = Util.EMPTY_RESPONSE;
                    response = (!(newBuilder2 instanceof Response.Builder) ? newBuilder2.body(responseBody) : OkHttp3Instrumentation.body(newBuilder2, responseBody)).build();
                }
                if (C1937g.m5858a("close", response.request().header("Connection"), true) || C1937g.m5858a("close", Response.header$default(response, "Connection", (String) null, 2, (Object) null), true)) {
                    exchange$okhttp.noNewExchangesOnConnection();
                }
                if (code == 204 || code == 205) {
                    ResponseBody body2 = response.body();
                    if ((body2 != null ? body2.contentLength() : -1) > 0) {
                        StringBuilder sb = new StringBuilder();
                        sb.append("HTTP ");
                        sb.append(code);
                        sb.append(" had non-zero Content-Length: ");
                        ResponseBody body3 = response.body();
                        if (body3 != null) {
                            l = Long.valueOf(body3.contentLength());
                        }
                        sb.append(l);
                        throw new ProtocolException(sb.toString());
                    }
                }
                return response;
            }
            Intrinsics.m5820a();
            throw null;
        }
        Intrinsics.m5822a("chain");
        throw null;
    }
}
