package okhttp3.internal.http1;

import com.newrelic.agent.android.instrumentation.httpclient.HttpResponseEntityImpl;
import java.io.EOFException;
import java.io.IOException;
import java.net.ProtocolException;
import java.net.Proxy;
import java.util.concurrent.TimeUnit;
import okhttp3.CookieJar;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.RequestLine;
import okhttp3.internal.http.StatusLine;
import okhttp3.internal.http2.Http2ExchangeCodec;
import p085c.p086a.p087a.p088a.outline;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.BufferedSink;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.ForwardingTimeout;
import p262g.Sink;
import p262g.Source;
import p262g.Timeout;

/* compiled from: Http1ExchangeCodec.kt */
public final class Http1ExchangeCodec implements ExchangeCodec {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final int HEADER_LIMIT = 262144;
    public static final long NO_CHUNK_YET = -1;
    public static final int STATE_CLOSED = 6;
    public static final int STATE_IDLE = 0;
    public static final int STATE_OPEN_REQUEST_BODY = 1;
    public static final int STATE_OPEN_RESPONSE_BODY = 4;
    public static final int STATE_READING_RESPONSE_BODY = 5;
    public static final int STATE_READ_RESPONSE_HEADERS = 3;
    public static final int STATE_WRITING_REQUEST_BODY = 2;
    public final OkHttpClient client;
    public final RealConnection connection;
    public long headerLimit;
    public final BufferedSink sink;
    public final BufferedSource source;
    public int state;
    public Headers trailers;

    /* compiled from: Http1ExchangeCodec.kt */
    public abstract class AbstractSource implements Source {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public AbstractSource() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.source.timeout());
        }

        public final boolean getClosed() {
            return this.closed;
        }

        public final ForwardingTimeout getTimeout() {
            return this.timeout;
        }

        public long read(C1948d dVar, long j) {
            if (dVar != null) {
                try {
                    return Http1ExchangeCodec.this.source.read(dVar, j);
                } catch (IOException e) {
                    Http1ExchangeCodec.this.getConnection().noNewExchanges();
                    responseBodyComplete$okhttp();
                    throw e;
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }

        public final void responseBodyComplete$okhttp() {
            if (Http1ExchangeCodec.this.state != 6) {
                if (Http1ExchangeCodec.this.state == 5) {
                    Http1ExchangeCodec.this.detachTimeout(this.timeout);
                    Http1ExchangeCodec.this.state = 6;
                    return;
                }
                StringBuilder a = outline.m2937a("state: ");
                a.append(Http1ExchangeCodec.this.state);
                throw new IllegalStateException(a.toString());
            }
        }

        public final void setClosed(boolean z) {
            this.closed = z;
        }

        public Timeout timeout() {
            return this.timeout;
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class ChunkedSink implements Sink {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public ChunkedSink() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.sink.timeout());
        }

        public synchronized void close() {
            if (!this.closed) {
                this.closed = true;
                Http1ExchangeCodec.this.sink.mo9468a("0\r\n\r\n");
                Http1ExchangeCodec.this.detachTimeout(this.timeout);
                Http1ExchangeCodec.this.state = 3;
            }
        }

        public synchronized void flush() {
            if (!this.closed) {
                Http1ExchangeCodec.this.sink.flush();
            }
        }

        public Timeout timeout() {
            return this.timeout;
        }

        public void write(C1948d dVar, long j) {
            if (dVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (!(!this.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (j != 0) {
                Http1ExchangeCodec.this.sink.mo9465a(j);
                Http1ExchangeCodec.this.sink.mo9468a("\r\n");
                Http1ExchangeCodec.this.sink.write(dVar, j);
                Http1ExchangeCodec.this.sink.mo9468a("\r\n");
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class ChunkedSource extends AbstractSource {
        public long bytesRemainingInChunk;
        public boolean hasMoreChunks;
        public final /* synthetic */ Http1ExchangeCodec this$0;
        public final HttpUrl url;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public ChunkedSource(Http1ExchangeCodec http1ExchangeCodec, HttpUrl httpUrl) {
            super();
            if (httpUrl != null) {
                this.this$0 = http1ExchangeCodec;
                this.url = httpUrl;
                this.bytesRemainingInChunk = -1;
                this.hasMoreChunks = true;
                return;
            }
            Intrinsics.m5822a("url");
            throw null;
        }

        private final void readChunkSize() {
            if (this.bytesRemainingInChunk != -1) {
                this.this$0.source.mo9496i();
            }
            try {
                this.bytesRemainingInChunk = this.this$0.source.mo9502l();
                String i = this.this$0.source.mo9496i();
                if (i != null) {
                    String obj = C1937g.m5865c(i).toString();
                    if (this.bytesRemainingInChunk >= 0) {
                        if (!(obj.length() > 0) || C1937g.m5864b(obj, ";", false, 2)) {
                            if (this.bytesRemainingInChunk == 0) {
                                this.hasMoreChunks = false;
                                Http1ExchangeCodec http1ExchangeCodec = this.this$0;
                                http1ExchangeCodec.trailers = http1ExchangeCodec.readHeaders();
                                OkHttpClient access$getClient$p = this.this$0.client;
                                if (access$getClient$p != null) {
                                    CookieJar cookieJar = access$getClient$p.cookieJar();
                                    HttpUrl httpUrl = this.url;
                                    Headers access$getTrailers$p = this.this$0.trailers;
                                    if (access$getTrailers$p != null) {
                                        HttpHeaders.receiveHeaders(cookieJar, httpUrl, access$getTrailers$p);
                                        responseBodyComplete$okhttp();
                                        return;
                                    }
                                    Intrinsics.m5820a();
                                    throw null;
                                }
                                Intrinsics.m5820a();
                                throw null;
                            }
                            return;
                        }
                    }
                    throw new ProtocolException("expected chunk size and optional extensions" + " but was \"" + this.bytesRemainingInChunk + obj + '\"');
                }
                throw new TypeCastException("null cannot be cast to non-null type kotlin.CharSequence");
            } catch (NumberFormatException e) {
                throw new ProtocolException(e.getMessage());
            }
        }

        public void close() {
            if (!getClosed()) {
                if (this.hasMoreChunks && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    this.this$0.getConnection().noNewExchanges();
                    responseBodyComplete$okhttp();
                }
                setClosed(true);
            }
        }

        public long read(C1948d dVar, long j) {
            if (dVar != null) {
                if (!(j >= 0)) {
                    throw new IllegalArgumentException(outline.m2931a("byteCount < 0: ", j).toString());
                } else if (!(!getClosed())) {
                    throw new IllegalStateException("closed".toString());
                } else if (!this.hasMoreChunks) {
                    return -1;
                } else {
                    long j2 = this.bytesRemainingInChunk;
                    if (j2 == 0 || j2 == -1) {
                        readChunkSize();
                        if (!this.hasMoreChunks) {
                            return -1;
                        }
                    }
                    long read = super.read(dVar, Math.min(j, this.bytesRemainingInChunk));
                    if (read != -1) {
                        this.bytesRemainingInChunk -= read;
                        return read;
                    }
                    this.this$0.getConnection().noNewExchanges();
                    ProtocolException protocolException = new ProtocolException("unexpected end of stream");
                    responseBodyComplete$okhttp();
                    throw protocolException;
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class FixedLengthSource extends AbstractSource {
        public long bytesRemaining;

        public FixedLengthSource(long j) {
            super();
            this.bytesRemaining = j;
            if (j == 0) {
                responseBodyComplete$okhttp();
            }
        }

        public void close() {
            if (!getClosed()) {
                if (this.bytesRemaining != 0 && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    Http1ExchangeCodec.this.getConnection().noNewExchanges();
                    responseBodyComplete$okhttp();
                }
                setClosed(true);
            }
        }

        public long read(C1948d dVar, long j) {
            if (dVar != null) {
                if (!(j >= 0)) {
                    throw new IllegalArgumentException(outline.m2931a("byteCount < 0: ", j).toString());
                } else if (!getClosed()) {
                    long j2 = this.bytesRemaining;
                    if (j2 == 0) {
                        return -1;
                    }
                    long read = super.read(dVar, Math.min(j2, j));
                    if (read != -1) {
                        long j3 = this.bytesRemaining - read;
                        this.bytesRemaining = j3;
                        if (j3 == 0) {
                            responseBodyComplete$okhttp();
                        }
                        return read;
                    }
                    Http1ExchangeCodec.this.getConnection().noNewExchanges();
                    ProtocolException protocolException = new ProtocolException("unexpected end of stream");
                    responseBodyComplete$okhttp();
                    throw protocolException;
                } else {
                    throw new IllegalStateException("closed".toString());
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class KnownLengthSink implements Sink {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public KnownLengthSink() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.sink.timeout());
        }

        public void close() {
            if (!this.closed) {
                this.closed = true;
                Http1ExchangeCodec.this.detachTimeout(this.timeout);
                Http1ExchangeCodec.this.state = 3;
            }
        }

        public void flush() {
            if (!this.closed) {
                Http1ExchangeCodec.this.sink.flush();
            }
        }

        public Timeout timeout() {
            return this.timeout;
        }

        public void write(C1948d dVar, long j) {
            if (dVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (!this.closed) {
                Util.checkOffsetAndCount(dVar.f7648c, 0, j);
                Http1ExchangeCodec.this.sink.write(dVar, j);
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class UnknownLengthSource extends AbstractSource {
        public boolean inputExhausted;

        public UnknownLengthSource() {
            super();
        }

        public void close() {
            if (!getClosed()) {
                if (!this.inputExhausted) {
                    responseBodyComplete$okhttp();
                }
                setClosed(true);
            }
        }

        public long read(C1948d dVar, long j) {
            if (dVar != null) {
                if (!(j >= 0)) {
                    throw new IllegalArgumentException(outline.m2931a("byteCount < 0: ", j).toString());
                } else if (!(!getClosed())) {
                    throw new IllegalStateException("closed".toString());
                } else if (this.inputExhausted) {
                    return -1;
                } else {
                    long read = super.read(dVar, j);
                    if (read != -1) {
                        return read;
                    }
                    this.inputExhausted = true;
                    responseBodyComplete$okhttp();
                    return -1;
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }
    }

    public Http1ExchangeCodec(OkHttpClient okHttpClient, RealConnection realConnection, BufferedSource gVar, BufferedSink fVar) {
        if (realConnection == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        } else if (gVar == null) {
            Intrinsics.m5822a("source");
            throw null;
        } else if (fVar != null) {
            this.client = okHttpClient;
            this.connection = realConnection;
            this.source = gVar;
            this.sink = fVar;
            this.headerLimit = (long) HEADER_LIMIT;
        } else {
            Intrinsics.m5822a("sink");
            throw null;
        }
    }

    /* access modifiers changed from: private */
    public final void detachTimeout(ForwardingTimeout lVar) {
        Timeout a0Var = lVar.f7666a;
        Timeout a0Var2 = Timeout.NONE;
        if (a0Var2 != null) {
            lVar.f7666a = a0Var2;
            a0Var.clearDeadline();
            a0Var.clearTimeout();
            return;
        }
        Intrinsics.m5822a("delegate");
        throw null;
    }

    private final boolean isChunked(Response response) {
        return C1937g.m5858a(HttpResponseEntityImpl.ENCODING_CHUNKED, Response.header$default(response, HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER, (String) null, 2, (Object) null), true);
    }

    private final Sink newChunkedSink() {
        boolean z = true;
        if (this.state != 1) {
            z = false;
        }
        if (z) {
            this.state = 2;
            return new ChunkedSink();
        }
        StringBuilder a = outline.m2937a("state: ");
        a.append(this.state);
        throw new IllegalStateException(a.toString().toString());
    }

    private final Source newChunkedSource(HttpUrl httpUrl) {
        if (this.state == 4) {
            this.state = 5;
            return new ChunkedSource(this, httpUrl);
        }
        StringBuilder a = outline.m2937a("state: ");
        a.append(this.state);
        throw new IllegalStateException(a.toString().toString());
    }

    private final Source newFixedLengthSource(long j) {
        if (this.state == 4) {
            this.state = 5;
            return new FixedLengthSource(j);
        }
        StringBuilder a = outline.m2937a("state: ");
        a.append(this.state);
        throw new IllegalStateException(a.toString().toString());
    }

    private final Sink newKnownLengthSink() {
        boolean z = true;
        if (this.state != 1) {
            z = false;
        }
        if (z) {
            this.state = 2;
            return new KnownLengthSink();
        }
        StringBuilder a = outline.m2937a("state: ");
        a.append(this.state);
        throw new IllegalStateException(a.toString().toString());
    }

    private final Source newUnknownLengthSource() {
        if (this.state == 4) {
            this.state = 5;
            getConnection().noNewExchanges();
            return new UnknownLengthSource();
        }
        StringBuilder a = outline.m2937a("state: ");
        a.append(this.state);
        throw new IllegalStateException(a.toString().toString());
    }

    private final String readHeaderLine() {
        String c = this.source.mo9481c(this.headerLimit);
        this.headerLimit -= (long) c.length();
        return c;
    }

    /* access modifiers changed from: private */
    public final Headers readHeaders() {
        Headers.Builder builder = new Headers.Builder();
        String readHeaderLine = readHeaderLine();
        while (true) {
            if (!(readHeaderLine.length() > 0)) {
                return builder.build();
            }
            builder.addLenient$okhttp(readHeaderLine);
            readHeaderLine = readHeaderLine();
        }
    }

    public void cancel() {
        getConnection().cancel();
    }

    public Sink createRequestBody(Request request, long j) {
        if (request == null) {
            Intrinsics.m5822a("request");
            throw null;
        } else if (request.body() != null && request.body().isDuplex()) {
            throw new ProtocolException("Duplex connections are not supported for HTTP/1");
        } else if (isChunked(request)) {
            return newChunkedSink();
        } else {
            if (j != -1) {
                return newKnownLengthSink();
            }
            throw new IllegalStateException("Cannot stream a request body without chunked encoding or a known content length!");
        }
    }

    public void finishRequest() {
        this.sink.flush();
    }

    public void flushRequest() {
        this.sink.flush();
    }

    public RealConnection getConnection() {
        return this.connection;
    }

    public final boolean isClosed() {
        return this.state == 6;
    }

    public Source openResponseBodySource(Response response) {
        if (response == null) {
            Intrinsics.m5822a("response");
            throw null;
        } else if (!HttpHeaders.promisesBody(response)) {
            return newFixedLengthSource(0);
        } else {
            if (isChunked(response)) {
                return newChunkedSource(response.request().url());
            }
            long headersContentLength = Util.headersContentLength(response);
            if (headersContentLength != -1) {
                return newFixedLengthSource(headersContentLength);
            }
            return newUnknownLengthSource();
        }
    }

    public Response.Builder readResponseHeaders(boolean z) {
        int i = this.state;
        boolean z2 = true;
        if (!(i == 1 || i == 3)) {
            z2 = false;
        }
        if (z2) {
            try {
                StatusLine parse = StatusLine.Companion.parse(readHeaderLine());
                Response.Builder headers = new Response.Builder().protocol(parse.protocol).code(parse.code).message(parse.message).headers(readHeaders());
                if (z && parse.code == 100) {
                    return null;
                }
                if (parse.code == 100) {
                    this.state = 3;
                    return headers;
                }
                this.state = 4;
                return headers;
            } catch (EOFException e) {
                throw new IOException(outline.m2941b("unexpected end of stream on ", getConnection().route().address().url().redact()), e);
            }
        } else {
            StringBuilder a = outline.m2937a("state: ");
            a.append(this.state);
            throw new IllegalStateException(a.toString().toString());
        }
    }

    public long reportedContentLength(Response response) {
        if (response == null) {
            Intrinsics.m5822a("response");
            throw null;
        } else if (!HttpHeaders.promisesBody(response)) {
            return 0;
        } else {
            if (isChunked(response)) {
                return -1;
            }
            return Util.headersContentLength(response);
        }
    }

    public final void skipConnectBody(Response response) {
        if (response != null) {
            long headersContentLength = Util.headersContentLength(response);
            if (headersContentLength != -1) {
                Source newFixedLengthSource = newFixedLengthSource(headersContentLength);
                Util.skipAll(newFixedLengthSource, Integer.MAX_VALUE, TimeUnit.MILLISECONDS);
                newFixedLengthSource.close();
                return;
            }
            return;
        }
        Intrinsics.m5822a("response");
        throw null;
    }

    public Headers trailers() {
        if (this.state == 6) {
            Headers headers = this.trailers;
            return headers != null ? headers : Util.EMPTY_HEADERS;
        }
        throw new IllegalStateException("too early; can't read the trailers yet".toString());
    }

    public final void writeRequest(Headers headers, String str) {
        if (headers == null) {
            Intrinsics.m5822a("headers");
            throw null;
        } else if (str != null) {
            if (this.state == 0) {
                this.sink.mo9468a(str).mo9468a("\r\n");
                int size = headers.size();
                for (int i = 0; i < size; i++) {
                    this.sink.mo9468a(headers.name(i)).mo9468a(": ").mo9468a(headers.value(i)).mo9468a("\r\n");
                }
                this.sink.mo9468a("\r\n");
                this.state = 1;
                return;
            }
            StringBuilder a = outline.m2937a("state: ");
            a.append(this.state);
            throw new IllegalStateException(a.toString().toString());
        } else {
            Intrinsics.m5822a("requestLine");
            throw null;
        }
    }

    public void writeRequestHeaders(Request request) {
        if (request != null) {
            RequestLine requestLine = RequestLine.INSTANCE;
            Proxy.Type type = getConnection().route().proxy().type();
            Intrinsics.m5821a((Object) type, "connection.route().proxy.type()");
            writeRequest(request.headers(), requestLine.get(request, type));
            return;
        }
        Intrinsics.m5822a("request");
        throw null;
    }

    private final boolean isChunked(Request request) {
        return C1937g.m5858a(HttpResponseEntityImpl.ENCODING_CHUNKED, request.header(HttpResponseEntityImpl.TRANSFER_ENCODING_HEADER), true);
    }
}
