package okhttp3.internal.http2;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p251i._Arrays;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;
import p262g.Source;

/* compiled from: Hpack.kt */
public final class Hpack {
    public static final Hpack INSTANCE;
    public static final Map<C1952h, Integer> NAME_TO_FIRST_INDEX;
    public static final int PREFIX_4_BITS = 15;
    public static final int PREFIX_5_BITS = 31;
    public static final int PREFIX_6_BITS = 63;
    public static final int PREFIX_7_BITS = 127;
    public static final int SETTINGS_HEADER_TABLE_SIZE = 4096;
    public static final int SETTINGS_HEADER_TABLE_SIZE_LIMIT = 16384;
    public static final Header[] STATIC_HEADER_TABLE = {new Header(Header.TARGET_AUTHORITY, ""), new Header(Header.TARGET_METHOD, "GET"), new Header(Header.TARGET_METHOD, "POST"), new Header(Header.TARGET_PATH, "/"), new Header(Header.TARGET_PATH, "/index.html"), new Header(Header.TARGET_SCHEME, "http"), new Header(Header.TARGET_SCHEME, "https"), new Header(Header.RESPONSE_STATUS, "200"), new Header(Header.RESPONSE_STATUS, "204"), new Header(Header.RESPONSE_STATUS, "206"), new Header(Header.RESPONSE_STATUS, "304"), new Header(Header.RESPONSE_STATUS, "400"), new Header(Header.RESPONSE_STATUS, "404"), new Header(Header.RESPONSE_STATUS, "500"), new Header("accept-charset", ""), new Header("accept-encoding", "gzip, deflate"), new Header("accept-language", ""), new Header("accept-ranges", ""), new Header("accept", ""), new Header("access-control-allow-origin", ""), new Header("age", ""), new Header("allow", ""), new Header("authorization", ""), new Header("cache-control", ""), new Header("content-disposition", ""), new Header("content-encoding", ""), new Header("content-language", ""), new Header("content-length", ""), new Header("content-location", ""), new Header("content-range", ""), new Header("content-type", ""), new Header("cookie", ""), new Header("date", ""), new Header("etag", ""), new Header("expect", ""), new Header("expires", ""), new Header("from", ""), new Header((String) Http2ExchangeCodec.HOST, ""), new Header("if-match", ""), new Header("if-modified-since", ""), new Header("if-none-match", ""), new Header("if-range", ""), new Header("if-unmodified-since", ""), new Header("last-modified", ""), new Header("link", ""), new Header("location", ""), new Header("max-forwards", ""), new Header("proxy-authenticate", ""), new Header("proxy-authorization", ""), new Header("range", ""), new Header("referer", ""), new Header("refresh", ""), new Header("retry-after", ""), new Header("server", ""), new Header("set-cookie", ""), new Header("strict-transport-security", ""), new Header((String) Http2ExchangeCodec.TRANSFER_ENCODING, ""), new Header("user-agent", ""), new Header("vary", ""), new Header("via", ""), new Header("www-authenticate", "")};

    static {
        Hpack hpack = new Hpack();
        INSTANCE = hpack;
        NAME_TO_FIRST_INDEX = hpack.nameToFirstIndex();
    }

    private final Map<C1952h, Integer> nameToFirstIndex() {
        LinkedHashMap linkedHashMap = new LinkedHashMap(STATIC_HEADER_TABLE.length);
        int length = STATIC_HEADER_TABLE.length;
        for (int i = 0; i < length; i++) {
            if (!linkedHashMap.containsKey(STATIC_HEADER_TABLE[i].name)) {
                linkedHashMap.put(STATIC_HEADER_TABLE[i].name, Integer.valueOf(i));
            }
        }
        Map<C1952h, Integer> unmodifiableMap = Collections.unmodifiableMap(linkedHashMap);
        Intrinsics.m5821a((Object) unmodifiableMap, "Collections.unmodifiableMap(result)");
        return unmodifiableMap;
    }

    public final C1952h checkLowercase(C1952h hVar) throws IOException {
        if (hVar != null) {
            int b = hVar.mo9540b();
            for (int i = 0; i < b; i++) {
                byte b2 = (byte) 65;
                byte b3 = (byte) 90;
                byte a = hVar.mo9533a(i);
                if (b2 <= a && b3 >= a) {
                    StringBuilder a2 = outline.m2937a("PROTOCOL_ERROR response malformed: mixed case name: ");
                    a2.append(hVar.mo9547g());
                    throw new IOException(a2.toString());
                }
            }
            return hVar;
        }
        Intrinsics.m5822a("name");
        throw null;
    }

    public final Map<C1952h, Integer> getNAME_TO_FIRST_INDEX() {
        return NAME_TO_FIRST_INDEX;
    }

    public final Header[] getSTATIC_HEADER_TABLE() {
        return STATIC_HEADER_TABLE;
    }

    /* compiled from: Hpack.kt */
    public static final class Reader {
        public Header[] dynamicTable;
        public int dynamicTableByteCount;
        public int headerCount;
        public final List<Header> headerList;
        public final int headerTableSizeSetting;
        public int maxDynamicTableByteCount;
        public int nextHeaderIndex;
        public final BufferedSource source;

        public Reader(Source zVar, int i) {
            this(zVar, i, 0, 4, (DefaultConstructorMarker) null);
        }

        public Reader(Source zVar, int i, int i2) {
            if (zVar != null) {
                this.headerTableSizeSetting = i;
                this.maxDynamicTableByteCount = i2;
                this.headerList = new ArrayList();
                this.source = C1050v.m4148a(zVar);
                Header[] headerArr = new Header[8];
                this.dynamicTable = headerArr;
                this.nextHeaderIndex = headerArr.length - 1;
                return;
            }
            Intrinsics.m5822a("source");
            throw null;
        }

        private final void adjustDynamicTableByteCount() {
            int i = this.maxDynamicTableByteCount;
            int i2 = this.dynamicTableByteCount;
            if (i >= i2) {
                return;
            }
            if (i == 0) {
                clearDynamicTable();
            } else {
                evictToRecoverBytes(i2 - i);
            }
        }

        private final void clearDynamicTable() {
            _Arrays.m5808a((Object[]) this.dynamicTable, (Object) null, 0, 0, 6);
            this.nextHeaderIndex = this.dynamicTable.length - 1;
            this.headerCount = 0;
            this.dynamicTableByteCount = 0;
        }

        private final int dynamicTableIndex(int i) {
            return this.nextHeaderIndex + 1 + i;
        }

        private final int evictToRecoverBytes(int i) {
            int i2 = 0;
            if (i > 0) {
                int length = this.dynamicTable.length;
                while (true) {
                    length--;
                    if (length < this.nextHeaderIndex || i <= 0) {
                        Header[] headerArr = this.dynamicTable;
                        int i3 = this.nextHeaderIndex;
                        System.arraycopy(headerArr, i3 + 1, headerArr, i3 + 1 + i2, this.headerCount);
                        this.nextHeaderIndex += i2;
                    } else {
                        Header header = this.dynamicTable[length];
                        if (header != null) {
                            int i4 = header.hpackSize;
                            i -= i4;
                            this.dynamicTableByteCount -= i4;
                            this.headerCount--;
                            i2++;
                        } else {
                            Intrinsics.m5820a();
                            throw null;
                        }
                    }
                }
                Header[] headerArr2 = this.dynamicTable;
                int i32 = this.nextHeaderIndex;
                System.arraycopy(headerArr2, i32 + 1, headerArr2, i32 + 1 + i2, this.headerCount);
                this.nextHeaderIndex += i2;
            }
            return i2;
        }

        private final C1952h getName(int i) throws IOException {
            if (isStaticHeader(i)) {
                return Hpack.INSTANCE.getSTATIC_HEADER_TABLE()[i].name;
            }
            int dynamicTableIndex = dynamicTableIndex(i - Hpack.INSTANCE.getSTATIC_HEADER_TABLE().length);
            if (dynamicTableIndex >= 0) {
                Header[] headerArr = this.dynamicTable;
                if (dynamicTableIndex < headerArr.length) {
                    Header header = headerArr[dynamicTableIndex];
                    if (header != null) {
                        return header.name;
                    }
                    Intrinsics.m5820a();
                    throw null;
                }
            }
            StringBuilder a = outline.m2937a("Header index too large ");
            a.append(i + 1);
            throw new IOException(a.toString());
        }

        private final void insertIntoDynamicTable(int i, Header header) {
            this.headerList.add(header);
            int i2 = header.hpackSize;
            if (i != -1) {
                Header header2 = this.dynamicTable[dynamicTableIndex(i)];
                if (header2 != null) {
                    i2 -= header2.hpackSize;
                } else {
                    Intrinsics.m5820a();
                    throw null;
                }
            }
            int i3 = this.maxDynamicTableByteCount;
            if (i2 > i3) {
                clearDynamicTable();
                return;
            }
            int evictToRecoverBytes = evictToRecoverBytes((this.dynamicTableByteCount + i2) - i3);
            if (i == -1) {
                int i4 = this.headerCount + 1;
                Header[] headerArr = this.dynamicTable;
                if (i4 > headerArr.length) {
                    Header[] headerArr2 = new Header[(headerArr.length * 2)];
                    System.arraycopy(headerArr, 0, headerArr2, headerArr.length, headerArr.length);
                    this.nextHeaderIndex = this.dynamicTable.length - 1;
                    this.dynamicTable = headerArr2;
                }
                int i5 = this.nextHeaderIndex;
                this.nextHeaderIndex = i5 - 1;
                this.dynamicTable[i5] = header;
                this.headerCount++;
            } else {
                this.dynamicTable[dynamicTableIndex(i) + evictToRecoverBytes + i] = header;
            }
            this.dynamicTableByteCount += i2;
        }

        private final boolean isStaticHeader(int i) {
            return i >= 0 && i <= Hpack.INSTANCE.getSTATIC_HEADER_TABLE().length - 1;
        }

        private final int readByte() throws IOException {
            return Util.and(this.source.readByte(), 255);
        }

        private final void readIndexedHeader(int i) throws IOException {
            if (isStaticHeader(i)) {
                this.headerList.add(Hpack.INSTANCE.getSTATIC_HEADER_TABLE()[i]);
                return;
            }
            int dynamicTableIndex = dynamicTableIndex(i - Hpack.INSTANCE.getSTATIC_HEADER_TABLE().length);
            if (dynamicTableIndex >= 0) {
                Header[] headerArr = this.dynamicTable;
                if (dynamicTableIndex < headerArr.length) {
                    List<Header> list = this.headerList;
                    Header header = headerArr[dynamicTableIndex];
                    if (header != null) {
                        list.add(header);
                        return;
                    } else {
                        Intrinsics.m5820a();
                        throw null;
                    }
                }
            }
            StringBuilder a = outline.m2937a("Header index too large ");
            a.append(i + 1);
            throw new IOException(a.toString());
        }

        private final void readLiteralHeaderWithIncrementalIndexingIndexedName(int i) throws IOException {
            insertIntoDynamicTable(-1, new Header(getName(i), readByteString()));
        }

        private final void readLiteralHeaderWithIncrementalIndexingNewName() throws IOException {
            insertIntoDynamicTable(-1, new Header(Hpack.INSTANCE.checkLowercase(readByteString()), readByteString()));
        }

        private final void readLiteralHeaderWithoutIndexingIndexedName(int i) throws IOException {
            this.headerList.add(new Header(getName(i), readByteString()));
        }

        private final void readLiteralHeaderWithoutIndexingNewName() throws IOException {
            this.headerList.add(new Header(Hpack.INSTANCE.checkLowercase(readByteString()), readByteString()));
        }

        public final List<Header> getAndResetHeaderList() {
            List<Header> a = _Arrays.m5803a(this.headerList);
            this.headerList.clear();
            return a;
        }

        public final int maxDynamicTableByteCount() {
            return this.maxDynamicTableByteCount;
        }

        public final C1952h readByteString() throws IOException {
            int readByte = readByte();
            boolean z = (readByte & 128) == 128;
            long readInt = (long) readInt(readByte, 127);
            if (!z) {
                return this.source.mo9477b(readInt);
            }
            C1948d dVar = new C1948d();
            Huffman.INSTANCE.decode(this.source, readInt, dVar);
            return dVar.mo9486e();
        }

        public final void readHeaders() throws IOException {
            while (!this.source.mo9501k()) {
                int and = Util.and(this.source.readByte(), 255);
                if (and == 128) {
                    throw new IOException("index == 0");
                } else if ((and & 128) == 128) {
                    readIndexedHeader(readInt(and, 127) - 1);
                } else if (and == 64) {
                    readLiteralHeaderWithIncrementalIndexingNewName();
                } else if ((and & 64) == 64) {
                    readLiteralHeaderWithIncrementalIndexingIndexedName(readInt(and, 63) - 1);
                } else if ((and & 32) == 32) {
                    int readInt = readInt(and, 31);
                    this.maxDynamicTableByteCount = readInt;
                    if (readInt < 0 || readInt > this.headerTableSizeSetting) {
                        StringBuilder a = outline.m2937a("Invalid dynamic table size update ");
                        a.append(this.maxDynamicTableByteCount);
                        throw new IOException(a.toString());
                    }
                    adjustDynamicTableByteCount();
                } else if (and == 16 || and == 0) {
                    readLiteralHeaderWithoutIndexingNewName();
                } else {
                    readLiteralHeaderWithoutIndexingIndexedName(readInt(and, 15) - 1);
                }
            }
        }

        public final int readInt(int i, int i2) throws IOException {
            int i3 = i & i2;
            if (i3 < i2) {
                return i3;
            }
            int i4 = 0;
            while (true) {
                int readByte = readByte();
                if ((readByte & 128) == 0) {
                    return i2 + (readByte << i4);
                }
                i2 += (readByte & 127) << i4;
                i4 += 7;
            }
        }

        /* JADX INFO: this call moved to the top of the method (can break code semantics) */
        public /* synthetic */ Reader(Source zVar, int i, int i2, int i3, DefaultConstructorMarker fVar) {
            this(zVar, i, (i3 & 4) != 0 ? i : i2);
        }
    }

    /* compiled from: Hpack.kt */
    public static final class Writer {
        public Header[] dynamicTable;
        public int dynamicTableByteCount;
        public boolean emitDynamicTableSizeUpdate;
        public int headerCount;
        public int headerTableSizeSetting;
        public int maxDynamicTableByteCount;
        public int nextHeaderIndex;
        public final C1948d out;
        public int smallestHeaderTableSizeSetting;
        public final boolean useCompression;

        public Writer(int i, C1948d dVar) {
            this(i, false, dVar, 2, (DefaultConstructorMarker) null);
        }

        public Writer(int i, boolean z, C1948d dVar) {
            if (dVar != null) {
                this.headerTableSizeSetting = i;
                this.useCompression = z;
                this.out = dVar;
                this.smallestHeaderTableSizeSetting = Integer.MAX_VALUE;
                this.maxDynamicTableByteCount = i;
                Header[] headerArr = new Header[8];
                this.dynamicTable = headerArr;
                this.nextHeaderIndex = headerArr.length - 1;
                return;
            }
            Intrinsics.m5822a("out");
            throw null;
        }

        public Writer(C1948d dVar) {
            this(0, false, dVar, 3, (DefaultConstructorMarker) null);
        }

        private final void adjustDynamicTableByteCount() {
            int i = this.maxDynamicTableByteCount;
            int i2 = this.dynamicTableByteCount;
            if (i >= i2) {
                return;
            }
            if (i == 0) {
                clearDynamicTable();
            } else {
                evictToRecoverBytes(i2 - i);
            }
        }

        private final void clearDynamicTable() {
            _Arrays.m5808a((Object[]) this.dynamicTable, (Object) null, 0, 0, 6);
            this.nextHeaderIndex = this.dynamicTable.length - 1;
            this.headerCount = 0;
            this.dynamicTableByteCount = 0;
        }

        private final int evictToRecoverBytes(int i) {
            int i2 = 0;
            if (i > 0) {
                int length = this.dynamicTable.length;
                while (true) {
                    length--;
                    if (length < this.nextHeaderIndex || i <= 0) {
                        Header[] headerArr = this.dynamicTable;
                        int i3 = this.nextHeaderIndex;
                        System.arraycopy(headerArr, i3 + 1, headerArr, i3 + 1 + i2, this.headerCount);
                        Header[] headerArr2 = this.dynamicTable;
                        int i4 = this.nextHeaderIndex;
                        Arrays.fill(headerArr2, i4 + 1, i4 + 1 + i2, (Object) null);
                        this.nextHeaderIndex += i2;
                    } else {
                        Header[] headerArr3 = this.dynamicTable;
                        Header header = headerArr3[length];
                        if (header != null) {
                            i -= header.hpackSize;
                            int i5 = this.dynamicTableByteCount;
                            Header header2 = headerArr3[length];
                            if (header2 != null) {
                                this.dynamicTableByteCount = i5 - header2.hpackSize;
                                this.headerCount--;
                                i2++;
                            } else {
                                Intrinsics.m5820a();
                                throw null;
                            }
                        } else {
                            Intrinsics.m5820a();
                            throw null;
                        }
                    }
                }
                Header[] headerArr4 = this.dynamicTable;
                int i32 = this.nextHeaderIndex;
                System.arraycopy(headerArr4, i32 + 1, headerArr4, i32 + 1 + i2, this.headerCount);
                Header[] headerArr22 = this.dynamicTable;
                int i42 = this.nextHeaderIndex;
                Arrays.fill(headerArr22, i42 + 1, i42 + 1 + i2, (Object) null);
                this.nextHeaderIndex += i2;
            }
            return i2;
        }

        private final void insertIntoDynamicTable(Header header) {
            int i = header.hpackSize;
            int i2 = this.maxDynamicTableByteCount;
            if (i > i2) {
                clearDynamicTable();
                return;
            }
            evictToRecoverBytes((this.dynamicTableByteCount + i) - i2);
            int i3 = this.headerCount + 1;
            Header[] headerArr = this.dynamicTable;
            if (i3 > headerArr.length) {
                Header[] headerArr2 = new Header[(headerArr.length * 2)];
                System.arraycopy(headerArr, 0, headerArr2, headerArr.length, headerArr.length);
                this.nextHeaderIndex = this.dynamicTable.length - 1;
                this.dynamicTable = headerArr2;
            }
            int i4 = this.nextHeaderIndex;
            this.nextHeaderIndex = i4 - 1;
            this.dynamicTable[i4] = header;
            this.headerCount++;
            this.dynamicTableByteCount += i;
        }

        public final void resizeHeaderTable(int i) {
            this.headerTableSizeSetting = i;
            int min = Math.min(i, 16384);
            int i2 = this.maxDynamicTableByteCount;
            if (i2 != min) {
                if (min < i2) {
                    this.smallestHeaderTableSizeSetting = Math.min(this.smallestHeaderTableSizeSetting, min);
                }
                this.emitDynamicTableSizeUpdate = true;
                this.maxDynamicTableByteCount = min;
                adjustDynamicTableByteCount();
            }
        }

        public final void writeByteString(C1952h hVar) throws IOException {
            if (hVar == null) {
                Intrinsics.m5822a("data");
                throw null;
            } else if (!this.useCompression || Huffman.INSTANCE.encodedLength(hVar) >= hVar.mo9540b()) {
                writeInt(hVar.mo9540b(), 127, 0);
                this.out.mo9467a(hVar);
            } else {
                C1948d dVar = new C1948d();
                Huffman.INSTANCE.encode(hVar, dVar);
                C1952h e = dVar.mo9486e();
                writeInt(e.mo9540b(), 127, 128);
                this.out.mo9467a(e);
            }
        }

        public final void writeHeaders(List<Header> list) throws IOException {
            int i;
            int i2;
            if (list != null) {
                if (this.emitDynamicTableSizeUpdate) {
                    int i3 = this.smallestHeaderTableSizeSetting;
                    if (i3 < this.maxDynamicTableByteCount) {
                        writeInt(i3, 31, 32);
                    }
                    this.emitDynamicTableSizeUpdate = false;
                    this.smallestHeaderTableSizeSetting = Integer.MAX_VALUE;
                    writeInt(this.maxDynamicTableByteCount, 31, 32);
                }
                int size = list.size();
                for (int i4 = 0; i4 < size; i4++) {
                    Header header = list.get(i4);
                    C1952h f = header.name.mo9546f();
                    C1952h hVar = header.value;
                    Integer num = Hpack.INSTANCE.getNAME_TO_FIRST_INDEX().get(f);
                    if (num != null) {
                        i2 = num.intValue() + 1;
                        if (2 <= i2 && 7 >= i2) {
                            if (Intrinsics.m5823a((Object) Hpack.INSTANCE.getSTATIC_HEADER_TABLE()[i2 - 1].value, (Object) hVar)) {
                                i = i2;
                            } else if (Intrinsics.m5823a((Object) Hpack.INSTANCE.getSTATIC_HEADER_TABLE()[i2].value, (Object) hVar)) {
                                i = i2;
                                i2++;
                            }
                        }
                        i = i2;
                        i2 = -1;
                    } else {
                        i2 = -1;
                        i = -1;
                    }
                    if (i2 == -1) {
                        int i5 = this.nextHeaderIndex + 1;
                        int length = this.dynamicTable.length;
                        while (true) {
                            if (i5 >= length) {
                                break;
                            }
                            Header header2 = this.dynamicTable[i5];
                            if (header2 != null) {
                                if (Intrinsics.m5823a((Object) header2.name, (Object) f)) {
                                    Header header3 = this.dynamicTable[i5];
                                    if (header3 == null) {
                                        Intrinsics.m5820a();
                                        throw null;
                                    } else if (Intrinsics.m5823a((Object) header3.value, (Object) hVar)) {
                                        i2 = Hpack.INSTANCE.getSTATIC_HEADER_TABLE().length + (i5 - this.nextHeaderIndex);
                                        break;
                                    } else if (i == -1) {
                                        i = (i5 - this.nextHeaderIndex) + Hpack.INSTANCE.getSTATIC_HEADER_TABLE().length;
                                    }
                                }
                                i5++;
                            } else {
                                Intrinsics.m5820a();
                                throw null;
                            }
                        }
                    }
                    if (i2 != -1) {
                        writeInt(i2, 127, 128);
                    } else if (i == -1) {
                        this.out.writeByte(64);
                        writeByteString(f);
                        writeByteString(hVar);
                        insertIntoDynamicTable(header);
                    } else if (!f.mo9539a(Header.PSEUDO_PREFIX) || !(!Intrinsics.m5823a((Object) Header.TARGET_AUTHORITY, (Object) f))) {
                        writeInt(i, 63, 64);
                        writeByteString(hVar);
                        insertIntoDynamicTable(header);
                    } else {
                        writeInt(i, 15, 0);
                        writeByteString(hVar);
                    }
                }
                return;
            }
            Intrinsics.m5822a("headerBlock");
            throw null;
        }

        public final void writeInt(int i, int i2, int i3) {
            if (i < i2) {
                this.out.writeByte(i | i3);
                return;
            }
            this.out.writeByte(i3 | i2);
            int i4 = i - i2;
            while (i4 >= 128) {
                this.out.writeByte(128 | (i4 & 127));
                i4 >>>= 7;
            }
            this.out.writeByte(i4);
        }

        /* JADX INFO: this call moved to the top of the method (can break code semantics) */
        public /* synthetic */ Writer(int i, boolean z, C1948d dVar, int i2, DefaultConstructorMarker fVar) {
            this((i2 & 1) != 0 ? 4096 : i, (i2 & 2) != 0 ? true : z, dVar);
        }
    }
}
