package okhttp3.internal.http2;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;
import p262g.C1952h;

/* compiled from: Http2.kt */
public final class Http2 {
    public static final String[] BINARY;
    public static final C1952h CONNECTION_PREFACE = C1952h.f7659f.mo9552c("PRI * HTTP/2.0\r\n\r\nSM\r\n\r\n");
    public static final String[] FLAGS = new String[64];
    public static final int FLAG_ACK = 1;
    public static final int FLAG_COMPRESSED = 32;
    public static final int FLAG_END_HEADERS = 4;
    public static final int FLAG_END_PUSH_PROMISE = 4;
    public static final int FLAG_END_STREAM = 1;
    public static final int FLAG_NONE = 0;
    public static final int FLAG_PADDED = 8;
    public static final int FLAG_PRIORITY = 32;
    public static final String[] FRAME_NAMES = {"DATA", "HEADERS", "PRIORITY", "RST_STREAM", "SETTINGS", "PUSH_PROMISE", "PING", "GOAWAY", "WINDOW_UPDATE", "CONTINUATION"};
    public static final int INITIAL_MAX_FRAME_SIZE = 16384;
    public static final Http2 INSTANCE = new Http2();
    public static final int TYPE_CONTINUATION = 9;
    public static final int TYPE_DATA = 0;
    public static final int TYPE_GOAWAY = 7;
    public static final int TYPE_HEADERS = 1;
    public static final int TYPE_PING = 6;
    public static final int TYPE_PRIORITY = 2;
    public static final int TYPE_PUSH_PROMISE = 5;
    public static final int TYPE_RST_STREAM = 3;
    public static final int TYPE_SETTINGS = 4;
    public static final int TYPE_WINDOW_UPDATE = 8;

    static {
        String[] strArr = new String[AnalyticAttribute.ATTRIBUTE_NAME_MAX_LENGTH];
        int i = 0;
        while (i < 256) {
            String binaryString = Integer.toBinaryString(i);
            Intrinsics.m5821a((Object) binaryString, "Integer.toBinaryString(it)");
            String format = Util.format("%8s", binaryString);
            if (format != null) {
                String replace = format.replace(SafeJsonPrimitive.NULL_CHAR, '0');
                Intrinsics.m5821a((Object) replace, "(this as java.lang.Strin…replace(oldChar, newChar)");
                strArr[i] = replace;
                i++;
            } else {
                Intrinsics.m5822a("$this$replace");
                throw null;
            }
        }
        BINARY = strArr;
        String[] strArr2 = FLAGS;
        strArr2[0] = "";
        strArr2[1] = "END_STREAM";
        int[] iArr = {1};
        strArr2[8] = "PADDED";
        for (int i2 = 0; i2 < 1; i2++) {
            int i3 = iArr[i2];
            String[] strArr3 = FLAGS;
            int i4 = i3 | 8;
            String str = strArr3[i3];
            strArr3[i4] = str + "|PADDED";
        }
        String[] strArr4 = FLAGS;
        strArr4[4] = "END_HEADERS";
        strArr4[32] = "PRIORITY";
        strArr4[36] = "END_HEADERS|PRIORITY";
        int[] iArr2 = {4, 32, 36};
        for (int i5 = 0; i5 < 3; i5++) {
            int i6 = iArr2[i5];
            for (int i7 = 0; i7 < 1; i7++) {
                int i8 = iArr[i7];
                String[] strArr5 = FLAGS;
                int i9 = i8 | i6;
                strArr5[i9] = FLAGS[i8] + "|" + FLAGS[i6];
                StringBuilder sb = new StringBuilder();
                sb.append(FLAGS[i8]);
                sb.append("|");
                FLAGS[i9 | 8] = outline.m2935a(sb, FLAGS[i6], "|PADDED");
            }
        }
        int length = FLAGS.length;
        for (int i10 = 0; i10 < length; i10++) {
            String[] strArr6 = FLAGS;
            if (strArr6[i10] == null) {
                strArr6[i10] = BINARY[i10];
            }
        }
    }

    public final String formatFlags(int i, int i2) {
        String str;
        if (i2 == 0) {
            return "";
        }
        if (!(i == 2 || i == 3)) {
            if (i == 4 || i == 6) {
                if (i2 == 1) {
                    return "ACK";
                }
                return BINARY[i2];
            } else if (!(i == 7 || i == 8)) {
                String[] strArr = FLAGS;
                if (i2 < strArr.length) {
                    str = strArr[i2];
                    if (str == null) {
                        Intrinsics.m5820a();
                        throw null;
                    }
                } else {
                    str = BINARY[i2];
                }
                if (i != 5 || (i2 & 4) == 0) {
                    return (i != 0 || (i2 & 32) == 0) ? str : C1937g.m5849a(str, "PRIORITY", "COMPRESSED", false, 4);
                }
                return C1937g.m5849a(str, "HEADERS", "PUSH_PROMISE", false, 4);
            }
        }
        return BINARY[i2];
    }

    public final String frameLog(boolean z, int i, int i2, int i3, int i4) {
        String[] strArr = FRAME_NAMES;
        return Util.format("%s 0x%08x %5d %-13s %s", z ? "<<" : ">>", Integer.valueOf(i), Integer.valueOf(i2), i3 < strArr.length ? strArr[i3] : Util.format("0x%02x", Integer.valueOf(i3)), formatFlags(i3, i4));
    }
}
