package okhttp3.internal.http2;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.Closeable;
import java.io.IOException;
import java.net.Socket;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.concurrent.TaskQueue$execute$1;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.http2.Http2Reader;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.Unit;
import p250f.p254l.p255b.C1896a;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.BufferedSink;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;

/* compiled from: Http2Connection.kt */
public final class Http2Connection implements Closeable {
    public static final int AWAIT_PING = 3;
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final Settings DEFAULT_SETTINGS;
    public static final int DEGRADED_PING = 2;
    public static final int DEGRADED_PONG_TIMEOUT_NS = 1000000000;
    public static final int INTERVAL_PING = 1;
    public static final int OKHTTP_CLIENT_WINDOW_SIZE = 16777216;
    public long awaitPingsSent;
    public long awaitPongsReceived;
    public final boolean client;
    public final String connectionName;
    public final Set<Integer> currentPushRequests;
    public long degradedPingsSent;
    public long degradedPongDeadlineNs;
    public long degradedPongsReceived;
    public long intervalPingsSent;
    public long intervalPongsReceived;
    public boolean isShutdown;
    public int lastGoodStreamId;
    public final Listener listener;
    public int nextStreamId;
    public final Settings okHttpSettings;
    public Settings peerSettings;
    public final PushObserver pushObserver;
    public final TaskQueue pushQueue;
    public long readBytesAcknowledged;
    public long readBytesTotal;
    public final ReaderRunnable readerRunnable;
    public final TaskQueue settingsListenerQueue;
    public final Socket socket;
    public final Map<Integer, Http2Stream> streams;
    public final TaskRunner taskRunner;
    public long writeBytesMaximum;
    public long writeBytesTotal;
    public final Http2Writer writer;
    public final TaskQueue writerQueue;

    /* compiled from: Http2Connection.kt */
    public static final class Builder {
        public boolean client;
        public String connectionName;
        public Listener listener;
        public int pingIntervalMillis;
        public PushObserver pushObserver;
        public BufferedSink sink;
        public Socket socket;
        public BufferedSource source;
        public final TaskRunner taskRunner;

        public Builder(boolean z, TaskRunner taskRunner2) {
            if (taskRunner2 != null) {
                this.client = z;
                this.taskRunner = taskRunner2;
                this.listener = Listener.REFUSE_INCOMING_STREAMS;
                this.pushObserver = PushObserver.CANCEL;
                return;
            }
            Intrinsics.m5822a("taskRunner");
            throw null;
        }

        public static /* synthetic */ Builder socket$default(Builder builder, Socket socket2, String str, BufferedSource gVar, BufferedSink fVar, int i, Object obj) throws IOException {
            if ((i & 2) != 0) {
                str = Util.peerName(socket2);
            }
            if ((i & 4) != 0) {
                gVar = C1050v.m4148a(C1050v.m4196b(socket2));
            }
            if ((i & 8) != 0) {
                fVar = C1050v.m4147a(C1050v.m4151a(socket2));
            }
            return builder.socket(socket2, str, gVar, fVar);
        }

        public final Http2Connection build() {
            return new Http2Connection(this);
        }

        public final boolean getClient$okhttp() {
            return this.client;
        }

        public final String getConnectionName$okhttp() {
            String str = this.connectionName;
            if (str != null) {
                return str;
            }
            Intrinsics.m5824b("connectionName");
            throw null;
        }

        public final Listener getListener$okhttp() {
            return this.listener;
        }

        public final int getPingIntervalMillis$okhttp() {
            return this.pingIntervalMillis;
        }

        public final PushObserver getPushObserver$okhttp() {
            return this.pushObserver;
        }

        public final BufferedSink getSink$okhttp() {
            BufferedSink fVar = this.sink;
            if (fVar != null) {
                return fVar;
            }
            Intrinsics.m5824b("sink");
            throw null;
        }

        public final Socket getSocket$okhttp() {
            Socket socket2 = this.socket;
            if (socket2 != null) {
                return socket2;
            }
            Intrinsics.m5824b("socket");
            throw null;
        }

        public final BufferedSource getSource$okhttp() {
            BufferedSource gVar = this.source;
            if (gVar != null) {
                return gVar;
            }
            Intrinsics.m5824b("source");
            throw null;
        }

        public final TaskRunner getTaskRunner$okhttp() {
            return this.taskRunner;
        }

        public final Builder listener(Listener listener2) {
            if (listener2 != null) {
                this.listener = listener2;
                return this;
            }
            Intrinsics.m5822a("listener");
            throw null;
        }

        public final Builder pingIntervalMillis(int i) {
            this.pingIntervalMillis = i;
            return this;
        }

        public final Builder pushObserver(PushObserver pushObserver2) {
            if (pushObserver2 != null) {
                this.pushObserver = pushObserver2;
                return this;
            }
            Intrinsics.m5822a("pushObserver");
            throw null;
        }

        public final void setClient$okhttp(boolean z) {
            this.client = z;
        }

        public final void setConnectionName$okhttp(String str) {
            if (str != null) {
                this.connectionName = str;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setListener$okhttp(Listener listener2) {
            if (listener2 != null) {
                this.listener = listener2;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setPingIntervalMillis$okhttp(int i) {
            this.pingIntervalMillis = i;
        }

        public final void setPushObserver$okhttp(PushObserver pushObserver2) {
            if (pushObserver2 != null) {
                this.pushObserver = pushObserver2;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setSink$okhttp(BufferedSink fVar) {
            if (fVar != null) {
                this.sink = fVar;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setSocket$okhttp(Socket socket2) {
            if (socket2 != null) {
                this.socket = socket2;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final void setSource$okhttp(BufferedSource gVar) {
            if (gVar != null) {
                this.source = gVar;
            } else {
                Intrinsics.m5822a("<set-?>");
                throw null;
            }
        }

        public final Builder socket(Socket socket2) throws IOException {
            return socket$default(this, socket2, (String) null, (BufferedSource) null, (BufferedSink) null, 14, (Object) null);
        }

        public final Builder socket(Socket socket2, String str) throws IOException {
            return socket$default(this, socket2, str, (BufferedSource) null, (BufferedSink) null, 12, (Object) null);
        }

        public final Builder socket(Socket socket2, String str, BufferedSource gVar) throws IOException {
            return socket$default(this, socket2, str, gVar, (BufferedSink) null, 8, (Object) null);
        }

        public final Builder socket(Socket socket2, String str, BufferedSource gVar, BufferedSink fVar) throws IOException {
            String str2;
            if (socket2 == null) {
                Intrinsics.m5822a("socket");
                throw null;
            } else if (str == null) {
                Intrinsics.m5822a("peerName");
                throw null;
            } else if (gVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (fVar != null) {
                this.socket = socket2;
                if (this.client) {
                    str2 = Util.okHttpName + SafeJsonPrimitive.NULL_CHAR + str;
                } else {
                    str2 = outline.m2941b("MockWebServer ", str);
                }
                this.connectionName = str2;
                this.source = gVar;
                this.sink = fVar;
                return this;
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }
    }

    /* compiled from: Http2Connection.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Settings getDEFAULT_SETTINGS() {
            return Http2Connection.DEFAULT_SETTINGS;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: Http2Connection.kt */
    public static abstract class Listener {
        public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
        public static final Listener REFUSE_INCOMING_STREAMS = new Http2Connection$Listener$Companion$REFUSE_INCOMING_STREAMS$1();

        /* compiled from: Http2Connection.kt */
        public static final class Companion {
            public Companion() {
            }

            public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
                this();
            }
        }

        public void onSettings(Http2Connection http2Connection, Settings settings) {
            if (http2Connection == null) {
                Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
                throw null;
            } else if (settings == null) {
                Intrinsics.m5822a("settings");
                throw null;
            }
        }

        public abstract void onStream(Http2Stream http2Stream) throws IOException;
    }

    /* compiled from: Http2Connection.kt */
    public final class ReaderRunnable implements Http2Reader.Handler, C1896a<Unit> {
        public final Http2Reader reader;
        public final /* synthetic */ Http2Connection this$0;

        public ReaderRunnable(Http2Connection http2Connection, Http2Reader http2Reader) {
            if (http2Reader != null) {
                this.this$0 = http2Connection;
                this.reader = http2Reader;
                return;
            }
            Intrinsics.m5822a("reader");
            throw null;
        }

        public void ackSettings() {
        }

        public void alternateService(int i, String str, C1952h hVar, String str2, int i2, long j) {
            if (str == null) {
                Intrinsics.m5822a("origin");
                throw null;
            } else if (hVar == null) {
                Intrinsics.m5822a("protocol");
                throw null;
            } else if (str2 == null) {
                Intrinsics.m5822a(Http2ExchangeCodec.HOST);
                throw null;
            }
        }

        /*  JADX ERROR: IndexOutOfBoundsException in pass: RegionMakerVisitor
            java.lang.IndexOutOfBoundsException: Index: 0, Size: 0
            	at java.util.ArrayList.rangeCheck(ArrayList.java:653)
            	at java.util.ArrayList.get(ArrayList.java:429)
            	at jadx.core.dex.nodes.InsnNode.getArg(InsnNode.java:101)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:611)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverseMonitorExits(RegionMaker.java:619)
            	at jadx.core.dex.visitors.regions.RegionMaker.processMonitorEnter(RegionMaker.java:561)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverse(RegionMaker.java:133)
            	at jadx.core.dex.visitors.regions.RegionMaker.makeRegion(RegionMaker.java:86)
            	at jadx.core.dex.visitors.regions.RegionMaker.processMonitorEnter(RegionMaker.java:598)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverse(RegionMaker.java:133)
            	at jadx.core.dex.visitors.regions.RegionMaker.makeRegion(RegionMaker.java:86)
            	at jadx.core.dex.visitors.regions.RegionMaker.processIf(RegionMaker.java:693)
            	at jadx.core.dex.visitors.regions.RegionMaker.traverse(RegionMaker.java:123)
            	at jadx.core.dex.visitors.regions.RegionMaker.makeRegion(RegionMaker.java:86)
            	at jadx.core.dex.visitors.regions.RegionMakerVisitor.visit(RegionMakerVisitor.java:49)
            */
        public final void applyAndAckSettings(boolean r21, okhttp3.internal.http2.Settings r22) {
            /*
                r20 = this;
                r12 = r20
                r0 = r22
                if (r0 == 0) goto L_0x0107
                f.l.c.m r14 = new f.l.c.m
                r14.<init>()
                f.l.c.n r15 = new f.l.c.n
                r15.<init>()
                f.l.c.n r11 = new f.l.c.n
                r11.<init>()
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0
                okhttp3.internal.http2.Http2Writer r16 = r1.getWriter()
                monitor-enter(r16)
                okhttp3.internal.http2.Http2Connection r10 = r12.this$0     // Catch:{ all -> 0x0104 }
                monitor-enter(r10)     // Catch:{ all -> 0x0104 }
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Settings r1 = r1.getPeerSettings()     // Catch:{ all -> 0x00ff }
                if (r21 == 0) goto L_0x002a
                r11.f7597b = r0     // Catch:{ all -> 0x00ff }
                goto L_0x0037
            L_0x002a:
                okhttp3.internal.http2.Settings r2 = new okhttp3.internal.http2.Settings     // Catch:{ all -> 0x00ff }
                r2.<init>()     // Catch:{ all -> 0x00ff }
                r2.merge(r1)     // Catch:{ all -> 0x00ff }
                r2.merge(r0)     // Catch:{ all -> 0x00ff }
                r11.f7597b = r2     // Catch:{ all -> 0x00ff }
            L_0x0037:
                T r2 = r11.f7597b     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Settings r2 = (okhttp3.internal.http2.Settings) r2     // Catch:{ all -> 0x00ff }
                int r2 = r2.getInitialWindowSize()     // Catch:{ all -> 0x00ff }
                long r2 = (long) r2     // Catch:{ all -> 0x00ff }
                int r1 = r1.getInitialWindowSize()     // Catch:{ all -> 0x00ff }
                long r4 = (long) r1     // Catch:{ all -> 0x00ff }
                long r2 = r2 - r4
                r14.f7596b = r2     // Catch:{ all -> 0x00ff }
                r9 = 0
                r7 = 0
                int r1 = (r2 > r7 ? 1 : (r2 == r7 ? 0 : -1))
                if (r1 == 0) goto L_0x0079
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x00ff }
                java.util.Map r1 = r1.getStreams$okhttp()     // Catch:{ all -> 0x00ff }
                boolean r1 = r1.isEmpty()     // Catch:{ all -> 0x00ff }
                if (r1 == 0) goto L_0x005c
                goto L_0x0079
            L_0x005c:
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x00ff }
                java.util.Map r1 = r1.getStreams$okhttp()     // Catch:{ all -> 0x00ff }
                java.util.Collection r1 = r1.values()     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Http2Stream[] r2 = new okhttp3.internal.http2.Http2Stream[r9]     // Catch:{ all -> 0x00ff }
                java.lang.Object[] r1 = r1.toArray(r2)     // Catch:{ all -> 0x00ff }
                if (r1 == 0) goto L_0x0071
                okhttp3.internal.http2.Http2Stream[] r1 = (okhttp3.internal.http2.Http2Stream[]) r1     // Catch:{ all -> 0x00ff }
                goto L_0x007a
            L_0x0071:
                f.e r0 = new f.e     // Catch:{ all -> 0x00ff }
                java.lang.String r1 = "null cannot be cast to non-null type kotlin.Array<T>"
                r0.<init>(r1)     // Catch:{ all -> 0x00ff }
                throw r0     // Catch:{ all -> 0x00ff }
            L_0x0079:
                r1 = 0
            L_0x007a:
                r15.f7597b = r1     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x00ff }
                T r2 = r11.f7597b     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Settings r2 = (okhttp3.internal.http2.Settings) r2     // Catch:{ all -> 0x00ff }
                r1.setPeerSettings(r2)     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x00ff }
                okhttp3.internal.concurrent.TaskQueue r6 = r1.settingsListenerQueue     // Catch:{ all -> 0x00ff }
                java.lang.StringBuilder r1 = new java.lang.StringBuilder     // Catch:{ all -> 0x00ff }
                r1.<init>()     // Catch:{ all -> 0x00ff }
                okhttp3.internal.http2.Http2Connection r2 = r12.this$0     // Catch:{ all -> 0x00ff }
                java.lang.String r2 = r2.getConnectionName$okhttp()     // Catch:{ all -> 0x00ff }
                r1.append(r2)     // Catch:{ all -> 0x00ff }
                java.lang.String r2 = " onSettings"
                r1.append(r2)     // Catch:{ all -> 0x00ff }
                java.lang.String r4 = r1.toString()     // Catch:{ all -> 0x00ff }
                r5 = 1
                okhttp3.internal.http2.Http2Connection$ReaderRunnable$applyAndAckSettings$$inlined$synchronized$lambda$1 r3 = new okhttp3.internal.http2.Http2Connection$ReaderRunnable$applyAndAckSettings$$inlined$synchronized$lambda$1     // Catch:{ all -> 0x00ff }
                r1 = r3
                r2 = r4
                r13 = r3
                r3 = r5
                r17 = r6
                r6 = r20
                r7 = r21
                r8 = r11
                r18 = 0
                r9 = r22
                r19 = r10
                r10 = r14
                r0 = r11
                r11 = r15
                r1.<init>(r2, r3, r4, r5, r6, r7, r8, r9, r10, r11)     // Catch:{ all -> 0x00fd }
                r1 = r17
                r2 = 0
                r1.schedule(r13, r2)     // Catch:{ all -> 0x00fd }
                monitor-exit(r19)     // Catch:{ all -> 0x0104 }
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ IOException -> 0x00d2 }
                okhttp3.internal.http2.Http2Writer r1 = r1.getWriter()     // Catch:{ IOException -> 0x00d2 }
                T r0 = r0.f7597b     // Catch:{ IOException -> 0x00d2 }
                okhttp3.internal.http2.Settings r0 = (okhttp3.internal.http2.Settings) r0     // Catch:{ IOException -> 0x00d2 }
                r1.applyAndAckSettings(r0)     // Catch:{ IOException -> 0x00d2 }
                goto L_0x00d8
            L_0x00d2:
                r0 = move-exception
                okhttp3.internal.http2.Http2Connection r1 = r12.this$0     // Catch:{ all -> 0x0104 }
                r1.failConnection(r0)     // Catch:{ all -> 0x0104 }
            L_0x00d8:
                monitor-exit(r16)
                T r0 = r15.f7597b
                r1 = r0
                okhttp3.internal.http2.Http2Stream[] r1 = (okhttp3.internal.http2.Http2Stream[]) r1
                if (r1 == 0) goto L_0x00fc
                okhttp3.internal.http2.Http2Stream[] r0 = (okhttp3.internal.http2.Http2Stream[]) r0
                if (r0 == 0) goto L_0x00f7
                int r1 = r0.length
                r9 = 0
            L_0x00e6:
                if (r9 >= r1) goto L_0x00fc
                r2 = r0[r9]
                monitor-enter(r2)
                long r3 = r14.f7596b     // Catch:{ all -> 0x00f4 }
                r2.addBytesToWriteWindow(r3)     // Catch:{ all -> 0x00f4 }
                monitor-exit(r2)
                int r9 = r9 + 1
                goto L_0x00e6
            L_0x00f4:
                r0 = move-exception
                monitor-exit(r2)
                throw r0
            L_0x00f7:
                p250f.p254l.p256c.Intrinsics.m5820a()
                r1 = 0
                throw r1
            L_0x00fc:
                return
            L_0x00fd:
                r0 = move-exception
                goto L_0x0102
            L_0x00ff:
                r0 = move-exception
                r19 = r10
            L_0x0102:
                monitor-exit(r19)     // Catch:{ all -> 0x0104 }
                throw r0     // Catch:{ all -> 0x0104 }
            L_0x0104:
                r0 = move-exception
                monitor-exit(r16)
                throw r0
            L_0x0107:
                java.lang.String r0 = "settings"
                p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r0)
                r1 = 0
                throw r1
            */
            throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Connection.ReaderRunnable.applyAndAckSettings(boolean, okhttp3.internal.http2.Settings):void");
        }

        public void data(boolean z, int i, BufferedSource gVar, int i2) throws IOException {
            if (gVar == null) {
                Intrinsics.m5822a("source");
                throw null;
            } else if (this.this$0.pushedStream$okhttp(i)) {
                this.this$0.pushDataLater$okhttp(i, gVar, i2, z);
            } else {
                Http2Stream stream = this.this$0.getStream(i);
                if (stream == null) {
                    this.this$0.writeSynResetLater$okhttp(i, ErrorCode.PROTOCOL_ERROR);
                    long j = (long) i2;
                    this.this$0.updateConnectionFlowControl$okhttp(j);
                    gVar.skip(j);
                    return;
                }
                stream.receiveData(gVar, i2);
                if (z) {
                    stream.receiveHeaders(Util.EMPTY_HEADERS, true);
                }
            }
        }

        public final Http2Reader getReader$okhttp() {
            return this.reader;
        }

        public void goAway(int i, ErrorCode errorCode, C1952h hVar) {
            int i2;
            Http2Stream[] http2StreamArr;
            if (errorCode == null) {
                Intrinsics.m5822a("errorCode");
                throw null;
            } else if (hVar != null) {
                hVar.mo9540b();
                synchronized (this.this$0) {
                    Object[] array = this.this$0.getStreams$okhttp().values().toArray(new Http2Stream[0]);
                    if (array != null) {
                        http2StreamArr = (Http2Stream[]) array;
                        this.this$0.isShutdown = true;
                    } else {
                        throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
                    }
                }
                for (Http2Stream http2Stream : http2StreamArr) {
                    if (http2Stream.getId() > i && http2Stream.isLocallyInitiated()) {
                        http2Stream.receiveRstStream(ErrorCode.REFUSED_STREAM);
                        this.this$0.removeStream$okhttp(http2Stream.getId());
                    }
                }
            } else {
                Intrinsics.m5822a("debugData");
                throw null;
            }
        }

        public void headers(boolean z, int i, int i2, List<Header> list) {
            boolean z2 = z;
            int i3 = i;
            List<Header> list2 = list;
            if (list2 == null) {
                Intrinsics.m5822a("headerBlock");
                throw null;
            } else if (this.this$0.pushedStream$okhttp(i3)) {
                this.this$0.pushHeadersLater$okhttp(i3, list2, z2);
            } else {
                synchronized (this.this$0) {
                    Http2Stream stream = this.this$0.getStream(i3);
                    if (stream != null) {
                        stream.receiveHeaders(Util.toHeaders(list), z2);
                    } else if (!this.this$0.isShutdown) {
                        if (i3 > this.this$0.getLastGoodStreamId$okhttp()) {
                            if (i3 % 2 != this.this$0.getNextStreamId$okhttp() % 2) {
                                Http2Stream http2Stream = new Http2Stream(i, this.this$0, false, z, Util.toHeaders(list));
                                this.this$0.setLastGoodStreamId$okhttp(i3);
                                this.this$0.getStreams$okhttp().put(Integer.valueOf(i), http2Stream);
                                String str = this.this$0.getConnectionName$okhttp() + '[' + i3 + "] onStream";
                                this.this$0.taskRunner.newQueue().schedule(new C1963xe89ff7cd(str, true, str, true, http2Stream, this, stream, i, list, z), 0);
                            }
                        }
                    }
                }
            }
        }

        public void ping(boolean z, int i, int i2) {
            if (z) {
                synchronized (this.this$0) {
                    if (i == 1) {
                        Http2Connection http2Connection = this.this$0;
                        http2Connection.intervalPongsReceived = http2Connection.intervalPongsReceived + 1;
                    } else if (i == 2) {
                        Http2Connection http2Connection2 = this.this$0;
                        http2Connection2.degradedPongsReceived = http2Connection2.degradedPongsReceived + 1;
                    } else if (i == 3) {
                        Http2Connection http2Connection3 = this.this$0;
                        http2Connection3.awaitPongsReceived = http2Connection3.awaitPongsReceived + 1;
                        Http2Connection http2Connection4 = this.this$0;
                        if (http2Connection4 != null) {
                            http2Connection4.notifyAll();
                        } else {
                            throw new TypeCastException("null cannot be cast to non-null type java.lang.Object");
                        }
                    }
                }
                return;
            }
            String str = this.this$0.getConnectionName$okhttp() + " ping";
            this.this$0.writerQueue.schedule(new Http2Connection$ReaderRunnable$ping$$inlined$execute$1(str, true, str, true, this, i, i2), 0);
        }

        public void priority(int i, int i2, int i3, boolean z) {
        }

        public void pushPromise(int i, int i2, List<Header> list) {
            if (list != null) {
                this.this$0.pushRequestLater$okhttp(i2, list);
            } else {
                Intrinsics.m5822a("requestHeaders");
                throw null;
            }
        }

        public void rstStream(int i, ErrorCode errorCode) {
            if (errorCode == null) {
                Intrinsics.m5822a("errorCode");
                throw null;
            } else if (this.this$0.pushedStream$okhttp(i)) {
                this.this$0.pushResetLater$okhttp(i, errorCode);
            } else {
                Http2Stream removeStream$okhttp = this.this$0.removeStream$okhttp(i);
                if (removeStream$okhttp != null) {
                    removeStream$okhttp.receiveRstStream(errorCode);
                }
            }
        }

        public void settings(boolean z, Settings settings) {
            if (settings != null) {
                String str = this.this$0.getConnectionName$okhttp() + " applyAndAckSettings";
                this.this$0.writerQueue.schedule(new Http2Connection$ReaderRunnable$settings$$inlined$execute$1(str, true, str, true, this, z, settings), 0);
                return;
            }
            Intrinsics.m5822a("settings");
            throw null;
        }

        public void windowUpdate(int i, long j) {
            if (i == 0) {
                synchronized (this.this$0) {
                    Http2Connection http2Connection = this.this$0;
                    http2Connection.writeBytesMaximum = http2Connection.getWriteBytesMaximum() + j;
                    Http2Connection http2Connection2 = this.this$0;
                    if (http2Connection2 != null) {
                        http2Connection2.notifyAll();
                    } else {
                        throw new TypeCastException("null cannot be cast to non-null type java.lang.Object");
                    }
                }
                return;
            }
            Http2Stream stream = this.this$0.getStream(i);
            if (stream != null) {
                synchronized (stream) {
                    stream.addBytesToWriteWindow(j);
                }
            }
        }

        public void invoke() {
            ErrorCode errorCode;
            ErrorCode errorCode2;
            ErrorCode errorCode3 = ErrorCode.INTERNAL_ERROR;
            e = null;
            try {
                this.reader.readConnectionPreface(this);
                while (this.reader.nextFrame(false, this)) {
                }
                errorCode = ErrorCode.NO_ERROR;
                try {
                    errorCode2 = ErrorCode.CANCEL;
                } catch (IOException e) {
                    e = e;
                }
            } catch (IOException e2) {
                e = e2;
                errorCode = errorCode3;
                try {
                    errorCode = ErrorCode.PROTOCOL_ERROR;
                    errorCode2 = ErrorCode.PROTOCOL_ERROR;
                    this.this$0.close$okhttp(errorCode, errorCode2, e);
                    Util.closeQuietly((Closeable) this.reader);
                } catch (Throwable th) {
                    th = th;
                    this.this$0.close$okhttp(errorCode, errorCode3, e);
                    Util.closeQuietly((Closeable) this.reader);
                    throw th;
                }
            } catch (Throwable th2) {
                th = th2;
                errorCode = errorCode3;
                this.this$0.close$okhttp(errorCode, errorCode3, e);
                Util.closeQuietly((Closeable) this.reader);
                throw th;
            }
            this.this$0.close$okhttp(errorCode, errorCode2, e);
            Util.closeQuietly((Closeable) this.reader);
        }
    }

    static {
        Settings settings = new Settings();
        settings.set(7, 65535);
        settings.set(5, 16384);
        DEFAULT_SETTINGS = settings;
    }

    public Http2Connection(Builder builder) {
        if (builder != null) {
            this.client = builder.getClient$okhttp();
            this.listener = builder.getListener$okhttp();
            this.streams = new LinkedHashMap();
            this.connectionName = builder.getConnectionName$okhttp();
            this.nextStreamId = builder.getClient$okhttp() ? 3 : 2;
            TaskRunner taskRunner$okhttp = builder.getTaskRunner$okhttp();
            this.taskRunner = taskRunner$okhttp;
            this.writerQueue = taskRunner$okhttp.newQueue();
            this.pushQueue = this.taskRunner.newQueue();
            this.settingsListenerQueue = this.taskRunner.newQueue();
            this.pushObserver = builder.getPushObserver$okhttp();
            Settings settings = new Settings();
            if (builder.getClient$okhttp()) {
                settings.set(7, OKHTTP_CLIENT_WINDOW_SIZE);
            }
            this.okHttpSettings = settings;
            Settings settings2 = DEFAULT_SETTINGS;
            this.peerSettings = settings2;
            this.writeBytesMaximum = (long) settings2.getInitialWindowSize();
            this.socket = builder.getSocket$okhttp();
            this.writer = new Http2Writer(builder.getSink$okhttp(), this.client);
            this.readerRunnable = new ReaderRunnable(this, new Http2Reader(builder.getSource$okhttp(), this.client));
            this.currentPushRequests = new LinkedHashSet();
            if (builder.getPingIntervalMillis$okhttp() != 0) {
                long nanos = TimeUnit.MILLISECONDS.toNanos((long) builder.getPingIntervalMillis$okhttp());
                TaskQueue taskQueue = this.writerQueue;
                String a = outline.m2935a(new StringBuilder(), this.connectionName, " ping");
                taskQueue.schedule(new Http2Connection$$special$$inlined$schedule$1(a, a, this, nanos), nanos);
                return;
            }
            return;
        }
        Intrinsics.m5822a("builder");
        throw null;
    }

    /* access modifiers changed from: private */
    public final void failConnection(IOException iOException) {
        ErrorCode errorCode = ErrorCode.PROTOCOL_ERROR;
        close$okhttp(errorCode, errorCode, iOException);
    }

    public static /* synthetic */ void start$default(Http2Connection http2Connection, boolean z, TaskRunner taskRunner2, int i, Object obj) throws IOException {
        if ((i & 1) != 0) {
            z = true;
        }
        if ((i & 2) != 0) {
            taskRunner2 = TaskRunner.INSTANCE;
        }
        http2Connection.start(z, taskRunner2);
    }

    public final synchronized void awaitPong() throws InterruptedException {
        while (this.awaitPongsReceived < this.awaitPingsSent) {
            wait();
        }
    }

    public void close() {
        close$okhttp(ErrorCode.NO_ERROR, ErrorCode.CANCEL, (IOException) null);
    }

    /* JADX WARNING: type inference failed for: r4v15, types: [java.lang.Object[]] */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:32:0x0079 */
    /* JADX WARNING: Multi-variable type inference failed */
    /* JADX WARNING: Unknown variable types count: 1 */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void close$okhttp(okhttp3.internal.http2.ErrorCode r4, okhttp3.internal.http2.ErrorCode r5, java.io.IOException r6) {
        /*
            r3 = this;
            r0 = 0
            if (r4 == 0) goto L_0x0097
            if (r5 == 0) goto L_0x0091
            boolean r1 = okhttp3.internal.Util.assertionsEnabled
            if (r1 == 0) goto L_0x0038
            boolean r1 = java.lang.Thread.holdsLock(r3)
            if (r1 != 0) goto L_0x0010
            goto L_0x0038
        L_0x0010:
            java.lang.AssertionError r4 = new java.lang.AssertionError
            java.lang.String r5 = "Thread "
            java.lang.StringBuilder r5 = p085c.p086a.p087a.p088a.outline.m2937a(r5)
            java.lang.Thread r6 = java.lang.Thread.currentThread()
            java.lang.String r0 = "Thread.currentThread()"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r6, (java.lang.String) r0)
            java.lang.String r6 = r6.getName()
            r5.append(r6)
            java.lang.String r6 = " MUST NOT hold lock on "
            r5.append(r6)
            r5.append(r3)
            java.lang.String r5 = r5.toString()
            r4.<init>(r5)
            throw r4
        L_0x0038:
            r3.shutdown(r4)     // Catch:{ IOException -> 0x003b }
        L_0x003b:
            monitor-enter(r3)
            java.util.Map<java.lang.Integer, okhttp3.internal.http2.Http2Stream> r4 = r3.streams     // Catch:{ all -> 0x008e }
            boolean r4 = r4.isEmpty()     // Catch:{ all -> 0x008e }
            r4 = r4 ^ 1
            r1 = 0
            if (r4 == 0) goto L_0x0066
            java.util.Map<java.lang.Integer, okhttp3.internal.http2.Http2Stream> r4 = r3.streams     // Catch:{ all -> 0x008e }
            java.util.Collection r4 = r4.values()     // Catch:{ all -> 0x008e }
            okhttp3.internal.http2.Http2Stream[] r0 = new okhttp3.internal.http2.Http2Stream[r1]     // Catch:{ all -> 0x008e }
            java.lang.Object[] r4 = r4.toArray(r0)     // Catch:{ all -> 0x008e }
            if (r4 == 0) goto L_0x005e
            r0 = r4
            okhttp3.internal.http2.Http2Stream[] r0 = (okhttp3.internal.http2.Http2Stream[]) r0     // Catch:{ all -> 0x008e }
            java.util.Map<java.lang.Integer, okhttp3.internal.http2.Http2Stream> r4 = r3.streams     // Catch:{ all -> 0x008e }
            r4.clear()     // Catch:{ all -> 0x008e }
            goto L_0x0066
        L_0x005e:
            f.e r4 = new f.e     // Catch:{ all -> 0x008e }
            java.lang.String r5 = "null cannot be cast to non-null type kotlin.Array<T>"
            r4.<init>(r5)     // Catch:{ all -> 0x008e }
            throw r4     // Catch:{ all -> 0x008e }
        L_0x0066:
            monitor-exit(r3)
            if (r0 == 0) goto L_0x0074
            int r4 = r0.length
        L_0x006a:
            if (r1 >= r4) goto L_0x0074
            r2 = r0[r1]
            r2.close(r5, r6)     // Catch:{ IOException -> 0x0071 }
        L_0x0071:
            int r1 = r1 + 1
            goto L_0x006a
        L_0x0074:
            okhttp3.internal.http2.Http2Writer r4 = r3.writer     // Catch:{ IOException -> 0x0079 }
            r4.close()     // Catch:{ IOException -> 0x0079 }
        L_0x0079:
            java.net.Socket r4 = r3.socket     // Catch:{ IOException -> 0x007e }
            r4.close()     // Catch:{ IOException -> 0x007e }
        L_0x007e:
            okhttp3.internal.concurrent.TaskQueue r4 = r3.writerQueue
            r4.shutdown()
            okhttp3.internal.concurrent.TaskQueue r4 = r3.pushQueue
            r4.shutdown()
            okhttp3.internal.concurrent.TaskQueue r4 = r3.settingsListenerQueue
            r4.shutdown()
            return
        L_0x008e:
            r4 = move-exception
            monitor-exit(r3)
            throw r4
        L_0x0091:
            java.lang.String r4 = "streamCode"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r4)
            throw r0
        L_0x0097:
            java.lang.String r4 = "connectionCode"
            p250f.p254l.p256c.Intrinsics.m5822a((java.lang.String) r4)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Connection.close$okhttp(okhttp3.internal.http2.ErrorCode, okhttp3.internal.http2.ErrorCode, java.io.IOException):void");
    }

    public final void flush() throws IOException {
        this.writer.flush();
    }

    public final boolean getClient$okhttp() {
        return this.client;
    }

    public final String getConnectionName$okhttp() {
        return this.connectionName;
    }

    public final int getLastGoodStreamId$okhttp() {
        return this.lastGoodStreamId;
    }

    public final Listener getListener$okhttp() {
        return this.listener;
    }

    public final int getNextStreamId$okhttp() {
        return this.nextStreamId;
    }

    public final Settings getOkHttpSettings() {
        return this.okHttpSettings;
    }

    public final Settings getPeerSettings() {
        return this.peerSettings;
    }

    public final long getReadBytesAcknowledged() {
        return this.readBytesAcknowledged;
    }

    public final long getReadBytesTotal() {
        return this.readBytesTotal;
    }

    public final ReaderRunnable getReaderRunnable() {
        return this.readerRunnable;
    }

    public final Socket getSocket$okhttp() {
        return this.socket;
    }

    public final synchronized Http2Stream getStream(int i) {
        return this.streams.get(Integer.valueOf(i));
    }

    public final Map<Integer, Http2Stream> getStreams$okhttp() {
        return this.streams;
    }

    public final long getWriteBytesMaximum() {
        return this.writeBytesMaximum;
    }

    public final long getWriteBytesTotal() {
        return this.writeBytesTotal;
    }

    public final Http2Writer getWriter() {
        return this.writer;
    }

    public final synchronized boolean isHealthy(long j) {
        if (this.isShutdown) {
            return false;
        }
        if (this.degradedPongsReceived >= this.degradedPingsSent || j < this.degradedPongDeadlineNs) {
            return true;
        }
        return false;
    }

    public final Http2Stream newStream(List<Header> list, boolean z) throws IOException {
        if (list != null) {
            return newStream(0, list, z);
        }
        Intrinsics.m5822a("requestHeaders");
        throw null;
    }

    public final synchronized int openStreamCount() {
        return this.streams.size();
    }

    public final void pushDataLater$okhttp(int i, BufferedSource gVar, int i2, boolean z) throws IOException {
        BufferedSource gVar2 = gVar;
        if (gVar2 != null) {
            C1948d dVar = new C1948d();
            int i3 = i2;
            long j = (long) i3;
            gVar2.mo9491g(j);
            gVar2.read(dVar, j);
            TaskQueue taskQueue = this.pushQueue;
            StringBuilder sb = new StringBuilder();
            sb.append(this.connectionName);
            sb.append('[');
            int i4 = i;
            sb.append(i4);
            sb.append("] onData");
            String sb2 = sb.toString();
            taskQueue.schedule(new Http2Connection$pushDataLater$$inlined$execute$1(sb2, true, sb2, true, this, i4, dVar, i3, z), 0);
            return;
        }
        Intrinsics.m5822a("source");
        throw null;
    }

    public final void pushHeadersLater$okhttp(int i, List<Header> list, boolean z) {
        if (list != null) {
            String str = this.connectionName + '[' + i + "] onHeaders";
            this.pushQueue.schedule(new Http2Connection$pushHeadersLater$$inlined$execute$1(str, true, str, true, this, i, list, z), 0);
            return;
        }
        Intrinsics.m5822a("requestHeaders");
        throw null;
    }

    public final void pushRequestLater$okhttp(int i, List<Header> list) {
        if (list != null) {
            synchronized (this) {
                if (this.currentPushRequests.contains(Integer.valueOf(i))) {
                    writeSynResetLater$okhttp(i, ErrorCode.PROTOCOL_ERROR);
                    return;
                }
                this.currentPushRequests.add(Integer.valueOf(i));
                String str = this.connectionName + '[' + i + "] onRequest";
                this.pushQueue.schedule(new Http2Connection$pushRequestLater$$inlined$execute$1(str, true, str, true, this, i, list), 0);
                return;
            }
        }
        Intrinsics.m5822a("requestHeaders");
        throw null;
    }

    public final void pushResetLater$okhttp(int i, ErrorCode errorCode) {
        if (errorCode != null) {
            String str = this.connectionName + '[' + i + "] onReset";
            this.pushQueue.schedule(new Http2Connection$pushResetLater$$inlined$execute$1(str, true, str, true, this, i, errorCode), 0);
            return;
        }
        Intrinsics.m5822a("errorCode");
        throw null;
    }

    public final Http2Stream pushStream(int i, List<Header> list, boolean z) throws IOException {
        if (list == null) {
            Intrinsics.m5822a("requestHeaders");
            throw null;
        } else if (!this.client) {
            return newStream(i, list, z);
        } else {
            throw new IllegalStateException("Client cannot push requests.".toString());
        }
    }

    public final boolean pushedStream$okhttp(int i) {
        return i != 0 && (i & 1) == 0;
    }

    public final synchronized Http2Stream removeStream$okhttp(int i) {
        Http2Stream remove;
        remove = this.streams.remove(Integer.valueOf(i));
        notifyAll();
        return remove;
    }

    public final void sendDegradedPingLater$okhttp() {
        synchronized (this) {
            if (this.degradedPongsReceived >= this.degradedPingsSent) {
                this.degradedPingsSent++;
                this.degradedPongDeadlineNs = System.nanoTime() + ((long) DEGRADED_PONG_TIMEOUT_NS);
                TaskQueue taskQueue = this.writerQueue;
                String a = outline.m2935a(new StringBuilder(), this.connectionName, " ping");
                taskQueue.schedule(new Http2Connection$sendDegradedPingLater$$inlined$execute$1(a, true, a, true, this), 0);
            }
        }
    }

    public final void setLastGoodStreamId$okhttp(int i) {
        this.lastGoodStreamId = i;
    }

    public final void setNextStreamId$okhttp(int i) {
        this.nextStreamId = i;
    }

    public final void setPeerSettings(Settings settings) {
        if (settings != null) {
            this.peerSettings = settings;
        } else {
            Intrinsics.m5822a("<set-?>");
            throw null;
        }
    }

    public final void setSettings(Settings settings) throws IOException {
        if (settings != null) {
            synchronized (this.writer) {
                synchronized (this) {
                    if (!this.isShutdown) {
                        this.okHttpSettings.merge(settings);
                    } else {
                        throw new ConnectionShutdownException();
                    }
                }
                this.writer.settings(settings);
            }
            return;
        }
        Intrinsics.m5822a("settings");
        throw null;
    }

    public final void shutdown(ErrorCode errorCode) throws IOException {
        if (errorCode != null) {
            synchronized (this.writer) {
                synchronized (this) {
                    if (!this.isShutdown) {
                        this.isShutdown = true;
                        int i = this.lastGoodStreamId;
                        this.writer.goAway(i, errorCode, Util.EMPTY_BYTE_ARRAY);
                        return;
                    }
                    return;
                }
            }
        }
        Intrinsics.m5822a(AnalyticAttribute.STATUS_CODE_ATTRIBUTE);
        throw null;
    }

    public final void start() throws IOException {
        start$default(this, false, (TaskRunner) null, 3, (Object) null);
    }

    public final void start(boolean z) throws IOException {
        start$default(this, z, (TaskRunner) null, 2, (Object) null);
    }

    public final void start(boolean z, TaskRunner taskRunner2) throws IOException {
        if (taskRunner2 != null) {
            if (z) {
                this.writer.connectionPreface();
                this.writer.settings(this.okHttpSettings);
                int initialWindowSize = this.okHttpSettings.getInitialWindowSize();
                if (initialWindowSize != 65535) {
                    this.writer.windowUpdate(0, (long) (initialWindowSize - 65535));
                }
            }
            TaskQueue newQueue = taskRunner2.newQueue();
            String str = this.connectionName;
            newQueue.schedule(new TaskQueue$execute$1(this.readerRunnable, str, true, str, true), 0);
            return;
        }
        Intrinsics.m5822a("taskRunner");
        throw null;
    }

    public final synchronized void updateConnectionFlowControl$okhttp(long j) {
        long j2 = this.readBytesTotal + j;
        this.readBytesTotal = j2;
        long j3 = j2 - this.readBytesAcknowledged;
        if (j3 >= ((long) (this.okHttpSettings.getInitialWindowSize() / 2))) {
            writeWindowUpdateLater$okhttp(0, j3);
            this.readBytesAcknowledged += j3;
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(3:26|27|28) */
    /* JADX WARNING: Code restructure failed: missing block: B:16:?, code lost:
        r3 = java.lang.Math.min((int) java.lang.Math.min(r12, r8.writeBytesMaximum - r8.writeBytesTotal), r8.writer.maxDataLength());
        r6 = (long) r3;
        r8.writeBytesTotal += r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
        java.lang.Thread.currentThread().interrupt();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x006b, code lost:
        throw new java.io.InterruptedIOException();
     */
    /* JADX WARNING: Missing exception handler attribute for start block: B:26:0x005f */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final void writeData(int r9, boolean r10, p262g.C1948d r11, long r12) throws java.io.IOException {
        /*
            r8 = this;
            r0 = 0
            r1 = 0
            int r3 = (r12 > r1 ? 1 : (r12 == r1 ? 0 : -1))
            if (r3 != 0) goto L_0x000d
            okhttp3.internal.http2.Http2Writer r12 = r8.writer
            r12.data(r10, r9, r11, r0)
            return
        L_0x000d:
            int r3 = (r12 > r1 ? 1 : (r12 == r1 ? 0 : -1))
            if (r3 <= 0) goto L_0x006e
            monitor-enter(r8)
        L_0x0012:
            long r3 = r8.writeBytesTotal     // Catch:{ InterruptedException -> 0x005f }
            long r5 = r8.writeBytesMaximum     // Catch:{ InterruptedException -> 0x005f }
            int r7 = (r3 > r5 ? 1 : (r3 == r5 ? 0 : -1))
            if (r7 < 0) goto L_0x0032
            java.util.Map<java.lang.Integer, okhttp3.internal.http2.Http2Stream> r3 = r8.streams     // Catch:{ InterruptedException -> 0x005f }
            java.lang.Integer r4 = java.lang.Integer.valueOf(r9)     // Catch:{ InterruptedException -> 0x005f }
            boolean r3 = r3.containsKey(r4)     // Catch:{ InterruptedException -> 0x005f }
            if (r3 == 0) goto L_0x002a
            r8.wait()     // Catch:{ InterruptedException -> 0x005f }
            goto L_0x0012
        L_0x002a:
            java.io.IOException r9 = new java.io.IOException     // Catch:{ InterruptedException -> 0x005f }
            java.lang.String r10 = "stream closed"
            r9.<init>(r10)     // Catch:{ InterruptedException -> 0x005f }
            throw r9     // Catch:{ InterruptedException -> 0x005f }
        L_0x0032:
            long r3 = r8.writeBytesMaximum     // Catch:{ all -> 0x005d }
            long r5 = r8.writeBytesTotal     // Catch:{ all -> 0x005d }
            long r3 = r3 - r5
            long r3 = java.lang.Math.min(r12, r3)     // Catch:{ all -> 0x005d }
            int r4 = (int) r3     // Catch:{ all -> 0x005d }
            okhttp3.internal.http2.Http2Writer r3 = r8.writer     // Catch:{ all -> 0x005d }
            int r3 = r3.maxDataLength()     // Catch:{ all -> 0x005d }
            int r3 = java.lang.Math.min(r4, r3)     // Catch:{ all -> 0x005d }
            long r4 = r8.writeBytesTotal     // Catch:{ all -> 0x005d }
            long r6 = (long) r3     // Catch:{ all -> 0x005d }
            long r4 = r4 + r6
            r8.writeBytesTotal = r4     // Catch:{ all -> 0x005d }
            monitor-exit(r8)
            long r12 = r12 - r6
            okhttp3.internal.http2.Http2Writer r4 = r8.writer
            if (r10 == 0) goto L_0x0058
            int r5 = (r12 > r1 ? 1 : (r12 == r1 ? 0 : -1))
            if (r5 != 0) goto L_0x0058
            r5 = 1
            goto L_0x0059
        L_0x0058:
            r5 = 0
        L_0x0059:
            r4.data(r5, r9, r11, r3)
            goto L_0x000d
        L_0x005d:
            r9 = move-exception
            goto L_0x006c
        L_0x005f:
            java.lang.Thread r9 = java.lang.Thread.currentThread()     // Catch:{ all -> 0x005d }
            r9.interrupt()     // Catch:{ all -> 0x005d }
            java.io.InterruptedIOException r9 = new java.io.InterruptedIOException     // Catch:{ all -> 0x005d }
            r9.<init>()     // Catch:{ all -> 0x005d }
            throw r9     // Catch:{ all -> 0x005d }
        L_0x006c:
            monitor-exit(r8)
            throw r9
        L_0x006e:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Connection.writeData(int, boolean, g.d, long):void");
    }

    public final void writeHeaders$okhttp(int i, boolean z, List<Header> list) throws IOException {
        if (list != null) {
            this.writer.headers(z, i, list);
        } else {
            Intrinsics.m5822a("alternating");
            throw null;
        }
    }

    public final void writePing(boolean z, int i, int i2) {
        try {
            this.writer.ping(z, i, i2);
        } catch (IOException e) {
            failConnection(e);
        }
    }

    public final void writePingAndAwaitPong() throws InterruptedException {
        writePing();
        awaitPong();
    }

    public final void writeSynReset$okhttp(int i, ErrorCode errorCode) throws IOException {
        if (errorCode != null) {
            this.writer.rstStream(i, errorCode);
        } else {
            Intrinsics.m5822a(AnalyticAttribute.STATUS_CODE_ATTRIBUTE);
            throw null;
        }
    }

    public final void writeSynResetLater$okhttp(int i, ErrorCode errorCode) {
        if (errorCode != null) {
            String str = this.connectionName + '[' + i + "] writeSynReset";
            this.writerQueue.schedule(new Http2Connection$writeSynResetLater$$inlined$execute$1(str, true, str, true, this, i, errorCode), 0);
            return;
        }
        Intrinsics.m5822a("errorCode");
        throw null;
    }

    public final void writeWindowUpdateLater$okhttp(int i, long j) {
        String str = this.connectionName + '[' + i + "] windowUpdate";
        this.writerQueue.schedule(new Http2Connection$writeWindowUpdateLater$$inlined$execute$1(str, true, str, true, this, i, j), 0);
    }

    /* JADX WARNING: Removed duplicated region for block: B:21:0x004a  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final okhttp3.internal.http2.Http2Stream newStream(int r11, java.util.List<okhttp3.internal.http2.Header> r12, boolean r13) throws java.io.IOException {
        /*
            r10 = this;
            r6 = r13 ^ 1
            r4 = 0
            okhttp3.internal.http2.Http2Writer r7 = r10.writer
            monitor-enter(r7)
            monitor-enter(r10)     // Catch:{ all -> 0x0084 }
            int r0 = r10.nextStreamId     // Catch:{ all -> 0x0081 }
            r1 = 1073741823(0x3fffffff, float:1.9999999)
            if (r0 <= r1) goto L_0x0013
            okhttp3.internal.http2.ErrorCode r0 = okhttp3.internal.http2.ErrorCode.REFUSED_STREAM     // Catch:{ all -> 0x0081 }
            r10.shutdown(r0)     // Catch:{ all -> 0x0081 }
        L_0x0013:
            boolean r0 = r10.isShutdown     // Catch:{ all -> 0x0081 }
            if (r0 != 0) goto L_0x007b
            int r8 = r10.nextStreamId     // Catch:{ all -> 0x0081 }
            int r0 = r10.nextStreamId     // Catch:{ all -> 0x0081 }
            int r0 = r0 + 2
            r10.nextStreamId = r0     // Catch:{ all -> 0x0081 }
            okhttp3.internal.http2.Http2Stream r9 = new okhttp3.internal.http2.Http2Stream     // Catch:{ all -> 0x0081 }
            r5 = 0
            r0 = r9
            r1 = r8
            r2 = r10
            r3 = r6
            r0.<init>(r1, r2, r3, r4, r5)     // Catch:{ all -> 0x0081 }
            r0 = 1
            if (r13 == 0) goto L_0x0043
            long r1 = r10.writeBytesTotal     // Catch:{ all -> 0x0081 }
            long r3 = r10.writeBytesMaximum     // Catch:{ all -> 0x0081 }
            int r13 = (r1 > r3 ? 1 : (r1 == r3 ? 0 : -1))
            if (r13 >= 0) goto L_0x0043
            long r1 = r9.getWriteBytesTotal()     // Catch:{ all -> 0x0081 }
            long r3 = r9.getWriteBytesMaximum()     // Catch:{ all -> 0x0081 }
            int r13 = (r1 > r3 ? 1 : (r1 == r3 ? 0 : -1))
            if (r13 < 0) goto L_0x0041
            goto L_0x0043
        L_0x0041:
            r13 = 0
            goto L_0x0044
        L_0x0043:
            r13 = 1
        L_0x0044:
            boolean r1 = r9.isOpen()     // Catch:{ all -> 0x0081 }
            if (r1 == 0) goto L_0x0053
            java.util.Map<java.lang.Integer, okhttp3.internal.http2.Http2Stream> r1 = r10.streams     // Catch:{ all -> 0x0081 }
            java.lang.Integer r2 = java.lang.Integer.valueOf(r8)     // Catch:{ all -> 0x0081 }
            r1.put(r2, r9)     // Catch:{ all -> 0x0081 }
        L_0x0053:
            monitor-exit(r10)     // Catch:{ all -> 0x0084 }
            if (r11 != 0) goto L_0x005c
            okhttp3.internal.http2.Http2Writer r11 = r10.writer     // Catch:{ all -> 0x0084 }
            r11.headers(r6, r8, r12)     // Catch:{ all -> 0x0084 }
            goto L_0x0066
        L_0x005c:
            boolean r1 = r10.client     // Catch:{ all -> 0x0084 }
            r0 = r0 ^ r1
            if (r0 == 0) goto L_0x006f
            okhttp3.internal.http2.Http2Writer r0 = r10.writer     // Catch:{ all -> 0x0084 }
            r0.pushPromise(r11, r8, r12)     // Catch:{ all -> 0x0084 }
        L_0x0066:
            monitor-exit(r7)
            if (r13 == 0) goto L_0x006e
            okhttp3.internal.http2.Http2Writer r11 = r10.writer
            r11.flush()
        L_0x006e:
            return r9
        L_0x006f:
            java.lang.String r11 = "client streams shouldn't have associated stream IDs"
            java.lang.IllegalArgumentException r12 = new java.lang.IllegalArgumentException     // Catch:{ all -> 0x0084 }
            java.lang.String r11 = r11.toString()     // Catch:{ all -> 0x0084 }
            r12.<init>(r11)     // Catch:{ all -> 0x0084 }
            throw r12     // Catch:{ all -> 0x0084 }
        L_0x007b:
            okhttp3.internal.http2.ConnectionShutdownException r11 = new okhttp3.internal.http2.ConnectionShutdownException     // Catch:{ all -> 0x0081 }
            r11.<init>()     // Catch:{ all -> 0x0081 }
            throw r11     // Catch:{ all -> 0x0081 }
        L_0x0081:
            r11 = move-exception
            monitor-exit(r10)     // Catch:{ all -> 0x0084 }
            throw r11     // Catch:{ all -> 0x0084 }
        L_0x0084:
            r11 = move-exception
            monitor-exit(r7)
            throw r11
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.http2.Http2Connection.newStream(int, java.util.List, boolean):okhttp3.internal.http2.Http2Stream");
    }

    public final void writePing() throws InterruptedException {
        synchronized (this) {
            this.awaitPingsSent++;
        }
        writePing(false, 3, 1330343787);
    }
}
