package okhttp3.internal.http2;

import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import okhttp3.internal.Util;
import okhttp3.internal.http2.Hpack;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p258m.Progressions;
import p250f.p258m._Ranges;
import p262g.BufferedSource;
import p262g.C1948d;
import p262g.C1952h;
import p262g.Source;
import p262g.Timeout;

/* compiled from: Http2Reader.kt */
public final class Http2Reader implements Closeable {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final Logger logger;
    public final boolean client;
    public final ContinuationSource continuation;
    public final Hpack.Reader hpackReader;
    public final BufferedSource source;

    /* compiled from: Http2Reader.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Logger getLogger() {
            return Http2Reader.logger;
        }

        public final int lengthWithoutPadding(int i, int i2, int i3) throws IOException {
            if ((i2 & 8) != 0) {
                i--;
            }
            if (i3 <= i) {
                return i - i3;
            }
            throw new IOException("PROTOCOL_ERROR padding " + i3 + " > remaining length " + i);
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: Http2Reader.kt */
    public static final class ContinuationSource implements Source {
        public int flags;
        public int left;
        public int length;
        public int padding;
        public final BufferedSource source;
        public int streamId;

        public ContinuationSource(BufferedSource gVar) {
            if (gVar != null) {
                this.source = gVar;
            } else {
                Intrinsics.m5822a("source");
                throw null;
            }
        }

        private final void readContinuationHeader() throws IOException {
            int i = this.streamId;
            int readMedium = Util.readMedium(this.source);
            this.left = readMedium;
            this.length = readMedium;
            int and = Util.and(this.source.readByte(), 255);
            this.flags = Util.and(this.source.readByte(), 255);
            if (Http2Reader.Companion.getLogger().isLoggable(Level.FINE)) {
                Http2Reader.Companion.getLogger().fine(Http2.INSTANCE.frameLog(true, this.streamId, this.length, and, this.flags));
            }
            int readInt = this.source.readInt() & Integer.MAX_VALUE;
            this.streamId = readInt;
            if (and != 9) {
                throw new IOException(and + " != TYPE_CONTINUATION");
            } else if (readInt != i) {
                throw new IOException("TYPE_CONTINUATION streamId changed");
            }
        }

        public void close() throws IOException {
        }

        public final int getFlags() {
            return this.flags;
        }

        public final int getLeft() {
            return this.left;
        }

        public final int getLength() {
            return this.length;
        }

        public final int getPadding() {
            return this.padding;
        }

        public final int getStreamId() {
            return this.streamId;
        }

        public long read(C1948d dVar, long j) throws IOException {
            if (dVar != null) {
                while (true) {
                    int i = this.left;
                    if (i == 0) {
                        this.source.skip((long) this.padding);
                        this.padding = 0;
                        if ((this.flags & 4) != 0) {
                            return -1;
                        }
                        readContinuationHeader();
                    } else {
                        long read = this.source.read(dVar, Math.min(j, (long) i));
                        if (read == -1) {
                            return -1;
                        }
                        this.left -= (int) read;
                        return read;
                    }
                }
            } else {
                Intrinsics.m5822a("sink");
                throw null;
            }
        }

        public final void setFlags(int i) {
            this.flags = i;
        }

        public final void setLeft(int i) {
            this.left = i;
        }

        public final void setLength(int i) {
            this.length = i;
        }

        public final void setPadding(int i) {
            this.padding = i;
        }

        public final void setStreamId(int i) {
            this.streamId = i;
        }

        public Timeout timeout() {
            return this.source.timeout();
        }
    }

    /* compiled from: Http2Reader.kt */
    public interface Handler {
        void ackSettings();

        void alternateService(int i, String str, C1952h hVar, String str2, int i2, long j);

        void data(boolean z, int i, BufferedSource gVar, int i2) throws IOException;

        void goAway(int i, ErrorCode errorCode, C1952h hVar);

        void headers(boolean z, int i, int i2, List<Header> list);

        void ping(boolean z, int i, int i2);

        void priority(int i, int i2, int i3, boolean z);

        void pushPromise(int i, int i2, List<Header> list) throws IOException;

        void rstStream(int i, ErrorCode errorCode);

        void settings(boolean z, Settings settings);

        void windowUpdate(int i, long j);
    }

    static {
        Logger logger2 = Logger.getLogger(Http2.class.getName());
        Intrinsics.m5821a((Object) logger2, "Logger.getLogger(Http2::class.java.name)");
        logger = logger2;
    }

    public Http2Reader(BufferedSource gVar, boolean z) {
        if (gVar != null) {
            this.source = gVar;
            this.client = z;
            ContinuationSource continuationSource = new ContinuationSource(gVar);
            this.continuation = continuationSource;
            this.hpackReader = new Hpack.Reader(continuationSource, 4096, 0, 4, (DefaultConstructorMarker) null);
            return;
        }
        Intrinsics.m5822a("source");
        throw null;
    }

    private final void readData(Handler handler, int i, int i2, int i3) throws IOException {
        if (i3 != 0) {
            int i4 = 0;
            boolean z = true;
            boolean z2 = (i2 & 1) != 0;
            if ((i2 & 32) == 0) {
                z = false;
            }
            if (!z) {
                if ((i2 & 8) != 0) {
                    i4 = Util.and(this.source.readByte(), 255);
                }
                handler.data(z2, i3, this.source, Companion.lengthWithoutPadding(i, i2, i4));
                this.source.skip((long) i4);
                return;
            }
            throw new IOException("PROTOCOL_ERROR: FLAG_COMPRESSED without SETTINGS_COMPRESS_DATA");
        }
        throw new IOException("PROTOCOL_ERROR: TYPE_DATA streamId == 0");
    }

    private final void readGoAway(Handler handler, int i, int i2, int i3) throws IOException {
        if (i < 8) {
            throw new IOException(outline.m2930a("TYPE_GOAWAY length < 8: ", i));
        } else if (i3 == 0) {
            int readInt = this.source.readInt();
            int readInt2 = this.source.readInt();
            int i4 = i - 8;
            ErrorCode fromHttp2 = ErrorCode.Companion.fromHttp2(readInt2);
            if (fromHttp2 != null) {
                C1952h hVar = C1952h.f7658e;
                if (i4 > 0) {
                    hVar = this.source.mo9477b((long) i4);
                }
                handler.goAway(readInt, fromHttp2, hVar);
                return;
            }
            throw new IOException(outline.m2930a("TYPE_GOAWAY unexpected error code: ", readInt2));
        } else {
            throw new IOException("TYPE_GOAWAY streamId != 0");
        }
    }

    private final List<Header> readHeaderBlock(int i, int i2, int i3, int i4) throws IOException {
        this.continuation.setLeft(i);
        ContinuationSource continuationSource = this.continuation;
        continuationSource.setLength(continuationSource.getLeft());
        this.continuation.setPadding(i2);
        this.continuation.setFlags(i3);
        this.continuation.setStreamId(i4);
        this.hpackReader.readHeaders();
        return this.hpackReader.getAndResetHeaderList();
    }

    private final void readHeaders(Handler handler, int i, int i2, int i3) throws IOException {
        if (i3 != 0) {
            int i4 = 0;
            boolean z = (i2 & 1) != 0;
            if ((i2 & 8) != 0) {
                i4 = Util.and(this.source.readByte(), 255);
            }
            if ((i2 & 32) != 0) {
                readPriority(handler, i3);
                i -= 5;
            }
            handler.headers(z, i3, -1, readHeaderBlock(Companion.lengthWithoutPadding(i, i2, i4), i4, i2, i3));
            return;
        }
        throw new IOException("PROTOCOL_ERROR: TYPE_HEADERS streamId == 0");
    }

    private final void readPing(Handler handler, int i, int i2, int i3) throws IOException {
        if (i != 8) {
            throw new IOException(outline.m2930a("TYPE_PING length != 8: ", i));
        } else if (i3 == 0) {
            int readInt = this.source.readInt();
            int readInt2 = this.source.readInt();
            boolean z = true;
            if ((i2 & 1) == 0) {
                z = false;
            }
            handler.ping(z, readInt, readInt2);
        } else {
            throw new IOException("TYPE_PING streamId != 0");
        }
    }

    private final void readPriority(Handler handler, int i, int i2, int i3) throws IOException {
        if (i != 5) {
            throw new IOException("TYPE_PRIORITY length: " + i + " != 5");
        } else if (i3 != 0) {
            readPriority(handler, i3);
        } else {
            throw new IOException("TYPE_PRIORITY streamId == 0");
        }
    }

    private final void readPushPromise(Handler handler, int i, int i2, int i3) throws IOException {
        if (i3 != 0) {
            int and = (i2 & 8) != 0 ? Util.and(this.source.readByte(), 255) : 0;
            handler.pushPromise(i3, this.source.readInt() & Integer.MAX_VALUE, readHeaderBlock(Companion.lengthWithoutPadding(i - 4, i2, and), and, i2, i3));
            return;
        }
        throw new IOException("PROTOCOL_ERROR: TYPE_PUSH_PROMISE streamId == 0");
    }

    private final void readRstStream(Handler handler, int i, int i2, int i3) throws IOException {
        if (i != 4) {
            throw new IOException("TYPE_RST_STREAM length: " + i + " != 4");
        } else if (i3 != 0) {
            int readInt = this.source.readInt();
            ErrorCode fromHttp2 = ErrorCode.Companion.fromHttp2(readInt);
            if (fromHttp2 != null) {
                handler.rstStream(i3, fromHttp2);
                return;
            }
            throw new IOException(outline.m2930a("TYPE_RST_STREAM unexpected error code: ", readInt));
        } else {
            throw new IOException("TYPE_RST_STREAM streamId == 0");
        }
    }

    private final void readSettings(Handler handler, int i, int i2, int i3) throws IOException {
        int readInt;
        if (i3 != 0) {
            throw new IOException("TYPE_SETTINGS streamId != 0");
        } else if ((i2 & 1) != 0) {
            if (i == 0) {
                handler.ackSettings();
                return;
            }
            throw new IOException("FRAME_SIZE_ERROR ack frame should be empty!");
        } else if (i % 6 == 0) {
            Settings settings = new Settings();
            Progressions a = _Ranges.m5827a((Progressions) _Ranges.m5828b(0, i), 6);
            int i4 = a.f7599b;
            int i5 = a.f7600c;
            int i6 = a.f7601d;
            if (i6 < 0 ? i4 >= i5 : i4 <= i5) {
                while (true) {
                    int and = Util.and(this.source.readShort(), 65535);
                    readInt = this.source.readInt();
                    if (and != 2) {
                        if (and == 3) {
                            and = 4;
                        } else if (and == 4) {
                            and = 7;
                            if (readInt < 0) {
                                throw new IOException("PROTOCOL_ERROR SETTINGS_INITIAL_WINDOW_SIZE > 2^31 - 1");
                            }
                        } else if (and == 5 && (readInt < 16384 || readInt > 16777215)) {
                        }
                    } else if (!(readInt == 0 || readInt == 1)) {
                        throw new IOException("PROTOCOL_ERROR SETTINGS_ENABLE_PUSH != 0 or 1");
                    }
                    settings.set(and, readInt);
                    if (i4 == i5) {
                        break;
                    }
                    i4 += i6;
                }
                throw new IOException(outline.m2930a("PROTOCOL_ERROR SETTINGS_MAX_FRAME_SIZE: ", readInt));
            }
            handler.settings(false, settings);
        } else {
            throw new IOException(outline.m2930a("TYPE_SETTINGS length % 6 != 0: ", i));
        }
    }

    private final void readWindowUpdate(Handler handler, int i, int i2, int i3) throws IOException {
        if (i == 4) {
            long and = Util.and(this.source.readInt(), 2147483647L);
            if (and != 0) {
                handler.windowUpdate(i3, and);
                return;
            }
            throw new IOException("windowSizeIncrement was 0");
        }
        throw new IOException(outline.m2930a("TYPE_WINDOW_UPDATE length !=4: ", i));
    }

    public void close() throws IOException {
        this.source.close();
    }

    public final boolean nextFrame(boolean z, Handler handler) throws IOException {
        if (handler != null) {
            try {
                this.source.mo9491g(9);
                int readMedium = Util.readMedium(this.source);
                if (readMedium <= 16384) {
                    int and = Util.and(this.source.readByte(), 255);
                    if (!z || and == 4) {
                        int and2 = Util.and(this.source.readByte(), 255);
                        int readInt = this.source.readInt() & Integer.MAX_VALUE;
                        if (logger.isLoggable(Level.FINE)) {
                            logger.fine(Http2.INSTANCE.frameLog(true, readInt, readMedium, and, and2));
                        }
                        switch (and) {
                            case 0:
                                readData(handler, readMedium, and2, readInt);
                                return true;
                            case 1:
                                readHeaders(handler, readMedium, and2, readInt);
                                return true;
                            case 2:
                                readPriority(handler, readMedium, and2, readInt);
                                return true;
                            case 3:
                                readRstStream(handler, readMedium, and2, readInt);
                                return true;
                            case 4:
                                readSettings(handler, readMedium, and2, readInt);
                                return true;
                            case 5:
                                readPushPromise(handler, readMedium, and2, readInt);
                                return true;
                            case 6:
                                readPing(handler, readMedium, and2, readInt);
                                return true;
                            case 7:
                                readGoAway(handler, readMedium, and2, readInt);
                                return true;
                            case 8:
                                readWindowUpdate(handler, readMedium, and2, readInt);
                                return true;
                            default:
                                this.source.skip((long) readMedium);
                                return true;
                        }
                    } else {
                        throw new IOException(outline.m2930a("Expected a SETTINGS frame but was ", and));
                    }
                } else {
                    throw new IOException(outline.m2930a("FRAME_SIZE_ERROR: ", readMedium));
                }
            } catch (EOFException unused) {
                return false;
            }
        } else {
            Intrinsics.m5822a("handler");
            throw null;
        }
    }

    public final void readConnectionPreface(Handler handler) throws IOException {
        if (handler == null) {
            Intrinsics.m5822a("handler");
            throw null;
        } else if (!this.client) {
            C1952h b = this.source.mo9477b((long) Http2.CONNECTION_PREFACE.mo9540b());
            if (logger.isLoggable(Level.FINE)) {
                Logger logger2 = logger;
                StringBuilder a = outline.m2937a("<< CONNECTION ");
                a.append(b.mo9541c());
                logger2.fine(Util.format(a.toString(), new Object[0]));
            }
            if (!Intrinsics.m5823a((Object) Http2.CONNECTION_PREFACE, (Object) b)) {
                StringBuilder a2 = outline.m2937a("Expected a connection header but was ");
                a2.append(b.mo9547g());
                throw new IOException(a2.toString());
            }
        } else if (!nextFrame(true, handler)) {
            throw new IOException("Required SETTINGS preface not received");
        }
    }

    private final void readPriority(Handler handler, int i) throws IOException {
        int readInt = this.source.readInt();
        handler.priority(i, readInt & Integer.MAX_VALUE, Util.and(this.source.readByte(), 255) + 1, (readInt & ((int) 2147483648L)) != 0);
    }
}
