package okhttp3.internal.platform;

import android.annotation.TargetApi;
import android.os.Build;
import android.security.NetworkSecurityPolicy;
import com.newrelic.agent.android.agentdata.HexAttributes;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import okhttp3.internal.platform.android.Android10CertificateChainCleaner;
import okhttp3.internal.platform.android.Android10SocketAdapter;
import okhttp3.internal.platform.android.ConscryptSocketAdapter;
import okhttp3.internal.platform.android.DeferredSocketAdapter;
import okhttp3.internal.platform.android.SocketAdapter;
import okhttp3.internal.platform.android.UtilKt;
import okhttp3.internal.tls.CertificateChainCleaner;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: Android10Platform.kt */
public final class Android10Platform extends Platform {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final boolean isSupported = (AndroidPlatform.Companion.isAndroid() && Build.VERSION.SDK_INT >= 29);
    public final List<SocketAdapter> socketAdapters;

    /* compiled from: Android10Platform.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Platform buildIfSupported() {
            if (isSupported()) {
                return new Android10Platform();
            }
            return null;
        }

        public final boolean isSupported() {
            return Android10Platform.isSupported;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Android10Platform() {
        List a = C1050v.m4159a((T[]) new SocketAdapter[]{Android10SocketAdapter.Companion.buildIfSupported(), ConscryptSocketAdapter.Companion.buildIfSupported(), new DeferredSocketAdapter("com.google.android.gms.org.conscrypt")});
        ArrayList arrayList = new ArrayList();
        for (Object next : a) {
            if (((SocketAdapter) next).isSupported()) {
                arrayList.add(next);
            }
        }
        this.socketAdapters = arrayList;
    }

    public CertificateChainCleaner buildCertificateChainCleaner(X509TrustManager x509TrustManager) {
        if (x509TrustManager != null) {
            Android10CertificateChainCleaner buildIfSupported = Android10CertificateChainCleaner.Companion.buildIfSupported(x509TrustManager);
            return buildIfSupported != null ? buildIfSupported : super.buildCertificateChainCleaner(x509TrustManager);
        }
        Intrinsics.m5822a("trustManager");
        throw null;
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<? extends Protocol> list) {
        T t = null;
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                T next = it.next();
                if (((SocketAdapter) next).matchesSocket(sSLSocket)) {
                    t = next;
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                socketAdapter.configureTlsExtensions(sSLSocket, str, list);
            }
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        T t;
        if (sSLSocket != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (((SocketAdapter) t).matchesSocket(sSLSocket)) {
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                return socketAdapter.getSelectedProtocol(sSLSocket);
            }
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    @TargetApi(24)
    public boolean isCleartextTrafficPermitted(String str) {
        if (str != null) {
            return NetworkSecurityPolicy.getInstance().isCleartextTrafficPermitted(str);
        }
        Intrinsics.m5822a("hostname");
        throw null;
    }

    public void log(String str, int i, Throwable th) {
        if (str != null) {
            UtilKt.androidLog(i, str, th);
        } else {
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        }
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        T t;
        if (sSLSocketFactory != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (((SocketAdapter) t).matchesSocketFactory(sSLSocketFactory)) {
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                return socketAdapter.trustManager(sSLSocketFactory);
            }
            return null;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
