package okhttp3.internal.platform;

import android.os.Build;
import com.newrelic.agent.android.agentdata.HexAttributes;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.security.cert.TrustAnchor;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import okhttp3.internal.platform.android.AndroidCertificateChainCleaner;
import okhttp3.internal.platform.android.CloseGuard;
import okhttp3.internal.platform.android.ConscryptSocketAdapter;
import okhttp3.internal.platform.android.DeferredSocketAdapter;
import okhttp3.internal.platform.android.SocketAdapter;
import okhttp3.internal.platform.android.StandardAndroidSocketAdapter;
import okhttp3.internal.platform.android.UtilKt;
import okhttp3.internal.tls.CertificateChainCleaner;
import okhttp3.internal.tls.TrustRootIndex;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: AndroidPlatform.kt */
public final class AndroidPlatform extends Platform {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final boolean isAndroid;
    public static final boolean isSupported;
    public final CloseGuard closeGuard;
    public final List<SocketAdapter> socketAdapters;

    /* compiled from: AndroidPlatform.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Platform buildIfSupported() {
            if (isSupported()) {
                return new AndroidPlatform();
            }
            return null;
        }

        public final boolean isAndroid() {
            return AndroidPlatform.isAndroid;
        }

        public final boolean isSupported() {
            return AndroidPlatform.isSupported;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: AndroidPlatform.kt */
    public static final class CustomTrustRootIndex implements TrustRootIndex {
        public final Method findByIssuerAndSignatureMethod;
        public final X509TrustManager trustManager;

        public CustomTrustRootIndex(X509TrustManager x509TrustManager, Method method) {
            if (x509TrustManager == null) {
                Intrinsics.m5822a("trustManager");
                throw null;
            } else if (method != null) {
                this.trustManager = x509TrustManager;
                this.findByIssuerAndSignatureMethod = method;
            } else {
                Intrinsics.m5822a("findByIssuerAndSignatureMethod");
                throw null;
            }
        }

        private final X509TrustManager component1() {
            return this.trustManager;
        }

        private final Method component2() {
            return this.findByIssuerAndSignatureMethod;
        }

        public static /* synthetic */ CustomTrustRootIndex copy$default(CustomTrustRootIndex customTrustRootIndex, X509TrustManager x509TrustManager, Method method, int i, Object obj) {
            if ((i & 1) != 0) {
                x509TrustManager = customTrustRootIndex.trustManager;
            }
            if ((i & 2) != 0) {
                method = customTrustRootIndex.findByIssuerAndSignatureMethod;
            }
            return customTrustRootIndex.copy(x509TrustManager, method);
        }

        public final CustomTrustRootIndex copy(X509TrustManager x509TrustManager, Method method) {
            if (x509TrustManager == null) {
                Intrinsics.m5822a("trustManager");
                throw null;
            } else if (method != null) {
                return new CustomTrustRootIndex(x509TrustManager, method);
            } else {
                Intrinsics.m5822a("findByIssuerAndSignatureMethod");
                throw null;
            }
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof CustomTrustRootIndex)) {
                return false;
            }
            CustomTrustRootIndex customTrustRootIndex = (CustomTrustRootIndex) obj;
            return Intrinsics.m5823a((Object) this.trustManager, (Object) customTrustRootIndex.trustManager) && Intrinsics.m5823a((Object) this.findByIssuerAndSignatureMethod, (Object) customTrustRootIndex.findByIssuerAndSignatureMethod);
        }

        public X509Certificate findByIssuerAndSignature(X509Certificate x509Certificate) {
            if (x509Certificate != null) {
                try {
                    Object invoke = this.findByIssuerAndSignatureMethod.invoke(this.trustManager, new Object[]{x509Certificate});
                    if (invoke != null) {
                        return ((TrustAnchor) invoke).getTrustedCert();
                    }
                    throw new TypeCastException("null cannot be cast to non-null type java.security.cert.TrustAnchor");
                } catch (IllegalAccessException e) {
                    throw new AssertionError("unable to get issues and signature", e);
                } catch (InvocationTargetException unused) {
                    return null;
                }
            } else {
                Intrinsics.m5822a("cert");
                throw null;
            }
        }

        public int hashCode() {
            X509TrustManager x509TrustManager = this.trustManager;
            int i = 0;
            int hashCode = (x509TrustManager != null ? x509TrustManager.hashCode() : 0) * 31;
            Method method = this.findByIssuerAndSignatureMethod;
            if (method != null) {
                i = method.hashCode();
            }
            return hashCode + i;
        }

        public String toString() {
            StringBuilder a = outline.m2937a("CustomTrustRootIndex(trustManager=");
            a.append(this.trustManager);
            a.append(", findByIssuerAndSignatureMethod=");
            a.append(this.findByIssuerAndSignatureMethod);
            a.append(")");
            return a.toString();
        }
    }

    static {
        boolean z;
        boolean z2 = true;
        try {
            Class.forName("com.android.org.conscrypt.OpenSSLSocketImpl");
            if (1 != 0) {
                z = true;
                isAndroid = z;
                if (!z || Build.VERSION.SDK_INT >= 30) {
                    z2 = false;
                } else if (1 == 0) {
                    StringBuilder a = outline.m2937a("Expected Android API level 21+ but was ");
                    a.append(Build.VERSION.SDK_INT);
                    throw new IllegalStateException(a.toString().toString());
                }
                isSupported = z2;
                return;
            }
            throw new IllegalStateException("Check failed.".toString());
        } catch (ClassNotFoundException | UnsatisfiedLinkError unused) {
            z = false;
        }
    }

    public AndroidPlatform() {
        List a = C1050v.m4159a((T[]) new SocketAdapter[]{StandardAndroidSocketAdapter.Companion.buildIfSupported$default(StandardAndroidSocketAdapter.Companion, (String) null, 1, (Object) null), ConscryptSocketAdapter.Companion.buildIfSupported(), new DeferredSocketAdapter("com.google.android.gms.org.conscrypt")});
        ArrayList arrayList = new ArrayList();
        for (Object next : a) {
            if (((SocketAdapter) next).isSupported()) {
                arrayList.add(next);
            }
        }
        this.socketAdapters = arrayList;
        this.closeGuard = CloseGuard.Companion.get();
    }

    private final boolean api23IsCleartextTrafficPermitted(String str, Class<?> cls, Object obj) throws InvocationTargetException, IllegalAccessException {
        try {
            Object invoke = cls.getMethod("isCleartextTrafficPermitted", new Class[0]).invoke(obj, new Object[0]);
            if (invoke != null) {
                return ((Boolean) invoke).booleanValue();
            }
            throw new TypeCastException("null cannot be cast to non-null type kotlin.Boolean");
        } catch (NoSuchMethodException unused) {
            return super.isCleartextTrafficPermitted(str);
        }
    }

    private final boolean api24IsCleartextTrafficPermitted(String str, Class<?> cls, Object obj) throws InvocationTargetException, IllegalAccessException {
        try {
            Object invoke = cls.getMethod("isCleartextTrafficPermitted", new Class[]{String.class}).invoke(obj, new Object[]{str});
            if (invoke != null) {
                return ((Boolean) invoke).booleanValue();
            }
            throw new TypeCastException("null cannot be cast to non-null type kotlin.Boolean");
        } catch (NoSuchMethodException unused) {
            return api23IsCleartextTrafficPermitted(str, cls, obj);
        }
    }

    public CertificateChainCleaner buildCertificateChainCleaner(X509TrustManager x509TrustManager) {
        if (x509TrustManager != null) {
            AndroidCertificateChainCleaner build = AndroidCertificateChainCleaner.Companion.build(x509TrustManager);
            return build != null ? build : super.buildCertificateChainCleaner(x509TrustManager);
        }
        Intrinsics.m5822a("trustManager");
        throw null;
    }

    public TrustRootIndex buildTrustRootIndex(X509TrustManager x509TrustManager) {
        if (x509TrustManager != null) {
            try {
                Method declaredMethod = x509TrustManager.getClass().getDeclaredMethod("findTrustAnchorByIssuerAndSignature", new Class[]{X509Certificate.class});
                Intrinsics.m5821a((Object) declaredMethod, "method");
                declaredMethod.setAccessible(true);
                return new CustomTrustRootIndex(x509TrustManager, declaredMethod);
            } catch (NoSuchMethodException unused) {
                return super.buildTrustRootIndex(x509TrustManager);
            }
        } else {
            Intrinsics.m5822a("trustManager");
            throw null;
        }
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<Protocol> list) {
        T t = null;
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                T next = it.next();
                if (((SocketAdapter) next).matchesSocket(sSLSocket)) {
                    t = next;
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                socketAdapter.configureTlsExtensions(sSLSocket, str, list);
            }
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public void connectSocket(Socket socket, InetSocketAddress inetSocketAddress, int i) throws IOException {
        if (socket == null) {
            Intrinsics.m5822a("socket");
            throw null;
        } else if (inetSocketAddress != null) {
            try {
                socket.connect(inetSocketAddress, i);
            } catch (ClassCastException e) {
                if (Build.VERSION.SDK_INT == 26) {
                    throw new IOException("Exception in connect", e);
                }
                throw e;
            }
        } else {
            Intrinsics.m5822a("address");
            throw null;
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        T t;
        if (sSLSocket != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (((SocketAdapter) t).matchesSocket(sSLSocket)) {
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                return socketAdapter.getSelectedProtocol(sSLSocket);
            }
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public Object getStackTraceForCloseable(String str) {
        if (str != null) {
            return this.closeGuard.createAndOpen(str);
        }
        Intrinsics.m5822a("closer");
        throw null;
    }

    public boolean isCleartextTrafficPermitted(String str) {
        if (str != null) {
            try {
                Class<?> cls = Class.forName("android.security.NetworkSecurityPolicy");
                Object invoke = cls.getMethod("getInstance", new Class[0]).invoke((Object) null, new Object[0]);
                Intrinsics.m5821a((Object) cls, "networkPolicyClass");
                Intrinsics.m5821a(invoke, "networkSecurityPolicy");
                return api24IsCleartextTrafficPermitted(str, cls, invoke);
            } catch (ClassNotFoundException unused) {
                return super.isCleartextTrafficPermitted(str);
            } catch (NoSuchMethodException unused2) {
                return super.isCleartextTrafficPermitted(str);
            } catch (IllegalAccessException e) {
                throw new AssertionError("unable to determine cleartext support", e);
            } catch (IllegalArgumentException e2) {
                throw new AssertionError("unable to determine cleartext support", e2);
            } catch (InvocationTargetException e3) {
                throw new AssertionError("unable to determine cleartext support", e3);
            }
        } else {
            Intrinsics.m5822a("hostname");
            throw null;
        }
    }

    public void log(String str, int i, Throwable th) {
        if (str != null) {
            UtilKt.androidLog(i, str, th);
        } else {
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        }
    }

    public void logCloseableLeak(String str, Object obj) {
        if (str == null) {
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        } else if (!this.closeGuard.warnIfOpen(obj)) {
            Platform.log$default(this, str, 5, (Throwable) null, 4, (Object) null);
        }
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        T t;
        if (sSLSocketFactory != null) {
            Iterator<T> it = this.socketAdapters.iterator();
            while (true) {
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (((SocketAdapter) t).matchesSocketFactory(sSLSocketFactory)) {
                    break;
                }
            }
            SocketAdapter socketAdapter = (SocketAdapter) t;
            if (socketAdapter != null) {
                return socketAdapter.trustManager(sSLSocketFactory);
            }
            return null;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
