package okhttp3.internal.platform;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.util.Arrays;
import java.util.List;
import javax.net.ssl.SSLSocket;
import okhttp3.Protocol;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: Jdk8WithJettyBootPlatform.kt */
public final class Jdk8WithJettyBootPlatform extends Platform {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final Class<?> clientProviderClass;
    public final Method getMethod;
    public final Method putMethod;
    public final Method removeMethod;
    public final Class<?> serverProviderClass;

    /* compiled from: Jdk8WithJettyBootPlatform.kt */
    public static final class AlpnProvider implements InvocationHandler {
        public final List<String> protocols;
        public String selected;
        public boolean unsupported;

        public AlpnProvider(List<String> list) {
            if (list != null) {
                this.protocols = list;
            } else {
                Intrinsics.m5822a("protocols");
                throw null;
            }
        }

        public final String getSelected$okhttp() {
            return this.selected;
        }

        public final boolean getUnsupported$okhttp() {
            return this.unsupported;
        }

        public Object invoke(Object obj, Method method, Object[] objArr) throws Throwable {
            if (obj == null) {
                Intrinsics.m5822a("proxy");
                throw null;
            } else if (method != null) {
                if (objArr == null) {
                    objArr = new Object[0];
                }
                String name = method.getName();
                Class<?> returnType = method.getReturnType();
                if (Intrinsics.m5823a((Object) name, (Object) "supports") && Intrinsics.m5823a((Object) Boolean.TYPE, (Object) returnType)) {
                    return true;
                }
                if (!Intrinsics.m5823a((Object) name, (Object) "unsupported") || !Intrinsics.m5823a((Object) Void.TYPE, (Object) returnType)) {
                    if (Intrinsics.m5823a((Object) name, (Object) "protocols")) {
                        if (objArr.length == 0) {
                            return this.protocols;
                        }
                    }
                    if ((Intrinsics.m5823a((Object) name, (Object) "selectProtocol") || Intrinsics.m5823a((Object) name, (Object) "select")) && Intrinsics.m5823a((Object) String.class, (Object) returnType) && objArr.length == 1 && (objArr[0] instanceof List)) {
                        Object obj2 = objArr[0];
                        if (obj2 != null) {
                            List list = (List) obj2;
                            int size = list.size();
                            if (size >= 0) {
                                int i = 0;
                                while (true) {
                                    Object obj3 = list.get(i);
                                    if (obj3 != null) {
                                        String str = (String) obj3;
                                        if (!this.protocols.contains(str)) {
                                            if (i == size) {
                                                break;
                                            }
                                            i++;
                                        } else {
                                            this.selected = str;
                                            return str;
                                        }
                                    } else {
                                        throw new TypeCastException("null cannot be cast to non-null type kotlin.String");
                                    }
                                }
                            }
                            String str2 = this.protocols.get(0);
                            this.selected = str2;
                            return str2;
                        }
                        throw new TypeCastException("null cannot be cast to non-null type kotlin.collections.List<*>");
                    } else if ((!Intrinsics.m5823a((Object) name, (Object) "protocolSelected") && !Intrinsics.m5823a((Object) name, (Object) "selected")) || objArr.length != 1) {
                        return method.invoke(this, Arrays.copyOf(objArr, objArr.length));
                    } else {
                        Object obj4 = objArr[0];
                        if (obj4 != null) {
                            this.selected = (String) obj4;
                            return null;
                        }
                        throw new TypeCastException("null cannot be cast to non-null type kotlin.String");
                    }
                } else {
                    this.unsupported = true;
                    return null;
                }
            } else {
                Intrinsics.m5822a("method");
                throw null;
            }
        }

        public final void setSelected$okhttp(String str) {
            this.selected = str;
        }

        public final void setUnsupported$okhttp(boolean z) {
            this.unsupported = z;
        }
    }

    /* compiled from: Jdk8WithJettyBootPlatform.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Platform buildIfSupported() {
            String property = System.getProperty("java.specification.version", "unknown");
            try {
                Intrinsics.m5821a((Object) property, "jvmVersion");
                if (Integer.parseInt(property) >= 9) {
                    return null;
                }
            } catch (NumberFormatException unused) {
            }
            try {
                Class<?> cls = Class.forName("org.eclipse.jetty.alpn.ALPN", true, (ClassLoader) null);
                Class<?> cls2 = Class.forName("org.eclipse.jetty.alpn.ALPN$Provider", true, (ClassLoader) null);
                Class<?> cls3 = Class.forName("org.eclipse.jetty.alpn.ALPN$ClientProvider", true, (ClassLoader) null);
                Class<?> cls4 = Class.forName("org.eclipse.jetty.alpn.ALPN$ServerProvider", true, (ClassLoader) null);
                Method method = cls.getMethod("put", new Class[]{SSLSocket.class, cls2});
                Method method2 = cls.getMethod("get", new Class[]{SSLSocket.class});
                Method method3 = cls.getMethod("remove", new Class[]{SSLSocket.class});
                Intrinsics.m5821a((Object) method, "putMethod");
                Intrinsics.m5821a((Object) method2, "getMethod");
                Intrinsics.m5821a((Object) method3, "removeMethod");
                Intrinsics.m5821a((Object) cls3, "clientProviderClass");
                Intrinsics.m5821a((Object) cls4, "serverProviderClass");
                return new Jdk8WithJettyBootPlatform(method, method2, method3, cls3, cls4);
            } catch (ClassNotFoundException | NoSuchMethodException unused2) {
                return null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Jdk8WithJettyBootPlatform(Method method, Method method2, Method method3, Class<?> cls, Class<?> cls2) {
        if (method == null) {
            Intrinsics.m5822a("putMethod");
            throw null;
        } else if (method2 == null) {
            Intrinsics.m5822a("getMethod");
            throw null;
        } else if (method3 == null) {
            Intrinsics.m5822a("removeMethod");
            throw null;
        } else if (cls == null) {
            Intrinsics.m5822a("clientProviderClass");
            throw null;
        } else if (cls2 != null) {
            this.putMethod = method;
            this.getMethod = method2;
            this.removeMethod = method3;
            this.clientProviderClass = cls;
            this.serverProviderClass = cls2;
        } else {
            Intrinsics.m5822a("serverProviderClass");
            throw null;
        }
    }

    public void afterHandshake(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            try {
                this.removeMethod.invoke((Object) null, new Object[]{sSLSocket});
            } catch (IllegalAccessException e) {
                throw new AssertionError("failed to remove ALPN", e);
            } catch (InvocationTargetException e2) {
                throw new AssertionError("failed to remove ALPN", e2);
            }
        } else {
            Intrinsics.m5822a("sslSocket");
            throw null;
        }
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<? extends Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            List<String> alpnProtocolNames = Platform.Companion.alpnProtocolNames(list);
            try {
                Object newProxyInstance = Proxy.newProxyInstance(Platform.class.getClassLoader(), new Class[]{this.clientProviderClass, this.serverProviderClass}, new AlpnProvider(alpnProtocolNames));
                this.putMethod.invoke((Object) null, new Object[]{sSLSocket, newProxyInstance});
            } catch (InvocationTargetException e) {
                throw new AssertionError("failed to set ALPN", e);
            } catch (IllegalAccessException e2) {
                throw new AssertionError("failed to set ALPN", e2);
            }
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            try {
                InvocationHandler invocationHandler = Proxy.getInvocationHandler(this.getMethod.invoke((Object) null, new Object[]{sSLSocket}));
                if (invocationHandler != null) {
                    AlpnProvider alpnProvider = (AlpnProvider) invocationHandler;
                    if (!alpnProvider.getUnsupported$okhttp() && alpnProvider.getSelected$okhttp() == null) {
                        Platform.log$default(this, "ALPN callback dropped: HTTP/2 is disabled. Is alpn-boot on the boot class path?", 0, (Throwable) null, 6, (Object) null);
                        return null;
                    } else if (alpnProvider.getUnsupported$okhttp()) {
                        return null;
                    } else {
                        return alpnProvider.getSelected$okhttp();
                    }
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type okhttp3.internal.platform.Jdk8WithJettyBootPlatform.AlpnProvider");
                }
            } catch (InvocationTargetException e) {
                throw new AssertionError("failed to get ALPN selected protocol", e);
            } catch (IllegalAccessException e2) {
                throw new AssertionError("failed to get ALPN selected protocol", e2);
            }
        } else {
            Intrinsics.m5822a("sslSocket");
            throw null;
        }
    }
}
