package okhttp3.internal.platform;

import java.util.List;
import javax.net.ssl.SSLParameters;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: Jdk9Platform.kt */
public class Jdk9Platform extends Platform {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final boolean isAvailable;

    /* compiled from: Jdk9Platform.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Jdk9Platform buildIfSupported() {
            if (isAvailable()) {
                return new Jdk9Platform();
            }
            return null;
        }

        public final boolean isAvailable() {
            return Jdk9Platform.isAvailable;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    static {
        Integer integer = Integer.getInteger("java.specification.version");
        isAvailable = (integer != null ? integer.intValue() : 8) >= 9;
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            SSLParameters sSLParameters = sSLSocket.getSSLParameters();
            List<String> alpnProtocolNames = Platform.Companion.alpnProtocolNames(list);
            Intrinsics.m5821a((Object) sSLParameters, "sslParameters");
            Object[] array = alpnProtocolNames.toArray(new String[0]);
            if (array != null) {
                sSLParameters.setApplicationProtocols((String[]) array);
                sSLSocket.setSSLParameters(sSLParameters);
                return;
            }
            throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            String applicationProtocol = sSLSocket.getApplicationProtocol();
            if (applicationProtocol != null && !Intrinsics.m5823a((Object) applicationProtocol, (Object) "")) {
                return applicationProtocol;
            }
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            throw new UnsupportedOperationException("clientBuilder.sslSocketFactory(SSLSocketFactory) not supported on JDK 9+");
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
