package okhttp3.internal.platform.android;

import android.net.http.X509TrustManagerExtensions;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.X509TrustManager;
import okhttp3.internal.tls.CertificateChainCleaner;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: Android10CertificateChainCleaner.kt */
public final class Android10CertificateChainCleaner extends CertificateChainCleaner {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final X509TrustManager trustManager;
    public final X509TrustManagerExtensions x509TrustManagerExtensions;

    /* compiled from: Android10CertificateChainCleaner.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Android10CertificateChainCleaner buildIfSupported(X509TrustManager x509TrustManager) {
            X509TrustManagerExtensions x509TrustManagerExtensions;
            if (x509TrustManager != null) {
                try {
                    x509TrustManagerExtensions = new X509TrustManagerExtensions(x509TrustManager);
                } catch (IllegalArgumentException unused) {
                    x509TrustManagerExtensions = null;
                }
                if (x509TrustManagerExtensions != null) {
                    return new Android10CertificateChainCleaner(x509TrustManager, x509TrustManagerExtensions);
                }
                return null;
            }
            Intrinsics.m5822a("trustManager");
            throw null;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Android10CertificateChainCleaner(X509TrustManager x509TrustManager, X509TrustManagerExtensions x509TrustManagerExtensions2) {
        if (x509TrustManager == null) {
            Intrinsics.m5822a("trustManager");
            throw null;
        } else if (x509TrustManagerExtensions2 != null) {
            this.trustManager = x509TrustManager;
            this.x509TrustManagerExtensions = x509TrustManagerExtensions2;
        } else {
            Intrinsics.m5822a("x509TrustManagerExtensions");
            throw null;
        }
    }

    public List<Certificate> clean(List<? extends Certificate> list, String str) throws SSLPeerUnverifiedException {
        if (list == null) {
            Intrinsics.m5822a("chain");
            throw null;
        } else if (str != null) {
            Object[] array = list.toArray(new X509Certificate[0]);
            if (array != null) {
                try {
                    List<X509Certificate> checkServerTrusted = this.x509TrustManagerExtensions.checkServerTrusted((X509Certificate[]) array, "RSA", str);
                    Intrinsics.m5821a((Object) checkServerTrusted, "x509TrustManagerExtensio…ficates, \"RSA\", hostname)");
                    return checkServerTrusted;
                } catch (CertificateException e) {
                    SSLPeerUnverifiedException sSLPeerUnverifiedException = new SSLPeerUnverifiedException(e.getMessage());
                    sSLPeerUnverifiedException.initCause(e);
                    throw sSLPeerUnverifiedException;
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
            }
        } else {
            Intrinsics.m5822a("hostname");
            throw null;
        }
    }

    public boolean equals(Object obj) {
        return (obj instanceof Android10CertificateChainCleaner) && ((Android10CertificateChainCleaner) obj).trustManager == this.trustManager;
    }

    public int hashCode() {
        return System.identityHashCode(this.trustManager);
    }
}
