package okhttp3.internal.platform.android;

import android.annotation.SuppressLint;
import android.net.SSLCertificateSocketFactory;
import android.os.Build;
import java.io.IOException;
import java.util.List;
import javax.net.SocketFactory;
import javax.net.ssl.SSLParameters;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import okhttp3.internal.platform.AndroidPlatform;
import okhttp3.internal.platform.Platform;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;

/* compiled from: Android10SocketAdapter.kt */
public final class Android10SocketAdapter implements SocketAdapter {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final SSLCertificateSocketFactory socketFactory;

    /* compiled from: Android10SocketAdapter.kt */
    public static final class Companion {
        public Companion() {
        }

        public final SocketAdapter buildIfSupported() {
            if (isSupported()) {
                return new Android10SocketAdapter();
            }
            return null;
        }

        public final boolean isSupported() {
            return AndroidPlatform.Companion.isAndroid() && Build.VERSION.SDK_INT >= 29;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public Android10SocketAdapter() {
        SocketFactory socketFactory2 = SSLCertificateSocketFactory.getDefault(10000);
        if (socketFactory2 != null) {
            this.socketFactory = (SSLCertificateSocketFactory) socketFactory2;
            return;
        }
        throw new TypeCastException("null cannot be cast to non-null type android.net.SSLCertificateSocketFactory");
    }

    @SuppressLint({"NewApi"})
    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<? extends Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            try {
                this.socketFactory.setUseSessionTickets(sSLSocket, true);
                SSLParameters sSLParameters = sSLSocket.getSSLParameters();
                Intrinsics.m5821a((Object) sSLParameters, "sslParameters");
                Object[] array = Platform.Companion.alpnProtocolNames(list).toArray(new String[0]);
                if (array != null) {
                    sSLParameters.setApplicationProtocols((String[]) array);
                    sSLSocket.setSSLParameters(sSLParameters);
                    return;
                }
                throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
            } catch (IllegalArgumentException e) {
                throw new IOException("Android internal error", e);
            }
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    @SuppressLint({"NewApi"})
    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            String applicationProtocol = sSLSocket.getApplicationProtocol();
            if (applicationProtocol != null && !Intrinsics.m5823a((Object) applicationProtocol, (Object) "")) {
                return applicationProtocol;
            }
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public boolean isSupported() {
        return Companion.isSupported();
    }

    public boolean matchesSocket(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            String name = sSLSocket.getClass().getName();
            Intrinsics.m5821a((Object) name, "sslSocket.javaClass.name");
            return C1937g.m5864b(name, "com.android.org.conscrypt", false, 2);
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public boolean matchesSocketFactory(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return false;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return null;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
