package okhttp3.internal.platform.android;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.X509TrustManager;
import okhttp3.internal.tls.CertificateChainCleaner;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: AndroidCertificateChainCleaner.kt */
public final class AndroidCertificateChainCleaner extends CertificateChainCleaner {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final Method checkServerTrusted;
    public final X509TrustManager trustManager;
    public final Object x509TrustManagerExtensions;

    /* compiled from: AndroidCertificateChainCleaner.kt */
    public static final class Companion {
        public Companion() {
        }

        public final AndroidCertificateChainCleaner build(X509TrustManager x509TrustManager) {
            Class<String> cls = String.class;
            if (x509TrustManager != null) {
                try {
                    Class<?> cls2 = Class.forName("android.net.http.X509TrustManagerExtensions");
                    Object newInstance = cls2.getConstructor(new Class[]{X509TrustManager.class}).newInstance(new Object[]{x509TrustManager});
                    Method method = cls2.getMethod("checkServerTrusted", new Class[]{X509Certificate[].class, cls, cls});
                    Intrinsics.m5821a((Object) newInstance, "extensions");
                    Intrinsics.m5821a((Object) method, "checkServerTrusted");
                    return new AndroidCertificateChainCleaner(x509TrustManager, newInstance, method);
                } catch (Exception unused) {
                    return null;
                }
            } else {
                Intrinsics.m5822a("trustManager");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public AndroidCertificateChainCleaner(X509TrustManager x509TrustManager, Object obj, Method method) {
        if (x509TrustManager == null) {
            Intrinsics.m5822a("trustManager");
            throw null;
        } else if (obj == null) {
            Intrinsics.m5822a("x509TrustManagerExtensions");
            throw null;
        } else if (method != null) {
            this.trustManager = x509TrustManager;
            this.x509TrustManagerExtensions = obj;
            this.checkServerTrusted = method;
        } else {
            Intrinsics.m5822a("checkServerTrusted");
            throw null;
        }
    }

    public List<Certificate> clean(List<? extends Certificate> list, String str) throws SSLPeerUnverifiedException {
        if (list == null) {
            Intrinsics.m5822a("chain");
            throw null;
        } else if (str != null) {
            try {
                Object array = list.toArray(new X509Certificate[0]);
                if (array != null) {
                    Object invoke = this.checkServerTrusted.invoke(this.x509TrustManagerExtensions, new Object[]{(X509Certificate[]) array, "RSA", str});
                    if (invoke != null) {
                        return (List) invoke;
                    }
                    throw new TypeCastException("null cannot be cast to non-null type kotlin.collections.List<java.security.cert.Certificate>");
                }
                throw new TypeCastException("null cannot be cast to non-null type kotlin.Array<T>");
            } catch (InvocationTargetException e) {
                SSLPeerUnverifiedException sSLPeerUnverifiedException = new SSLPeerUnverifiedException(e.getMessage());
                sSLPeerUnverifiedException.initCause(e);
                throw sSLPeerUnverifiedException;
            } catch (IllegalAccessException e2) {
                throw new AssertionError(e2);
            }
        } else {
            Intrinsics.m5822a("hostname");
            throw null;
        }
    }

    public boolean equals(Object obj) {
        return (obj instanceof AndroidCertificateChainCleaner) && ((AndroidCertificateChainCleaner) obj).trustManager == this.trustManager;
    }

    public int hashCode() {
        return System.identityHashCode(this.trustManager);
    }
}
