package okhttp3.internal.platform.android;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.List;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import okhttp3.internal.platform.AndroidPlatform;
import okhttp3.internal.platform.Platform;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: AndroidSocketAdapter.kt */
public class AndroidSocketAdapter implements SocketAdapter {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public final Method getAlpnSelectedProtocol;
    public final Method setAlpnProtocols;
    public final Method setHostname;
    public final Method setUseSessionTickets;
    public final Class<? super SSLSocket> sslSocketClass;

    /* compiled from: AndroidSocketAdapter.kt */
    public static final class Companion {
        public Companion() {
        }

        public final SocketAdapter buildIfSupported(String str) {
            if (str != null) {
                try {
                    return new AndroidSocketAdapter(Class.forName(str + ".OpenSSLSocketImpl"));
                } catch (Exception e) {
                    UtilKt.androidLog(5, "unable to load android socket classes", e);
                    return null;
                }
            } else {
                Intrinsics.m5822a("packageName");
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public AndroidSocketAdapter(Class<? super SSLSocket> cls) {
        if (cls != null) {
            this.sslSocketClass = cls;
            Method declaredMethod = cls.getDeclaredMethod("setUseSessionTickets", new Class[]{Boolean.TYPE});
            Intrinsics.m5821a((Object) declaredMethod, "sslSocketClass.getDeclar…:class.javaPrimitiveType)");
            this.setUseSessionTickets = declaredMethod;
            this.setHostname = this.sslSocketClass.getMethod("setHostname", new Class[]{String.class});
            this.getAlpnSelectedProtocol = this.sslSocketClass.getMethod("getAlpnSelectedProtocol", new Class[0]);
            this.setAlpnProtocols = this.sslSocketClass.getMethod("setAlpnProtocols", new Class[]{byte[].class});
            return;
        }
        Intrinsics.m5822a("sslSocketClass");
        throw null;
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<? extends Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list == null) {
            Intrinsics.m5822a("protocols");
            throw null;
        } else if (matchesSocket(sSLSocket)) {
            try {
                this.setUseSessionTickets.invoke(sSLSocket, new Object[]{true});
                if (str != null) {
                    this.setHostname.invoke(sSLSocket, new Object[]{str});
                }
                this.setAlpnProtocols.invoke(sSLSocket, new Object[]{Platform.Companion.concatLengthPrefixed(list)});
            } catch (IllegalAccessException e) {
                throw new AssertionError(e);
            } catch (InvocationTargetException e2) {
                throw new AssertionError(e2);
            }
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (!matchesSocket(sSLSocket)) {
            return null;
        } else {
            try {
                byte[] bArr = (byte[]) this.getAlpnSelectedProtocol.invoke(sSLSocket, new Object[0]);
                if (bArr == null) {
                    return null;
                }
                Charset charset = StandardCharsets.UTF_8;
                Intrinsics.m5821a((Object) charset, "StandardCharsets.UTF_8");
                return new String(bArr, charset);
            } catch (NullPointerException e) {
                if (Intrinsics.m5823a((Object) e.getMessage(), (Object) "ssl == null")) {
                    return null;
                }
                throw e;
            } catch (IllegalAccessException e2) {
                throw new AssertionError(e2);
            } catch (InvocationTargetException e3) {
                throw new AssertionError(e3);
            }
        }
    }

    public boolean isSupported() {
        return AndroidPlatform.Companion.isSupported();
    }

    public boolean matchesSocket(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            return this.sslSocketClass.isInstance(sSLSocket);
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public boolean matchesSocketFactory(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return false;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return null;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
