package okhttp3.internal.platform.android;

import java.util.List;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.Protocol;
import okhttp3.internal.platform.Platform;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;

/* compiled from: DeferredSocketAdapter.kt */
public final class DeferredSocketAdapter implements SocketAdapter {
    public SocketAdapter delegate;
    public boolean initialized;
    public final String socketPackage;

    public DeferredSocketAdapter(String str) {
        if (str != null) {
            this.socketPackage = str;
        } else {
            Intrinsics.m5822a("socketPackage");
            throw null;
        }
    }

    private final synchronized SocketAdapter getDelegate(SSLSocket sSLSocket) {
        if (!this.initialized) {
            try {
                Class cls = sSLSocket.getClass();
                while (true) {
                    String name = cls.getName();
                    if (!(!Intrinsics.m5823a((Object) name, (Object) this.socketPackage + ".OpenSSLSocketImpl"))) {
                        break;
                    }
                    cls = cls.getSuperclass();
                    Intrinsics.m5821a((Object) cls, "possibleClass.superclass");
                }
                this.delegate = new AndroidSocketAdapter(cls);
            } catch (Exception e) {
                Platform platform = Platform.Companion.get();
                platform.log("Failed to initialize DeferredSocketAdapter " + this.socketPackage, 5, e);
            }
            this.initialized = true;
        }
        return this.delegate;
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<? extends Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list != null) {
            SocketAdapter delegate2 = getDelegate(sSLSocket);
            if (delegate2 != null) {
                delegate2.configureTlsExtensions(sSLSocket, str, list);
            }
        } else {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            SocketAdapter delegate2 = getDelegate(sSLSocket);
            if (delegate2 != null) {
                return delegate2.getSelectedProtocol(sSLSocket);
            }
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public boolean isSupported() {
        return true;
    }

    public boolean matchesSocket(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            String name = sSLSocket.getClass().getName();
            Intrinsics.m5821a((Object) name, "sslSocket.javaClass.name");
            return C1937g.m5864b(name, this.socketPackage, false, 2);
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public boolean matchesSocketFactory(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return false;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            return null;
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
