package okhttp3.internal.publicsuffix;

import java.net.IDN;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.atomic.AtomicBoolean;
import okhttp3.internal.Util;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.p251i.Sequences;
import p250f.p254l.p255b.C1907l;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p250f.p260o.C1930a;
import p250f.p260o.C1932b;
import p250f.p260o.Sequence;
import p250f.p261p.C1937g;

/* compiled from: PublicSuffixDatabase.kt */
public final class PublicSuffixDatabase {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final char EXCEPTION_MARKER = '!';
    public static final List<String> PREVAILING_RULE = C1050v.m4212c("*");
    public static final String PUBLIC_SUFFIX_RESOURCE = "publicsuffixes.gz";
    public static final byte[] WILDCARD_LABEL = {(byte) 42};
    public static final PublicSuffixDatabase instance = new PublicSuffixDatabase();
    public final AtomicBoolean listRead = new AtomicBoolean(false);
    public byte[] publicSuffixExceptionListBytes;
    public byte[] publicSuffixListBytes;
    public final CountDownLatch readCompleteLatch = new CountDownLatch(1);

    /* compiled from: PublicSuffixDatabase.kt */
    public static final class Companion {
        public Companion() {
        }

        /* access modifiers changed from: private */
        public final String binarySearch(byte[] bArr, byte[][] bArr2, int i) {
            int i2;
            boolean z;
            int i3;
            int and;
            byte[] bArr3 = bArr;
            byte[][] bArr4 = bArr2;
            int length = bArr3.length;
            int i4 = 0;
            while (i4 < length) {
                int i5 = (i4 + length) / 2;
                while (i5 > -1 && bArr3[i5] != ((byte) 10)) {
                    i5--;
                }
                int i6 = i5 + 1;
                int i7 = 1;
                while (true) {
                    i2 = i6 + i7;
                    if (bArr3[i2] == ((byte) 10)) {
                        break;
                    }
                    i7++;
                }
                int i8 = i2 - i6;
                int i9 = i;
                boolean z2 = false;
                int i10 = 0;
                int i11 = 0;
                while (true) {
                    if (z2) {
                        i3 = 46;
                        z = false;
                    } else {
                        z = z2;
                        i3 = Util.and(bArr4[i9][i10], 255);
                    }
                    and = i3 - Util.and(bArr3[i6 + i11], 255);
                    if (and == 0) {
                        i11++;
                        i10++;
                        if (i11 == i8) {
                            break;
                        } else if (bArr4[i9].length != i10) {
                            z2 = z;
                        } else if (i9 == bArr4.length - 1) {
                            break;
                        } else {
                            i9++;
                            z2 = true;
                            i10 = -1;
                        }
                    } else {
                        break;
                    }
                }
                if (and >= 0) {
                    if (and <= 0) {
                        int i12 = i8 - i11;
                        int length2 = bArr4[i9].length - i10;
                        int length3 = bArr4.length;
                        for (int i13 = i9 + 1; i13 < length3; i13++) {
                            length2 += bArr4[i13].length;
                        }
                        if (length2 >= i12) {
                            if (length2 <= i12) {
                                Charset charset = StandardCharsets.UTF_8;
                                Intrinsics.m5821a((Object) charset, "UTF_8");
                                return new String(bArr3, i6, i8, charset);
                            }
                        }
                    }
                    i4 = i2 + 1;
                }
                length = i6 - 1;
            }
            return null;
        }

        public final PublicSuffixDatabase get() {
            return PublicSuffixDatabase.instance;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public static final /* synthetic */ byte[] access$getPublicSuffixListBytes$p(PublicSuffixDatabase publicSuffixDatabase) {
        byte[] bArr = publicSuffixDatabase.publicSuffixListBytes;
        if (bArr != null) {
            return bArr;
        }
        Intrinsics.m5824b("publicSuffixListBytes");
        throw null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:44:0x009d  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x00bd  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x00d7  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final java.util.List<java.lang.String> findMatchingRule(java.util.List<java.lang.String> r12) {
        /*
            r11 = this;
            java.util.concurrent.atomic.AtomicBoolean r0 = r11.listRead
            boolean r0 = r0.get()
            r1 = 1
            r2 = 0
            if (r0 != 0) goto L_0x0016
            java.util.concurrent.atomic.AtomicBoolean r0 = r11.listRead
            boolean r0 = r0.compareAndSet(r2, r1)
            if (r0 == 0) goto L_0x0016
            r11.readTheListUninterruptibly()
            goto L_0x0023
        L_0x0016:
            java.util.concurrent.CountDownLatch r0 = r11.readCompleteLatch     // Catch:{ InterruptedException -> 0x001c }
            r0.await()     // Catch:{ InterruptedException -> 0x001c }
            goto L_0x0023
        L_0x001c:
            java.lang.Thread r0 = java.lang.Thread.currentThread()
            r0.interrupt()
        L_0x0023:
            byte[] r0 = r11.publicSuffixListBytes
            if (r0 == 0) goto L_0x0029
            r0 = 1
            goto L_0x002a
        L_0x0029:
            r0 = 0
        L_0x002a:
            if (r0 == 0) goto L_0x0109
            int r0 = r12.size()
            byte[][] r3 = new byte[r0][]
            r4 = 0
        L_0x0033:
            if (r4 >= r0) goto L_0x005a
            java.lang.Object r5 = r12.get(r4)
            java.lang.String r5 = (java.lang.String) r5
            java.nio.charset.Charset r6 = java.nio.charset.StandardCharsets.UTF_8
            java.lang.String r7 = "UTF_8"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r6, (java.lang.String) r7)
            if (r5 == 0) goto L_0x0052
            byte[] r5 = r5.getBytes(r6)
            java.lang.String r6 = "(this as java.lang.String).getBytes(charset)"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r5, (java.lang.String) r6)
            r3[r4] = r5
            int r4 = r4 + 1
            goto L_0x0033
        L_0x0052:
            f.e r12 = new f.e
            java.lang.String r0 = "null cannot be cast to non-null type java.lang.String"
            r12.<init>(r0)
            throw r12
        L_0x005a:
            r12 = 0
        L_0x005b:
            java.lang.String r4 = "publicSuffixListBytes"
            r5 = 0
            if (r12 >= r0) goto L_0x0074
            okhttp3.internal.publicsuffix.PublicSuffixDatabase$Companion r6 = Companion
            byte[] r7 = r11.publicSuffixListBytes
            if (r7 == 0) goto L_0x0070
            java.lang.String r6 = r6.binarySearch(r7, r3, r12)
            if (r6 == 0) goto L_0x006d
            goto L_0x0075
        L_0x006d:
            int r12 = r12 + 1
            goto L_0x005b
        L_0x0070:
            p250f.p254l.p256c.Intrinsics.m5824b(r4)
            throw r5
        L_0x0074:
            r6 = r5
        L_0x0075:
            if (r0 <= r1) goto L_0x009a
            java.lang.Object r12 = r3.clone()
            byte[][] r12 = (byte[][]) r12
            int r7 = r12.length
            int r7 = r7 - r1
            r8 = 0
        L_0x0080:
            if (r8 >= r7) goto L_0x009a
            byte[] r9 = WILDCARD_LABEL
            r12[r8] = r9
            okhttp3.internal.publicsuffix.PublicSuffixDatabase$Companion r9 = Companion
            byte[] r10 = r11.publicSuffixListBytes
            if (r10 == 0) goto L_0x0096
            java.lang.String r9 = r9.binarySearch(r10, r12, r8)
            if (r9 == 0) goto L_0x0093
            goto L_0x009b
        L_0x0093:
            int r8 = r8 + 1
            goto L_0x0080
        L_0x0096:
            p250f.p254l.p256c.Intrinsics.m5824b(r4)
            throw r5
        L_0x009a:
            r9 = r5
        L_0x009b:
            if (r9 == 0) goto L_0x00b8
            int r0 = r0 - r1
            r12 = 0
        L_0x009f:
            if (r12 >= r0) goto L_0x00b8
            okhttp3.internal.publicsuffix.PublicSuffixDatabase$Companion r4 = Companion
            byte[] r7 = r11.publicSuffixExceptionListBytes
            if (r7 == 0) goto L_0x00b2
            java.lang.String r4 = r4.binarySearch(r7, r3, r12)
            if (r4 == 0) goto L_0x00af
            r5 = r4
            goto L_0x00b8
        L_0x00af:
            int r12 = r12 + 1
            goto L_0x009f
        L_0x00b2:
            java.lang.String r12 = "publicSuffixExceptionListBytes"
            p250f.p254l.p256c.Intrinsics.m5824b(r12)
            throw r5
        L_0x00b8:
            r12 = 6
            r0 = 46
            if (r5 == 0) goto L_0x00d7
            java.lang.StringBuilder r3 = new java.lang.StringBuilder
            r3.<init>()
            r4 = 33
            r3.append(r4)
            r3.append(r5)
            java.lang.String r3 = r3.toString()
            char[] r1 = new char[r1]
            r1[r2] = r0
            java.util.List r12 = p250f.p261p.C1937g.m5850a((java.lang.CharSequence) r3, (char[]) r1, (boolean) r2, (int) r2, (int) r12)
            return r12
        L_0x00d7:
            if (r6 != 0) goto L_0x00de
            if (r9 != 0) goto L_0x00de
            java.util.List<java.lang.String> r12 = PREVAILING_RULE
            return r12
        L_0x00de:
            if (r6 == 0) goto L_0x00eb
            char[] r3 = new char[r1]
            r3[r2] = r0
            java.util.List r3 = p250f.p261p.C1937g.m5850a((java.lang.CharSequence) r6, (char[]) r3, (boolean) r2, (int) r2, (int) r12)
            if (r3 == 0) goto L_0x00eb
            goto L_0x00ed
        L_0x00eb:
            f.i.h r3 = p250f.p251i.C1892h.f7579b
        L_0x00ed:
            if (r9 == 0) goto L_0x00fa
            char[] r1 = new char[r1]
            r1[r2] = r0
            java.util.List r12 = p250f.p261p.C1937g.m5850a((java.lang.CharSequence) r9, (char[]) r1, (boolean) r2, (int) r2, (int) r12)
            if (r12 == 0) goto L_0x00fa
            goto L_0x00fc
        L_0x00fa:
            f.i.h r12 = p250f.p251i.C1892h.f7579b
        L_0x00fc:
            int r0 = r3.size()
            int r1 = r12.size()
            if (r0 <= r1) goto L_0x0107
            goto L_0x0108
        L_0x0107:
            r3 = r12
        L_0x0108:
            return r3
        L_0x0109:
            java.lang.IllegalStateException r12 = new java.lang.IllegalStateException
            java.lang.String r0 = "Unable to load publicsuffixes.gz resource from the classpath."
            java.lang.String r0 = r0.toString()
            r12.<init>(r0)
            throw r12
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.publicsuffix.PublicSuffixDatabase.findMatchingRule(java.util.List):java.util.List");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0050, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0051, code lost:
        p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0054, code lost:
        throw r2;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final void readTheList() throws java.io.IOException {
        /*
            r4 = this;
            java.lang.Class<okhttp3.internal.publicsuffix.PublicSuffixDatabase> r0 = okhttp3.internal.publicsuffix.PublicSuffixDatabase.class
            java.lang.String r1 = "publicsuffixes.gz"
            java.io.InputStream r0 = r0.getResourceAsStream(r1)
            if (r0 == 0) goto L_0x0055
            g.m r1 = new g.m
            g.o r2 = new g.o
            g.a0 r3 = new g.a0
            r3.<init>()
            r2.<init>(r0, r3)
            r1.<init>(r2)
            g.g r0 = p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4148a((p262g.Source) r1)
            int r1 = r0.readInt()     // Catch:{ all -> 0x004e }
            long r1 = (long) r1     // Catch:{ all -> 0x004e }
            byte[] r1 = r0.mo9497i(r1)     // Catch:{ all -> 0x004e }
            int r2 = r0.readInt()     // Catch:{ all -> 0x004e }
            long r2 = (long) r2     // Catch:{ all -> 0x004e }
            byte[] r2 = r0.mo9497i(r2)     // Catch:{ all -> 0x004e }
            r3 = 0
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, (java.lang.Throwable) r3)
            monitor-enter(r4)
            if (r1 == 0) goto L_0x0047
            r4.publicSuffixListBytes = r1     // Catch:{ all -> 0x004b }
            if (r2 == 0) goto L_0x0043
            r4.publicSuffixExceptionListBytes = r2     // Catch:{ all -> 0x004b }
            monitor-exit(r4)
            java.util.concurrent.CountDownLatch r0 = r4.readCompleteLatch
            r0.countDown()
            return
        L_0x0043:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x004b }
            throw r3
        L_0x0047:
            p250f.p254l.p256c.Intrinsics.m5820a()     // Catch:{ all -> 0x004b }
            throw r3
        L_0x004b:
            r0 = move-exception
            monitor-exit(r4)
            throw r0
        L_0x004e:
            r1 = move-exception
            throw r1     // Catch:{ all -> 0x0050 }
        L_0x0050:
            r2 = move-exception
            p085c.p132d.p133a.p134a.p140c.p143n.C1050v.m4176a((java.io.Closeable) r0, (java.lang.Throwable) r1)
            throw r2
        L_0x0055:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.publicsuffix.PublicSuffixDatabase.readTheList():void");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:20:?, code lost:
        return;
     */
    /* JADX WARNING: Missing exception handler attribute for start block: B:12:0x0027 */
    /* JADX WARNING: No exception handlers in catch block: Catch:{  } */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private final void readTheListUninterruptibly() {
        /*
            r5 = this;
            r0 = 0
        L_0x0001:
            r5.readTheList()     // Catch:{  }
            if (r0 == 0) goto L_0x000d
            java.lang.Thread r1 = java.lang.Thread.currentThread()     // Catch:{ InterruptedIOException -> 0x0027, IOException -> 0x0010 }
            r1.interrupt()     // Catch:{ InterruptedIOException -> 0x0027, IOException -> 0x0010 }
        L_0x000d:
            return
        L_0x000e:
            r1 = move-exception
            goto L_0x002c
        L_0x0010:
            r1 = move-exception
            okhttp3.internal.platform.Platform$Companion r2 = okhttp3.internal.platform.Platform.Companion     // Catch:{ all -> 0x000e }
            okhttp3.internal.platform.Platform r2 = r2.get()     // Catch:{ all -> 0x000e }
            java.lang.String r3 = "Failed to read public suffix list"
            r4 = 5
            r2.log(r3, r4, r1)     // Catch:{ all -> 0x000e }
            if (r0 == 0) goto L_0x0026
            java.lang.Thread r0 = java.lang.Thread.currentThread()
            r0.interrupt()
        L_0x0026:
            return
        L_0x0027:
            java.lang.Thread.interrupted()     // Catch:{ all -> 0x000e }
            r0 = 1
            goto L_0x0001
        L_0x002c:
            if (r0 == 0) goto L_0x0035
            java.lang.Thread r0 = java.lang.Thread.currentThread()
            r0.interrupt()
        L_0x0035:
            throw r1
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.publicsuffix.PublicSuffixDatabase.readTheListUninterruptibly():void");
    }

    public final String getEffectiveTldPlusOne(String str) {
        int i;
        int i2;
        C1930a aVar;
        if (str != null) {
            String unicode = IDN.toUnicode(str);
            Intrinsics.m5821a((Object) unicode, "unicodeDomain");
            boolean z = true;
            List a = C1937g.m5850a((CharSequence) unicode, new char[]{'.'}, false, 0, 6);
            List<String> findMatchingRule = findMatchingRule(a);
            if (a.size() == findMatchingRule.size() && findMatchingRule.get(0).charAt(0) != '!') {
                return null;
            }
            if (findMatchingRule.get(0).charAt(0) == '!') {
                i2 = a.size();
                i = findMatchingRule.size();
            } else {
                i2 = a.size();
                i = findMatchingRule.size() + 1;
            }
            int i3 = i2 - i;
            List a2 = C1937g.m5850a((CharSequence) str, new char[]{'.'}, false, 0, 6);
            if (a2 != null) {
                Sequence fVar = new Sequences(a2);
                if (i3 < 0) {
                    z = false;
                }
                if (z) {
                    if (i3 != 0) {
                        if (fVar instanceof C1932b) {
                            fVar = ((C1932b) fVar).mo9410a(i3);
                        } else {
                            aVar = new C1930a(fVar, i3);
                            return C1050v.m4156a(aVar, ".", (CharSequence) null, (CharSequence) null, 0, (CharSequence) null, (C1907l) null, 62);
                        }
                    }
                    aVar = fVar;
                    return C1050v.m4156a(aVar, ".", (CharSequence) null, (CharSequence) null, 0, (CharSequence) null, (C1907l) null, 62);
                }
                throw new IllegalArgumentException(("Requested element count " + i3 + " is less than zero.").toString());
            }
            Intrinsics.m5822a("$this$asSequence");
            throw null;
        }
        Intrinsics.m5822a("domain");
        throw null;
    }

    public final void setListBytes(byte[] bArr, byte[] bArr2) {
        if (bArr == null) {
            Intrinsics.m5822a("publicSuffixListBytes");
            throw null;
        } else if (bArr2 != null) {
            this.publicSuffixListBytes = bArr;
            this.publicSuffixExceptionListBytes = bArr2;
            this.listRead.set(true);
            this.readCompleteLatch.countDown();
        } else {
            Intrinsics.m5822a("publicSuffixExceptionListBytes");
            throw null;
        }
    }
}
