package okhttp3.internal.tls;

import java.security.GeneralSecurityException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: BasicCertificateChainCleaner.kt */
public final class BasicCertificateChainCleaner extends CertificateChainCleaner {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final int MAX_SIGNERS = 9;
    public final TrustRootIndex trustRootIndex;

    /* compiled from: BasicCertificateChainCleaner.kt */
    public static final class Companion {
        public Companion() {
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    public BasicCertificateChainCleaner(TrustRootIndex trustRootIndex2) {
        if (trustRootIndex2 != null) {
            this.trustRootIndex = trustRootIndex2;
        } else {
            Intrinsics.m5822a("trustRootIndex");
            throw null;
        }
    }

    private final boolean verifySignature(X509Certificate x509Certificate, X509Certificate x509Certificate2) {
        if (!Intrinsics.m5823a((Object) x509Certificate.getIssuerDN(), (Object) x509Certificate2.getSubjectDN())) {
            return false;
        }
        try {
            x509Certificate.verify(x509Certificate2.getPublicKey());
            return true;
        } catch (GeneralSecurityException unused) {
            return false;
        }
    }

    public List<Certificate> clean(List<? extends Certificate> list, String str) throws SSLPeerUnverifiedException {
        if (list == null) {
            Intrinsics.m5822a("chain");
            throw null;
        } else if (str != null) {
            ArrayDeque arrayDeque = new ArrayDeque(list);
            ArrayList arrayList = new ArrayList();
            Object removeFirst = arrayDeque.removeFirst();
            Intrinsics.m5821a(removeFirst, "queue.removeFirst()");
            arrayList.add(removeFirst);
            int i = 0;
            boolean z = false;
            while (i < 9) {
                Object obj = arrayList.get(arrayList.size() - 1);
                if (obj != null) {
                    X509Certificate x509Certificate = (X509Certificate) obj;
                    X509Certificate findByIssuerAndSignature = this.trustRootIndex.findByIssuerAndSignature(x509Certificate);
                    if (findByIssuerAndSignature != null) {
                        if (arrayList.size() > 1 || (!Intrinsics.m5823a((Object) x509Certificate, (Object) findByIssuerAndSignature))) {
                            arrayList.add(findByIssuerAndSignature);
                        }
                        if (verifySignature(findByIssuerAndSignature, findByIssuerAndSignature)) {
                            return arrayList;
                        }
                        z = true;
                    } else {
                        Iterator it = arrayDeque.iterator();
                        Intrinsics.m5821a((Object) it, "queue.iterator()");
                        while (it.hasNext()) {
                            Object next = it.next();
                            if (next != null) {
                                X509Certificate x509Certificate2 = (X509Certificate) next;
                                if (verifySignature(x509Certificate, x509Certificate2)) {
                                    it.remove();
                                    arrayList.add(x509Certificate2);
                                }
                            } else {
                                throw new TypeCastException("null cannot be cast to non-null type java.security.cert.X509Certificate");
                            }
                        }
                        if (z) {
                            return arrayList;
                        }
                        throw new SSLPeerUnverifiedException("Failed to find a trusted cert that signed " + x509Certificate);
                    }
                    i++;
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type java.security.cert.X509Certificate");
                }
            }
            throw new SSLPeerUnverifiedException("Certificate chain too long: " + arrayList);
        } else {
            Intrinsics.m5822a("hostname");
            throw null;
        }
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        return (obj instanceof BasicCertificateChainCleaner) && Intrinsics.m5823a((Object) ((BasicCertificateChainCleaner) obj).trustRootIndex, (Object) this.trustRootIndex);
    }

    public int hashCode() {
        return this.trustRootIndex.hashCode();
    }
}
