package okhttp3.internal.tls;

import java.security.cert.Certificate;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Locale;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLSession;
import okhttp3.internal.HostnamesKt;
import okhttp3.internal.Util;
import okhttp3.internal.http2.Http2ExchangeCodec;
import p085c.p086a.p087a.p088a.outline;
import p250f.TypeCastException;
import p250f.p251i.C1892h;
import p250f.p251i._Arrays;
import p250f.p254l.p256c.Intrinsics;
import p250f.p261p.C1937g;

/* compiled from: OkHostnameVerifier.kt */
public final class OkHostnameVerifier implements HostnameVerifier {
    public static final int ALT_DNS_NAME = 2;
    public static final int ALT_IPA_NAME = 7;
    public static final OkHostnameVerifier INSTANCE = new OkHostnameVerifier();

    private final List<String> getSubjectAltNames(X509Certificate x509Certificate, int i) {
        try {
            Collection<List<?>> subjectAlternativeNames = x509Certificate.getSubjectAlternativeNames();
            if (subjectAlternativeNames == null) {
                return C1892h.f7579b;
            }
            ArrayList arrayList = new ArrayList();
            for (List next : subjectAlternativeNames) {
                if (next != null) {
                    if (next.size() >= 2) {
                        if (!(!Intrinsics.m5823a(next.get(0), (Object) Integer.valueOf(i)))) {
                            Object obj = next.get(1);
                            if (obj != null) {
                                arrayList.add((String) obj);
                            }
                        }
                    }
                }
            }
            return arrayList;
        } catch (CertificateParsingException unused) {
            return C1892h.f7579b;
        }
    }

    private final boolean verifyHostname(String str, X509Certificate x509Certificate) {
        Locale locale = Locale.US;
        Intrinsics.m5821a((Object) locale, "Locale.US");
        if (str != null) {
            String lowerCase = str.toLowerCase(locale);
            Intrinsics.m5821a((Object) lowerCase, "(this as java.lang.String).toLowerCase(locale)");
            List<String> subjectAltNames = getSubjectAltNames(x509Certificate, 2);
            if ((subjectAltNames instanceof Collection) && subjectAltNames.isEmpty()) {
                return false;
            }
            for (String verifyHostname : subjectAltNames) {
                if (INSTANCE.verifyHostname(lowerCase, verifyHostname)) {
                    return true;
                }
            }
            return false;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
    }

    private final boolean verifyIpAddress(String str, X509Certificate x509Certificate) {
        String canonicalHost = HostnamesKt.toCanonicalHost(str);
        List<String> subjectAltNames = getSubjectAltNames(x509Certificate, 7);
        if ((subjectAltNames instanceof Collection) && subjectAltNames.isEmpty()) {
            return false;
        }
        for (String canonicalHost2 : subjectAltNames) {
            if (Intrinsics.m5823a((Object) canonicalHost, (Object) HostnamesKt.toCanonicalHost(canonicalHost2))) {
                return true;
            }
        }
        return false;
    }

    public final List<String> allSubjectAltNames(X509Certificate x509Certificate) {
        if (x509Certificate != null) {
            return _Arrays.m5805a(getSubjectAltNames(x509Certificate, 7), getSubjectAltNames(x509Certificate, 2));
        }
        Intrinsics.m5822a("certificate");
        throw null;
    }

    public boolean verify(String str, SSLSession sSLSession) {
        if (str == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.HOST);
            throw null;
        } else if (sSLSession != null) {
            try {
                Certificate certificate = sSLSession.getPeerCertificates()[0];
                if (certificate != null) {
                    return verify(str, (X509Certificate) certificate);
                }
                throw new TypeCastException("null cannot be cast to non-null type java.security.cert.X509Certificate");
            } catch (SSLException unused) {
                return false;
            }
        } else {
            Intrinsics.m5822a("session");
            throw null;
        }
    }

    public final boolean verify(String str, X509Certificate x509Certificate) {
        if (str == null) {
            Intrinsics.m5822a(Http2ExchangeCodec.HOST);
            throw null;
        } else if (x509Certificate == null) {
            Intrinsics.m5822a("certificate");
            throw null;
        } else if (Util.canParseAsIpAddress(str)) {
            return verifyIpAddress(str, x509Certificate);
        } else {
            return verifyHostname(str, x509Certificate);
        }
    }

    private final boolean verifyHostname(String str, String str2) {
        if (!(str == null || str.length() == 0) && !C1937g.m5864b(str, ".", false, 2) && !C1937g.m5859a(str, "..", false, 2)) {
            if (!(str2 == null || str2.length() == 0) && !C1937g.m5864b(str2, ".", false, 2) && !C1937g.m5859a(str2, "..", false, 2)) {
                if (!C1937g.m5859a(str, ".", false, 2)) {
                    str = outline.m2941b(str, ".");
                }
                if (!C1937g.m5859a(str2, ".", false, 2)) {
                    str2 = outline.m2941b(str2, ".");
                }
                Locale locale = Locale.US;
                Intrinsics.m5821a((Object) locale, "Locale.US");
                if (str2 != null) {
                    String lowerCase = str2.toLowerCase(locale);
                    Intrinsics.m5821a((Object) lowerCase, "(this as java.lang.String).toLowerCase(locale)");
                    if (!C1937g.m5853a((CharSequence) lowerCase, (CharSequence) "*", false, 2)) {
                        return Intrinsics.m5823a((Object) str, (Object) lowerCase);
                    }
                    if (!C1937g.m5864b(lowerCase, "*.", false, 2) || C1937g.m5836a((CharSequence) lowerCase, '*', 1, false, 4) != -1 || str.length() < lowerCase.length() || Intrinsics.m5823a((Object) "*.", (Object) lowerCase)) {
                        return false;
                    }
                    String substring = lowerCase.substring(1);
                    Intrinsics.m5821a((Object) substring, "(this as java.lang.String).substring(startIndex)");
                    if (!C1937g.m5859a(str, substring, false, 2)) {
                        return false;
                    }
                    int length = str.length() - substring.length();
                    return length <= 0 || C1937g.m5860b(str, '.', length - 1, false, 4) == -1;
                }
                throw new TypeCastException("null cannot be cast to non-null type java.lang.String");
            }
        }
        return false;
    }
}
