package okhttp3.logging;

import com.newrelic.agent.android.util.SafeJsonPrimitive;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.util.List;
import java.util.concurrent.TimeUnit;
import okhttp3.Call;
import okhttp3.Connection;
import okhttp3.EventListener;
import okhttp3.Handshake;
import okhttp3.HttpUrl;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.logging.HttpLoggingInterceptor;
import p085c.p086a.p087a.p088a.outline;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: LoggingEventListener.kt */
public final class LoggingEventListener extends EventListener {
    public final HttpLoggingInterceptor.Logger logger;
    public long startNs;

    public /* synthetic */ LoggingEventListener(HttpLoggingInterceptor.Logger logger2, DefaultConstructorMarker fVar) {
        this(logger2);
    }

    private final void logWithTime(String str) {
        long millis = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - this.startNs);
        HttpLoggingInterceptor.Logger logger2 = this.logger;
        logger2.log('[' + millis + " ms] " + str);
    }

    public void callEnd(Call call) {
        if (call != null) {
            logWithTime("callEnd");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void callFailed(Call call, IOException iOException) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (iOException != null) {
            logWithTime("callFailed: " + iOException);
        } else {
            Intrinsics.m5822a("ioe");
            throw null;
        }
    }

    public void callStart(Call call) {
        if (call != null) {
            this.startNs = System.nanoTime();
            StringBuilder a = outline.m2937a("callStart: ");
            a.append(call.request());
            logWithTime(a.toString());
            return;
        }
        Intrinsics.m5822a("call");
        throw null;
    }

    public void canceled(Call call) {
        if (call != null) {
            logWithTime("canceled");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void connectEnd(Call call, InetSocketAddress inetSocketAddress, Proxy proxy, Protocol protocol) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (inetSocketAddress == null) {
            Intrinsics.m5822a("inetSocketAddress");
            throw null;
        } else if (proxy != null) {
            logWithTime("connectEnd: " + protocol);
        } else {
            Intrinsics.m5822a("proxy");
            throw null;
        }
    }

    public void connectFailed(Call call, InetSocketAddress inetSocketAddress, Proxy proxy, Protocol protocol, IOException iOException) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (inetSocketAddress == null) {
            Intrinsics.m5822a("inetSocketAddress");
            throw null;
        } else if (proxy == null) {
            Intrinsics.m5822a("proxy");
            throw null;
        } else if (iOException != null) {
            logWithTime("connectFailed: " + protocol + SafeJsonPrimitive.NULL_CHAR + iOException);
        } else {
            Intrinsics.m5822a("ioe");
            throw null;
        }
    }

    public void connectStart(Call call, InetSocketAddress inetSocketAddress, Proxy proxy) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (inetSocketAddress == null) {
            Intrinsics.m5822a("inetSocketAddress");
            throw null;
        } else if (proxy != null) {
            logWithTime("connectStart: " + inetSocketAddress + SafeJsonPrimitive.NULL_CHAR + proxy);
        } else {
            Intrinsics.m5822a("proxy");
            throw null;
        }
    }

    public void connectionAcquired(Call call, Connection connection) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (connection != null) {
            logWithTime("connectionAcquired: " + connection);
        } else {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        }
    }

    public void connectionReleased(Call call, Connection connection) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (connection != null) {
            logWithTime("connectionReleased");
        } else {
            Intrinsics.m5822a(Http2ExchangeCodec.CONNECTION);
            throw null;
        }
    }

    public void dnsEnd(Call call, String str, List<? extends InetAddress> list) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (str == null) {
            Intrinsics.m5822a("domainName");
            throw null;
        } else if (list != null) {
            logWithTime("dnsEnd: " + list);
        } else {
            Intrinsics.m5822a("inetAddressList");
            throw null;
        }
    }

    public void dnsStart(Call call, String str) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (str != null) {
            logWithTime(outline.m2941b("dnsStart: ", str));
        } else {
            Intrinsics.m5822a("domainName");
            throw null;
        }
    }

    public void proxySelectEnd(Call call, HttpUrl httpUrl, List<? extends Proxy> list) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (httpUrl == null) {
            Intrinsics.m5822a("url");
            throw null;
        } else if (list != null) {
            logWithTime("proxySelectEnd: " + list);
        } else {
            Intrinsics.m5822a("proxies");
            throw null;
        }
    }

    public void proxySelectStart(Call call, HttpUrl httpUrl) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (httpUrl != null) {
            logWithTime("proxySelectStart: " + httpUrl);
        } else {
            Intrinsics.m5822a("url");
            throw null;
        }
    }

    public void requestBodyEnd(Call call, long j) {
        if (call != null) {
            logWithTime(outline.m2931a("requestBodyEnd: byteCount=", j));
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void requestBodyStart(Call call) {
        if (call != null) {
            logWithTime("requestBodyStart");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void requestFailed(Call call, IOException iOException) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (iOException != null) {
            logWithTime("requestFailed: " + iOException);
        } else {
            Intrinsics.m5822a("ioe");
            throw null;
        }
    }

    public void requestHeadersEnd(Call call, Request request) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (request != null) {
            logWithTime("requestHeadersEnd");
        } else {
            Intrinsics.m5822a("request");
            throw null;
        }
    }

    public void requestHeadersStart(Call call) {
        if (call != null) {
            logWithTime("requestHeadersStart");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void responseBodyEnd(Call call, long j) {
        if (call != null) {
            logWithTime(outline.m2931a("responseBodyEnd: byteCount=", j));
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void responseBodyStart(Call call) {
        if (call != null) {
            logWithTime("responseBodyStart");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void responseFailed(Call call, IOException iOException) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (iOException != null) {
            logWithTime("responseFailed: " + iOException);
        } else {
            Intrinsics.m5822a("ioe");
            throw null;
        }
    }

    public void responseHeadersEnd(Call call, Response response) {
        if (call == null) {
            Intrinsics.m5822a("call");
            throw null;
        } else if (response != null) {
            logWithTime("responseHeadersEnd: " + response);
        } else {
            Intrinsics.m5822a("response");
            throw null;
        }
    }

    public void responseHeadersStart(Call call) {
        if (call != null) {
            logWithTime("responseHeadersStart");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    public void secureConnectEnd(Call call, Handshake handshake) {
        if (call != null) {
            logWithTime("secureConnectEnd: " + handshake);
            return;
        }
        Intrinsics.m5822a("call");
        throw null;
    }

    public void secureConnectStart(Call call) {
        if (call != null) {
            logWithTime("secureConnectStart");
        } else {
            Intrinsics.m5822a("call");
            throw null;
        }
    }

    /* compiled from: LoggingEventListener.kt */
    public static class Factory implements EventListener.Factory {
        public final HttpLoggingInterceptor.Logger logger;

        public Factory() {
            this((HttpLoggingInterceptor.Logger) null, 1, (DefaultConstructorMarker) null);
        }

        public Factory(HttpLoggingInterceptor.Logger logger2) {
            if (logger2 != null) {
                this.logger = logger2;
            } else {
                Intrinsics.m5822a("logger");
                throw null;
            }
        }

        public EventListener create(Call call) {
            if (call != null) {
                return new LoggingEventListener(this.logger, (DefaultConstructorMarker) null);
            }
            Intrinsics.m5822a("call");
            throw null;
        }

        /* JADX INFO: this call moved to the top of the method (can break code semantics) */
        public /* synthetic */ Factory(HttpLoggingInterceptor.Logger logger2, int i, DefaultConstructorMarker fVar) {
            this((i & 1) != 0 ? HttpLoggingInterceptor.Logger.DEFAULT : logger2);
        }
    }

    public LoggingEventListener(HttpLoggingInterceptor.Logger logger2) {
        this.logger = logger2;
    }
}
